/*****REXX - Do not remove this line******/
/* BEGINPROLOGUE************************************************/
/*                                                             */
/* MODULE: FRNODBEW.CMD                     VisualInfo         */
/*                                                             */
/* 5697-250                                                    */
/*     (C) Copyright IBM Corp. 1993, 1997.                     */
/*         All Rights Reserved.                                */
/*         US Government Users Restricted Rights -             */
/*         Use, duplication or disclosure restricted by GSA    */
/*         ADP Schedule Contract with IBM Corp.                */
/*                                                             */
/*     Licensed Materials - Property of IBM                    */
/*                                                             */
/*                                                             */
/* Date: July 1997                                             */
/*                                                             */
/* Status: Version 2 Release 3 Modification 0                  */
/*                                                             */
/* Description: frnodbew.cmd - this rexx command file is used  */
/*                             to dump the frnoinst.ini file   */
/*                             to stdout, frnoinst.ini was     */
/*                             implemented in V2.3             */
/*                                                             */
/* Dependencies:                                               */
/* This assumes the following:                                 */
/*     REXXUTIL.DLL is in the DLL PATH                         */
/*                                                             */
/* Restrictions:                                               */
/*                                                             */
/*                                                             */
/* Notes:                                                      */
/*                                                             */
/* *ENDPROLOGUE**************************************************/

/* MAIN */

   say 'FRNODBEW.CMD Started'

   call Init

   /* get FRNROOT env. var */
   RootDir = "";
   RootDir = VALUE('FRNROOT',,'OS2ENVIRONMENT')
   if RootDir = "" then do
      say 'Error:  FRNROOT Not set'
      return 1
   end /* do */

   /* locate the ini file */
   inifile = RootDir || '\frnoinst.ini'
   if translate(stream(inifile,'c','QUERY EXISTS')) <> translate(inifile) then do
      say 'Error:  'inifile' not found'
      return 2
   end /* do */

   say 'Processing 'inifile

   Do i = 1 to Components.0
      do j = 1 to Keys.0
         result = '';
         result = SysIni( inifile, Components.i, Keys.j)
         if result <> 'ERROR:' & result <> '' then
            say Components.i Keys.j ' = ' result
      end /* do */
   end /* do */

   call CleanUp

   say 'FRNODBEW.CMD Completed'

   return(0);

/* Initialization procedure */
Init:
   TRUE = (0 = 0); FALSE = \TRUE;
   if RxFuncQuery('SysIni') <> 0 then do
      call RxFuncAdd 'SysIni', 'RexxUtil', 'SysIni'
      Dropfunc = TRUE                  
   end /* do */                        

   Components.1 = "VisualInfo INSTALL"
   Components.2 = "VisualInfo UPDATE"
   Components.3 = "VisualInfo STANDARDCLIENT"
   Components.4 = "VisualInfo PGMTOOLKIT"
   Components.5 = "VisualInfo STANDALONE"
   Components.6 = "VisualInfo STANDARDSERVER"
   Components.7 = "VisualInfo IS2TOOL"
   Components.8 = "VisualInfo VITOOL"
   Components.9 = "VisualInfo IMAGESERVICES" 
   Components.10 = "VisualInfo LIBRARYCLIENT" 
   Components.11 = "VisualInfo INSTALLPROGRAM"
   Components.12 = "VisualInfo CLIENTAPPLICATION"
   Components.13 = "VisualInfo LIBRARYSERVER"
   Components.14 = "VisualInfo OBJECTSERVER"
   Components.15 = "VisualInfo SYSTEMADMINISTRATION"
   Components.16 = "VisualInfo SYSTEMCONFIGURATIONUTILITY"
   Components.17 = "VisualInfo CONFIGURATIONSERVER"
   Components.18 = "VisualInfo LISTMANAGERSERVER"
   Components.19 = "VisualInfo VIFAXSUPPORT"
   Components.20 = "VisualInfo VIFFST"
   Components.0 = 20

   Keys.1 = "Install_lang"
   Keys.2 = "Run_lang"
   Keys.3 = "Feature"
   Keys.4 = "Feature_Name"
   Keys.5 = "Component"
   Keys.6 = "VRM"
   Keys.7 = "Date"
   Keys.9 = "Action"
   Keys.0 = 9

   return;

/* CleanUp Procedure */
CleanUp:
   if Dropfunc = TRUE then
      call RxFuncDrop 'SysIni'
   return;



































