/* Check for REXX interpreter: if not loaded, next line will execute.
@GOTO NOREXX
*/
/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/* MODULE:       FRNOUTBG.CMD                                                */
/*               ImagePlus VisualInfo                                        */
/*                                                                           */
/*               5621-326, 5655-036, 5622-213, 5655-071, 5655-072            */
/*               (C) Copyright IBM Corp. 1993, 1994.  All rights Reserved.   */
/*               US Government Users Restricted Rights -                     */
/*               Use, duplication or disclosure restricted by GSA            */
/*               ADP Schedule Contract with IBM Corp.                        */
/*                                                                           */
/*               Licensed Materials - Property of IBM                        */
/*                                                                           */
/*                                                                           */
/* Status      : Version 1 Release 1 Modification 0                          */
/*                                                                           */
/* Description : Backup command file generation utility                      */
/*                                                                           */
/*                                                                           */
/*                                                                           */
/*                                                                           */
/*                                                                           */
/* OS          : OS/2 2.1                                                    */
/* Language    : REXX                                                        */
/* Dependencies: None                                                        */
/* Restrictions: None                                                        */
/*                                                                           */
/* Entry Points: main                                                        */
/*               CheckDrive                                                  */
/*               SetOps                                                      */
/*               InitEnv                                                     */
/*               TermEnv                                                     */
/*               GetNetworkTable                                             */
/*               WriteOutput                                                 */
/*               BackupOutFile                                               */
/*               InitBUOutput                                                */
/*               AddBUServerOutput                                           */
/*               ParseLMCtl                                                  */
/*               GetNetToken                                                 */
/*               AddBUObjOutput                                              */
/*               GetVolDrive                                                 */
/*               TermBUOutput                                                */
/*               GetRow                                                      */
/*               SQLErr                                                      */
/*               WriteLog                                                    */
/*                                                                           */
/* Change History:                                                           */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/


/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : main                                                  */
/*                                                                           */
/*  Dependencies     : Global Variables : None.                              */
/*                     Product Functions: None.                              */
/*                                                                           */
/*  Restrictions     : None.                                                 */
/*                                                                           */
/*  Input Parameters : d:              - backup target drive for data other  */
/*                                       than objects                        */
/*                     /Nnetwork_table - specifies name of network table     */
/*                                       for input (default FRNOLINT.TBL)    */
/*                     /Bbackup_pgm    - specifies name of output command    */
/*                                       file (default FRNOUTBK.CMD)         */
/*                     /Od:            - specifies object data backup cmds   */
/*                                       should be generated using target    */
/*                                       drive d:                            */
/*                     /S              - specifies object data backup cmds   */
/*                                       should use source drive ?: if the   */
/*                                       drive cannot be determined, rather  */
/*                                       than prompting the user for a drive */
/*                                                                           */
/*  Output Parameters: None.                                                 */
/*                                                                           */
/*  Synopsis         : FRNOUTBG d: /Nnetwork_table /Bbackup_pgm /Od: /S      */
/*                                                                           */
/*  Return values    : None.                                                 */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1. Check arguments and set defaults.                                 */
/*      2. Initialize environment, switching to output subdirectory.         */
/*      3. Read network table.                                               */
/*      4. Build output array containing initial information and server      */
/*         information based on network table.                               */
/*      5. If "/O" option was specified, add object backup information       */
/*         to array.                                                         */
/*      6. Write output array to file, renaming existing output file if      */
/*         necessary.                                                        */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

Address CMD '@ECHO OFF'
Address COMMAND
traceop = 'Off'; Interpret 'Trace' traceop
Signal On Syntax
Signal On Halt

/* Get arguments and check/set options                                       */
Parse Upper Arg drive options

drive      = CheckDrive(drive)
nettablefn = 'FRNOLINT.TBL'
outputfn   = 'FRNOUTBK.CMD'
odrive     = ''

If drive='' | \SetOps(options) then Do
   Say ' '
   Say 'Incorrect arguments; should be:'
   Say ' '
   Say '   d: </Nnetwork_table> </Bbackup_pgm> </Od: </S>> '
   Return
   End

If InitEnv('FRNROOT')=0 then Do             /* If init is successful:        */
   If GetNetworkTable(nettablefn)=0 then    /* read network table to array   */
      Say 'Unable to read network table' nettablefn'.'
   Else Do                                  /* if no error init output data, */
      ok = InitBUOutput(outputfn outputlogfn drive path)
      If ok then
         ok = AddBUServerOutput(drive path) /* add server output data        */
      If odrive<>'' & lbosdb<>'' & ok then  /* if object data included,      */
         ok = AddBUObjOutput(odrive)        /* add object output data        */
      If ok then                            /* if successful,                */
         ok = TermBUOutput(outputfn outputlogfn)  /* finish output file data */
      If ok then                            /* if successful,                */
         ok = WriteOutput(outputfn)         /* write data to command file    */
      If ok then Do                         /* if successful, display/log.   */
         msg = outputfn 'generated.'
         ioout = WriteLog(18, Date('O') Time('N'), msg)
         Say msg
         End                                /* End: successful so display/log*/
      End                                   /* End: no error.                */
   End                                      /* End: init was successful.     */
Call TermEnv                                /* Perform termination           */

Return

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/*  SYNTAX ERROR AND HALT TRAP                                               */
/*                                                                           */
/*  Description      : Display error message and terminate program.          */
/*                                                                           */
/*  Process Flow     : - Display an appropriate error message depending upon */
/*                       error condition & return code                       */
/*                     - If connected to a database, disconnect              */
/*                     - If DB/2 was started, stop it                        */
/*                     - Exit program.                                       */
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
SYNTAX:
HALT:

   If Condition('C')='SYNTAX' then Do
      If rc=43 then
         Say 'Error: could not locate external Rexx utility or SQL routines!'
      Else
         Say 'Internal error' rc 'on line' sigl '('Errortext(rc)').'
      End
   If Condition('C')='HALT' then
      Say 'Program terminated by user.'

   If rowdata.dbopen=1 then                    /* if database is open,    */
      Call SQLDBS "STOP USING DATABASE"        /* close the database      */
   If db2started=1 then                        /* if db2 was started,     */
      Call SQLDBS 'STOP DATABASE MANAGER'      /* stop it.                */

   Exit

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : CheckDrive                                            */
/*                                                                           */
/*  Description      : Procedure to test for valid drive specification.      */
/*                                                                           */
/*  Dependencies     : Global Variables : traceop                            */
/*                     Product Functions: None.                              */
/*                                                                           */
/*  Restrictions     : None.                                                 */
/*                                                                           */
/*  Input Parameters : drive - drive specification                           */
/*                                                                           */
/*  Output Parameters: drive - validated drive specification                 */
/*                                                                           */
/*  Synopsis         : drive = CheckDrive( drive )                           */
/*                                                                           */
/*  Return values    : null string if drive was not valid, otherwise         */
/*                     drive letter followed by colon                        */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1. Remove leading/trailing blanks from "drive" and if only a single  */
/*         character is left, append a colon.                                */
/*      2. If length is not now 2, reset "drive" to null.                    */
/*      3. If drive letter is not a letter or not followed by a colon        */
/*         reset "drive" to null.                                            */
/*      4. Return "drive".                                                   */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/
CheckDrive: Procedure Expose traceop
   Interpret 'Trace' traceop                /* Set tracing to desired value. */
   Parse Upper Arg drive                    /* Get argument - drive spec     */

   drive = Strip(drive)                     /* Remove blanks                 */
   If Length(drive)=1 then                  /* If no colon, add one          */
      drive = drive':'
   If Length(drive)<>2 then                 /* If incorrect length or not    */
      drive = ''                            /* valid chars, set to null.     */
   Else If \Datatype(Left(drive, 1), 'U') | ,
           Right(drive, 1)<>':' then
      drive = ''

   Return drive                             /* Return modified drive spec.   */

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : SetOps                                                */
/*                                                                           */
/*  Description      : Procedure to check and set options.                   */
/*                                                                           */
/*  Dependencies     : Global Variables : traceop, nettablefn, outputfn,     */
/*                                        outputlogfn, odrive                */
/*                     Product Functions: None.                              */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Input Parameters :  options - option argument string                     */
/*                                                                           */
/*  Output Parameters:  success - success indicator                          */
/*                                                                           */
/*  Synopsis         :  SetOps( options )                                    */
/*                                                                           */
/*  Return values    :  1 indicates success                                  */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1. Initialize success flag to 1 and quiet flag to 0.                 */
/*      2. Loop through all words in "options" string:                       */
/*         a) check that the word begins with "\" or "-" and has at least    */
/*            one more character                                             */
/*         b) if the option is "N", save remaining chars in "nettablefn"     */
/*         c) if the option is "B", save remaining chars in "outputfn"       */
/*         d) if the option is "O", save remaining chars in "odrive" and     */
/*            call CheckDrive() to test for validity.                        */
/*         e) if the option is "S", set quiet flag to 1.                     */
/*      3. Build the log filename and place in "outputlogfn".                */
/*      3. Return success indicator.                                         */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/
SetOps: Procedure Expose traceop nettablefn outputfn outputlogfn odrive quietop
   Interpret 'Trace' traceop                /* Set tracing to desired value. */
   Parse Upper Arg options                  /* Get argument (option list)    */

   success = 1                              /* Initialize success flag       */
   quietop = 0                              /* Initialize quiet option flag  */
   Do n=1 to Words(options) While success   /* Loop through options          */
                                            /* extract delimiter & option    */
      Parse Value Word(options, n) With 1 del 2 op 3 opdat
                                            /* check delimiter & length;     */
      If (del<>'/' & del<>'-') then
         success = 0                        /* indicate problem.             */
      Else Do                               /* else ok,                      */
         Select                             /* save the options...           */
            When op='N' then Do             /* Network table filename        */
               nettablefn = opdat
               If Pos('\', nettablefn)>0 | ,
                  Pos(':', nettablefn)>0 | ,
                  Length(nettablefn)=0 then
                  success = 0
               End
            When op='B' then Do             /* Backup command filename       */
               outputfn = opdat
               If Pos('\', outputfn)>0 | ,
                  Pos(':', outputfn)>0 | ,
                  Length(outputfn)=0 then
                  success = 0
               End
            When op='O' then Do             /* Object data backup drive      */
               odrive = CheckDrive(opdat)
               If odrive='' then
                  success = 0
               End
            When op='S' then Do             /* Quiet option                  */
               quietop = 1
               End
            Otherwise                       /* If any other option,          */
               success = 0                  /* indicate problem.             */
            End                             /* End: select.                  */
         End                                /* End: do.                      */
      End                                   /* End: loop.                    */

   posn = Lastpos('.', outputfn)-1          /* Locate last '.' in output     */
   If posn<1 then                           /* if none, set to full fn       */
      posn = Length(outputfn)               /* and build log filename.       */
   outputlogfn = Substr(outputfn, 1, posn)'.LOG'

   Return success                           /* Return success indicator      */

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : InitEnv                                               */
/*                                                                           */
/*  Description      : Procedure to set up environment.                      */
/*                                                                           */
/*  Dependencies     : Global Variables : traceop, program, path             */
/*                     Product Functions: None.                              */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Input Parameters :  frnroot - name of environment variable containing    */
/*                                frnroot directory                          */
/*                                                                           */
/*  Output Parameters:  returncode - success indicator                       */
/*                                                                           */
/*  Synopsis         :  InitEnv( frnroot )                                   */
/*                                                                           */
/*  Return values    :  0 indicates success.                                 */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1. Display initialization message.                                   */
/*      2. Determine program name and place in "program" variable.           */
/*      3. Determine setting of "frnroot" environment variable and change    */
/*         to this path.                                                     */
/*      4. If one exists, delete temporary file.                             */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/
InitEnv: Procedure Expose traceop program path
   Interpret 'Trace' traceop                /* Set tracing to desired value. */
   Parse Upper Arg frnroot .                /* Get argument (env. variable)  */

   returncode = 0                           /* Initialize return code        */

   /* First extract program name from source environment string:             */
   Parse Upper Source . . program .         /* Get program name              */
   If Pos('.', program) > 0 then            /* Remove '.' and extension;     */
      program = Delstr(program, Pos('.', program))
   If Lastpos('\', program) > 0 then        /* Remove drive and path.        */
      program = Substr(program, Lastpos('\', program) + 1)

   /* Now determine FRNROOT subdirectory from environment variable:          */
   If returncode=0 then Do                  /* If no errors occurred:        */
                                               /* get frnroot env var value  */
      path = Translate(Value(frnroot,,'OS2ENVIRONMENT'))
      If Strip(path)='' then Do                /* if not found, say message  */
         Say 'Unable to locate' frnroot 'environment variable.'
         returncode = -1                       /* and set return code.       */
         End                                   /* End: frnroot not found.    */
      End                                      /* End: no errors.            */

   /* Last, change to FRNROOT directory and remove temporary file:           */
   If returncode=0 then Do                  /* If no errors occurred:        */
      /* Next, if still Ok, change to desired drive/subdirectory:            */
      If Right(path,1)='\' then             /* If one was supplied,          */
         path = Left(path, Length(path)-1)  /* remove ending backslash       */
      Call Setlocal                         /* Save current environment      */
      newdir = Translate(Directory(path))   /* Set to specified directory    */
      If Right(newdir,1)='\' then           /* Remove trailing \ if there    */
         newdir = Left(newdir, Length(newdir)-1)
      If newdir<>path then Do               /* and check... if bad say msg,  */
         Say 'Invalid' frnroot 'drive/directory specification:' path'.'
         returncode = -1                    /* and set return code           */
         End                                /* End: if path was bad          */
      Else Do                               /* If change dir was successful, */
                                            /* remove temp file:             */
         Address CMD 'IF EXIST' program'.TMP DEL' program'.TMP'
         End                                /* End: Else Do (chgdir Ok)      */
      End                                   /* End: Else Do (no errors)      */

   Return returncode

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : TermEnv                                               */
/*                                                                           */
/*  Description      : Procedure to terminate environment set up.            */
/*                                                                           */
/*  Dependencies     : Global Variables : traceop, program                   */
/*                     Product Functions: None.                              */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  TermEnv                                              */
/*                                                                           */
/*  Return values    :  None.                                                */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1. Close log file.                                                   */
/*      2. Return to original directory.                                     */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/
TermEnv: Procedure Expose traceop program
   Interpret 'Trace' traceop                /* Set tracing to desired value. */

   ioout = Stream(program'.LOG', 'C', 'close') /* Close log file             */
   Call Endlocal                               /* restore environment        */

   Return

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : GetNetworkTable                                       */
/*                                                                           */
/*  Description      : Procedure to read network table into array.           */
/*                                                                           */
/*  Dependencies     : Global Variables : traceop, nettable.                 */
/*                     Product Functions: None.                              */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Input Parameters :  fn        - filename to read                         */
/*                                                                           */
/*  Output Parameters:  lines     - number of lines read                     */
/*                                                                           */
/*  Synopsis         :  GetNetworkTable( fn )                                */
/*                                                                           */
/*  Return values    :  number of lines successfully read                    */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1. Initialize number of lines read and network table array.          */
/*      2. Read each line in "fn" into array,  translate equal, comma        */
/*         and tab characters to blank and upper-case line.                  */
/*      3. Return number of lines read.                                      */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/
GetNetworkTable: Procedure Expose traceop nettable.
   Interpret 'Trace' traceop                /* Set tracing to desired value. */
   Parse Upper Arg fn .                     /* Get argument (filename)       */

   lines = 0                                /* Init number of lines          */
   nettable. = ''                           /* Init table array              */
   Do While Lines(fn)                       /* Loop through input file:      */
      lines = lines + 1                     /* increment # lines, get line & */
                                            /* remove commas, equals & tabs  */
      nettable.lines = Translate(Linein(fn), ' ', '=')
      nettable.lines = Translate(nettable.lines, ' ', ',')
      nettable.lines = Translate(nettable.lines, ' ', '09'x)
      nettable.lines = Translate(nettable.lines)  /* and upper-case line.    */
      End
   nettable.0 = lines                       /* Save counter in array.        */

   Return lines

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : WriteOutput                                           */
/*                                                                           */
/*  Description      : Procedure to write output array to file.              */
/*                                                                           */
/*  Dependencies     : Global Variables : traceop, outdata.                  */
/*                     Product Functions: None.                              */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Input Parameters :  fn       - output filename                           */
/*                                                                           */
/*  Output Parameters:  success indicator                                    */
/*                                                                           */
/*  Synopsis         :  WriteOutput( fn )                                    */
/*                                                                           */
/*  Return values    :  1 indicates success                                  */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1. Call BackupOutFile(fn) to create backup of output file.           */
/*      2. Write each line in array outdata. to output file.                 */
/*      3. If an error occurs display message and delete the output file.    */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/
WriteOutput: Procedure Expose traceop outdata.
   Interpret 'Trace' traceop                /* Set tracing to desired value. */
   Parse Upper Arg fn .                     /* Get argument (filename)       */

   If BackupOutFile(fn) then Do             /* If rename of old file Ok,     */
      Do n=1 to outdata.0 Until ioout<>0    /* Loop through output lines:    */
         ioout = Lineout(fn, outdata.n)     /* write the line                */
         End                                /* End: loop.                    */
      If ioout<>0 then Do                   /* If an error occurred,         */
         Say 'Error writing file' fn'!'     /* display msg & close file.     */
         temp = Stream(fn, 'C', 'close')
         If n>1 then                        /* If lines written, erase.      */
            Address CMD 'IF EXIST' fn 'ERASE' fn '/F'
         End
      End                                   /* End: rename ok.               */

   Return \ioout

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : BackupOutFile                                         */
/*                                                                           */
/*  Description      : Procedure to create backup of output file.            */
/*                                                                           */
/*  Dependencies     : Global Variables : traceop                            */
/*                     Product Functions: None.                              */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Input Parameters :  outfn    - output filename                           */
/*                                                                           */
/*  Output Parameters:  success indicator                                    */
/*                                                                           */
/*  Synopsis         :  BackupOutFile( outfn )                               */
/*                                                                           */
/*  Return values    :  1 indicates success                                  */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1. Initialize success indicator.                                     */
/*      2. If the output file exists, then:                                  */
/*         a) remove final period-delimited word from output filename        */
/*            (i.e. the file extension)                                      */
/*         b) start with '.BAK', then continue with '.000' through '.999',   */
/*            appending these extensions to the filename to create a name    */
/*            which does not exist.                                          */
/*         c) if b) did not find a file, display an error message; otherwise */
/*            rename the output file to the new name.                        */
/*      3. Return success indicator.                                         */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/
BackupOutFile: Procedure Expose traceop
   Interpret 'Trace' traceop                /* Set tracing to desired value. */
   Parse Upper Arg outfn .                  /* Get argument (filename)       */

   success = 1                              /* Initialize success flag       */
   If Lines(outfn) then Do                  /* If output file already exists,*/
      ioout = Stream(outfn, 'C', 'close')   /* close the file                */
      del = LastPos('.', outfn)             /* Locate last period in name    */
      If del<2 then                         /* and save initial part only.   */
         name = outfn
      Else
         name = Left(outfn, del-1)
      copyfn = name'.BAK'                   /* Initialize to .BAK for 1st try*/
      Do n=1 to 1000 While Lines(copyfn)    /* Loop through possible names:  */
         ioout = Stream(copyfn, 'C', 'close')  /* close the file             */
         If n>999 then                         /* if out of names,           */
            success = 0                        /* indicate error,            */
         Else                                  /* else build next one.       */
            copyfn = name||'.'||Right('000'||Strip(n), 3)
         End                                   /* End: Loop through names.   */
      If \success then                         /* If none found ?! say msg!  */
         Say 'No more backup filenames left for' outfn'!'
      Else Do                                  /* else found a name to use,  */
         Address CMD 'REN' outfn copyfn        /* rename the file;           */
         If rc<>0 then Do                      /* if it fails tell the user  */
            Say 'Unable to make backup copy of' outfn'!'
            success = 0                        /* and set error indicator.   */
            End                                /* End: copy failed.          */
         Else                                  /* Else copy ok, tell user.   */
            Say 'Previous command file' outfn 'saved as' copyfn'.'
         End                                   /* End: found a name to use.  */
      End                                      /* End: output file exists.   */

   Return success

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : InitBUOutput                                          */
/*                                                                           */
/*  Description      : Procedure to initialize backup command array.         */
/*                                                                           */
/*  Dependencies     : Global Variables : traceop, outdata.                  */
/*                     Product Functions: None.                              */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Input Parameters :  fn       - output filename                           */
/*                      logfn    - log filename                              */
/*                      drive    - backup drive                              */
/*                      path     - frnroot directory                         */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  InitBUOutput( fn logfn drive path )                  */
/*                                                                           */
/*  Return values    :  always 1                                             */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1. Initialize "outdata." array.                                      */
/*      2. Set "outdata.0" to 11 (number of lines).                          */
/*      3. Set array elements 1-11 to command file header and frnroot        */
/*         backup commands.                                                  */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/
InitBUOutput: Procedure Expose traceop outdata.
   Interpret 'Trace' traceop                /* Set tracing to desired value. */

   Parse Arg fn logfn drive path .          /* Get Args: fn, drive & frnroot */
   outdata. = ""
   outdata.0 = 12
   outdata.1 = "/* Check for REXX interpreter: if not loaded, next line will execute."
   outdata.2 = "@GOTO NOREXX"
   outdata.3 = " * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */"
   outdata.4 = "/*                                                                           */"
   outdata.4 = Overlay(Strip(Substr(fn, 1, 65))':', outdata.4, 4)
   outdata.5 = "/* REXX program to backup system                                             */"
   outdata.6 = "/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */"
   outdata.7 = "'@ECHO OFF'"
   outdata.8 = "io=Lineout('"logfn"', Substr(Date('O') Time('N'), 1, 18) 'Backup started.')"
   outdata.9 = "/* Backup base system: * * * * * * * * * * * * * * * * * * * * * * * * * * * */"
   outdata.10= "'ECHO READY TO BACKUP BASE PROGRAMS AND DATA'"
   outdata.11= "'PAUSE'"
   outdata.12= "'BACKUP.EXE" path"\*.*" drive "/S'"

   Return 1

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : AddBUServerOutput                                     */
/*                                                                           */
/*  Description      : Procedure to add servers to backup command array.     */
/*                                                                           */
/*  Dependencies     : Global Variables : traceop, outdata., nettable.,      */
/*                                        lbosdb                             */
/*                     Product Functions: None.                              */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Input Parameters :  drive    - backup drive                              */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  AddBUServerOutput( drive )                           */
/*                                                                           */
/*  Return values    :  always 1                                             */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1. Do the following for each blank-delimited token in the            */
/*         network table array ("nettable."):                                */
/*         a) if the token ends in a colon, reset "currentdb" to null;       */
/*            if it is "SERVER:" and the word after next is "LOCAL",         */
/*            save the last qualifier of the next word in "currentdb"        */
/*         b) if "currentdb" is not null and the token is "SERVER_TYPE",     */
/*            get the next token. If it is either "FRNOSOS2" or "FRNLSOS2"   */
/*            then generate database backup commands for "currentdb",        */
/*            and add the database name to "lbosdb"; if it is either         */
/*            "FRNCS" or "FRNCACHE" then generate list manager backup cmds.  */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/
AddBUServerOutput: Procedure Expose traceop outdata. nettable. lbosdb
   Interpret 'Trace' traceop                /* Set tracing to desired value. */

   Parse Arg drive path .                   /* Get Arg: BU drive & frnroot   */
   outlines = outdata.0                     /* save current # of lines       */
   currentdb = ''                           /* init current db name          */
   lbosdb = ''                              /* init lbos db name             */
   netline = 1                              /* init current net table line   */
   netword = 1                              /* init current net table word   */
   token = GetNetToken()                    /* get first net table token     */

   Do While token<>''                       /* Process all net table tokens: */
                                               /* if it looks like a server, */
      If Length(token)>1 & Right(token, 1)=':' then Do
         currentdb = ''                        /* reset current db name      */
         If token='SERVER:' then Do            /* if a server entry,         */
            currentdb = GetNetToken()          /* get next token (database)  */
            token = GetNetToken()              /* and type (LOCAL | REMOTE). */
            If token='LOCAL' then              /* If a local server, extract */
                                               /* last qualifier (db name);  */
               currentdb = Strip(Substr(currentdb||' ', LastPos('.', currentdb)+1))
            Else                               /* otherwise not local,       */
               currentdb = ''                  /* reset db name.             */
            End                                /* End: a server entry.       */
         End                                   /* End: looks like server.    */

                                               /* Else if in a server entry, */
      Else If currentdb<>'' & token='SERVER_TYPE' then Do
         token = GetNetToken()                 /* get token; if lan server:  */
         If token='FRNOSOS2' | token='FRNLSOS2' then Do
            If token='FRNOSOS2' then           /* if lbos server, save name  */
               lbosdb = lbosdb||currentdb||' '
            outlines = outlines + 1            /* generate commands.         */
            outdata.outlines = "/* Backup database:  * * * * * * * * * * * * * * * * * * * * * * * * * * * * */"
            outlines = outlines + 1
            outdata.outlines = "'ECHO READY TO BACKUP DATABASE" currentdb"'"
            outlines = outlines + 1
            outdata.outlines = "'PAUSE'"
            outlines = outlines + 1
            outdata.outlines = "'CALL DBM BACKUP DATABASE" currentdb "ALL TO" Left(drive, 1)"'"
            outdata.0 = outlines
            End                                   /* End: correct serv type. */
                                                  /* Else if List Mgr server:*/
         Else If token='FRNCS' | token='FRNCACHE' | token='FRNOLM' then Do
                                                  /* determine List path     */
            lstpath = ParseLMCtl(path"\LSTMGR\CTL\"currentdb".CTL")
                                                  /* if found & not frnroot, */
            If lstpath<>'' & \Abbrev(lstpath"\", path"\") then Do
               If Right(lstpath,1)='\' then       /* Remove trailing backsl. */
                  lstpath = Left(lstpath, Length(lstpath)-1)
               outlines = outlines + 1            /* generate commands.      */
               outdata.outlines = "/* Backup list:  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */"
               outlines = outlines + 1
               outdata.outlines = "'ECHO READY TO BACKUP LIST" currentdb"'"
               outlines = outlines + 1
               outdata.outlines = "'PAUSE'"
               outlines = outlines + 1
               outdata.outlines= "'BACKUP.EXE" lstpath"\*.*" drive "/S'"
               outdata.0 = outlines
               End                                /* End: found, not frnroot.*/
            End                                   /* End: correct serv type. */
         End                                      /* End: in a server entry. */

      token = GetNetToken()                    /* Get next net table token.  */
      End                                   /* End: process all net tbl toks.*/

   Return 1

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : ParseLMCtl                                            */
/*                                                                           */
/*  Description      : Procedure to obtain list manager directory from       */
/*                     control file.                                         */
/*                                                                           */
/*  Dependencies     : Global Variables : traceop                            */
/*                     Product Functions: None.                              */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Input Parameters :  filename - list manager control file                 */
/*                                                                           */
/*  Output Parameters:  lpath - list path                                    */
/*                                                                           */
/*  Synopsis         :  ParseLMCtl( filename )                               */
/*                                                                           */
/*  Return values    :  null string if unable to determine list path         */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1. Initialize "lpath" to null.                                       */
/*      2. Read lines of "filename" and for each,                            */
/*         locate colons; if 4th is found, set "lpath" to the word which     */
/*         follows.                                                          */
/*      3. Return "lpath".                                                   */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/
ParseLMCtl: Procedure Expose traceop
   Interpret 'Trace' traceop                /* Set tracing to desired value. */

   Parse Arg filename .                     /* Get argument: ctrl filename   */
   lpath = ''                               /* Initialize returned path      */

   counter = 0                              /* Init colon counter            */
   Do While Lines(filename)                 /* Loop through input file...    */
      line = Translate(Linein(filename))    /* get the line & upper-case     */
      cpos = 0                              /* init colon position to 0      */
      Do Until cpos<1                       /* Loop, scanning for colons:    */
         cpos = Pos(":", line, cpos+1)      /* search, starting from last pos*/
         If cpos>0 then Do                  /* If one is found,              */
            counter = counter + 1           /* increment counter;            */
            If counter=4 then               /* if 4th, save next word.       */
               lpath = Word(Substr(line,cpos+1),1)
            End                             /* End: colon was found.         */
         End                                /* End: loop, scanning.          */
      End                                   /* End: loop through input file. */

   Return lpath                             /* Return list path, or null.    */

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : GetNetToken                                           */
/*                                                                           */
/*  Description      : Procedure to obtain next word in network table array. */
/*                                                                           */
/*  Dependencies     : Global Variables : traceop, nettable., netline,       */
/*                                        netword                            */
/*                     Product Functions: None.                              */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  token - next blank-delimited token in table          */
/*                                                                           */
/*  Synopsis         :  GetNetToken( )                                       */
/*                                                                           */
/*  Return values    :  null string if at end of array, else next token      */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1. Initialize "token" to null.                                       */
/*      2. If there are no more words on the current line (based on          */
/*         "netline" and "netword" variables), scan until one is found       */
/*         or the array ends.                                                */
/*      3. Get the next blank-delimited token. If start of comment ("/*"),   */
/*         call GetNetToken() until end of comment ("*/") is located.        */
/*      4. Return the token.                                                 */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/
GetNetToken: Procedure Expose traceop nettable. netline netword
   Interpret 'Trace' traceop                /* Set tracing to desired value. */

   token = ''                               /* Initialize returned token     */

   /* Loop 'till line & word point to a word or there are no more lines:     */
   Do While (netword>Words(nettable.netline)) & (netline<=nettable.0)
      netline = netline + 1
      netword = 1
      End

   /* If we didn't run out of lines, get the token, skipping comments:       */
   If netline <= nettable.0 then Do
      token = Subword(nettable.netline, netword, 1)
      netword = netword + 1                 /* move pointer to next word     */
      If Left(token, 2)='/*' then Do        /* if a comment, loop 'till end: */
         Do While Right(token, 2)<>'*/' & token<>''
            token = GetNetToken()           /* call ourselves to get next one*/
            End                             /* End: loop 'till end.          */
         If token='' then                   /* If end not found warn user,   */
            Say 'Warning - unbalanced comments in network table.'
         Else                               /* otherwise at end of comment,  */
            token = GetNetToken()           /* get next token.               */
         End                                /* End: if a comment.            */
      End                                   /* End: get the token.           */

   Return token

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : AddBUObjOutput                                        */
/*                                                                           */
/*  Description      : Procedure to add object data to backup command array. */
/*                                                                           */
/*  Dependencies     : Global Variables : traceop, outdata., lbosdb, quietop */
/*                     Product Functions: SQLDBS.                            */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Input Parameters :  drive    - backup drive                              */
/*                                                                           */
/*  Output Parameters:  noerr    - success indicator                         */
/*                                                                           */
/*  Synopsis         :  AddBUObjOutput( drive )                              */
/*                                                                           */
/*  Return values    :  1 indicates success                                  */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1. Initialize success indicator and valid drive letters (A-Z).       */
/*      2. Load SQL subroutines SQLDBS, and SQLEXEC and REXX utility         */
/*         SysDriveInfo.                                                     */
/*      3. Issue the 'START DATABASE MANAGER' command.                       */
/*      4. For each database in "lbosdb":                                    */
/*         a) determine the staging area path and add backup commands to     */
/*            "outdata." array                                               */
/*         b) determine the volumes in use and add their backup commands.    */
/*      5. If it was not already running, issue 'STOP DATABASE MANAGER'      */
/*         command.                                                          */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/
AddBUObjOutput: Procedure Expose traceop outdata. lbosdb quietop
   Interpret 'Trace' traceop                /* Set tracing to desired value. */
 
   Parse Arg drive .                        /* Get Arg: BU drive             */
   outlines = outdata.0                     /* save current # of lines       */
   noerr = 1                                /* init returned result          */
   drivelets = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ' /* init drive letters            */

   /* First load SQL and REXX Utility subroutines:                           */
   Call RxFuncDrop 'SQLDBS'
   Call RxFuncDrop 'SQLEXEC'
   Call RxFuncDrop 'SysDriveInfo'
   Call Rxfuncadd 'SQLDBS', 'SQLAR', 'SQLDBS'
   Call Rxfuncadd 'SQLEXEC', 'SQLAR', 'SQLEXEC'
   Call Rxfuncadd 'SysDriveInfo', 'RexxUtil', 'SysDriveInfo'
   If Rxfuncquery('SQLDBS') <> 0 | ,        /* If any fn's did not load,     */
      Rxfuncquery('SQLEXEC') <> 0 | ,       /* display a message;            */
      Rxfuncquery('SysDriveInfo') <> 0 then Do
      Say 'Error loading external Rexx utility or SQL routines!'
      noerr = 0
      End

   Else Do                                  /* Else extern functions loaded: */

      /* Next, start DB2 if needed:                                          */
      Call SQLDBS 'START DATABASE MANAGER'  /* Try to start DB2 and          */
      db2started = 1                        /* init started flag;            */
      If (result<>0) | (SQLCA.SQLCODE<>0) then Do /* if error...             */
         db2started = 0                           /* change flag; if not     */
                                                  /* DB2 already running,    */
         If \((result=0) & (SQLCA.SQLCODE=-1026)) then Do
            noerr = 0                             /* set result & display msg*/
            temp = SQLErr(result, SQLCA.SQLCODE, SQLMSG, "START DATABASE MANAGER" dbname)
            End                                   /* End: not DB2 running.   */
         End                                      /* End: if error.          */
      /* Loop, generating commands for staging and volumes for each database:*/
      If noerr then Do dbnum=1 to Words(lbosdb)
         dbname = Subword(lbosdb, dbnum, 1)
         /* Next, determine the path to the staging area & generate commands:*/
         If noerr then Do                   /* If Ok so far:                 */
            sqlquery =  "SELECT STA_PATH " ,/* Build SQL query: staging path */
                        "FROM BASE_STAGING "/* from BASE_STAGING table       */
            stapath = ''                    /* init staging path             */
            rowdata. = 0                    /* init row data array           */
            Do Until \noerr | \rowdata.dbopen  /* Loop until done|error:     */
               noerr = GetRow( dbname, 1, sqlquery ) /* get a row;           */
               If noerr & rowdata.dbopen then        /* if successful        */
                  stapath = rowdata.1                /* save staging path.   */
               End                                   /* End: Loop            */

            If stapath='' then Do           /* If staging path not set,      */
               noerr = 0                    /* set result & display msg.     */
               Say 'Unable to determine staging path.'
               End                          /* End: staging path not set.    */
            Else Do                         /* Otherwise (ok), add commands: */
               outlines = outlines + 1
               outdata.outlines = "/* Backup objects for database" Left(dbname||":",9) "* * * * * * * * * * * * * * * * * * */"
               outlines = outlines + 1
               outdata.outlines = "/* Backup staging area:  * * * * * * * * * * * * * * * * * * * * * * * * * * */"
               outlines = outlines + 1
               outdata.outlines = "'ECHO READY TO BACKUP STAGING AREA'"
               outlines = outlines + 1
               outdata.outlines = "'PAUSE'"
               outlines = outlines + 1
               outdata.outlines = "'XCOPY" stapath"*.*" drive"\ /S /E /R'"
               outdata.0 = outlines
               End                          /* End: ok, add commands.        */
            End                             /* End: ok so far.               */

         /* Next, determine the volumes used and generate commands:          */
         If noerr then Do                      /* If Ok so far:              */
            sqlquery =  "SELECT VOL_LABEL, " , /* Build SQL query: vol label,*/
                               "DEV_DEVMGRNAME, " ,  /* device mgr name      */
                               "DEV_DRIVELIST " ,    /* and drive list       */
                        "FROM BASE_DEVMGR, " ,       /* from BASE_DEVMGR,    */
                             "BASE_STGCLSDEVMGR, " , /* BASE_STGCLSDEVMGR and*/
                             "BASE_VOLUMES " ,       /* BASE_VOLUMES tables, */
                        "WHERE DEV_DEVMGRID=SCD_DEVMGRID AND " ,    /*  see  */
                              "SCD_STGCLASSID=VOL_STGCLASSID AND " ,/*   |   */
                              "VOL_STATUS NOT IN ('U', 'O')"        /*   V   */
                                                  /* match device mgr & stor */
                                                  /* classes and \unassigned */
                                                  /* or overflow volume.     */
            rowdata. = 0                       /* init row data array        */
            Do Until \noerr | \rowdata.dbopen  /* Loop until done|error:     */
               noerr = GetRow( dbname, 3, sqlquery ) /* get a row;           */
               If noerr & rowdata.dbopen then Do     /* if successful:       */
                  vollabel  = Strip(rowdata.1)       /* save volume label,   */
                  devmgr    = Strip(rowdata.2)       /* device mgr name and  */
                  drivelist = Strip(rowdata.3)       /* drive list; then conv*/
                                                     /* list 2 binary&add 0's*/
                  drivelist = Reverse(X2B(D2X(drivelist)))||Copies('0', Length(drivelets))
                  drivenum = Pos('1', drivelist)     /* locate first drive   */
                  If drivenum=0 then                 /* if none, display msg */
                     Say 'No drives are assigned to volume' vollabel'.'
                  Else Do                            /* else 1 or more drives*/
                                                     /* find which one to use*/
                     voldrive = GetVolDrive(drivelist, drivelets, vollabel)
                                                     /* and add commands.    */
                     outlines = outlines + 1
                     outdata.outlines = "/* Backup volume:  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */"
                     outlines = outlines + 1
                     outdata.outlines = "'ECHO READY TO BACKUP VOLUME" vollabel"'"
                     outlines = outlines + 1
                     outdata.outlines = "'PAUSE'"
                     outlines = outlines + 1
                     If devmgr='FRNOPDDM' then
                        outdata.outlines = "'XCOPY" voldrive"\"vollabel"\LBOSDATA\*.*" drive"\ /S /E /R'"
                     Else
                        outdata.outlines = "'XCOPY" voldrive"\LBOSDATA\*.*" drive"\ /S /E /R'"
                     outdata.0 = outlines
                     End                       /* End: one or more drives.   */
                  End                          /* End: got row successfully. */
               End                             /* End: Loop.                 */
            End                             /* End: ok so far.               */
         If \noerr then Do                  /* If an error occurred,         */
            noerr = 1                       /* reset flag & say message.     */

            Say 'Unable to generate volume backup commands for database' dbname'.'
            End
         End                                /* End: Loop for each database.  */

      /* Last, stop DB2 if it was started:                                   */
      If db2started then Do                 /* If DB2 was started above:     */
         Call SQLDBS 'STOP DATABASE MANAGER'      /* try to stop it.         */
         If (result<>0) | (SQLCA.SQLCODE<>0) then /* if error, display msg   */
            temp = SQLErr(result, SQLCA.SQLCODE, SQLMSG, "STOP DATABASE MANAGER" dbname)
         End                                /* End: DB2 was started.         */
      End                                   /* End: external fn's loaded Ok. */

   Return noerr

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : GetVolDrive                                           */
/*                                                                           */
/*  Description      : Procedure to determine which drive has correct label. */
/*                                                                           */
/*  Dependencies     : Global Variables : traceop, quietop, rowdata.,        */
/*                                        db2started                         */
/*                     Product Functions: None.                              */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Input Parameters :  drivelist - list of drive flags                      */
/*                      drivelets - list of valid drive letters              */
/*                      volume    - volume label to search for               */
/*                                                                           */
/*  Output Parameters:  drive     - drive with correct label                 */
/*                                                                           */
/*  Synopsis         :  GetVolDrive( drivelist, drivelets, volume )          */
/*                                                                           */
/*  Return values    :  drive with matching volume label                     */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1. Initialize "drive" to null.                                       */
/*      2. For each drive in "drivelist", compare volume label to "volume"   */
/*         and if correct save in "drive".                                   */
/*      3. If correct label was not found, prompt user for drive.            */
/*      4. Return "drive".                                                   */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/
GetVolDrive: Procedure Expose traceop quietop rowdata. db2started
   Interpret 'Trace' traceop                /* Set tracing to desired value. */
   drivelist = Arg(1)                       /* Get Args: list of drive flags */
   drivelets = Arg(2)                                 /* drive letters       */
   volume    = Arg(3)                                 /* volume label        */

   drive = ''                               /* Init drive letter             */
   Do Until drive<>''                       /* Loop until a drive is set.    */
      posn = 0                              /* init scan position            */
      Do Until posn=0 | drive<>''           /* Loop until found or no more   */
         posn = Pos('1', drivelist, posn+1) /* find next drive to check      */
         If posn>0 then Do                  /* if one was found:             */
            curdrive = Substr(drivelets, posn, 1) /* get letter & check label*/
            Parse Value SysDriveInfo(curdrive) with . . . label .
            If label=volume then                  /* if correct label        */
               drive = curdrive':'                /* save drive letter.      */
            End                                   /* End: a drive was found. */
         End                                /* End: loop 'till found or done */
      If drive='' & quietop then            /* If no drive, but prompt is    */
         drive = '?:'                       /* not desired, set to "?".      */

      If drive='' then Do                   /* If no drive yet, prompt for it*/
         Say 'Unable to locate volume "'volume'" on any configured drives.'
         Say 'Please insert the correct volume or type the correct drive'
         Say 'letter for this volume and press ENTER:'
         Parse Upper Pull drive             /* get user input and            */
         drive = CheckDrive(drive)          /* check.                        */
         End                                /* End: no drive yet.            */
      End                                   /* End: Loop 'till drive set.    */

   Return drive

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : TermBUOutput                                          */
/*                                                                           */
/*  Description      : Procedure to add termination commands to backup       */
/*                     command array.                                        */
/*                                                                           */
/*  Dependencies     : Global Variables : traceop, outdata.                  */
/*                     Product Functions: None.                              */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Input Parameters :  fn       - output filename                           */
/*                      logfn    - log filename                              */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  TermBUOutput( fn logfn )                             */
/*                                                                           */
/*  Return values    :  always 1                                             */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1. Append command file termination lines to "outdata." array.        */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/
TermBUOutput: Procedure Expose traceop outdata.
   Interpret 'Trace' traceop                /* Set tracing to desired value. */

   Parse Arg fn logfn .                     /* Get Arg: output filename      */
   outlines = outdata.0                     /* save current # of lines       */
   outlines = outlines + 1
   outdata.outlines = "/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */"
   outlines = outlines + 1
   outdata.outlines = "io=Lineout('"logfn"', Substr(Date('O') Time('N'), 1, 18) 'Backup completed.')"
   outlines = outlines + 1
   outdata.outlines = "/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */"
   outlines = outlines + 1
   outdata.outlines = "/*                                                                           */"
   outdata.outlines = Overlay('End of '||Strip(Substr(fn, 1, 65)), outdata.outlines, 4)
   outlines = outlines + 1
   outdata.outlines = "/* The following code is executed if the REXX interpreter is not loaded.     */"
   outlines = outlines + 1
   outdata.outlines = "/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *"
   outlines = outlines + 1
   outdata.outlines = ":NOREXX"
   outlines = outlines + 1
   outdata.outlines = "CLS"
   outlines = outlines + 1
   outdata.outlines = "@ECHO"
   outlines = outlines + 1
   outdata.outlines = "@ECHO The REXX Interpreter is required for this program."
   outlines = outlines + 1
   outdata.outlines = "@ECHO Please use Selective Install to add it to your system."
   outlines = outlines + 1
   outdata.outlines = "@REM * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */"
   outdata.0 = outlines

   Return 1

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : GetRow                                                */
/*                                                                           */
/*  Description      : Procedure to fetch row via SELECT.                    */
/*                                                                           */
/*  Dependencies     : Global Variables : traceop, program, cmdresult,       */
/*                                        sqlresult rowdata.                 */
/*                     Product Functions: SQLDBS, SQLEXEC                    */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Input Parameters :  dbname    - database name                            */
/*                      numvars   - number of output variables               */
/*                      sqlstmt   - SQL select statement                     */
/*                                                                           */
/*  Output Parameters:  success indicator                                    */
/*                                                                           */
/*  Synopsis         :  GetRow( dbname, numvars, sqlstmt )                   */
/*                                                                           */
/*  Return values    :  1 indicates success.                                 */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1. If first entry, indicated by rowdata.dbopen flag:                 */
/*         a) log the query                                                  */
/*         b) issue 'START USING DATABASE' command                           */
/*         a) declare the cursor and open it.                                */
/*      2. Fetch the cursor into rowdata.n, where n=1 to numvars.            */
/*      3. If an error occurs, or at end of results, close the cursor        */
/*         and issue 'STOP USING DATABASE' command.                          */
/*      4. Return success flag.                                              */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/
GetRow: Procedure Expose traceop program cmdresult sqlresult rowdata. db2started
   Interpret 'Trace' traceop                /* Set tracing to desired value. */
   dbname    = Arg(1)                       /* Get Args: database name,      */
   numvars   = Arg(2)                                 /* output variable #   */
   sqlstmt   = Arg(3)                                 /* SQL Select statement*/
   result        = 0                        /* Init result                   */
   SQLCA.SQLCODE = 0                        /* and SQLCode vars.             */

   If \rowdata.dbopen then Do                     /* If database not open,   */
      Call SQLDBS "START USING DATABASE" dbname   /* connect to database     */
      If (result<>0) | (SQLCA.SQLCODE<>0) then    /* if error, say messages  */
         temp = SQLErr(result, SQLCA.SQLCODE, SQLMSG, "START USING DATABASE" dbname)
      Else Do                                     /* Else connected Ok,      */
         rowdata.dbopen = 1                       /* flag database open      */
         Call SQLEXEC "PREPARE S1 FROM :sqlstmt"  /* prepare statement       */
         If (result<>0) | (SQLCA.SQLCODE<>0) then /* if error, say messages  */
            temp = SQLErr(result, SQLCA.SQLCODE, SQLMSG, "PREPARE S1 FROM" sqlstmt)
         Else Do                                     /* else statement ready */
            Call SQLEXEC "DECLARE C1 CURSOR FOR S1"  /* declare cursor       */
            If (result<>0) | (SQLCA.SQLCODE<>0) then /* if error, say msgs   */
               temp = SQLErr(result, SQLCA.SQLCODE, SQLMSG, "DECLARE C1 CURSOR FOR S1")
            Else Do                                     /* else cursor dcl'd */
               Call SQLEXEC "OPEN C1"                   /* open cursor       */
               If (result<>0) | (SQLCA.SQLCODE<>0) then /* if error, say msgs*/
                  temp = SQLErr(result, SQLCA.SQLCODE, SQLMSG, "OPEN C1")
               Else                                     /* else flag         */
                  rowdata.cursoropen = 1                /* cursor open.      */
               End                                      /* End: cursor dcl'd */
            End                                      /* End: statement ready */
         End                                      /* End: connected Ok       */
      End                                         /* End: database not open. */

   If (result=0) & (SQLCA.SQLCODE=0) then Do      /* if Ok so far,           */
      sqlstmt = "FETCH C1 INTO"                   /* build fetch statement   */
      Do temp=1 to numvars                        /* including requested     */
         If temp>1 then                           /* number of result vars,  */
            sqlstmt = sqlstmt||','                /* sep'rated by commas.    */
         sqlstmt = sqlstmt ":rowdata."temp
         End
      Call SQLEXEC sqlstmt                        /* Execute fetch statement */
                                                  /* if error, say messages  */
      If (result<>0) | (SQLCA.SQLCODE<>0 & SQLCA.SQLCODE<>100) then
         temp = SQLErr(result, SQLCA.SQLCODE, SQLMSG, sqlstmt)
      End                                         /* End: Ok so far.         */

   cmdresult = result                             /* Save command result     */
   success = (result=0) & (SQLCA.SQLCODE>=0)      /* Save success indicator  */
   If \success then                               /* If failure, display msg */
      Say 'Problem executing "'sqlstmt'".'

   If (result<>0) | ,                             /* If a DB2 error,         */
      (SQLCA.SQLCODE<0) | ,                       /* or an SQL error,        */
      (SQLCA.SQLCODE=100) then Do                 /* or at end of table:     */
      If rowdata.cursoropen then Do               /* if cursor is open,      */
         Call SQLEXEC "CLOSE C1"                  /* try to close,           */
         If (result<>0) | (SQLCA.SQLCODE<>0) then /* if error, say messages  */
            temp = SQLErr(result, SQLCA.SQLCODE, SQLMSG, "CLOSE C1")
         rowdata.cursoropen = 0                   /* flag cursor closed      */
         End                                      /* End: cursor is open.    */
      If rowdata.dbopen then Do                   /* if database is open,    */
         Call SQLDBS "STOP USING DATABASE"        /* close the database      */
         If (result<>0) | (SQLCA.SQLCODE<>0) then /* if error, say messages  */
            temp = SQLErr(result, SQLCA.SQLCODE, SQLMSG, "STOP USING DATABASE")
         rowdata.dbopen = 0                       /* flag database closed    */
         End                                      /* End: database is open.  */
      End

   Return success                                 /* Return success indicator*/

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : SQLErr                                                */
/*                                                                           */
/*  Description      : Procedure to display SQL error messages.              */
/*                                                                           */
/*  Dependencies     : Global Variables : traceop, program                   */
/*                     Product Functions: None.                              */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Input Parameters :  return      - DB2/2 return code                      */
/*                      sqlreturn   - SQL return code                        */
/*                      sqlmsg      - SQL message text                       */
/*                      commandtext - DB2/2 command text                     */
/*                                                                           */
/*  Output Parameters:  success indicator                                    */
/*                                                                           */
/*  Synopsis         :  SQLErr( return, sqlreturn, sqlmsg, commandtext )     */
/*                                                                           */
/*  Return values    :  always 1                                             */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1. Display command text and return codes.                            */
/*      2. If SQL return code was not 0, display SQL messages.               */
/*      3. If temp message file is not empty, display these messages.        */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/
SQLErr: Procedure Expose traceop program
   Interpret 'Trace' traceop                /* Set tracing to desired value. */
   return      = Arg(1)                     /* Get Args: DB2 return code,    */
   sqlreturn   = Arg(2)                              /*  SQL return code,    */
   sqlmsg      = Arg(3)                              /*  SQL message text,   */
   commandtext = Arg(4)                              /*  DB2 command text.   */

   Say 'Problem executing SQL statement:'   /* Display SQL statement         */
   Say commandtext
                                            /* Display return codes          */
   Say 'DB2 Return Code =' return'; SQL Return Code = 'sqlreturn'.'
                                            /* If SQL error or message file: */
   If sqlreturn<>0 | Lines(program'.TMP')>0  then Do
      Say 'SQL messages:'                   /* Display header line           */
      If sqlreturn<>0 then Do               /* If SQL error, display SQLMSG: */
                                            /* remove CRLFs and nulls,       */
         outline = Translate(sqlmsg, '   ', '000D0A'x)
         outline = Strip(outline)           /* remove blanks                 */
         If outline<>'' then                /* If not empty, display line.   */
            Say outline
         End                                      /* End: if SQL error       */
      Do While Lines(program'.TMP')>0       /* If lines in temp message file:*/
                                            /* get output line; remove CRLFs */
         outline = Translate(Linein(program'.TMP'), '   ', '000D0A'x)
         outline = Strip(outline)           /* remove blanks                 */
         If outline<>'' then                /* If not empty, display line.   */
            Say outline
         End                                /* End: data in msg file         */
      End                                   /* End: SQL error or msg file    */
   ioout = Stream(program'.TMP', 'C', 'close') /* Close temp file.           */
                                            /* If found, delete temp file    */
   Address CMD 'IF EXIST' program'.TMP DEL' program'.TMP'

   Return 1

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : WriteLog                                              */
/*                                                                           */
/*  Description      : Procedure to write to log file.                       */
/*                                                                           */
/*  Dependencies     : Global Variables : traceop, program                   */
/*                     Product Functions: None.                              */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Input Parameters :  indent   - number of columns to indent text          */
/*                      pretext  - prefix text                               */
/*                      maintext - main text to log                          */
/*                                                                           */
/*  Output Parameters:  success indicator                                    */
/*                                                                           */
/*  Synopsis         :  WriteLog( indent, pretext, maintext )                */
/*                                                                           */
/*  Return values    :  ioout - result of Lineout function.                  */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1. Truncate or pad prefix text to value of indent columns.           */
/*      2. Write main text lines to log, with prefix text at left, to        */
/*         a max of 98 column line length.                                   */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/
WriteLog: Procedure Expose traceop program
   Interpret 'Trace' traceop                /* Set tracing to desired value. */

   indent   = Arg(1)                        /* Get args: indent columns      */
   pretext  = Arg(2)                                   /* prefix text        */
   maintext = Arg(3)                                   /* main text          */

   pretext = Substr(pretext, 1, indent)     /* Force length of prefix text   */
   maxlen  = 98 - indent                    /* Set maximum line length.      */

   Do While Length(maintext)>maxlen         /* While text is longer than max */
      split = Lastpos(' ', maintext, maxlen)/* Locate blank for split        */
      If split=0 then                       /* If no blank, force split      */
         split=maxlen                       /* at column "maxlen".           */
                                            /* Write the line...             */
      ioout = Lineout(program'.LOG', pretext||Substr(maintext, 1, split))
      maintext = Substr(maintext, split+1)  /* Remove text already written   */
      pretext = Copies(' ', indent)         /* and blank the prefix text.    */
      End                                   /* End: While longer than max.   */
                                            /* Write remainder               */
   ioout = Lineout(program'.LOG', pretext||maintext)

   Return ioout

/*****************************************************************************/
/* End of FRNOMIBG.CMD                                                       */
/* The following code is executed if the REXX interpreter is not loaded.     */
/*****************************************************************************
:NOREXX
CLS
@ECHO
@ECHO The REXX Interpreter is required for this program.
@ECHO Please use Selective Install to add it to your system.
@REM *************************************************************************/
