/*BEGINPROLOGUE***************************************************************
*
* MODULE: FRNODM.H                         VisualInfo
*
* 5697-250, 5621-326, 5655-036, 5622-213, 5655-071 and 5655-072
* (C) Copyright IBM Corp. 1993,1995.
* All Rights Reserved.
*
* US Government Users Restricted Rights
* - Use, duplication or disclosure
* restricted by GSA ADP Schedule Con-
* tract with IBM Corp.
*
* Licensed Materials - Property of IBM
*
*   Description:      This include file contains all of the defines
*                     and data structures required by the
*                     Device Manager.
*
*
*   Notes:
*
*     Dependencies:        This file must be included AFTER OS2.h.
*
*     Restrictions:
*
*   Module Type:           Header file
*
*
*ENDPROLOGUE*****************************************************************/


/*-----------------------------------------------------------------------------
*
*   Insure that this include file will not be called recursively
*
*----------------------------------------------------------------------------*/

#if __cplusplus
extern "C" {
#endif

#ifndef IPSDM_DEFINED
#define IPSDM_DEFINED

/*-----------------------------------------------------------------------------
*
*                        Device Manager Defines
*
*----------------------------------------------------------------------------*/
#define MAX_DM_DESCRIPTION_LEN  80     /* Maximum length of a DM description */
#define MAX_DM_PARAMS_LEN      128     /* Maximum length of a DM parameter */
                                       /*  string */

                                       /*--------------------------------------
                                            Defines for the mount request status
                                         ------------------------------------*/
#define DEVMGR_MOUNT_COMPLETE     1    /* Mount request was completed (mounted) */
#define DEVMGR_MOUNT_INCOMPLETE   2    /* Mount request could not be completed */
#define DEVMGR_MOUNT_CANCELLED    3    /* Mount request was cancelled by user */
#define DEVMGR_MOUNT_DEFERRED     4    /* Mount request was deferred by user */
#define DEVMGR_MOUNT_OFFLINE      5    /* Mount request is for an offline vol */

//---------------------------------------------------------------------------
// Values for cmdPriority, used to indicate how fast a client wants a
//  request processed.
//---------------------------------------------------------------------------
#define OM_RUSH_PRIORITY        1    /* Process it as soon as possible.      */
#define OM_NORMAL_PRIORITY      2    /* Process it in a reasonable amount    */
                                     /*   of time (but behind RUSH requests).*/
#define OM_BACKGROUND_PRIORITY  3    /* Process it whenever it can be done   */
                                     /*   (but behind NORMAL requests).      */

//---------------------------------------------------------------------------
// Maximum volume name length (including end of string character)
//---------------------------------------------------------------------------

#define MAX_VOL_NAME_LENGTH      33

//---------------------------------------------------------------------------
// Maximum length of a device access specifier(including end of string char)
//---------------------------------------------------------------------------

#define MAX_DEV_ACC_SPEC_LEN    37

//---------------------------------------------------------------------------
// Maximum file name length
//   For: directory and name of file (excluding the drive)
//---------------------------------------------------------------------------

#define MAX_FILE_NAME_LENGTH    234


//---------------------------------------------------------------------------
// Defines for the status of a volume
//---------------------------------------------------------------------------

#define OM_OFFLINE               0   /* Not accessible without manual       */
                                     /*   intervention                      */
#define OM_ONLINE                2   /* Accessible without manual           */
                                     /*   intervention, but not in the drive*/
#define OM_INLINE                4   /* Online and in the drive, but no     */
                                     /*   active mounts                     */
#define OM_MOUNTED               6   /* Online and in the drive with active */
                                     /*   mounts                            */
#define OM_FIXED                 8   /* Online and fixed                    */

/*-----------------------------------------------------------------------------
*
*    The DMINITSTRUCT describes Device Manager initialization parameters
*
*----------------------------------------------------------------------------*/
typedef struct tagDMINITSTRUCT
   {
   USHORT      cbStruct;               /* Number of bytes in this structure */
   BITSL       fDrives;                /* Drives to be managed by the Device */
                                       /*   Manager */
                                       /* Device Manager DLL name */
   CHAR        szDescription[MAX_DM_DESCRIPTION_LEN + 1];
                                       /* Device Manager description */
                                       /* (+1 for NULL character) */
   CHAR        szParms[MAX_DM_PARAMS_LEN + 1];
                                       /* Device Manager specific parameters */
                                       /* (+1 for NULL character) */
   HQUEUE      hQueue;                 /* Queue handle to be used by the Device */
                                       /*   Manager for sending completion */
                                       /*   notification of a mount request */
   HWND        hWnd;                   /* Window handle used by Device Manager */
                                       /*   for any End User Interface needed */
   }
  DMINITSTRUCT;

typedef DMINITSTRUCT     *PDMINITSTRUCT;

/*-----------------------------------------------------------------------------
*
*    The DMINITRCSTRUCT describes the Device Manager initialization return
*    code information.
*
*----------------------------------------------------------------------------*/
typedef struct tagDMINITRCSTRUCT
   {
   USHORT        cbStruct;             /* Number of bytes in this structure */
   SHORT         sDMRC;                /* Device Manager extended return code */
   }
   DMINITRCSTRUCT;

typedef DMINITRCSTRUCT     *PDMINITRCSTRUCT;

//-----------------------------------------------------------------------------
//
//   The VOLUMEID describes volume identification information.
//
//-----------------------------------------------------------------------------

typedef struct _VOLUMEID
  {
   USHORT        cbStruct;             /* Number of bytes in this structure*/
   CHAR          szVolName[MAX_VOL_NAME_LENGTH];
                                       /* Volume name string               */
   ULONG         ulVolSer;             /* Volume serial number             */
  }
   VOLUMEID;

typedef VOLUMEID  *PVOLUMEID;

//-----------------------------------------------------------------------------
//
//   The VOLINFOSTRUCT describes the volume information
//
//-----------------------------------------------------------------------------

typedef struct _VOLINFOSTRUCT
  {
   USHORT        cbStruct;             /* Number of bytes in this structure  */
   USHORT        usStatus;             /* Status of the volume               */
   CHAR          szDevAccSpec[MAX_DEV_ACC_SPEC_LEN];
                                       /* Device access specifier            */
   ULONG         ulSize;               /* Size of a volume in thousands of   */
                                       /*   bytes                            */
   ULONG         ulFreeSpace;          /* Free space on the volume in        */
                                       /*   thousands of bytes               */
   VOLUMEID      FlipSideVolID;        /* Flip side volume ID structure.     */
                                       /* Caller is responsible to NULL out  */
                                       /* szVolName & ulVolSer before calling*/
                                       /* When there is a flip side volume,  */
                                       /* the called function will set these */
                                       /* fields.                            */
  }
   VOLINFOSTRUCT;

typedef VOLINFOSTRUCT  *PVOLINFOSTRUCT;

/*-----------------------------------------------------------------------------
*
*    The ONLINEVOLSTRUCT describes the volume identification and status
*    information.
*
*----------------------------------------------------------------------------*/
typedef struct tagONLINEVOLSTRUCT
   {
   USHORT        cbStruct;             /* Number of bytes in this structure */
   VOLUMEID      VolumeID;             /* Volume information */
   USHORT        usStatus;             /* Status of the volume */
   }
   ONLINEVOLSTRUCT;

typedef ONLINEVOLSTRUCT     *PONLINEVOLSTRUCT;

/*-----------------------------------------------------------------------------
*
*                Device Manager SPI Function Prototypes
*
*----------------------------------------------------------------------------*/


SHORT  SIMENTRY DevMgrInit(               PDMINITSTRUCT,
                                 PDMINITRCSTRUCT );

SHORT  SIMENTRY DevMgrMountVolume(        PVOLUMEID, BOOL, UCHAR,
                                 USHORT, PVOLINFOSTRUCT );

SHORT  SIMENTRY DevMgrDismountVolume(     USHORT, PVOLUMEID,
                                 PVOLINFOSTRUCT );

SHORT  SIMENTRY DevMgrQueryVolume(        PVOLUMEID, PVOLINFOSTRUCT,
                                 PBOOL );

SHORT  SIMENTRY DevMgrQueryOnlineVolumes( PUSHORT,
                                 PONLINEVOLSTRUCT  * );

SHORT  SIMENTRY DevMgrFree( VOID );

SHORT  SIMENTRY DevMgrFastQueryVolume(    PVOLUMEID, BOOL, PVOLINFOSTRUCT,
                                                   PBOOL );

#endif

#if __cplusplus
}
#endif

