/*BEGINPROLOGUE***************************************************/
/*                                                               */
/* MODULE: frnolmla.h                                            */
/*                                                               */
/*                                                               */
/* COPYRIGHT:                                                    */
/* ----------                                                    */
/* Digital Library Version 1 - 5648-A08.                         */
/* VisualInfo Version 2 Release 2.0 - 5697-250.                  */
/* (C) Copyright IBM Corp., 1994, 1996.  All Rights Reserved     */
/*                                                               */
/* US Government Users Restricted Rights                         */
/* Use, duplication or disclosure restricted by GSA ADP Schedule */
/* Contract with IBM Corp.  Licensed Materials - Property of IBM */
/*                                                               */
/* Description: frnolmla.h - this include is used by programs    */
/*                           calling the List Manager APIs       */
/*                                                               */
/* Dependencies:                                                 */
/* Restrictions:                                                 */
/* Change History:                                               */
/* ---------------------------------------------------------     */
/* Date    PTR    Init   Description                             */
/* ------  -----  ----   -----------------------------------     */
/*                                                               */
/*                                                               */
/*ENDPROLOGUE*****************************************************/

#ifdef __cplusplus
     extern "C" {
#endif

#ifndef INCL_LSTAPI_INCLUDED

#define INCL_LSTAPI_INCLUDED

#ifndef CICS_ENV
#pragma pack(1)
#endif

//BMubos2.tgn
#ifdef AIX
 #ifndef SIMENTRY
   #define SIMENTRY
 #endif
#else
//EMubos2.tgn
 #ifndef SIMENTRY
  #define SIMENTRY _System
 #endif
#endif  //Aubos2.tgn

/* Maximum length for null-terminated input parameters.  Length does NOT
   include byte for null-terminator. Lengths indicate the value that would
   be returned by the strlen function */

#define LST_STOREID_LEN                26
#define LST_WKSTNID_LEN                17
#define LST_USERID_LEN                  8
#define LST_PASSWORD_LEN                8
#define LST_KEY_LEN                    75
#define LST_LISTID_LEN                  8


/* Cursor position tokens */
#define LST_FIRST_ELEMENT             -2147483647L
#define LST_LAST_ELEMENT               2147483647L
#define LST_CURSOR_POSITION           +0L
#define LST_PREV_ELEMENT              -1L
#define LST_NEXT_ELEMENT              +1L
#define LST_FIRST_AVAILABLE_ELEMENT    2147483646L // returns the element
                                                   // closest to the head of the
                                                   // list that is not open by
                                                   // any application


/* Timeout tokens */
#define LST_INDEFINITE_WAIT           -1L
#define LST_NO_WAIT                    0L


/* Element Retention tokens */
#define LST_RETENTION_FOREVER         -1L
#define LST_RETENTION_LRU             -2L


/* List Manager, List, and Element handle type definitions */
typedef LHANDLE HLSTMGR;
typedef HLSTMGR * PHLSTMGR;

typedef LHANDLE HLIST;
typedef HLIST * PHLIST;

typedef LHANDLE HELEMENT;
typedef HELEMENT * PHELEMENT;
typedef PHELEMENT * PPHELEMENT;


/* Storetype tokens.  Storetypes may be ORed together when passed as a
   parameter, and should be tested with the AND operator, not the EQUALS
   operator.

   Valid combinations:

   WORK_MEMORY - access element in memory, but do not reserve disk space at the
                 server for the element.  Not supported for LstCreateList.

   WORK_DISK   - NOT SUPPORTED

   WORK_MEMORY | MSTR_DISK  - access element in memory and reserve disk space
                              at the server for the element

   WORK_DISK | MSTR_DISK  - access element on disk and reserve disk space at
                            the server for the element

   MSTR_DISK - only valid Storetype value for LstCreateList */


typedef enum
{
  WORK_MEMORY   = 1,
  WORK_DISK     = 2,
  MSTR_DISK     = 4,
  DESC_ONLY_MEMORY = 8     // future use

} STORETYPE;


/* Type definitions for null-terminated string parameters */
typedef CHAR NEW_CHAR;         //Aubos2.pjs
typedef CHAR LISTID[LST_LISTID_LEN + 1];
typedef LISTID * PLISTID;
typedef CHAR STOREID[LST_STOREID_LEN + 1];
typedef CHAR WKSTNID[LST_WKSTNID_LEN + 1];
typedef CHAR USERID[LST_USERID_LEN + 1];
typedef CHAR PASSWORD[LST_PASSWORD_LEN + 1];
typedef CHAR ELEMKEY[LST_KEY_LEN + 1];


/* Operation codes returned in Event Notification messages */
/* Note that the OpCode LST_APPL_INIT is NEVER sent to the event handler
   by the List Manager.  It is provided so that an application
   may pass it to the event handler to indicate initialization */
typedef enum
{
   LST_APPL_INIT,
   LST_CONNECT,
   LST_DISCONNECT,
   LST_SERVER_SHUTDOWN,
   LST_CREATE_LIST,
   LST_DESTROY_LIST,
   LST_OPEN_LIST,
   LST_CLOSE_LIST,
   LST_INSERT,
   LST_REMOVE,
   LST_RETRIEVE,
   LST_MOVE,
   LST_COPY

}  OPCODE;


/* Format of Event Notification messages.  Event Notification messages must
   NOT be deallocated and are only valid at the time of the EventHandler
   function invocation.  The pointer to the Event Notification message should
   not be accessed after the EventHandler function does a "return". */
typedef struct
{
   OPCODE         OpCode;
   WKSTNID        szWkstnName;
   USERID         szUserName;
   LISTID         szSourceListName;
   ULONG          ulSourceNumElements;
   LISTID         szTargetListName;
   ULONG          ulTargetNumElements;

}  EVENTPARMS;

typedef EVENTPARMS * PEVENTPARMS;

typedef VOID ( * PEVENTPROC) (PEVENTPARMS);


/* format of element information buffer returned from LstQueryList */
typedef struct
{
   STORETYPE                   StoreType;
   LONG                        lRetention;
   ULONG                       ulLength;
   ULONG                       ulDescLength;
   CHAR                        szKey[LST_KEY_LEN + 1];
   BOOL                        bExclusive;
   USHORT                      usUseCount;
   LONG                        lWhenCreated;     /* C/2 time_t format */
   LONG                        lWhenReferenced;  /* C/2 time_t format */

}  ELEMINFO;

typedef ELEMINFO * PELEMINFO;


/* check to see if error codes already defined */
#ifndef LST_ERR_REQUEST_FAILED

/* Error return codes */
typedef enum
{
   LST_ERR_REQUEST_FAILED             = 9100,
   LST_ERR_INITIALIZATION_FAILED      = 9101,
   LST_ERR_TERMINATION_FAILED         = 9102,
   LST_ERR_FRNROOT_UNDEFINED          = 9103,
   LST_ERR_WKSTNID_UNDEFINED          = 9104,
   LST_ERR_INVALID_SESSION_HANDLE     = 9105,
   LST_ERR_INVALID_LIST_HANDLE        = 9106,
   LST_ERR_INVALID_ELEM_HANDLE        = 9107,
   LST_ERR_INVALID_ACCESS_MODE        = 9108,
   LST_ERR_INVALID_STORENAME          = 9109,
   LST_ERR_INVALID_USERNAME           = 9110,
   LST_ERR_INVALID_ELEMLEN            = 9111,
   LST_ERR_INVALID_ELEMKEY            = 9112,
   LST_ERR_INVALID_RETENTION          = 9113,
   LST_ERR_INVALID_STORETYPE          = 9114,
   LST_ERR_INVALID_DESTROY            = 9115,
   LST_ERR_INVALID_LISTNAME           = 9116,
   LST_ERR_INVALID_NOTIFY             = 9117,
   LST_ERR_INVALID_NUMLISTS           = 9118,
   LST_ERR_INVALID_NUMELEMS           = 9119,
   LST_ERR_INVALID_REQUEST            = 9120,
   LST_ERR_LIST_NOT_FOUND             = 9121,
   LST_ERR_DUPLICATE_LISTNAME         = 9122,
   LST_ERR_ELEM_NOT_FOUND             = 9123,
   LST_ERR_ELEM_IN_USE                = 9124,
   LST_ERR_ISO_SESSION_FAILURE        = 9125,
   LST_ERR_INSUFFICIENT_MEMORY        = 9126,
   LST_ERR_DUPLICATE_KEY              = 9127,
   LST_ERR_LIST_IN_USE                = 9128,
   LST_ERR_INSUFFICIENT_DISK_SPACE    = 9129,
   LST_ERR_FILE_ACCESS_FAILURE        = 9130,
   LST_ERR_DATABASE_INCONSISTENT      = 9131,
   LST_ERR_INSUFFICIENT_FHANDLES      = 9132,
   LST_ERR_LOGFILE_OPEN_FAILURE       = 9133,
   LST_ERR_SERVER_ALREADY_ACTIVE      = 9134,
   LST_ERR_LIST_ALREADY_OPEN          = 9135,
   LST_ERR_DUPLICATE_SIGNON_ID        = 9136,
   LST_ERR_SEMAPHORE_ERROR            = 9137,

   LST_ERR_INTERNAL_FAILURE           = 9139

}  LSTERRCODE;

#endif

/* List Configuration begin */

#define CNF_DEFAULT_SERVER               "FRNOCSVR"
#define CNF_DEFAULT_LIST                 "DFLTLIST"

#define CNF_NAMESERVER_SERVERNAME        "FRNONSVR"
#define CNF_NAMESERVER_LISTNAME          "NAMELIST"
#define CNF_NAMESERVER_APPNAME           "NAMESERVER"
#define CNF_ALL                          "ALL"

#define CNF_CONTENTCLASSHANDLER_APPNAME  "CONTENTCLASSHANDLER"

#define CNF_APPNAME_LEN                30
#define CNF_KEYNAME_LEN                40

typedef CHAR CNFAPP[CNF_APPNAME_LEN + 1];
typedef CHAR CNFKEY[CNF_KEYNAME_LEN + 1];

/* Structure holding the Application Name and Key Name */
/* of the configuation data.                           */
typedef struct
{
   CNFAPP         szAppName;
   CNFKEY         szKeyName;

}  CNFDATAKEY;

typedef CNFDATAKEY  * PCNFDATAKEY;
typedef PCNFDATAKEY * PPCNFDATAKEY;


typedef struct {
   CNFDATAKEY           cnfDataKey;
   CHAR                 chNextByte;
} CNFDATA;
typedef CNFDATA * PCNFDATA;

/* List Configuration end   */

/* Function Prototypes */

/* Changed the API names for CAPI compliance. */
/* Kept the old names for migration purposes. */

#define LstXtractElementLength(hElement)      LstQueryElementLength(hElement)

#define LstXtractElementStoreType(hElement)   LstQueryElementStoreType(hElement)

#define LstXtractElementStorage(hElement)     LstQueryElementStorage(hElement)

#define LstXtractElementDescription(hElement)\
        LstQueryElementDescription(hElement)

#define LstXtractElementDescLength(hElement)\
        LstQueryElementDescLength(hElement)

#define LstXtractElementRetention(hElement)   LstQueryElementRetention(hElement)

#define LstXtractElementKey(hElement,pszElementKey)\
        LstQueryElementKey(hElement,pszElementKey)

#define LstXtractCatalogHandle(hLstMgr)       LstQueryCatalogHandle(hLstMgr)

SHORT SIMENTRY LstConnectListMgr (STOREID  pszStoreName,
                                  USERID   pszUserName,
                                  PASSWORD pszPassword,
                                  PEVENTPROC pEventHandler,
                                  PHLSTMGR      phLstMgr);


SHORT SIMENTRY LstDisconnectListMgr(HLSTMGR    hLstMgr);


SHORT SIMENTRY LstCreateList (HLSTMGR          hLstMgr,
                              LISTID           pszListName,
                              LONG             lRetentionPeriod,
                              STORETYPE        StoreType);


SHORT SIMENTRY LstDestroyList (HLSTMGR          hLstMgr,
                               LISTID           pszListName);


SHORT SIMENTRY LstOpenList (HLSTMGR       hLstMgr,
                            LISTID        pszListName,
                            BOOL          bNotify,
                            BOOL          bExclusive,
                            PHLIST        phList);


SHORT SIMENTRY LstCloseList (HLIST       hList);


SHORT SIMENTRY LstCreateElement (HLSTMGR        hLstMgr,
                                 ULONG          ulElementLength,
                                 LONG           lRetentionPeriod,
                                 STORETYPE      StoreType,
                                 PHELEMENT      phElement);

SHORT SIMENTRY LstFreeElement (HELEMENT      hElement,
                               BOOL          bDestroy);


SHORT SIMENTRY LstInsertElement (HELEMENT    hElement,
                                 HLIST       hList,
                                 LONG        lCursorPosition,
                                 ELEMKEY     pszElementKey);

SHORT SIMENTRY LstRemoveElement (HLIST        hList,
                                 LONG         lCursorPosition,
                                 ELEMKEY      pszElementKey,
                                 STORETYPE    StoreType,
                                 LONG         lTimeout,
                                 BOOL         bDestroy,
                                 PHELEMENT    phElement);


SHORT SIMENTRY LstRetrieveElement (HLIST        hList,
                                   LONG         lCursorPosition,
                                   ELEMKEY          pszElementKey,
                                   STORETYPE    StoreType,
                                   BOOL         bExclusive,
                                   LONG         lTimeout,
                                   PHELEMENT    phElement);

SHORT SIMENTRY LstUpdateElement (HELEMENT    hElement);

SHORT SIMENTRY LstSetElementKey (HELEMENT     hElement,
                                 ELEMKEY      pszElementKey);

SHORT SIMENTRY LstMoveElement (HLIST         hSourceList,
                               LONG          lSourceCursorPosition,
                               ELEMKEY       pszSourceElementKey,
                               HLIST         hTargetList,
                               LONG          lTargetCursorPosition,
                               ELEMKEY       pszTargetElementKey);

SHORT SIMENTRY LstCopyElement (HLIST         hSourceList,
                               LONG          lSourceCursorPosition,
                               ELEMKEY       pszSourceElementKey,
                               HLIST         hTargetList,
                               LONG          lTargetCursorPosition,
                               ELEMKEY       pszTargetElementKey);

SHORT SIMENTRY LstDescribeElement (HELEMENT              hElement,
                                   HELEMENT              hDescription);
 /* skip the declarations for list mgr for BAPI */
#ifndef CICS_ENV
SHORT SIMENTRY LstQueryListNames (HLSTMGR                 hLstMgr,
                                  PUSHORT                 pusNumLists,
                                  PHELEMENT               phElement);

SHORT SIMENTRY LstQueryList (HLIST                        hList,
                             ULONG                        ulDescriptionLength,
                             PULONG                       pulNumElements,
                             PHELEMENT                    phElement);

ULONG SIMENTRY LstQueryElementLength (HELEMENT          hElement);

STORETYPE SIMENTRY LstQueryElementStoreType (HELEMENT   hElement);

PVOID SIMENTRY LstQueryElementStorage (HELEMENT         hElement);

SHORT SIMENTRY LstSetElementStorage (HELEMENT     hElement,
                                     PVOID        pBuffer);

PVOID SIMENTRY LstQueryElementDescription (HELEMENT     hElement);

ULONG SIMENTRY LstQueryElementDescLength (HELEMENT      hElement);

LONG  SIMENTRY LstQueryElementRetention (HELEMENT       hElement);

USHORT SIMENTRY LstQueryElementKey (HELEMENT            hElement,
                                    ELEMKEY             pszElementKey);

HLIST SIMENTRY LstQueryCatalogHandle (HLSTMGR           hLstMgr);
#endif


SHORT SIMENTRY CnfLogon (STOREID   pszCfgSrvName,
                         USERID    pszUserName,
                         PASSWORD  pszPassword,
                         PHLSTMGR phCfgSvr);

SHORT SIMENTRY CnfLogoff (HLSTMGR hCfgSvr);

VOID SIMENTRY CnfFree (PPVOID ppData);

SHORT SIMENTRY CnfWriteData (HLSTMGR    hCfgSvr,
                             LISTID     pszListName,
                             PSZ        pszAppName,
                             PSZ        pszKeyName,
                             PVOID      pValue,
                             ULONG      ulSize,
                             ULONG      ulNumData,
                             PPHELEMENT pphElement);

SHORT SIMENTRY CnfReadData (HLSTMGR    hCfgSvr,
                            LISTID     pszListName,
                            PSZ        pszAppName,
                            PSZ        pszKeyName,
                            ULONG      ulSize,
                            BOOL       bExclusive,
                            PULONG     pulNumData,
                            PPVOID     ppData,
                            PPHELEMENT pphElement);

SHORT SIMENTRY CnfQueryData (HLSTMGR        hCfgSvr,
                             LISTID         pszListName,
                             PSZ            pszAppName,
                             PSZ            pszKeyName,
                             PULONG         pulNumData,
                             PPCNFDATAKEY   ppCnfDataKey);

SHORT SIMENTRY CnfMergeData( PCNFDATA pCnfData1,
                             ULONG    ulNumCnfData1,
                             PCNFDATA pCnfData2,
                             ULONG    ulNumCnfData2,
                             ULONG    ulLenUserData,
                             PULONG   pulNumMergedCnfData,
                             PPVOID   ppMergedCnfData );

VOID SIMENTRY CnfCopyData( PVOID    pTargetBuffer,
                           PCNFDATA pSourceCnfData,
                           ULONG    ulNumCnfData,
                           ULONG    ulCopyLength );

SHORT SIMENTRY CnfReleaseExclusiveData( ULONG       ulNumData,
                                        PPHELEMENT  pphElement);

#ifndef CICS_ENV
#pragma pack()
#endif

#endif

#ifdef __cplusplus
     }
#endif
