/*BEGINPROLOGUE***************************************************/
/*                                                               */
/* MODULE: FRNSMSRV.H                                            */
/*                                                               */
/* COPYRIGHT:                                                    */
/* ----------                                                    */
/* Digital Library Version 1 - 5648-A08.                         */
/* VisualInfo Version 2 Release 2.0 - 5697-250.                  */
/* (C) Copyright IBM Corp., 1994, 1996.  All Rights Reserved     */
/*                                                               */
/* US Government Users Restricted Rights                         */
/* Use, duplication or disclosure restricted by GSA ADP Schedule */
/* Contract with IBM Corp.  Licensed Materials - Property of IBM */
/*                                                               */
/*                                                               */
/* Description: FRNSMSA.H  - SMS API defines for the LAN         */
/*                           based object server interface.      */
/*                                                               */
/* Dependencies:                                                 */
/* Restrictions:                                                 */
/*                                                               */
/*                                                               */
/*  Notes:                                                       */
/*ENDPROLOGUE*****************************************************/
#ifndef SMS_INCLUDED

#if __cplusplus
extern "C" {
#endif

#define SMS_INCLUDED

/******************************* Control Table *******************************/
//
#define SMS_CTL_CONFIG_ID_SIZE             17   /* Size of Configuration ID */
#define SMS_CTL_CONFIG_DESC_SIZE           81   /* Size of Description Field */
#define SMS_CTL_CONFIG_ID_LEN              SMS_CTL_CONFIG_ID_SIZE - 1
                                                /* Length of configuration ID */
#define SMS_CTL_CONFIG_DESC_LEN            SMS_CTL_CONFIG_DESC_SIZE - 1
                                                /* Length of Configuration description */

/***************************   Collection table ******************************/
//
#define SMS_COL_COLLNAME_SIZE               45  /* Size of Collection Name */
#define SMS_COL_COLLNAME_LEN               SMS_COL_COLLNAME_SIZE -1
                                                /* Length of Collection Name */

/*************************** Storage Class Table ****************************/
//
#define SMS_STC_STGCLASSNAME_SIZE          9    /* Size of Storage Class Name */
#define SMS_STC_STGCLASSNAME_LEN           SMS_STC_STGCLASSNAME_SIZE-1
                                               /* Length of Storage Class Name */

/****************************** Volume Table ********************************/
//
#define SMS_VOL_VOLLABEL_SIZE              33   /* Volume label Size */
#define SMS_VOL_OFFLINE_LOC_SIZE           129  /* Length of string telling the
                                                   offline location of a Volume */
#define SMS_VOL_VOLLABEL_LEN               SMS_VOL_VOLLABEL_SIZE - 1
#define SMS_VOL_OFFLINE_LOC_LEN            SMS_VOL_OFFLINE_LOC_SIZE - 1
#define SMS_VOL_DATE_SIZE                  10
#define SMS_VOL_DATE_LEN                   SMS_VOL_DATE_SIZE - 1
            /**********************************************************/
           /* Use with usNumSubDirs parameter in the VOLUMEINFOSTRUCT */
#define VOLTABLE_MAX_SUBDIR_BUCKETS        100  /* Maximum Number of paths use to
                                                   store objects  */
            /******************************************************/
           /* Use with ucStatus parameter in the VOLUMEINFOSTRUCT */
#define VOLTABLE_STATUS_OVERFLOW           'O'  /* Overflow Volume status   */
#define VOLTABLE_STATUS_ASSIGNED           'A'  /* Assigned Volume Status   */
#define VOLTABLE_STATUS_UNASSIGNED         'U'  /* Unassigned Volume Status */
#define VOLTABLE_STATUS_VOLUMEFULL         'F'  /* Volume is Full Status    */

/***************************** Storage Group Table ***************************/
//
#define SMS_STG_STGGRPNAME_SIZE             33  /* Size of Storage Group Name */
#define SMS_STG_STGGRPNAME_LEN              SMS_STG_STGGRPNAME_SIZE - 1

/*************************** Management Class Table **************************/
//
#define SMS_MGC_MGTCLASSNAME_SIZE           9   /* Size of Management Class name */
#define SMS_MGC_MGTCLASSNAME_LEN            SMS_MGC_MGTCLASSNAME_SIZE-1
                                                /* Length of Management Class name */


/********************************* String Table ******************************/
//
#define SMS_STRING_SIZE                     255 /* Size of the path to objects
                                                   used in string table */
/******************************* Device Mgr. Table ***************************/
//
#define SMS_DEV_FILENAME_SIZE              9    /* Size of Device Manager
#define SMS_DEV_FILENAME_LEN               SMS_DEV_FILENAME_SIZE - 1
                                                   Filename */
#define SMS_DEV_DESCR_SIZE                 81   /* Size of Device Manager
#define SMS_DEV_DESCR_LEN                  SMS_DEV_DESCR_SIZE - 1
                                                   description field */
#define SMS_DEV_PARMS_SIZE                 129  /* Size of Parameter field
#define SMS_DEV_PARMS_LEN                  SMS_DEV_PARMS_SIZE - 1
                                                   used to initialize a Device */

// Device Manager Drive List to be used with lDevDriveList parameter in the
//  DEVMGRINFOSTRUCT
#define SMS_DEV_DRIVE_A                    0x00000001L
#define SMS_DEV_DRIVE_B                    0x00000002L
#define SMS_DEV_DRIVE_C                    0x00000004L
#define SMS_DEV_DRIVE_D                    0x00000008L
#define SMS_DEV_DRIVE_E                    0x00000010L
#define SMS_DEV_DRIVE_F                    0x00000020L
#define SMS_DEV_DRIVE_G                    0x00000030L
#define SMS_DEV_DRIVE_H                    0x00000040L
#define SMS_DEV_DRIVE_I                    0x00000080L
#define SMS_DEV_DRIVE_J                    0x00000100L
#define SMS_DEV_DRIVE_K                    0x00000200L
#define SMS_DEV_DRIVE_L                    0x00000400L
#define SMS_DEV_DRIVE_M                    0x00000800L
#define SMS_DEV_DRIVE_N                    0x00001000L
#define SMS_DEV_DRIVE_O                    0x00002000L
#define SMS_DEV_DRIVE_P                    0x00004000L
#define SMS_DEV_DRIVE_Q                    0x00008000L
#define SMS_DEV_DRIVE_R                    0x00010000L
#define SMS_DEV_DRIVE_S                    0x00020000L
#define SMS_DEV_DRIVE_T                    0x00040000L
#define SMS_DEV_DRIVE_U                    0x00080000L
#define SMS_DEV_DRIVE_V                    0x00100000L
#define SMS_DEV_DRIVE_W                    0x00200000L
#define SMS_DEV_DRIVE_X                    0x00400000L
#define SMS_DEV_DRIVE_Y                    0x00800000L
#define SMS_DEV_DRIVE_Z                    0x01000000L

/*************************** Staging Table ***********************************/
//
#define SMS_STA_STAGEPATH_SIZE             81 /* Size of the Stager path */
#define SMS_STA_STAGEPATH_LEN              SMS_STA_STAGEPATH_SIZE - 1

/************************* Logon Access Control Table *************************/
//
    /* Used with the ulAttributes parameter in the LOGONINFOSTRUCT */
#define SMS_ADMINISTRATOR                  0x00000001L   /* Yes Admin    */
#define SMS_NO_ADMINISTRATOR               0x00000000L   /* Not an Admin */
#define SMS_RENOTE_LIBRARYID               0x00000002L   /* Not an Admin */

/* To use with attributes parameter in the Storage Class structure      */
/* Remote tells the system that the Storage class is on a remote server */
/* The Local flag tell the system that the storage class is attached to */
/* the local server.  The RESERVED flag is for future use by the system */
/* The two user defined flags are ignored by the                        */
/* system and be set to meet the needs of user defined functions.       */
/* Know other values may be used within this ULONG value. If flags are  */
/* set on bits 5 through 32, the system will not find the storage class */
/* data and the results would be undetermined.                          */
#define SMS_REMOTE                         0x00000002L   /*   */
#define SMS_LOCAL                          0x00000001L   /*   */
#define SMS_RESERVED                       0x00000004L   /*   */
#define SMS_USERDEF1                       0x00000008L   /* USER DEFINABLE  */
#define SMS_USERDEF2                       0x000000016L  /* USER DEFINABLE  */
//
#define SMS_USERID_SIZE                    27 /* Size of userid String */
#define SMS_PASSWORD_SIZE                  9  /* Size of Password string */
#define SMS_USERID_LEN                     SMS_USERID_SIZE - 1
#define SMS_PASSWORD_LEN                   SMS_PASSWORD_SIZE - 1

// Standard defines
#define MAX_SMS_ROWS                        65535 /* Maximum number of rows
                                                     that can be returned in a
                                                     in a query */

#define MAX_ASSOC_STRING_LENGTH             33 /* Maximum size of an associated
                                                  string */

#define SMS_STR_MAX_STRING_SIZE             255 /* Maximum size a string can be */

/* Define for the usValidationType parameter used in the Ip2SMSValidateEntites
   API. */

#define SMS_PROPER_VALIDATION               1 /* If can exist Validation */
#define SMS_EXIST_VALIDATION                2 /* If it does exist Validation */

#define SMS_LIB_SEV_NAME_SIZE               27 /* Size of a Library server name */
#define SMS_OBJ_SERVER_NAME_SIZE            27 /* Size of Base Object server name */
#define SMS_LIB_SEV_NAME_LEN                SMS_LIB_SEV_NAME_SIZE - 1
#define SMS_OBJ_SERVER_NAME_LEN             SMS_OBJ_SERVER_NAME_SIZE - 1


// Define to be used in timeout values and retention values for all tables
// meaning to last forever.

#define SMS_FOREVER                        -1


/*    Enumeration  for Entity to operate upon       */

                  // Valid tokens for smsEntityTypes,
typedef enum      //                  smsValidationEntityType,
{                 //                  smsAssociatedEntityType

   SMS_COLLECTION    =   1LU,  /* COLLECTION TABLE    */
   SMS_STGGRP        =   2LU,  /* STORAGE GROUP TABLE */
   SMS_STGCLASS      =   3LU,  /* STORAGE CLASSTABLE */
   SMS_VOLUME        =   4LU,  /* VOLUME TABLE */
   SMS_DEVMGR        =   5LU,  /* DEVICE MANAGER TABLE */
   SMS_MGTCLASS      =   6LU,  /* MANAGEMENT CLASS TABLE */
   SMS_CONFIG        =   7LU,  /* CONFIGURATION TABLE */
   SMS_STAGE         =   8LU,  /* STAGER TABLE */
   SMS_LOGON         =   9LU,  /* ACCESS TABLE */
   SMS_LIBSERVER     =  10LU,  /* LIBRARY SERVER */
   SMS_OBJECTSERVER  =  11LU,  /* BASE OBJECTSERVER */
   SMS_DEFAULT       =  100000 /* This has been added because the UL */
                               /* form only works if the /Sm flag is */
                               /* used to include the migration      */
                               /* extensions.                        */
}  SMSENTITY;

/*********************************************************************/
/* C DECLARATION FOR TABLE BASE_LIBSERVERSTRUCT            */
/*********************************************************************/


typedef struct
{
  USHORT       cbStruct;                 /* Structure Size */
  SMSENTITY    smsEntity;               /* Type Entity we are acting on */
  ULONG        ulAttributes;
  CHAR         szLibServerName[SMS_LIB_SEV_NAME_SIZE];

} LIBSERVERSTRUCT;

typedef LIBSERVERSTRUCT * PLIBSERVERSTRUCT;


/*********************************************************************/
/* C DECLARATION FOR TABLE BASE_OBJECTSERVER                */
/*********************************************************************/


typedef struct
{
  USHORT       cbStruct;                 /* Structure Size */
  SMSENTITY    smsEntity;               /* Type Entity we are acting on */
  ULONG        ulAttributes;
  CHAR         szObjServerName[SMS_OBJ_SERVER_NAME_SIZE];

}REMOBJSEVSTRUCT;

typedef REMOBJSEVSTRUCT * PREMOBJSEVSTRUCT;


/*********************************************************************/
/* C DECLARATION FOR TABLE BASE_CONTROL                              */
/*********************************************************************/

   /* MIGRATION STRUCTURE USED IN THE CNTLCONFIGINFOSTRUCT */
typedef struct
{

 CHAR                    szMigStartTimeHrs[2];       // Start Time Hours
 CHAR                    szMigStartTimeMins[2];      // Start Time Minutes
 SHORT                   sMigrationMinutes;          // Amonut of time to Run

} MIGSCHED;

/* Configuration Structure */

typedef struct
{

  SMSENTITY    smsEntity;               // Type Entity we are acting on
  BOOL         bConfigInUse;            // Flag stating the current configuration being
                                        // used for LBOS. Not updatable nor is it
                                        // creatable.
  USHORT       usMaxProcess;            // Maximum number of processes LBOS
                                        // will create to proces request from Library
                                        // Server.
  LONG         lLibraryReceiveTimeout;  // Maximum time in milliseconds the LBOS
                                        // should wait when attempting to recieve a
                                        // message from Library Server.
  LONG         lClientReceiveTimeout;   // Maximum time in milliseconds the LBOS
                                        // should wait when attempting to recieve a
                                        // message from Daemon.
  LONG         lPurgerTimeout;          // Amount of time in milliseconds LBOS processors
                                        // should wait when theres insufficent disk space
                                        // in the staging area
  LONG         lMountTimeout;           // The amount of time in milliseconds that LBOS
                                        // processors should wait for the Mounter to
                                        // respond.
  USHORT       usPurgerCycle;           // The amount of time in minutes the LBOS Purger
                                        // process should wait between sweeps of the
                                        // staging Area.
  USHORT       usMigratorCycle;         // The amount of time in minutes the LBOS Migrator
                                        // process should wait between sweeps of the
                                        // Database for objects to migrate.
  USHORT       usDestagerCycle;         // The amount of time in minutes the LBOS
                                        // Destager process should wait between moves of
                                        // objects from the staging Area.
  USHORT       usStagerBatchSize;       // Amount of files process during one sweep
                                        // of the staging area.
  USHORT       usMigratorBatchSize;     // Amount of files migrated that should be
                                        // process during a migration between
                                        // Storage Classes.
  MIGSCHED     migSchedule[7];          // Migration Schedule for Entire week
  USHORT       usCtlMaxListBoxMsgs;     //
  USHORT       cbStruct;                // Structure Size
  CHAR         szConfigName[SMS_CTL_CONFIG_ID_SIZE];
                                        // Name of Configuration or its ID
  CHAR         szConfigDescription[SMS_CTL_CONFIG_DESC_SIZE];
                                        // Decription of configuration

}  CNTLCONFIGINFOSTRUCT;

typedef  CNTLCONFIGINFOSTRUCT * PCNTLCONFIGINFOSTRUCT;
/********************************************************************/
/* C DECLARATION FOR TABLE BASE_LOGON                               */
/********************************************************************/

typedef struct{

SMSENTITY smsEntity;                     // Type Entity we are acting on
ULONG     ulAttributes;                  //
USHORT    cbStruct;                      // Size of the Structure
CHAR      szUserID[SMS_USERID_SIZE];     // Userid
CHAR      szPassword[SMS_PASSWORD_SIZE]; // Password
CHAR      szLibServerName[SMS_LIB_SEV_NAME_SIZE];

}LOGONINFOSTRUCT;

typedef   LOGONINFOSTRUCT    *  PLOGONINFOSTRUCT;


/*********************************************************************/
/* C DECLARATION FOR TABLE BASE_STAGING                              */
/*********************************************************************/


typedef struct
{
  SMSENTITY    smsEntity;        // Type Entity we are acting on
  USHORT       usID;             // Staging Area IDentifier default = 1
  double       dSize;            // Maximum Amount of Staging Area Space in MB
  double       dSpaceUsed;       // The amount of Staging Area in bytes that
                                 // is currently being used for staging.
  USHORT       usPercentStart;   // The percentage of space that is used before
                                 // the lease recently used object is deleted
                                 // from Staging Area.
  USHORT       usPercentStop;    // The percentage of space that is needed in
                                 // order for the deletion to stop.
  USHORT       cbStruct;         // Size of  structure
  CHAR         szPath[SMS_STA_STAGEPATH_SIZE];
                                 // Path of the Staging Area.

} STAGEINFOSTRUCT;

typedef STAGEINFOSTRUCT * PSTAGEINFOSTRUCT;


/*********************************************************************/
/* C DECLARATION FOR TABLE BASE_DEVICE_MANAGER                       */
/*********************************************************************/

typedef struct
{

  SMSENTITY    smsEntity;     // Type Entity we are acting on
  LONG         lDevDriveList; // List of drives under control of Device Manger
  BOOL         bDevEnable;    // Flag indicating if device manger is used
  USHORT       cbStruct;      // Size of structure
  CHAR         szDevMgName[SMS_DEV_FILENAME_SIZE];     // Device Name, should be
                                                       // name of device manager
                                                       // DLL.
  CHAR         szDevMgDescription[SMS_DEV_DESCR_SIZE]; // Description of device
                                                       // manager
  CHAR         szDevParameters[SMS_DEV_PARMS_SIZE];    // Parameters to be used
                                                       // with device manger

} DEVMGRINFOSTRUCT;

typedef DEVMGRINFOSTRUCT  * PDEVMGRINFOSTRUCT;


/*********************************************************************/
/* C DECLARATION FOR TABLE BASE_STORAGECLASS                         */
/*********************************************************************/


typedef struct
{
  SMSENTITY     smsEntity;        // Type Entity we are acting on
  ULONG         ulAttributes;     // usAttributes is not Currently Implemented
  LONG          lRemoteRetention; // NOT IMPLEMENTED
  USHORT        cbStruct;         // Size of structure
  CHAR          szStorageClassName[SMS_STC_STGCLASSNAME_SIZE];
                                  // Name of Storage Class
  CHAR          szObjServerName[SMS_OBJ_SERVER_NAME_SIZE];
  CHAR          szRemoteCollectionName[SMS_COL_COLLNAME_SIZE];
  CHAR          szRemoteMgtClassName[SMS_MGC_MGTCLASSNAME_SIZE];
  CHAR          szRemoteStgClassName[SMS_STC_STGCLASSNAME_SIZE];

} STGCLASSINFOSTRUCT;

typedef STGCLASSINFOSTRUCT * PSTGCLASSINFOSTRUCT;



/*********************************************************************/
/* C DECLARATION FOR TABLE BASE_VOLUMES                              */
/*********************************************************************/

typedef struct _VOLUMEINFOSTRUCT
{
  SMSENTITY     smsEntity;    // Type Entity we are acting on
  ULONG         ulSerial;     // Serial which is assigned volume when formatted
  ULONG         ulSize;       // Volume size indicating storage capacity
  ULONG         ulFreeSpace;  // Estimation of availabe storage on volume
  ULONG         ulAttributes; // NOT IMPLEMENTED YET
  USHORT        usMediaType;  // NOT IMPLEMENTED YET
  USHORT        usNumSubDirs; // Number of paths used to store objects
  USHORT        cbStruct;     // Size of structure
  UCHAR         ucStatus;     // Status of the volume
  CHAR          szOfflineLocation[SMS_VOL_OFFLINE_LOC_SIZE];
                              // Text signifing location of Offline Volume
  CHAR          szLabel[SMS_VOL_VOLLABEL_SIZE];
                              // Unique volume label
  CHAR          szVolLastReferencedDate[SMS_VOL_DATE_SIZE];
  CHAR          szStorageClassName[SMS_STC_STGCLASSNAME_SIZE];
                              // Name of associated Storage Class

} VOLUMEINFOSTRUCT;

typedef VOLUMEINFOSTRUCT * PVOLUMEINFOSTRUCT;



/*********************************************************************/
/* C DECLARATION FOR TABLE BASE_STORAGEGROUP_CLASS                   */
/*********************************************************************/

typedef struct
{
  SMSENTITY    smsEntity;     // Type Entity we are acting on
  USHORT       cbStruct;      // Size of structure
  CHAR         szStorageGroupName[SMS_STG_STGGRPNAME_SIZE];
                              // Name of Storage Group
}STORAGEGRPINFOSTRUCT;

typedef  STORAGEGRPINFOSTRUCT * PSTORAGEGRPINFOSTRUCT;


/***************** BASE_MANAGEMENT_TRANSITION **********************/

typedef struct
{
  LONG               lLastRefer;   // The last referenced transition period
  LONG               lSinceEnter;  // The number of days since object's entrance
                                   //into the Storage Class
  LONG               lStageCycle;  // The number of days after which the object
                                   // should be copied into the Staging Area
  LONG               lStageTimes;  // The number of times that object in this
                                   //  Storage Class should be staged.
  CHAR               szStorageClassName[SMS_STC_STGCLASSNAME_SIZE];
                                   // Target Storage Class for a given sequence

}MGTTRANINFOSTRUCT;

typedef  MGTTRANINFOSTRUCT    *  PMGTTRANINFOSTRUCT;
/*********************************************************************/
/* C DECLARATION FOR TABLE BASE_MANAGEMENT_CLASS                     */
/*********************************************************************/


typedef struct
{

  SMSENTITY          smsEntity;           // Type Entity we are acting on
  LONG               lMgtRetentionPeriod; //
  ULONG              ulAttributes;        //
  ULONG              ulTransitionPeriod;  // Number of days after which objects
                                          // managed by the Management Class
                                          // should be transition to the next
                                          // Management class
  PMGTTRANINFOSTRUCT pMgtTranInfoStruct;  // Pointer to transitions
  USHORT             cbStruct;            // Size of structure
  USHORT             usNumRows;           // Amount of transitions
  CHAR               szMgtClassName[SMS_MGC_MGTCLASSNAME_SIZE];
                                          // Managemnt Class Name
  CHAR               szTransitionTargetMgt[SMS_MGC_MGTCLASSNAME_SIZE];
                                          // Next Management Class to go to

} MGTCLASSINFOSTRUCT;

typedef MGTCLASSINFOSTRUCT * PMGTCLASSINFOSTRUCT;

/*********************************************************************/
/* C DECLARATION FOR TABLE BASE_COLLECTION                           */
/*********************************************************************/



typedef struct
 {

  SMSENTITY     smsEntity;       // Type Entity we are acting on
  USHORT        cbStruct;        // Size of structure
  ULONG         ulAttributes;    //
  CHAR          szCollectionName[SMS_COL_COLLNAME_SIZE];
                                 // Collection Name
  CHAR          szStgGroupName[SMS_STG_STGGRPNAME_SIZE];
                                 // Associated Storage Group Name
  CHAR          szMgtClassName[SMS_MGC_MGTCLASSNAME_SIZE];
                                 // Associated Management Class Name

 } COLLECTIONINFOSTRUCT;

typedef COLLECTIONINFOSTRUCT * PCOLLECTIONINFOSTRUCT;


typedef LHANDLE HLBOS;     /* Handle to LBOS */

typedef HLBOS * PHLBOS;    /* Pointer LBOS handle */


/***********************/


#define SMS_ASSOC_TYPE 15

typedef CHAR MAXASSOCSTRING[MAX_ASSOC_STRING_LENGTH];

typedef MAXASSOCSTRING  * PMAXASSOCSTRING;

typedef PMAXASSOCSTRING  * PPMAXASSOCSTRING;


/*************************************************/
// Function prototypes for SMS API's



SHORT SIMENTRY  Ip2SMSCreateEntity (HLBOS           hLBOS,
                                    SMSENTITY       smsEntityType,
                                    PVOID           pEntityInfo,
                                    PASYNCCTLSTRUCT pAsyncCtlStruct,
                                    PRCSTRUCT       pRC);





SHORT SIMENTRY Ip2SMSAssociateEntity (HLBOS           hLBOS,
                                      SMSENTITY       smsEntityType,
                                      PSZ             pszEntityName,
                                      SMSENTITY       smsAssociateEntityType,
                                      PSZ             pszAssociateEntityName,
                                      PASYNCCTLSTRUCT pAsyncCtlStruct,
                                      PRCSTRUCT       pRC);



SHORT SIMENTRY Ip2SMSDisassociateEntity (HLBOS           hLBOS,
                                         SMSENTITY       smsEntityType,
                                         PSZ             pszEntityName,
                                         SMSENTITY       smsAssociateEntityType,
                                         PSZ             pszAssociateEntityName,
                                         PASYNCCTLSTRUCT pAsyncCtlStruct,
                                         PRCSTRUCT       pRC);


SHORT SIMENTRY Ip2SMSDeleteEntity (HLBOS           hLBOS,
                                   SMSENTITY       smsEntityType,
                                   PSZ             pszEntityName,
                                   PASYNCCTLSTRUCT pAsyncCtlStruct,
                                   PRCSTRUCT       pRC);





SHORT SIMENTRY Ip2SMSUpdateEntity (HLBOS           hLBOS,
                                   SMSENTITY       smsEntityType,
                                   PSZ             pszEntityName,
                                   PVOID           pEntityInfo,
                                   ULONG           ulReserve,
                                   PASYNCCTLSTRUCT pAsyncCtlStruct,
                                   PRCSTRUCT       pRC);




SHORT SIMENTRY Ip2SMSQueryEntityInfo (HLBOS           hLBOS,
                                      SMSENTITY       smsEntityType,
                                      PSZ             pszEntityName,
                                      USHORT          usNumRows,
                                      ULONG           ulReserve,
                                      PASYNCCTLSTRUCT pAsyncCtlStruct,
                                      PRCSTRUCT       pRC);



SHORT SIMENTRY Ip2SMSLogonLBOS (PSZ             pszUserID,
                                PSZ             pszPassword,
                                PSZ             pszServName,
                                PHLBOS          phLBOS,
                                PRCSTRUCT       pRC);





SHORT SIMENTRY Ip2SMSLogoffLBOS (HLBOS           hLBOS,
                                 PRCSTRUCT       pRC);


SHORT SIMENTRY Ip2SMSQueryAssociatedEntityInfo (HLBOS           hLBOS,
                                                SMSENTITY       smsEntityType,
                                                PSZ             pszEntityName,
                                                SMSENTITY       smsAssociatedEntityType,
                                                USHORT          usNumRows,
                                                PASYNCCTLSTRUCT pAsyncCtlStruct,
                                                PRCSTRUCT       pRC);


SHORT SIMENTRY  Ip2SMSFreeEntityInfo (PVOID           pQueryInfo,
                                      SMSENTITY       smsEntityType,
                                      PRCSTRUCT       pRC);

SHORT SIMENTRY Ip2SMSValidateEntities (HLBOS             hLBOS,
                                       SMSENTITY         smsEntityType,
                                       PSZ               pszEntityName,
                                       SMSENTITY         smsValidationEntityType,
                                       PSZ               pszValidationEntityName,
                                       USHORT            usValidationType,
                                       PASYNCCTLSTRUCT   pAsyncCtlStruct,
                                       PRCSTRUCT         pRC);

SHORT SIMENTRY Ip2SMSQueryDriveInfo (HLBOS            hLBOS,
                                      PRCSTRUCT       pRC);


#if __cplusplus
}
#endif

#endif
