/******************************************************************************
 *
 *    FILE NAME:  FRNOWFEX.H   (VHLPI - External Include file)
 *
 *=============================================================================
 *
 *    5697-250, 5621-326
 *    Copyright (C) IBM Corp. 1995, 1996.  All Rights Reserved.
 *
 *    US Government Users Restricted Rights - Use, duplication or
 *    disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 *    Licensed Materials - Property of IBM
 *
 *=============================================================================
 *
 *    DESCRIPTION:
 *       This is the external header file for the VHLPI module.
 *       It defines structures, #typedefs, global data, etc., needed to
 *       access the VisualInfo High Level Programming Interface functions.
 *
 *****************************************************************************/

/*---------------------------------------------------------------------------*/
/*    If this file has already been presented to the compiler, then don't    */
/*    compile the statements in this file again. If FRNOWFEX has already     */
/*    been defined, then all the statements in this file are ignored.        */
/*---------------------------------------------------------------------------*/
#ifndef FRNOWFEX
#define FRNOWFEX

/*---------------------------------------------------------------------------*/
/*                           Include     files                               */
/*---------------------------------------------------------------------------*/
#define  INCL_REXXSAA
#include <rexxsaa.h>
/*                     VisualInfo Interface information                      */
#define  FRN_INCL_FI
#define  FRN_INCL_FO
#include <frnp.h>
#include <frnolg.h>
#include <frnpfi2.h>
#include <frnplw.h>
#include <fiws.h>

#pragma pack(1)
/*---------------------------------------------------------------------------*/
/*                                                                           */
/*          VisualInfo High Level Programming Interface Return Codes         */
/*          --------------------------------------------------------         */
/*    These are the possible internal return code values received from       */
/*    the VHLPI functions.  All APIs return an APIRET value.                 */
/*                                                                           */
/*---------------------------------------------------------------------------*/
#define SBVI_FAILED                900   /* General failure of VHLPI         */
#define SBVI_ILLEGAL_CLASSNAME     901   /* Supplied Class Name is illegal   */
#define SBVI_INVALID_PARAMS        902   /* Incorrect number of parameters   */
#define SBVI_TOO_MANY_PARAMS       903   /* Parameters too large for stack   */
#define SBVI_REXX_VAR_ERROR        904   /* Error trying to set REXX variable*/
#define SBVI_BAD_INDXCLS           905   /* NonExistent or Duplicate IxClass */
#define SBVI_BAD_ATTRIBUTE         906   /* NonExistent or Duplicate Attribs */
#define SBVI_BAD_ITEMID            907   /* Invalid ItemID, doesn't exist,   */
#define SBVI_BAD_FOLDER            908   /* Invalid FolderID or doesn't exist*/
#define SBVI_BAD_DOCUMENT          909   /* Invalid DocID or doesn't exist   */
#define SBVI_BAD_PARAM_VALUE       910   /* Parameter value invalid          */
#define SBVI_OPEN_FILE_ERROR       911   /* Open error with file             */
#define SBVI_READ_FILE_ERROR       912   /* Read error with file             */
#define SBVI_WRITE_FILE_ERROR      913   /* Write error with file            */
#define SBVI_BUFFER_OVERFLOW       914   /* Buffer too small to store data   */
#define SBVI_PM_ERROR              915   /* Presentation manager error       */
#define SBVI_MEMORY_ERROR          916   /* Couldn't allocate needed memory  */
#define SBVI_SEARCH_NO_MATCH       917   /* NO items found for search critera*/
#define SBVI_INVALID_REXX_VAR      918   /* Invalid Rexx variable name       */
#define SBVI_EMPTY_LIST            919   /* No items returned                */
#define SBVI_REQ_OUTPUT_TOO_BIG    920   /* Req output data exceeds SBM max  */
#define SBVI_UNSUPPORTED_CC        921   /* Unsupported content class        */
#define SBVI_ILLEGAL_FILENAME      922   /* Invalid file name                */
#define SBVI_ILLEGAL_CC            923   /* Invalid content class            */
#define SBVI_ITEM_CHECKEDOUT       924   /* Item/parent Folder is checked out*/
#define SBVI_BAD_SNAPSHOT          925   /* Bad snap shot info obtained      */
#define SBVI_ITEM_NOT_CHECKEDOUT   926   /* Item not yet checked-out         */
#define SBVI_UPDATE_NOT_ALLOWED    927   /* No update access allowed         */
#define SBVI_OPEN_NOTELOG_ERROR    928   /* Unable to open the NoteLog       */
#define SBVI_ZERO_BUFFER_SIZE      929   /* Invalid buffer size              */
#define SBVI_MAXFILEHANDLE_ERROR   930   /* Could not set Max. File Handles  */
#define SBVI_EMPTY_DOCUMENT        931   /* Document contains no pages       */
#define SBVI_INVALID_FLAG          932   /* Invalid flag not Y/N             */
#define SBVI_REQ_ATTR_MISSING      933   /* Required Attributes missing      */
#define SBVI_BAD_WORKBASKET        934   /* Invalid Work Basket or undefined */
#define SBVI_INVALID_CLASSNAME     935   /* Invalid Index Class Name         */
#define SBVI_NO_ATTRIBUTE_FOUND    936   /* No attributes found for Index Cls*/
#define SBVI_GET_ATTRIBUTE_FAILED  937   /* Could not get attribute info     */
#define SBVI_EMPTY_NOTELOG         938   /* NoteLog does not exist           */
#define SBVI_GET_TOC_FAILED        939   /* Could not get Table of Contents  */
#define SBVI_LOAD_WS_FAILED        940   /* Could not load a Working Set     */
#define SBVI_CREATE_THREAD_FAILED  941   /* Could not create a thread        */
#define SBVI_CREATE_DSP_FAILED     942   /* Could not create a IS/2 window   */
#define SBVI_CREATE_SEM_FAILED     943   /* Could not create a semaphore     */

/*---------------------------------------------------------------------------*/
/*                                                                           */
/*          VisualInfo High Level Programming Interface Event Codes          */
/*          -------------------------------------------------------          */
/*    These are the possible event code values used for logging various      */
/*    VisualInfo High Level Programming Interface calls or other results.    */
/*                                                                           */
/*---------------------------------------------------------------------------*/
#define SBVI_EV_START            31000   /* Module started                   */
#define SBVI_EV_STOP             31004   /* Module ended normally            */
#define SBVI_EV_ABORT            31005   /* Module abnormally end            */
#define SBVI_EV_CALL             31007   /* VisualInfo Api invoked           */
#define SBVI_EV_RETURN           31011   /* VisualInfo Api returned          */
#define SBVI_EV_MISC             31099   /* Miscellaneous event occurred     */

/*---------------------------------------------------------------------------*/
/*                                                                           */
/*          VisualInfo High Level Programming Interface Definitions          */
/*          -------------------------------------------------------          */
/*    These are the definitions used by the VHLPI modules.                   */
/*                                                                           */
/*---------------------------------------------------------------------------*/
#define SBVI_BROKER               "FRNOWFBK" /* SBVI Broker name (default)   */
#define SBVI_SERVICE              "FRNOWFSV" /* SBVI Service name (default)  */
#define SBVI_REXX                 "FRNOWFRX" /* SBVI Rexx Api DLL name       */
#define SBVI_INIFILE         "FRNOWFINIFILE" /* SBVI Path/Name of INI file   */
#define DEFAULT_INIFILE         "FRNOWF.INI" /* Default SBVI INI file        */
#define SBVI_TASK_TITLE           "FRNOWFSB" /* SBVI PM class and task name  */
#define SBM_SEND_BUFFER_SIZE           4096  /* SBVI Requester send buf size */
#define SBM_RECEIVE_BUFFER_SIZE       65536  /* SBVI Requester recv bufsize  */
#define SBVI_TIMEOUT                  30000  /* 30 sec timeout for SBM sends */
#define SBVI_BROKER_VER                 100  /* SBVI Broker version number   */
#define MAX_NUM_ATTRB                    50  /* Max Indx Attrs as Rexx params*/
#define MAX_CMD_PARAMS                  102  /* Max CmdLine Rexx parameters  */
#define MAX_LFT_IXCLASS                  10  /* ListFolderTOC max IxClasses  */
#define MIN_FILEHANDLE                   60  /* Min number of file handles   */
#define MAX_FILEHANDLE                  300  /* Max number of file handles   */
#define MAX_SEARCH_PSZ_LENGTH           256  /* Max length of adv search crit*/

/*---------------------------------------------------------------------------*/
/*                                                                           */
/*          VisualInfo High Level Programming Interface INI Variables        */
/*          ---------------------------------------------------------        */
/*    These are the Initialization variable names used by the VHLPI          */
/*    modules.  (Names NOT case sensitive)                                   */
/*                                                                           */
/*---------------------------------------------------------------------------*/
#define INI_DSPDOC_CLOSE   "DisplayDocClose" /* Flag to close Display at exit*/
#define INI_DSPDOC_UPDATE "DisplayDocUpdate" /* Flag if doc changes allowed  */
#define INI_DSPDOC_WAIT     "DisplayDocWait" /* Api wait (sec) before return */
#define INI_DSPDOC_XORG         "DspDocXOrg" /* DispDoc initial X org. of win*/
#define INI_DSPDOC_YORG         "DspDocYOrg" /* DispDoc initial Y org. of win*/
#define INI_DSPDOC_XVAL         "DspDocXVal" /* DispDoc initial Length of win*/
#define INI_DSPDOC_YVAL         "DspDocYVal" /* DispDoc initial Height of win*/
#define INI_EXTERN_MARKUP    "UseExtMarkups" /* Use External Markups for docs*/
#define INI_IS2_EXITDIR         "IS2ExitDir" /* Image Services User Exits dir*/
#define INI_IS2_WORKDIR         "IS2WorkDir" /* Image Services Working direct*/
#define INI_LIBNAME                "Library" /* VisualInfo Logon Library     */
#define INI_LOGGING                "Logging" /* ON/OFF switch for logging    */
#define INI_LOGPATH            "LogFilePath" /* Path of the Log file         */
#define INI_MAXFILEHANDLE    "MaxFileHandle" /* Max. number of file handles  */
#define INI_REQ_TIMEOUT         "ReqTimeout" /* Timeout for SBM Requests     */
#define INI_SBM                   "UsingSBM" /* ON/OFF for Service Broker Mgr*/
#define INI_SCAN_CC          "ScanContClass" /* Content Class for scanned doc*/
#define INI_USERDLL            "UserService" /* Name of User created Service */
#define INI_USERID                  "UserId" /* VisualInfo Logon UserId      */

/*---------------------------------------------------------------------------*/
/*                                                                           */
/*          VisualInfo High Level Programming Interface Structures           */
/*          ------------------------------------------------------           */
/*    These are the structure definitions used in the VHLPI calls.           */
/*                                                                           */
/*---------------------------------------------------------------------------*/
/*         Structure containing Integrator Session (Broker) data             */
/*---------------------------------------------------------------------------*/
typedef struct SessionDataStructure {
   USERDATASTRUCT   UserData;       /* VI Logon user data structure          */
   CHAR             szBroker[9];    /* SBM Broker name                       */
   PID              pidRequester;   /* Process ID of Requester task          */
}  SESSIONSTRUCT;
typedef SESSIONSTRUCT *PSESSIONSTRUCT;

/*---------------------------------------------------------------------------*/
/*         Structure containing Integrator Instance (Service) data           */
/*---------------------------------------------------------------------------*/
typedef struct InstanceDataStructure {
   CHAR             szService[9];   /* SBM Service name                      */
   CHAR             szBroker[9];    /* SBM Broker name                       */
}  INSTANCSTRUCT;
typedef INSTANCSTRUCT *PINSTANCSTRUCT;

/*---------------------------------------------------------------------------*/
/*         Structure for Class Attribute arrays                              */
/*---------------------------------------------------------------------------*/
typedef struct AttributePair {
   PSZ        pszAttrbName;         /* Pointer to Attribute Name             */
   PSZ        pszAttrbValue;        /* Pointer to Attribute Value            */
}  ATTRBPAIR;
typedef ATTRBPAIR *PATTRBPAIR;

/*---------------------------------------------------------------------------*/
/*         Structure for AdminItemNoteLog output data                        */
/*---------------------------------------------------------------------------*/
typedef struct _AdminItemNoteLogOut {
   ULONG      ulNoteSize;           /* NoteLog text size                     */
   CHAR       achNoteLogText[1];    /* actual NoteLog text                   */
}  ADMINITEMNOTELOGOUT;
typedef ADMINITEMNOTELOGOUT *PADMINITEMNOTELOGOUT;

/*---------------------------------------------------------------------------*/
/*         Structure for Item Id with attribute names and values             */
/*---------------------------------------------------------------------------*/
typedef struct ItemAttributes {
   ITEMID        pszItemID;         /* Item Id of item                       */
   USHORT        usNumAttrb;        /* Numb of attribute name/values in list */
   PATTRBPAIR    pAttrList;         /* Attribute name/value list             */
}  ITEMATTRB;
typedef ITEMATTRB *PITEMATTRB;

/*---------------------------------------------------------------------------*/
/*         Structure for Content Class Info output data                      */
/*---------------------------------------------------------------------------*/
typedef struct ListCCInfoData {
   CHAR          szName[9];                            /* Content Class name */
   CHAR          szDesc[41];                           /* Content Class desc */
   PVOID         pUserStruct;                          /* User-defined ptr   */
}  LISTCCINFODATA;
typedef LISTCCINFODATA *PLISTCCINFODATA;

/*---------------------------------------------------------------------------*/
/*         Structure for ListFolderTOC output data                           */
/*---------------------------------------------------------------------------*/
typedef struct ListFolderTOCOutData {
   ITEMID        szItemID;                                 /* Item ID        */
   USHORT        usItemType;                               /* Item Type      */
   CHAR          szClassName[SIM_CLASS_NAME_LENGTH+1];     /* Index Class    */
   PVOID         pUserStruct;                              /* User struct    */
}  LFOLDERTOCDATA;
typedef LFOLDERTOCDATA *PLFOLDERTOCDATA;

/*---------------------------------------------------------------------------*/
/*         Structure for Index Class Attribute output data                   */
/*---------------------------------------------------------------------------*/
typedef struct ListICAttrData {
   CHAR          szAttrName[SIM_ATTR_NAME_LENGTH+1];   /* Attribute name     */
   BOOL          fRequired;                            /* Required field  ?? */
   BOOL          fIndexKeyField;                       /* Index Key Field ?? */
   BITS          fIndexKeyUnique;                      /* Index Key Unique?? */
   BITS          fTypeFlags;                           /* Data type flags    */
   USHORT        usAttrType;                           /* Attribute type     */
   LONG          lMin;                                 /* Min values         */
   LONG          lMax;                                 /* Max values         */
   PVOID         pUserStruct;                          /* User-defined ptr   */
}  LISTICATTRDATA;
typedef LISTICATTRDATA *PLISTICATTRDATA;

/*---------------------------------------------------------------------------*/
/* Notes: Possible values for fTypeFlags, usAttrType, lMin and lMax are      */
/*        documented in:                                                     */
/*        "ImagePlus VisualInfo Application Programming Reference, Volume 3: */
/*        Common Data Structures and Database Tables"  page 10.              */
/*                                                                           */
/*        Be sure to include the header file "FRNPFI.H" in \frnv1r0\include  */
/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
/*         Structure for ListItemInfo output data                            */
/*---------------------------------------------------------------------------*/
typedef struct _ItemInfoStruct {
   ITEMID     szItemID;                            /* ItemID                 */
   USHORT     usItemType;                          /* Doc|Folder|Wbasket     */
   CHAR       szClassName[SIM_CLASS_NAME_LENGTH+1];/* Index class for search */
   USHORT     usNbrAttrIds;                        /* input # of ret items   */
   PATTRBPAIR pAttrList;                           /* ptr to Attr pair struct*/
   PVOID      pUserStruct;                         /* reserved for user      */
} SBVIITEMINFOSTRUCT;
typedef SBVIITEMINFOSTRUCT *PSBVIITEMINFOSTRUCT;

/*---------------------------------------------------------------------------*/
/*         Structure for ListFolderItemAttr output data                      */
/*---------------------------------------------------------------------------*/
typedef struct _ListFolderItemAttrData {
   USHORT             usNbrItemIDs;                 /* #ItemIDs in folder    */
   SBVIITEMINFOSTRUCT aItemInfoStruct[1];           /* ptr to ItemInfo       */
}  LISTFOLDERITEMATTRSTRUCT;
typedef LISTFOLDERITEMATTRSTRUCT *PLISTFOLDERITEMATTRSTRUCT;

/*---------------------------------------------------------------------------*/
/*         Structure for ListWorkBasket output data                          */
/*---------------------------------------------------------------------------*/
typedef struct ListWorkBasketOutData {
   ITEMID        szItemID;                               /* Item ID          */
   CHAR          szWBasketName[OIM_ITEMNAME_LENGTH+1];   /* WorkBasket name  */
   PVOID         pUserStruct;                            /* ptr- User struct */
}  LWBASKETDATA;
typedef LWBASKETDATA *PLWBASKETDATA;

/*---------------------------------------------------------------------------*/
/*                                                                           */
/*          VisualInfo High Level Programming Interface Prototypes           */
/*          ------------------------------------------------------           */
/*    These are the function prototypes used for the VHLPI utility           */
/*    functions. These utilities are accessable by ALL VHLPI functions.      */
/*                                                                           */
/*---------------------------------------------------------------------------*/
#define OpenLog                 OPENLOG
#define CloseLog                CLOSELOG
#define WriteLog                WRITELOG
#define StoreLog                STORELOG
#define ReadINI                 READINI
#define SearchINI               SEARCHINI
APIRET APIENTRY OpenLog( VOID );
APIRET APIENTRY CloseLog( VOID );
APIRET APIENTRY WriteLog(
                   RCSTRUCT       *pRCStruct, /* I VI return code structure  */
                   PSESSIONSTRUCT  pSession,  /* I Ptr to VHLPI session struc*/
                   PSZ             pszService,/* I SBM Service name          */
                   PSZ             pszProc,   /* I Calling procedure name    */
                   PSZ             pszParams);/* I Api parameters or descrip.*/
APIRET APIENTRY StoreLog(
                   LONG            lRC,       /* I Return code to Log        */
                   LONG            lRC2,      /* I Second Return code to Log */
                   USHORT          usEvent,   /* I VHLPI event code          */
                   PID             pidRequest,/* I Process ID of the appl.   */
                   PSZ             pszBroker, /* I VHLPI Broker name         */
                   PSZ             pszService,/* I VHLPI Service name        */
                   PSZ             pszUserId, /* I User ID logged onto VI    */
                   PSZ             pszProc,   /* I Calling procedure name    */
                   PSZ             pszApi,    /* I Called procedure name     */
                   PSZ             pszParams);/* I Api parameters or descrip.*/
APIRET APIENTRY ReadINI( VOID );
APIRET APIENTRY SearchINI(
                   PSZ          pszSearchItem,/* I Name of cnfg variable     */
                   PSZ         *ppszValue );  /* O Addr of pntr to INI info  */

/*---------------------------------------------------------------------------*/
/*                                                                           */
/*               Simulated Service Broker Manager Prototype                  */
/*               ------------------------------------------                  */
/*    This is the function prototype used to call User supplied service      */
/*    routines via the Simulated Service Broker Manager executeable.         */
/*                                                                           */
/*---------------------------------------------------------------------------*/
APIRET APIENTRY SbmCallService (
              PSZ              pBroker,      /* I Broker name                */
              PSZ              pService,     /* I Service name               */
              PSZ              pFunction,    /* I Function name              */
              PVOID            pInData,      /* I Input data buffer          */
              ULONG            InDataSize,   /* I Input buffer size          */
              PVOID            pOutData,     /* O Output data buffer         */
              PULONG           pOutDataSize, /*IO Output buffer size         */
              PLONG            pRC,          /* O Return code                */
              ULONG            TimeOut );    /* I Timeout (millisec)         */

/*---------------------------------------------------------------------------*/
/*                                                                           */
/*          VisualInfo High Level Programming Interface Prototypes           */
/*          ------------------------------------------------------           */
/*    These are the function prototypes used for the VHLPI calls.            */
/*    NOTE - VHLPI APIs are referenced as Mixed case or Upper case.          */
/*                                                                           */
/*---------------------------------------------------------------------------*/
#define VhlAddFolderItem              VHLADDFOLDERITEM
#define VhlAdminItemNoteLog           VHLADMINITEMNOTELOG
#define VhlChangeItemIndex            VHLCHANGEITEMINDEX
#define VhlCheckInItem                VHLCHECKINITEM
#define VhlCheckOutItem               VHLCHECKOUTITEM
#define VhlCloseDocViews              VHLCLOSEDOCVIEWS
#define VhlCopyDoc                    VHLCOPYDOC
#define VhlCreateFolder               VHLCREATEFOLDER
#define VhlCreateFolderAddItem        VHLCREATEFOLDERADDITEM
#define VhlDeleteItem                 VHLDELETEITEM
#define VhlDisplayDocView             VHLDISPLAYDOCVIEW
#define VhlDisplayVIItem              VHLDISPLAYVIITEM
#define VhlExportDocObj               VHLEXPORTDOCOBJ
#define VhlGetVIUserID                VHLGETVIUSERID
#define VhlImportDocObj               VHLIMPORTDOCOBJ
#define VhlListContClasses            VHLLISTCONTCLASSES
#define VhlListFolderItems            VHLLISTFOLDERITEMS
#define VhlListFolderItemsAttr        VHLLISTFOLDERITEMSATTR
#define VhlListFolderXrefItem         VHLLISTFOLDERXREFITEM
#define VhlListIndexClassAttr         VHLLISTINDEXCLASSATTR
#define VhlListIndexClasses           VHLLISTINDEXCLASSES
#define VhlListItemCC                 VHLLISTITEMCC
#define VhlListItemInfo               VHLLISTITEMINFO
#define VhlListWBItems                VHLLISTWBITEMS
#define VhlListWorkBaskets            VHLLISTWORKBASKETS
#define VhlRemoveFolderItem           VHLREMOVEFOLDERITEM
#define VhlScanDoc                    VHLSCANDOC
#define VhlSearchAdv                  VHLSEARCHADV
#define VhlSearchItem                 VHLSEARCHITEM

#define RxVhlLoadFuncs                RXVHLLOADFUNCS
#define RxVhlDropFuncs                RXVHLDROPFUNCS
#define RxGetProcessId                RXGETPROCESSID

#define RxVhlAddFolderItem            RXVHLADDFOLDERITEM
#define RxVhlAdminItemNoteLog         RXVHLADMINITEMNOTELOG
#define RxVhlChangeItemIndex          RXVHLCHANGEITEMINDEX
#define RxVhlCheckInItem              RXVHLCHECKINITEM
#define RxVhlCheckOutItem             RXVHLCHECKOUTITEM
#define RxVhlCloseDocViews            RXVHLCLOSEDOCVIEWS
#define RxVhlCopyDoc                  RXVHLCOPYDOC
#define RxVhlCreateFolder             RXVHLCREATEFOLDER
#define RxVhlCreateFolderAddItem      RXVHLCREATEFOLDERADDITEM
#define RxVhlDeleteItem               RXVHLDELETEITEM
#define RxVhlDisplayDocView           RXVHLDISPLAYDOCVIEW
#define RxVhlDisplayVIItem            RXVHLDISPLAYVIITEM
#define RxVhlExportDocObj             RXVHLEXPORTDOCOBJ
#define RxVhlGetVIUserID              RXVHLGETVIUSERID
#define RxVhlImportDocObj             RXVHLIMPORTDOCOBJ
#define RxVhlListContClasses          RXVHLLISTCONTCLASSES
#define RxVhlListFolderItems          RXVHLLISTFOLDERITEMS
#define RxVhlListFolderItemsAttr      RXVHLLISTFOLDERITEMSATTR
#define RxVhlListFolderXrefItem       RXVHLLISTFOLDERXREFITEM
#define RxVhlListIndexClassAttr       RXVHLLISTINDEXCLASSATTR
#define RxVhlListIndexClasses         RXVHLLISTINDEXCLASSES
#define RxVhlListItemCC               RXVHLLISTITEMCC
#define RxVhlListItemInfo             RXVHLLISTITEMINFO
#define RxVhlListWBItems              RXVHLLISTWBITEMS
#define RxVhlListWorkBaskets          RXVHLLISTWORKBASKETS
#define RxVhlRemoveFolderItem         RXVHLREMOVEFOLDERITEM
#define RxVhlScanDoc                  RXVHLSCANDOC
#define RxVhlSearchAdv                RXVHLSEARCHADV
#define RxVhlSearchItem               RXVHLSEARCHITEM

LONG APIENTRY VhlAddFolderItem(
              PITEMID          pszitemid,         /* I Item Id to add to folder       */
              PITEMID          pFolderID);        /* I Item Id of folder              */

LONG APIENTRY VhlAdminItemNoteLog(
              PITEMID          pItemID,           /* I Item Id containing the Note Log*/
              PSZ              pFuncInd,          /* I Function to perform (add, etc,)*/
              PPVOID           ppShrMem,          /* I ptr to Shared Mem              */
              PSZ              pszFileName);      /* I filename name                  */

LONG APIENTRY VhlChangeItemIndex(
              PITEMID          pszitemid,         /* I Item Id to change              */
              PSZ              pszClassName,      /* I Index Class name               */
              USHORT           usNumAttrb,        /* I Num of attrib pairs            */
              PATTRBPAIR       pAttrList);        /* I Attrib pair array              */

LONG APIENTRY VhlCheckInItem(
              PITEMID          pItemID,           /* I ItemID to be checked-in        */
              PSZ              pUserID);          /* O UserID who checked out Item    */

LONG APIENTRY VhlCheckOutItem(
              PITEMID          pItemID,           /* I ItemID to be checked-out       */
              PSZ              pUserID);          /* O UserID who checked out Item    */

LONG APIENTRY VhlCloseDocViews( VOID );

LONG APIENTRY VhlCopyDoc(
              PITEMID          pszItemID,         /* I Orginal Item Id                */
              PSZ              pszClassName,      /* I Index Class name               */
              USHORT           usNumAttrb,        /* I Num of attrib pairs            */
              PATTRBPAIR       pAttrList,         /* I Attrib pair array              */
              PITEMID          pItemID);          /* O ID of created document         */

LONG APIENTRY VhlCreateFolder(
              PSZ              pszClassName,      /* I Index Class name               */
              USHORT           usNumAttrb,        /* I Num of attrib pairs            */
              PATTRBPAIR       pAttrList,         /* I Attrib pair array              */
              PITEMID          pFolderID);        /* O ID of created folder           */

LONG APIENTRY VhlCreateFolderAddItem(
              PSZ              pszClassName,      /* I Folder Index Class name        */
              USHORT           usNumAttrb,        /* I Num of Class attrib pairs      */
              PATTRBPAIR       pAttrList,         /* I Class attrib pair array        */
              PITEMID          pItemID,           /* I Item Id to add to folder       */
              PITEMID          pFolderID);        /* O Created folder ID name         */

LONG APIENTRY VhlDeleteItem(
              PITEMID          pItemID);          /* I Item Id to be deleted          */

LONG APIENTRY VhlDisplayDocView(
              PITEMID          pItemID,           /* I Document ID for display        */
              PSIMPOSSIZE      pWndPosSize);      /* I Initial window position        */

LONG APIENTRY VhlDisplayVIItem(
              PITEMID          pItemID,           /* I Item ID for display            */
              BOOL             fUpdateFlg,        /* I Update flag TRUE/FALSE         */
              USHORT           usView,            /* I View window control            */
              USHORT           usNote,            /* I Note window control            */
              USHORT           usIndex);          /* I Indx window control            */

LONG APIENTRY VhlExportDocObj(
              PITEMID          pszItemID,         /* I Document Item ID               */
              PSZ              pszFileName,       /* I Export file name               */
              PSZ              pszContClass);     /* I Content class name             */

PSZ  APIENTRY VhlGetVIUserID(
              PSZ              pUserID);          /* I VI logged-on UserID            */

LONG APIENTRY VhlImportDocObj(
              PSZ              pszFileName,       /* I File Name                      */
              PSZ              pszContClass,      /* I Content class name             */
              PSZ              pszClassName,      /* I Class Index name               */
              USHORT           usNumAttrb,        /* I Num of attrib pairs            */
              PATTRBPAIR       pAttrList,         /* I Attrib pair array              */
              PITEMID          pItemID);          /* O ID of created document         */

LONG APIENTRY VhlListContClasses(
              PUSHORT          pusNumItems,       /* IO Ptr number/size List          */
              PLISTCCINFODATA  pListCCInfoData);  /* O CClass Info data               */

LONG APIENTRY VhlListFolderItems(
              PITEMID          pszFolderID,       /* I Item Id of folder              */
              USHORT           usNumClass,        /* I # of IndexClasses              */
              PSZ              pszClassName,      /* I ptr -IndexClasses              */
              PUSHORT          pusNumItems,       /*IO Ptr size/number ItemList       */
              PLFOLDERTOCDATA  pItemList);        /* O ItemID list buffer             */

LONG APIENTRY VhlListFolderItemsAttr(
              PITEMID          pItemID,           /* I Item Id of folder              */
              PPVOID           ppShrMem);         /* O pItemInfo list buffer          */

LONG APIENTRY VhlListFolderXrefItem(
              PITEMID          pszItemID,         /* I ItemID to list XREF            */
              PUSHORT          pusNumFolders,     /*IO Ptr size/number Folders        */
              PITEMID          pFolderList);      /* O FolderID list return buffer    */

LONG APIENTRY VhlListIndexClassAttr(
              PSZ              pszClassName,      /* I Ptr to Index Class name        */
              PUSHORT          pusNumItems,       /* IO Ptr number/size List          */
              PLISTICATTRDATA  pListICAttrData);  /* O CClass Info data               */

LONG APIENTRY VhlListIndexClasses(
              PULONG           pulNumSize,        /*IO Ptr to size IxClass            */
              PSZ              pIxClassList);     /* O IxClass list ret buffer        */

LONG APIENTRY VhlListItemCC(
              PITEMID          pItemID,           /* I Item Id                        */
              PSZ              pContClass);       /* O ptr to item's Content Class    */

LONG APIENTRY VhlListItemInfo(
              PITEMID          pItemID,           /* I Item Id                        */
              PPVOID           ppShrMem);         /* O ItemInfo shrmemory address     */

LONG APIENTRY VhlListWBItems(
              PSZ              pszWorkBasket,     /* I Ptr-WorkBasket name            */
              PUSHORT          pusNumItems,       /*IO ptr to number/size of buffer   */
              PITEMID          pItemList);        /* O ItemID list buffer             */

LONG APIENTRY VhlListWorkBaskets(
              PUSHORT          pusNumWkBasket,    /*IO Ptr no. WorkBaskets            */
              PLWBASKETDATA    pWkBasketList);    /* O WorkBasket list array          */

LONG APIENTRY VhlRemoveFolderItem(
              PITEMID          pItemID,           /* I Item Id to be removed          */
              PITEMID          pFolderID);        /* I FolderID removed from          */

LONG APIENTRY VhlScanDoc(
              PSZ              pszClassName,      /* I Index Class name               */
              USHORT           usNumAttrb,        /* I Num of attrib pairs            */
              PATTRBPAIR       pAttrList,         /* I Attrib pair array              */
              PUSHORT          pusNumItems,       /*IO Ptr size/number ItemList       */
              PITEMID          pItemList);        /* O ItemID list buffer             */

LONG APIENTRY VhlSearchAdv(
              PSZ              pszClassName,      /* I Index Class name               */
              PSZ              pszCriteria,       /* I Search Criteria                */
              USHORT           usSQLType,         /* I SQL type                       */
              USHORT           usType,            /* I Type filter                    */
              USHORT           usWipType,         /* I WorkInProgress filter          */
              USHORT           usSuspend,         /* I Suspend filter                 */
              PSZ              pszFolderIndex,    /* I Folder Index Class name        */
              PUSHORT          pusNumItems,       /*IO Ptr size/number ItemList       */
              PITEMID          pItemList );       /* O ItemID list buffer             */

LONG APIENTRY VhlSearchItem(
              PSZ              pszClassName,      /* I Index Class name               */
              USHORT           usNumAttrb,        /* I Num of attrib pairs            */
              PATTRBPAIR       pAttrSpec,         /* I Attrib pair array              */
              PUSHORT          pusNumItems,       /*IO Ptr size/number ItemList       */
              PITEMID          pItemList);        /* O ItemID list buffer             */

RexxFunctionHandler RxVhlLoadFuncs;
RexxFunctionHandler RxVhlDropFuncs;
RexxFunctionHandler RxGetProcessId;

RexxFunctionHandler RxVhlAddFolderItem;
RexxFunctionHandler RxVhlAdminItemNoteLog;
RexxFunctionHandler RxVhlChangeItemIndex;
RexxFunctionHandler RxVhlCheckInItem;
RexxFunctionHandler RxVhlCheckOutItem;
RexxFunctionHandler RxVhlCloseDocViews;
RexxFunctionHandler RxVhlCopyDoc;
RexxFunctionHandler RxVhlCreateFolder;
RexxFunctionHandler RxVhlCreateFolderAddItem;
RexxFunctionHandler RxVhlDeleteItem;
RexxFunctionHandler RxVhlDisplayDocView;
RexxFunctionHandler RxVhlDisplayVIItem;
RexxFunctionHandler RxVhlExportDocObj;
RexxFunctionHandler RxVhlGetVIUserID;
RexxFunctionHandler RxVhlImportDocObj;
RexxFunctionHandler RxVhlListContClasses;
RexxFunctionHandler RxVhlListFolderItems;
RexxFunctionHandler RxVhlListFolderItemsAttr;
RexxFunctionHandler RxVhlListFolderXrefItem;
RexxFunctionHandler RxVhlListIndexClassAttr;
RexxFunctionHandler RxVhlListIndexClasses;
RexxFunctionHandler RxVhlListItemCC;
RexxFunctionHandler RxVhlListItemInfo;
RexxFunctionHandler RxVhlListWBItems;
RexxFunctionHandler RxVhlListWorkBaskets;
RexxFunctionHandler RxVhlRemoveFolderItem;
RexxFunctionHandler RxVhlScanDoc;
RexxFunctionHandler RxVhlSearchAdv;
RexxFunctionHandler RxVhlSearchItem;

#pragma pack()
#endif
