/*BEGINPROLOGUE***************************************************/
/*                                                               */
/* MODULE: FRNPCAPI.H                                            */
/*                                                               */
/* COPYRIGHT:                                                    */
/* ----------                                                    */
/* Digital Library Version 1 - 5648-A08.                         */
/* VisualInfo Version 2 Release 2.0 - 5697-250.                  */
/* (C) Copyright IBM Corp., 1994, 1996.  All Rights Reserved     */
/*                                                               */
/* US Government Users Restricted Rights                         */
/* Use, duplication or disclosure restricted by GSA ADP Schedule */
/* Contract with IBM Corp.  Licensed Materials - Property of IBM */
/*                                                               */
/* Description: FRNPCAPI.H - structures and constant defs for    */
/*                           common ImagePlus APIs               */
/*                                                               */
/* Dependencies: USHORT and other standard types must be         */
/*               defined                                         */
/* Restrictions:                                                 */
/*                                                               */
/* Notes:                                                        */
/*  Convention for return codes                                  */
/*    0 = standard success value                                 */
/*    1-999 = reserved                                           */
/*    1000-1999 = CPI information codes                          */
/*    2000-2999 = Product specific information codes             */
/*    3000-3999 = CPI warning codes                              */
/*    4000-4999 = Product specific warning codes                 */
/*    5000-6499 = CPI error codes                                */
/*    6500-9999 = Product specific error codes                   */
/*  Within the range above, the values are:                      */
/*    1000-1299 = common/shared CPI information codes            */
/*    3000-3299 = common/shared CPI warning codes                */
/*    5000-5999 = common/shared CPI error codes                  */
/*                                                               */
/*ENDPROLOGUE*****************************************************/

#ifndef FRNPCAPI_DEFINED
#define FRNPCAPI_DEFINED

/* The following is to support C++ compilers */

#ifdef __cplusplus
   extern "C" {
#endif

#ifndef IWPM_TOO
typedef ULONG HERR;
typedef ULONG BITS;       /* one or more boolean values */
#endif

#ifndef CICS_ENV
#ifndef FRNPCAPI_NOPPSZ
#define FRNPCAPI_NOPPSZ 1 /* indicate PPSZ defined */
typedef PSZ *PPSZ;        /* some APIs may need this type */
#endif

#ifndef FRNPCAPI_NOPULONG
#ifndef __BSEDOS__
#define FRNPCAPI_NOPULONG 1 /* indicate PULONG defined */
typedef ULONG *PULONG;
#endif
#endif

#ifndef FRNPCAPI_NOPPULONG
#define FRNPCAPI_NOPPULONG 1 /* indicate PPULONG defined   */
typedef PULONG *PPULONG;   /* some APIs may need this type */
#endif
#endif

/* If the target compiler is not IBM C-Set/2 or Borland, then */
/* define SIMENTRY prior to the include of this header file.  */
/* The target compiler must provide a linkage convention      */
/* equivalent to the C-Set/2 "_System" selection.             */

#ifndef SIMENTRY
   #ifdef __IBMC__
      #define SIMENTRY _System
   #endif
   #ifdef __IBMCPP__
      #define SIMENTRY _System
   #endif
   #ifdef __BORLANDC__
      #define SIMENTRY _syscall
   #endif
#endif

/* define FRNPCAPI_NOSTRUCT to prevent definition of structures */

#ifndef FRNPCAPI_NOSTRUCT
#ifndef IWPM_TOO
typedef struct _RCSTRUCT
  {
   ULONG  ulStruct;        /* size of this data structure       */
   ULONG  ulRC;            /* final completion return code      */
   USHORT usReserved;      /* short parameter (reserved)        */
   USHORT usParam;         /* short parameter                   */
   ULONG  ulParam1;        /* long parameter or pointer         */
   ULONG  ulParam2;        /* long parameter or pointer         */
   ULONG  ulExtRC;         /* external/secondary return code    */
   ULONG  ulExtReason;     /* external/secondary reason code    */
   PVOID  pApplData;       /* for app use, wrapped back         */
   ULONG  ulApplData;      /* for app use, wrapped back         */
   ULONG  ulReserved;      /* reserved for future use           */
   HERR   hErrLog;         /* handle to logged error chain      */
  } RCSTRUCT;
typedef RCSTRUCT *PRCSTRUCT;
#endif

typedef struct _ASYNCCTLSTRUCT
  {
   ULONG  ulStruct;        /* size of this data structure       */
   BITS   fOptions;        /* see SIM_OPT_ flags                */
   PVOID  hSync;           /* optional: window handle for msg   */
                           /*  or semaphore                     */
   ULONG  ulMsgId;         /* ID of message to post             */
   ULONG  ulMsgparm1;      /* optional message parameter        */
   ULONG  ulMsgparm2;      /* optional message parameter        */
  } ASYNCCTLSTRUCT;
  typedef ASYNCCTLSTRUCT *PASYNCCTLSTRUCT;
#endif  /* end of FRNPCAPI_NOSTRUCT test */

/* constants for ASYNCCTLSTRUCT.fOptions */

#define SIM_OPT_SYNC   1   /* call synchronously */
#define SIM_OPT_ASYNC  2   /* call asynchronously */
#define SIM_OPT_MSG    4   /* use window message */
#define SIM_OPT_SEM    8   /* use semaphore      */

/* RETURN CODES */

#define SIM_RC_OK 0  /* success */

/* informational codes */

#define SIM_RC_ASYNC_STARTED       1001
#define SIM_RC_FUNCTION_TERMINATED 1002
#define SIM_RC_RECOVERY_STARTED    1003
#define SIM_RC_RECOVERY_COMPLETED  1004

/* warning codes       */

#define SIM_RC_DLL_NOT_INIT        3001
#define SIM_RC_PRC_INVALID         3002   /* NULL or invalid pointer */
#define SIM_RC_PASYNC_INVALID      3003   /* NULL or invalid pointer */
#define SIM_RC_NO_ASYNC_SUPPORT    3004   /* API does not support async */
#define SIM_RC_OPTIONS_INVALID     3005   /* options flag is invalid */
#define SIM_RC_USERID_INVALID      3010   /* userid: invalid syntax or data */
#define SIM_RC_USERID_UNKNOWN      3011   /* userid not found (unknown user)*/
#define SIM_RC_PASSWORD_INVALID    3012   /* password: invalid syntax/data  */
#define SIM_RC_PASSWORD_WRONG      3013   /* password is incorrect   */
#define SIM_RC_NOT_LOGGED_ON       3014   /* logon required first    */
#define SIM_RC_NOT_AUTHORIZED      3015   /* access control rejected request*/
#define SIM_RC_ALREADY_LOGGED_ON   3016
#define SIM_RC_HANDLE_INVALID      3020   /* NULL or invalid handle  */
#define SIM_RC_WINDOW_HANDLE_INVALID 3021 /* specifically a window handle  */
#define SIM_RC_INUSE               3022   /* object checked out or in use  */
#define SIM_RC_BUSY                3023   /* function or device is busy    */
#define SIM_RC_NOT_SUPPORTED       3024   /* function not supported        */
#define SIM_RC_NOT_OPEN            3025   /* object not open               */
#define SIM_RC_NOT_FOUND           3026   /* search failed                 */
#define SIM_RC_PRIORITY_INVALID    3027   /* priority specified is invalid */
#define SIM_RC_READ_ONLY           3028   /* read-only, no write access    */
#define SIM_RC_DELETE_PENDING      3029   /* marked deleted                */
#define SIM_RC_TIMEOUT             3030   /* operation timed-out           */
#define SIM_RC_PASSWORD_EXPIRED    3031   /* password expired              */

#define SIM_RC_COUNT_ZERO          3040    /* count cannot be zero         */
#define SIM_RC_COUNT_TOOLOW        3041    /* count lower than minimum     */
#define SIM_RC_COUNT_TOOHIGH       3042    /* count exceeds maximum        */

#define SIM_RC_BUFFER_NULL         3050   /* buffer pointer cannot be NULL */
#define SIM_RC_BUFSIZE_ZERO        3051   /* buffer size cannot be zero    */
#define SIM_RC_BUFSIZE_TOOLOW      3052   /* buffer size < minimum         */
#define SIM_RC_BUFSIZE_TOOHIGH     3053   /* buffer size > maximum         */

#define SIM_RC_CC_INVALID          3060   /* unrecognized content class    */
#define SIM_RC_CC_NOT_SUPPORTED    3061   /* class not yet supported       */

#define SIM_RC_FILENAME_INVALID    3070   /* filename is invalid format    */
#define SIM_RC_FILENAME_NULL       3071   /* no filename provided          */
#define SIM_RC_FILE_NOT_FOUND      3072   /* filename could not be found   */

#define SIM_RC_DEVICE_UNAVAILABLE  3080   /* device is not available for use*/
#define SIM_RC_DEVICE_DLL_NOTFOUND 3081   /* could not find device support */

/* error codes         */

#define SIM_RC_OUT_OF_MEMORY       5001
#define SIM_RC_DEADLOCK            5002
#define SIM_RC_NETWORK_FAILURE     5003   /* for connection to server  */
#define SIM_RC_DEVICE_FAILURE      5004
#define SIM_RC_EXTERNAL_ERROR      5010   /* replaces platform error   */
#define SIM_RC_DLL_NOTFOUND        5011
#define SIM_RC_PGM_NOTFOUND        5012
#define SIM_RC_RECOVERY_FAILED     5013
#define SIM_RC_CONNECTION_LIMIT    5014
#define SIM_RC_INIT_FAILED         5015
#define SIM_RC_THREAD_LIMIT        5016
#define SIM_RC_SEMAPHORE_LIMIT     5017

/* CONTENT CLASS VALUES */

/* Values from 0-4095 are reserved for IBM definition */
/* Values from 4096-32767 are for application use.    */
/* Even though the content class is a ULONG data type, the  */
/* ..range goes only from 0-32767.                          */

/* IBM "OCA" and TIFF codes */
#define SIM_CC_UNKNOWN        0  /* Content class unknown */
#define SIM_CC_MODCA_IS2      1  /* MODCA-P document (IS/2) */
#define SIM_CC_TIFF5          2  /* TIFF V5, multi-page allowed */
#define SIM_CC_MODCA_PAGE     3  /* *** unused *** */
#define SIM_CC_IOCA_FS11      4  /* IOCA data only (FS11) */
#define SIM_CC_IOCA_TILED     5  /* tiled IOCA only */
#define SIM_CC_GOCA           6  /* GOCA data only  */
#define SIM_CC_AOCA           7  /* AOCA data only  */
#define SIM_CC_BCOCA          8  /* BCOCA data only  */
#define SIM_CC_TIFF5_PAGE    11  /* TIFF V5, single page  */
#define SIM_CC_TIFF6         12  /* TIFF V6, multi-page   */
#define SIM_CC_TIFF6_PAGE    13  /* TIFF V6, single page  */
#define SIM_CC_TIFF_SINGLE_STRIP  14  /* raster in a single strip */
#define SIM_CC_MODCA_FORM    15  /* MODCA-P form overlay */
#define SIM_CC_MODCA_L       16  /* MODCA-L document     */
#define SIM_CC_MODCA_SINGLE_IMAGE 17 /*single image-page MODCA document */
#define SIM_CC_IOCA_IRM      30  /* IRM version of IOCA, non-standard */
#define SIM_CC_TIFF_IRM      31  /* IRM version of TIFF, single-page  */

#define SIM_CC_ASCII         40  /* flat ascii text               */
#define SIM_CC_EBCDIC        41  /* flat EBCDIC text              */
#define SIM_CC_BINARY        42  /* unformatted binary data       */
#define SIM_CC_TEXT          43  /* text, where code page, etc. is*/
                                 /* ..determined by auxiliary     */
                                 /* ..information stored elsewhere*/
#define SIM_CC_PPDS          44  /* printer data stream (text)    */
#define SIM_CC_MGDS          45  /* IBM MGDS format for forms and */
                                 /* ..field data                  */

/* fax formats */

#define SIM_CC_TIFF_G3_STANDARD  50  /* standard fax, TIFF header */
#define SIM_CC_TIFF_G3_FINE  51  /* higher resolution fax         */
                                 /* standard: approx 100 dpi      */
                                 /* fine: approx 200 dpi          */
/* * * MORE FAX CATEGORIES MAY BE DEFINED * * */

/* bitmaps */

#define SIM_CC_OS2V2_BMP     70  /* OS/2 2.0 bitmap               */
#define SIM_CC_OS2V13_BMP    71  /* OS/2 1.3 bitmap               */
#define SIM_CC_OS2V12_BMP    72  /* OS/2 1.2 bitmap               */
#define SIM_CC_WINV3_BMP     73  /* MS Windows V3 bitmap          */

/* command files/programs */

#define SIM_CC_OS2EXE        90  /* executable program (OS/2)     */
#define SIM_CC_OS2CMD        91  /* command file (OS/2)           */
#define SIM_CC_OS2DLL        92  /* DLL (OS/2)                    */
#define SIM_CC_AIXEXE        93  /* executable program (AIX)      */
#define SIM_CC_AIXCMD        94  /* command file (AIX)            */

/* spreadsheets */

#define SIM_CC_WKS          120  /* standard 1-2-3 spreadsheet    */
#define SIM_CC_WG1          121  /* graphics, from 1-2-3/G        */
#define SIM_CC_EXCEL        122  /* Microsoft Excel               */
#define SIM_CC_QUATTRO      124  /* Quattro Pro spreadsheet       */

/* word processing formats */

#define SIM_CC_WP           150  /* WordPerfect format            */
#define SIM_CC_WORD         151  /* Microsoft Word format         */
#define SIM_CC_PRS          152  /* Freelance presentation        */
#define SIM_CC_DESCRIBE     153  /* DeScribe text editor          */
#define SIM_CC_PFS          154  /* PFS:First Choice              */
#define SIM_CC_MULTIMATE    155  /* Multimate, Multimate Advantage*/
#define SIM_CC_VKS          156  /* Volkswriter                   */
#define SIM_CC_IBMWA        157  /* Writing Assistant             */
#define SIM_CC_TOTALWORD    158  /* Total Word                    */
#define SIM_CC_WORDSTAR     159  /* WordStar DOS or Windows       */
#define SIM_CC_DWRITE       160  /* DisplayWrite                  */
#define SIM_CC_OFSWRITE     161  /* OfficeWriter                  */
#define SIM_CC_XYWRITE      162  /* XyWrite III, IIIPlus, IV,     */
                                 /* XyWrite for Windows           */
#define SIM_CC_RICHTEXT     163  /* Microsoft Rich Text           */
#define SIM_CC_ADVWRITE     164  /* HP AdvanceWrite Plus          */
#define SIM_CC_QAWRITE      165  /* QA Write                      */
#define SIM_CC_MSCRIPT      166  /* Lotus Manuscript              */
#define SIM_CC_RFILE        167  /* Rapid File                    */
#define SIM_CC_WANGPC       168  /* Wang PC                       */
#define SIM_CC_PEACH        169  /* PeachText 5000                */
#define SIM_CC_ENABLE       170  /* Enable                        */
#define SIM_CC_FWORK        171  /* Framework III, IV             */
#define SIM_CC_DIGITAL      172  /* Digital DX, WPS-Plus          */
#define SIM_CC_MASS         173  /* MASS 11                       */
#define SIM_CC_IBMFFT       174  /* DCA - Final Form text         */
#define SIM_CC_AMIPRO       175  /* AmiPro                        */
#define SIM_CC_INTER        176  /* Interleaf Publisher           */
#define SIM_CC_LEGACY       177  /* Legacy                        */
#define SIM_CC_UNIPLEX      178  /* Uniplex OnGo                  */
#define SIM_CC_FRAMEMAK     179  /* FrameMaker                    */
#define SIM_CC_WINWRITE     180  /* Windows Write                 */
#define SIM_CC_MACW         181  /* MacWrite, MacWrite II         */
#define SIM_CC_WRITENOW     182  /* WriteNow                      */
#define SIM_CC_PWRITE       183  /* Professional Write            */

/* image formats or composite formats or audio/video */

#define SIM_CC_PCX          200  /* PC Paintbrush File Format     */
#define SIM_CC_RFT          201  /* IBM RFT:DCA revisable         */
#define SIM_CC_TARGA        202  /* Targa image                   */
#define SIM_CC_WAV          203  /* WAV sound files               */
#define SIM_CC_MIDI         204  /* MIDI sound files              */
#define SIM_CC_AVI          205  /* AVI movies                    */
#define SIM_CC_GIF          206  /* Graphics Interchange Format   */
#define SIM_CC_JPG          207  /* JPEG File Interchange Format  */
                                 /* (JFIF)                        */
#define SIM_CC_KODAK_PCD    208  /* Kodak Photo CD image          */
#define SIM_CC_IBMVSS       209  /* IBM video stream server       */
                                 /* ..external object             */

/* others */
#define SIM_CC_POSTSCRIPT   300  /* postscript data               */
#define SIM_CC_BKMGR_READ   301  /* BookManager read format       */
#define SIM_CC_EPS          302  /* encapsulated postscript       */
#define SIM_CC_AFP          303  /* IBM advanced function print   */
                                 /* datastream (example: LIST3820)*/
#define SIM_CC_DCX          304  /* DCX - multi-page PCX          */
#define SIM_CC_MPEG         305  /* MPEG document                 */


/* ImagePlus application-specific data types */

#define SIM_CC_FRN_NOTE     400  /* application note log          */
#define SIM_CC_FRN_HISTORY  401  /* application history log       */

#define SIM_CC_USER  4096  /* start custom user/appl formats here */

/*
 * end support for C++
 */
#ifdef __cplusplus
   }
#endif

#endif  /* ifndef FRNPCAPI_DEFINED */
