/*BEGINPROLOGUE***************************************************/
/*                                                               */
/* MODULE: frnpfi.h                                              */
/*                                                               */
/*                                                               */
/* COPYRIGHT:                                                    */
/* ----------                                                    */
/* Digital Library Version 1 - 5648-A08.                         */
/* VisualInfo Version 2 Release 2.0 - 5697-250.                  */
/* (C) Copyright IBM Corp., 1994, 1996.  All Rights Reserved     */
/*                                                               */
/* US Government Users Restricted Rights                         */
/* Use, duplication or disclosure restricted by GSA ADP Schedule */
/* Contract with IBM Corp.  Licensed Materials - Property of IBM */
/*                                                               */
/*                                                               */
/* Description: frnpfi.h   - this include is used by programs    */
/*                           calling the Object Index Mgr APIs   */
/*                           for SimLib functions and            */
/*                           data structures                     */
/*                                                               */
/* Dependencies:                                                 */
/* Restrictions:                                                 */
/*                                                               */
/*                                                               */
/* Notes:                                                        */
/*                                                               */
/* Change History:                                               */
/*        01/22/97 - MW,  added #define for SM and GTR Search    */
/*                        engines.                               */
/*        09/08/95 - TSL, added SimLibLogoffPatron.              */
/*        07/01/96 - MW,  added SimLibCreateItemPartExtSrch,     */
/*                   SimLibDeletePartExtSrch,                    */
/*                   SimLibReplacePartExtSrch.                   */
/*                                                               */
/*ENDPROLOGUE*****************************************************/


#ifndef FRNPFI
#define FRNPFI 1

#ifdef __cplusplus
     extern "C" {
#endif

/*
 * Common definitions
 */

#include "frnplcli.h"

//
// structure packing
//
#pragma pack(1)

/*
 * defines for Startup/Shutdown Session Services
 */
#define SIM_SS_NORMAL                        2
#define SIM_SS_CONFIG                        1  // for admin, disables
                                                // ..most caching
#define SIM_OPT_SAVE                         0  /* see "close" */
#define SIM_OPT_DISCARD                      1


/* The next constants are the semantic type for an item,
 * ..or the affiliated type for an object/part.
 * Individual constants that are valid for some APIs, like
 * .."create item" are not valid on others.
 * Any item semantic type that is an odd number is treated as
 * ..a document item. Also avoid setting the '2' bit (folder)
 * ..on any new types.
 */
#define SIM_DOCUMENT                    0x0001
#define SIM_FOLDER                      0x0002
#define SIM_WORKBASKET                  0x0004
#define SIM_ANNOTATION                  0x0008
#define SIM_HISTORY                     0x0010
#define SIM_EVENT                       0x0010  // Same as history
#define SIM_WORKFLOW                    0x0020
#define SIM_NOTE                        0x0040
#define SIM_BASE                        0x0080  /* normal object */
#define SIM_ALL                         0x0100
#define SIM_ACL_ITEM                    0X0200
#define SIM_FOLDER_DOC                  0X0400
#define SIM_MGDS                        0X0800

#define SIM_ACTION_ALL                       1
#define SIM_ACTION_SELECTED                  2

#define SIM_XREF_ALL_FILTER                  1
#define SIM_XREF_FOLDERS_ONLY_FILTER         2
#define SIM_XREF_WB_ONLY_FILTER              3

/*
 * Defines for search
 */
#define SIM_SEARCH_BUILD_ONLY                0
#define SIM_SEARCH_STATIC                    1
#define SIM_SEARCH_DYNAMIC                   2
#define SIM_SEARCH_STATIC_ONLY               3

#define SIM_SEARCH_VIEW                      0
#define SIM_SEARCH_ALLVIEWS                  1

#define SIM_SEARCH_MAKE_FOLDER               0
#define SIM_SEARCH_MEMLIST                   1
#define SIM_SEARCH_MEMLIST_ONE               2
// DCR 173 - TGB - 5.16.95
#define SIM_SEARCH_USER_ATTR                 3
#define SIM_SEARCH_USER_SYSTEM_ATTR          4
// END 173

#define SIM_SYSTEM_ATTR                      1
#define SIM_USER_ATTR                        2
#define SIM_WORK_ATTR                        4

#define SIM_ACCESS_SHARED_READ               0
#define SIM_ACCESS_EXCL_READ                 1
#define SIM_ACCESS_READ_WRITE                2
#define SIM_ACCESS_UNKNOWN                   3

/*
 * System defined Index Class Definitions and their attributes
 */

#define SIM_INDEX_INDEX_CLASSES              4
#define SIM_INDEX_VIEWS                      5
#define SIM_INDEX_NOINDEX                    6
#define SIM_INDEX_SEARCH                     7
#define SIM_INDEX_ATTR_ICID                12    /* index class AVT 12-32 */
#define SIM_INDEX_ATTR_ICDOCOBJSVR         13
#define SIM_INDEX_ATTR_ICDOCCOL            14
#define SIM_INDEX_ATTR_ICNOTEOBJSVR        15
#define SIM_INDEX_ATTR_ICNOTEOBJCOL        16
#define SIM_INDEX_ATTR_ICEVENTOBJSVR       17
#define SIM_INDEX_ATTR_ICEVENTOBJCOL       18
#define SIM_INDEX_ATTR_ICWFPRIORITY        19
#define SIM_INDEX_ATTR_ICWFENABLE          20
#define SIM_INDEX_ATTR_ICWFNAME            21
#define SIM_INDEX_ATTR_ICFOLDERENABLE      22
#define SIM_INDEX_ATTR_ICFOLDERATTR        23
#define SIM_INDEX_ATTR_ICFOLDERCLASS       24
#define SIM_INDEX_ATTR_ICSAVEFCN           25
#define SIM_INDEX_ATTR_ICSAVEDLL           26
#define SIM_INDEX_ATTR_ICNEXTWBFCN         27
#define SIM_INDEX_ATTR_ICNEXTWBDLL         28
#define SIM_INDEX_ATTR_ICNEXTWFFCN         29
#define SIM_INDEX_ATTR_ICNEXTWFDLL         30
#define SIM_INDEX_ATTR_ICSMSFCN            31
#define SIM_INDEX_ATTR_ICSMSDLL            32
#define SIM_INDEX_ATTR_VIEWID        33   /* View AVT 33-39 */
#define SIM_INDEX_ATTR_VIEWNAMEID    34
#define SIM_INDEX_ATTR_VIEWMNEMONIC  35
#define SIM_INDEX_ATTR_VIEWSEARCHFCN 36
#define SIM_INDEX_ATTR_VIEWSEARCHDLL 37
#define SIM_INDEX_ATTR_VIEWSORTFCN   38
#define SIM_INDEX_ATTR_VIEWSORTDLL   39
#define SIM_INDEX_ATTR_NISOURCE      40   /* NOINDEX AVT 40-42 */
#define SIM_INDEX_ATTR_NIUSERID      41
#define SIM_INDEX_ATTR_NITIMESTAMP   42
#define SIM_INDEX_ATTR_SRCHTEMP      43   /* Search AVT 43 */

/*
 * Attribute type defines
 */

//
// Attribute types
//
#define SIM_ATTR_UNDEFINED           0
#define SIM_ATTR_VSTRING             1
#define SIM_ATTR_FSTRING             2
#define SIM_ATTR_SHORT               3
#define SIM_ATTR_LONG                4
#define SIM_ATTR_FLOAT               5    // Not supported
#define SIM_ATTR_DECIMAL             6
#define SIM_ATTR_DATE                7
#define SIM_ATTR_TIME                8
#define SIM_ATTR_TIMESTAMP           9

//
// Attribute extended types for string attrs
//
#define SIM_ATTR_NONE                0
#define SIM_ATTR_ALPHA               1
#define SIM_ATTR_ALPHANUM            2
#define SIM_ATTR_ALPHANUM_EXT        4
#define SIM_ATTR_NUMERIC             8
#define SIM_ATTR_OTHER              16

/*
 * Attribute access defines
 */

#define SIM_ATTR_ALLOW_NULL          1
#define SIM_ATTR_READABLE            2
#define SIM_ATTR_WRITEABLE           4
#define SIM_ATTR_READWRITE           6
#define SIM_ATTR_SYSTEM_WRITE_ONLY   8
#define SIM_ATTR_RESERVED           16

/*
 * List Classes Defines for fClassOptions parameter on SimLibListClasses
 */

#define SIM_LIST_ALL                0  /* all classes */
#define SIM_LIST_NORMAL_ATTRS_ONLY  1  /* if normal logon, only classes */
                                       /* ..with attributes             */
                                       /* in config logon, same as "all"*/
/* following are old values - do not use */
/* They are all mapped to the same value */
#define SIM_ENUM_USER_ACCESS      1
#define SIM_ENUM_USER_OWNER       1
#define SIM_ENUM_APPL             1

/*
 * OIM TypeDefs
 */

/*
 * TOC Entry Structure
 */

/* usItemStatus field value for TOCENTRYSTRUCT*/
#define SIM_TOC_ADD          1
#define SIM_TOC_MODIFIED     2
#define SIM_TOC_DELETE       3

/* Text Search Manager Search States - available for Digital Library only. */  

#define SIM_SEARCH_STATE_TOBEUPDATED        0X100
#define SIM_SEARCH_STATE_TOBEDELETED        0X200
#define SIM_SEARCH_STATE_QUEUED_DELETE      0X301
#define SIM_SEARCH_STATE_QUEUED_UPDATE      0X302
#define SIM_SEARCH_STATE_INDEXED            0X400
#define SIM_SEARCH_STATE_ERROR              0XFFF

/* Text Search Manager Class Name - available for Digital Library only. */     
#define SIM_CLASS_NAME_SEARCHINDEX          "FRN$SEARCH"
/* Number of Attributes in Search Index Class */
#define NBR_ATTR_SEARCH                     8

/* Search Index Class's Attributes order - available for Digital Library only*/ 
#define FRNSEARCHENGINE                     0
#define FRNSEARCHINDEX                      1
#define FRNSEARCHSTATE                      2
#define FRNSEARCHTIMESTAMP                  3
#define FRNSEARCHITEMID                     4
#define FRNSEARCHCLASSID                    5
#define FRNSEARCHPARTNO                     6
#define FRNSEARCHINFO                       7

/* Search Engine names  - available for Digital Library only. */
#define SEARCHENGINE_SM                     1 	// D2728    	
#define SEARCHENGINE_GTR                    2   // D2728

typedef struct _TOCENTRYSTRUCT {
   ULONG                   ulStruct;        // size
   USHORT                  usItemStatus;    // TOC item status
   USHORT                  usIndexClass;    // class of the item
   USHORT                  usItemType;      // item type (folder, doc, etc)
   ITEMID                  szItemID;        // item id
   TIMESTAMP               tsItemChanged;   // changed time stamp
   } TOCENTRYSTRUCT, *PTOCENTRYSTRUCT;

/* Constants related to SimLibGetTOCData() */

#define SIM_TOC_SNAPSHOT_USER_ATTR      1   /* user-defined attrs */
#define SIM_TOC_SNAPSHOT_SYSTEM_ATTR    2   /* system-defined attrs */
#define SIM_TOC_SNAPSHOT_CHECKOUT_ATTR  4   /* checkout holder    */
#define SIM_TOC_SNAPSHOT_WORK_ATTR      8   /* workflow attrs     */
#define SIM_TOC_SNAPSHOT_SUSPEND_ATTR  16   /* release criteria   */
#define SIM_TOC_SNAPSHOT_ALL           31   /* all the above      */

#define SIM_TOC_MAX_ENTRY_COUNT 50          /* max items to handle */

   /* Annotation Structure used in the affiliated TOC entry structure*/
typedef struct _ANNOTATIONSTRUCT {
   ULONG             ulStruct;        // size
   ULONG             ulPart;          // part number which annotation refers to
   ULONG             ulPageNumber;    // page number which annotation refers to
   USHORT            usX;             // X coordinate for annotation
   USHORT            usY;             // Y coordinate for annotation
   USHORT            usT;             // Time value or Z coordinate for annotation
   USHORT            usAnnotUnused;   // For structure alignment
   } ANNOTATIONSTRUCT, *PANNOTATIONSTRUCT;

/*
 * Affiliated TOC Entry Structure
 */
typedef struct _AFFTOCENTRYSTRUCT {
   ULONG             ulStruct;        // size
   ANNOTATIONSTRUCT  AnnotationData;  // used only for annotation type
   ULONG             ulObjType;       // type of object:
                                      //    annotation, note, event or base
   OBJ               Obj;             // Object
   ULONG             ulObjConCls;     // content class of object
   ULONG             ulObjLength;     // number of bytes in the object
   LONG              lObjSeqAfter;    // object's sequence order
   ULONG             ulObjFlags;      // flag bits for the object
   TIMESTAMP         tsCreate;        // created time stamp
   TIMESTAMP         tsChanged;       // changed time stamp
   } AFFTOCENTRYSTRUCT, *PAFFTOCENTRYSTRUCT;

/*
 * Attribute list structure
 */

typedef struct _ATTRLISTSTRUCT {
   ULONG    ulStruct;
   PSZ      pszAttributeValue;
   BITS     fAttrFlags;
   USHORT   usAttrId;
   USHORT   usAttrType;
} ATTRLISTSTRUCT, *PATTRLISTSTRUCT;

/*
 * Class info and attribute structures.
 */
#define SIM_CLASS_NAME_LENGTH    32
#define SIM_DESCRIPTION_LENGTH   40
#define SIM_ATTR_NAME_LENGTH     32
#define SIM_COLLECTION_NAME_LENGTH 44
#define SIM_SERVER_NAME_LENGTH 8
#define SIM_ACCESS_LIST_NAME_LENGTH ACCESS_LIST_NAME_SIZE

typedef struct _CLASSATTRSTRUCT {
   ULONG            ulStruct;
#ifdef __WIN16__
   BOOL32           fAttrRequiredField;
#else
   BOOL             fAttrRequiredField;
#endif
   BITS             fAttrAccess;
   USHORT           usAttrId;
} CLASSATTRSTRUCT, *PCLASSATTRSTRUCT;

/*  Defines for usIndexType*/

#define ACCESS_LIST_NAME_SIZE    (RS_ITEM_ID_LENGTH + 1)
#define SIM_DESCRIPTION_LENGTH   40

typedef struct _CLASSINFOSTRUCT {
   ULONG            ulStruct;
   PCLASSATTRSTRUCT pClassAttrStruct;
   USHORT           usNbrAttrIds;
   USHORT           usMaxVersions;
   USHORT           usIndexClass;
   USHORT           usViewID;
   CHAR             szACLName[SIM_ACCESS_LIST_NAME_LENGTH+1];
   CHAR             achLanguageCode[SIM_LANGUAGE_CODE_LENGTH+1];
   CHAR             szClassName[SIM_CLASS_NAME_LENGTH+1];
   CHAR             szDescription[SIM_DESCRIPTION_LENGTH+1];
   CHAR             szCollectionName[SIM_COLLECTION_NAME_LENGTH+1];// default collection
   CHAR             szStoreSite[SIM_SERVER_NAME_LENGTH+1]; // default server
} CLASSINFOSTRUCT, *PCLASSINFOSTRUCT;

/*
 * class index attribute / index structs
 */

#define SIM_INDEX_NAME_LENGTH 18

// Values for fIndexFlags of CLASSINDEXSTRUCT
#define SIM_INDEX_UNIQUE      1
#define SIM_INDEX_NOT_UNIQUE  2

// Values for usIndexSortOrder of CLASSINDEXATTRSTRUCT
#define SIM_INDEX_ASCENDING      1
#define SIM_INDEX_DESCENDING     2

typedef struct _CLASSINDEXATTRSTRUCT {
   ULONG             ulStruct;
   USHORT            usAttrId;
   USHORT            usIndexSortOrder;
} CLASSINDEXATTRSTRUCT, *PCLASSINDEXATTRSTRUCT;

typedef struct _CLASSINDEXSTRUCT {
   ULONG             ulStruct;
   BITS              fIndexFlags;
   PCLASSINDEXATTRSTRUCT pClassIndexAttr;
   USHORT            usNbrAttrIds;
   CHAR              szIndexName[SIM_INDEX_NAME_LENGTH+1];
}  CLASSINDEXSTRUCT, *PCLASSINDEXSTRUCT;


typedef struct _ICVIEWSTRUCT {
   ULONG             ulStruct;
   struct _ICVIEWSTRUCT   *pNextView;
   PATTRLISTSTRUCT   pAttr;
   USHORT            usIndexClass;
   USHORT            usViewId;
   USHORT            usNumAttributes;
} ICVIEWSTRUCT, *PICVIEWSTRUCT;

typedef struct _WMSNAPSHOTSTRUCT {
   ULONG             ulStruct;
   USHORT            usWIPStatus;
   USHORT            usReleaseType;
   USHORT            usPriority;
   ITEMID            szWorkFlowID;
   TIMESTAMP         tsWFEntry;
   TIMESTAMP         tsEnteredWB;
   ITEMID            szWorkBasketID;
} WMSNAPSHOTSTRUCT, *PWMSNAPSHOTSTRUCT;

typedef struct _SNAPSHOTSTRUCT {
   ULONG             ulStruct;
   PWMSNAPSHOTSTRUCT pWmSnapshot;
   PICVIEWSTRUCT     pICView;
   USHORT            usNumViews;
   USHORT            usItemType;
   ULONG             ulOpenStatus;
   ITEMID            szItemID;
   USERIDENT         useridCheckout;
   TIMESTAMP         tsCreate;
   TIMESTAMP         tsModify;
} SNAPSHOTSTRUCT, *PSNAPSHOTSTRUCT;

/*
 * Index class/view ID type defines
 */
#define SIM_INDEXCLASSID                    1
#define SIM_VIEWID                          2

/*
 * ulAccessControl defines
 */
#define SIM_ACC_VALUE                       0
#define SIM_ACC_USER                        1
#define SIM_ACC_CLASS                       2
#define SIM_ACC_DEFAULT                     3
#define SIM_ACC_SYSTEM_CHOOSE               4
#define SIM_ACC_NONE                        5

/*
 * Attribute information and query structures.
 */

/* Defines for usHorizontalOrientation */
#define SIM_ATTR_LEFT_TO_RIGHT      0
#define SIM_ATTR_RIGHT_TO_LEFT      1

/* Defines for usVerticalOrientation */
#define SIM_ATTR_TOP_TO_BOTTOM      0
#define SIM_ATTR_BOTTOM_TO_TOP      1

/* Defines for usMode */
#define SIM_ATTR_VISUAL             0
#define SIM_ATTR_IMPLICIT           1
#define SIM_ATTR_EXPLICIT           2   // not currently supported

/* Defines for usNumericSelectionDefault */
#define SIM_ATTR_HINDI              0
#define SIM_ATTR_ARABIC             1

typedef struct _ATTRINFOSTRUCT {
   ULONG            ulStruct;
#ifdef __WIN16__
   BOOL32           fUseBidirectional;
   BOOL32           fSymmetricSwapping;
   BOOL32           fShaping;
#else
   BOOL             fUseBidirectional;
   BOOL             fSymmetricSwapping;
   BOOL             fShaping;
#endif
   LONG             lMin;
   LONG             lMax;
   BITS             fTypeFlags;
   USHORT           usAttrType;
   USHORT           usHorizontalOrientation;
   USHORT           usVerticalOrientation;  /* not currently supported */
   USHORT           usMode;
   USHORT           usNumericSelectionDefault;
   CHAR             szAttributeName[SIM_ATTR_NAME_LENGTH+1];
   CHAR             achLanguageCode[SIM_LANGUAGE_CODE_LENGTH+1];
} ATTRINFOSTRUCT, *PATTRINFOSTRUCT;

/*
 *  Criteria structure for search
 */
typedef struct _LIBSEARCHCRITERIASTRUCT {
   ULONG     ulStruct;             // Size of structure
   ULONG     ulReturnLimit;        // Max items returned/view searched
   BITS      fSearch;              // Search flags
   PSZ       pszSearchString;      // Expression string
   USHORT    usViewID;             // View to search
   USHORT    usSearchUnused;       // Dummy parm for packing--not used
   } LIBSEARCHCRITERIASTRUCT, *PLIBSEARCHCRITERIASTRUCT;

/*
 * NAMESTRUCT for attribute, index class and view names and IDs
 */
typedef struct _NAMESTRUCT {
   ULONG          ulStruct;
   USHORT         usID;
   CHAR           szName[SIM_CLASS_NAME_LENGTH+1];
   CHAR           szDescription[SIM_DESCRIPTION_LENGTH+1];
} NAMESTRUCT, *PNAMESTRUCT;

#define SIM_LABEL_LENGTH         50

/*
 * Item info struct
 */

typedef struct _ITEMINFOSTRUCT {
   ULONG    ulStruct;
#ifdef __WIN16__
   BOOL32   fSuspended;
#else
   BOOL     fSuspended;
#endif
   USHORT   usItemType;
   USHORT   usIndexClass;
   ULONG    ulOpenStatus;
   USHORT   usWipStatus;
   USERID   useridCheckout;
   CHAR     szLabel[SIM_LABEL_LENGTH+1];
}  ITEMINFOSTRUCT, *PITEMINFOSTRUCT;

/*
 * Folder manager SIMLIB function prototypes
 */

ULONG SIMENTRY SimLibLogon(
      PSZ            pszDBName,        // library database
      PSZ            pszApplicationName, // library tableset
      PSZ            pszUserID,        // user ID
      PSZ            pszPassword,      // user ID password
      PSZ            pszNewPassword,   // if any, new password
      PSZ            pszProxyID,       // proxy ID
      PSZ            pszProxyScope,    // proxy scope
      BITS           fSession,         // session access
      PASYNCCTLSTRUCT pAsyncCtl,       // asynchronous control block
      PRCSTRUCT      pRC);             // pointer to return data structure

ULONG SIMENTRY SimLibLogoff(
      HSESSION       hSession,         // session pointer
      PASYNCCTLSTRUCT pAsyncCtl,       // asynchronous control block
      PRCSTRUCT      pRC);             // pointer to return data structure

ULONG SIMENTRY SimLibLogoffPatron(     // Added by TSL - 09/08/95
      HSESSION       hSession,         // session pointer
      PSZ            pszPatronID,      // Patron's userid to be logged off
      PSZ            pszPassword,      // Patron's password
      PASYNCCTLSTRUCT pAsyncCtl,       // asynchronous control block
      PRCSTRUCT      pRC);             // pointer to return data structure

ULONG SIMENTRY SimLibAddFolderItem(
      HSESSION        hSession,        // Handle to a folder manager session.
      PITEMID         pszFolderID,     // Pointer to folder id.
      PITEMID         pszItemID,       // Pointer to an item ID.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibChangeIndexClass(
      HSESSION        hSession,        // Handle to a folder manager session.
      HITEM           hItem,           // Handle to a virtual item.
      USHORT          usClassId,       // index class identifier.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibCloseAttr(
      HSESSION        hSession,        // Handle to a folder manager session.
      HITEM           hItem,           // Handle to a virtual item.
      ULONG           ulDisposition,   // Save or discard virtual item attribute mods.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibCreateItem(
      HSESSION        hSession,        // Handle to a folder manager session.
      USHORT          usItemType,      // The item type.
      USHORT          usIndexClass,    // Index class identifier.
      USHORT          usNumOfAttrs,    // # of ATTRLISTSTRUCT structures in AttributeList.
      PATTRLISTSTRUCT pAttributeList,  // array of ATTRLISTSTRUCT structs holding attributes for this item.
      ULONG           ulAccessControl, // Access control type.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibDeleteItem(
      HSESSION        hSession,        // Handle to a folder manager session.
      PITEMID         pszItemID,       // Pointer to an item ID.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibFree(
            HSESSION    hSession,      // handle to a session
            PVOID       pBuffer,       // pointer to the memory block to be free
            PRCSTRUCT   pRC);          // pointer to return data structure

ULONG SIMENTRY SimLibGetAttrInfo(
      HSESSION        hSession,        // Handle to a folder manager session.
      USHORT          usAttributeId,   // Unique attribute identifier.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibGetClassIndexes(
      HSESSION        hSession,        // Handle to a folder manager session.
      USHORT          usIndexClass,    // Index class identifier.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibGetClassInfo(
      HSESSION        hSession,        // Handle to a folder manager session.
      USHORT          usClassType,     // Type of ID (class or view)
      USHORT          usID,            // Index class or view identifier.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibGetIndexClassView(
      HSESSION        hSession,        // Handle to a folder manager session.
      USHORT          usClassId,       // Index Class id
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);             // Pointer to return data structure.

ULONG SIMENTRY SimLibGetItemAffiliatedTOC(
      HSESSION        hSession,        // Handle to a folder manager session.
      PITEMID         pszItemID,       // Pointer to an item ID.
      USHORT          usAffiliatedType,// Affiliated object type.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibGetItemInfo(
      HSESSION        hSession,        // Handle to a folder manager session.
      PITEMID         pszItemID,       // Pointer to an item ID.
      USHORT          usClassId,       // Index class ID.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibGetItemType(
      HSESSION        hSession,        // Handle to a folder manager session.
      PITEMID         pszItemID,       // Pointer to an item ID.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibGetItemXREF(
      HSESSION        hSession,        // Handle to a folder manager session.
      PITEMID         pszItemID,       // Pointer to the item to be cross referenced.
      ULONG           ulFilter,        // Desired filtering indicator.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibGetTOC(
      HSESSION        hSession,        // Handle to a folder manager session.
      PITEMID         pszItemID,       // Pointer to an item ID.
      USHORT          usItemType,      // The item type.
      USHORT          usWipFilter,     // WIP status of search items.
      USHORT          usSuspendFilter, // Suspend status of search items.
      USHORT          usNbrOfClasses,  // # of index class identifiers in pusClassIdList.
      PUSHORT         pusClassIdList,  // Pointer to index class identifiers list that indicates TOC items.
      PVOID           pLinkCriteria,   // Not used
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibGetItemSnapshot(
      HSESSION        hSession,        // Handle to a folder manager session.
      PITEMID         pszItemID,       // Pointer to an item ID.
      BITS            fReadAttrInd,    // Attribute values to return to calling function.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibGetTOCData(
      HSESSION        hSession,        // Handle to a folder manager session.
      PTOCENTRYSTRUCT pTOCEntries,     // Pointer to the TOC entry array
      ULONG           ulEntryCount,    // Number of entries in TOC array
      BITS            fDataOptions,    // Options to select what data
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibListClasses(
      HSESSION        hSession,        // Handle to a folder manager session.
      BITS            fClassOptions,   // Class options
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibListClassViews(
      HSESSION        hSession,        // Handle to a SIM session.
      USHORT          usClassId,       // Index class view identifier.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibOpenItemAttr(
      HSESSION        hSession,        // Handle to a folder manager session.
      PITEMID         pszItemID,       // Pointer to an item ID.
      USHORT          usClassId,       // Index class ID.
      ULONG           ulAccessLevel,   // Desired access level.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibReadAttr(
      HSESSION        hSession,        // Handle to a folder manager session.
      HITEM           hItem,           // Handle to a virtual item.
      USHORT          usAttributeId,   // Unique attribute identifier.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibRemoveFolderItem(
      HSESSION        hSession,        // Handle to a folder manager session.
      PITEMID         pszFolderID,   // Pointer to folder id.
      PITEMID         pszItemID,       // Pointer to an item ID.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibSaveAttr(
      HSESSION        hSession,        // Handle to a folder manager session.
      HITEM           hItem,           // Handle to a virtual item.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibSearch(
      HSESSION        hSession,        // Handle to a folder manager session.
      PITEMID         pszItemFilter,   // Folder item ID to search.
      PVOID           pLinkCriteria,   // Pointer to search for link attributes.
      USHORT          usStatDyn,       // Static or dynamic query.
      USHORT          usTypeFilter,    // Type of search items.
      BITS            fWipFilter,      // WIP status of search items.
      USHORT          usSuspendFilter, // Suspend status of search items.
      USHORT          usIndexClass,    // Index class identifier.
      USHORT          usNumCriteria,   // Number of elements in the pCriteria array.
      PLIBSEARCHCRITERIASTRUCT pCriteria,  // Pointer to search criteria array for views/attributes.
      ULONG           ulMemListRequest, // three values (SIM_SEARCH...)
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibSetIndexClassView(
      HSESSION        hSession,        // Handle to a folder manager session.
      USHORT          usClassId,       // Index Class id
      USHORT          usClassViewId,   // View id
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibWriteAttr(
      HSESSION        hSession,        // Handle to a folder manager session.
      HITEM           hItem,           // Handle to a virtual item.
      USHORT          usAttributeId,   // Unique attribute identifier.
      PSZ             pszAttributeValue, // Pointer to value to be assigned to specified attribute.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibGetSessionType(
      HSESSION        hSession,        // Handle to a folder manager session.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibCreateItemPartExtSrch( // Digital Library only.
      HSESSION        hSession,   // Handle to a folder manager session created at SimLibLogon
      PATTRLISTSTRUCT pAttributeList, // Ptr to an array of ATTRLISTSTRUCT
      USHORT          usNumOfAttrs,   // Number of structures in pAttributeList array
      USHORT          usIndexClass,   // Index class
      PITEMID         pszItemID,      // Ptr to item ID of pre existing ITEM
      HOBJ            hObj,           // Ptr to object handle block
      ULONG           ulConCls,       // Content class ID
      ULONG           ulAffiliatedType, // Type of affliated object
      PVOID           pAffiliatedData,  // Ptr to data structure
      PSZ             pszFullFileName,  // Ptr to filename
      PVOID           pObjBuffer,       // Ptr to memory buffer
      ULONG           ulObjSize,        // Size of object
      PSZ             pszSearchEngine,  // Ptr to name of Search Engine
      PSZ             pszSearchIndex,   // Ptr to Search Index
      PSZ             pszSearchInfo,    // Ptr to Search Info
      BOOL            bCallExtSrch,     // If TRUE, call SimLibProcExtSrch
      PASYNCCTLSTRUCT pAsyncCtl,  // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);       // Pointer to return data structure.

ULONG SIMENTRY SimLibDeleteItemPartExtSrch( // Digital Library only.
      HSESSION        hSession,   // Handle to a folder manager session created at SimLibLogon
      PITEMID         pszItemID,  // Ptr to item ID of pre existing ITEM
      HOBJ            hObj,       // Ptr to object handle block
      PSZ             pszSearchEngine,  // Ptr to name of Search Engine
      PSZ             pszSearchIndex,   // Ptr to Search Index
      BOOL            bCallExtSrch,  // If TRUE, call SimLibProcExtSrch
      PRCSTRUCT       pRC);          // Pointer to return data structure.

ULONG SIMENTRY SimLibReplacePartExtSrch(    // Digital Library only.
      HSESSION        hSession,   // Handle to a folder manager session created at SimLibLogon
      HOBJ            hDestObj,   // Ptr to destination object handle block
      HOBJ            hSrcObj,    // Ptr to source object handle block
      PSZ             pszSearchEngine,  // Ptr to name of Search Engine
      PSZ             pszSearchIndex,   // Ptr to Search Index
      BOOL            bCallExtSrch,  // If TRUE, call SimLibProcExtSrch
      PRCSTRUCT       pRC);          // Pointer to return data structure.


//
// structure packing default
//
#pragma pack()
#ifdef __cplusplus
     }
#endif
#endif // End of FRNPFI.H
