/*BEGINPROLOGUE***************************************************/
/*                                                               */
/* MODULE: frnpfo.h                                              */
/*                                                               */
/* COPYRIGHT:                                                    */
/* ----------                                                    */
/* Digital Library Version 1 - 5648-A08.                         */
/* VisualInfo Version 2 Release 2.0 - 5697-250.                  */
/* (C) Copyright IBM Corp., 1994, 1996.  All Rights Reserved     */
/*                                                               */
/* US Government Users Restricted Rights                         */
/* Use, duplication or disclosure restricted by GSA ADP Schedule */
/* Contract with IBM Corp.  Licensed Materials - Property of IBM */
/*                                                               */
/*                                                               */
/* Description: frnpfo.h   - this include is used by programs    */
/*                           calling the Object Manager APIs     */
/*                                                               */
/* Dependencies:                                                 */
/* Restrictions:                                                 */
/*                                                               */
/*                                                               */
/* Notes:                                                        */
/*                                                               */
/*ENDPROLOGUE*****************************************************/


#ifndef FRNPFO
#define FRNPFO 1

//
// The following is to support C++ compilers
//
#ifdef __cplusplus
   extern "C" {
#endif

/*
 * Common definitions
 */

//#define OM_SHARED_READ          0      // Object is opened for reading only,
//#define OM_SHARED_READ_ONLY     4
//#define OM_EXCL_READ            1      // Object is opened for reading only,
//#define OM_EXCL_WRITE           8
//#define OM_READ_WRITE           2      // Object is opened for reading and

#ifdef __WIN16__
   #define SIM_WIN_MAX_IO_SIZE      64000
#endif

/*
 * structure packing
 */
#pragma pack(1)


#define OM_RUSH_PRIORITY        1      // Process it as soon as possible.
#define OM_NORMAL_PRIORITY      2      // Process it in a reasonable amount
#define OM_BACKGROUND_PRIORITY  3      // Process it whenever it can be done

#define SIM_OPEN_DISK           0     // Get object on disk
#define SIM_OPEN_MEMORY         1     // Get object in memory
#define SIM_CLOSE               0     // close object after completion
#define SIM_OPEN                2     // Leave object open

#define SIM_POS_BEGIN           0     // Seek from beginning of object
#define SIM_POS_CURRENT         1     // Seek from current
#define SIM_POS_END             2      // Seek from end


#define SIM_PRI_DEFAULT         0      // system priority
#define SIM_PRI_RUSH            1      // high priority
#define SIM_PRI_NORMAL          2      // medium priority
#define SIM_PRI_BACKGROUND      3      // low priority

#define SIM_DELETE_ITEM         0      // delete item if no more parts left
#define SIM_DELETE_ALL          0      // delete all instances
#define SIM_DELETE_ARCHIVE      1      // delete all instances
#define SIM_DELETE_STAGED       2      // delete all instances
#define SIM_DELETE_OBJECT_ONLY  3      // don't delete item if no more parts left

#define SIM_STAGE_SERVER        0      // stage object only at server level
#define SIM_STAGE_USER          1      // stage object to user cache if possible

#define SIM_VER_ALL             0      // all versions
#define SIM_VER_ADDNEW          1      // new version
#define SIM_VER_UNIQUE          2      // unique version

/*
 * TypeDefs
 */

#define MAXCOLNMSZ               44+1
#define MAXOBJNMSZ               44+1
#define MAXMGTCLSNMSZ            8+1
#define MAXSTGCLSNMSZ            8+1
#define MAXSTRSITENMSZ           26+1
#define MAXSTGHINTNMSZ           30+1
#define MAXDATACLSNMSZ           8+1
#define MAXFULLFILENAME          252+1

typedef struct _SMS {
     ULONG     ulStruct;
     LONG      lSMSRetention;
     CHAR      szCollectionName[MAXCOLNMSZ];
     CHAR      szObjectName[MAXOBJNMSZ];
     CHAR      szMgtCls[MAXMGTCLSNMSZ];
     CHAR      szStgCls[MAXSTGCLSNMSZ];
     CHAR      szDataCls[MAXSTGCLSNMSZ];
     CHAR      szStoreSite[MAXSTRSITENMSZ];
     CHAR      szStoreHint[MAXSTGHINTNMSZ];
     } SMS;
typedef SMS*   PSMS;

//
// defines for ucAvail
//
#define         SIM_OM_READY           1
#define         SIM_OM_PENDING         2
#define         SIM_OM_AVAILABLE       3
#define         SIM_OM_INVENTORIED     4
#define         SIM_OM_UNAVAILABLE     5

typedef struct _OBJINFOSTRUCT {
   ULONG        ulStruct;
   ULONG        ulObjSize;
   LONG         lSMSRetention;
   LONG         lEstimateRetrieveTime;
   ULONG        ulAvail;
   ULONG        ulObjConCls;
   USHORT       usPageNum;
   TIMESTAMP    tsCreate;
   TIMESTAMP    tsExpiration;
   TIMESTAMP    tsLastRef;
   TIMESTAMP    tsModify;
   TIMESTAMP    tsEnterSG;
   TIMESTAMP    tsEnterSC;
   CHAR         szCollectionName[MAXCOLNMSZ];
   CHAR         szObjectName[MAXOBJNMSZ];
   CHAR         szMgtCls[MAXMGTCLSNMSZ];
   CHAR         szStgCls[MAXSTGCLSNMSZ];
   CHAR         szDataCls[MAXDATACLSNMSZ];
   CHAR         szStoreSite[MAXSTRSITENMSZ];
   } OBJINFOSTRUCT, *POBJINFOSTRUCT;

typedef unsigned char *  PHBUF;

//
// Added to support fStageControl for SimLibStageObject.
//

typedef enum {
   SIM_PREFETCH,
   SIM_STAGE_IT
   } STG_CTL;

/*
 * Folder manager function prototypes
 */


ULONG SIMENTRY SimLibReopenObject(
            HSESSION    hSession,      // handle to a session
            HOBJACC     hObjAcc,       // object acess handle
            ULONG       ulAccessLevel, // access mode of object to be opened
#ifdef __WIN16__
            BOOL32      fConflict,     // access mode conflict flag
            BOOL32      fCommit,       // commit  flag
#else
            BOOL        fConflict,     // access mode conflict flag
            BOOL        fCommit,       // commit  flag
#endif
            BITS        fOpenControl,  // control bits for open
            PASYNCCTLSTRUCT pAsyncCtl,     // asynchronous control block
            PRCSTRUCT   pRC);          // pointer to return data structure


ULONG SIMENTRY SimLibCloseObject(
            HSESSION    hSession,      // handle to a session
            HOBJACC     hObjAcc,       // object acess handle
#ifdef __WIN16__
            BOOL32      fCommit,       // flag used to save virtual copy
#else
            BOOL        fCommit,       // flag used to save virtual copy
#endif
            PASYNCCTLSTRUCT pAsyncCtl,     // asynchronous control block
            PRCSTRUCT   pRC);          // pointer to return data structure


ULONG SIMENTRY  SimLibCopyObject(
            HSESSION    hSession,      // handle to a session
            HOBJ        hDestObj,      // destination objects access handle
            HOBJ        hSrcObj,       // Source objects access handle
            PSMS        pSMS,           // pointer to SMS info struct
            ULONG       ulPriority,    // priority for servicing object
#ifdef __WIN16__
            BOOL32      fDelete,       // delete source object flag
#else
            BOOL        fDelete,       // delete source object flag
#endif
            PASYNCCTLSTRUCT pAsyncCtl,     // asynchronous control block
            PRCSTRUCT   pRC);          // pointer to return data structure

ULONG SIMENTRY  SimLibChangeObjectSMS(
            HSESSION    hSession,      // handle to a session
            HOBJ        hObj,          // objects  handle
            PSMS        pSMS,           // pointer to SMS info struct
            BITS        fChangeControl,// control bits for change option
            PASYNCCTLSTRUCT pAsyncCtl,     // asynchronous control block
            PRCSTRUCT   pRC);          // pointer to return data structure

ULONG SIMENTRY SimLibOpenObject(
            HSESSION    hSession,      // handle to a session
            HOBJ        hObj,          // object acess handle
            ULONG       ulAccessLevel, // access mode of object to be opened
            ULONG       ulPriority,    // open access priority
#ifdef __WIN16__
            BOOL32      fConflict,
#else
            BOOL        fConflict,
#endif
            BITS        fOpenControl,  // control bits for open
            PASYNCCTLSTRUCT pAsyncCtl,     // asynchronous control block
            PRCSTRUCT   pRC);          // pointer to return data structure

ULONG SIMENTRY SimLibOpenObjectByUniqueName(
            HSESSION    hSession,      // handle to a session
            PSZ         pszUniqueName, // object acess handle
            ULONG       ulAccessLevel, // access mode of object to be opened
            ULONG       ulPriority,    // open access priority
#ifdef __WIN16__
            BOOL32      fConflict,
#else
            BOOL        fConflict,
#endif
            BITS        fOpenControl,  // control bits for open
            PASYNCCTLSTRUCT pAsyncCtl,     // asynchronous control block
            PRCSTRUCT   pRC);          // pointer to return data structure

ULONG SIMENTRY SimLibResizeObject(
            HSESSION    hSession,      // handle to a session
            HOBJACC     hObjAcc,       // objects access handle
            ULONG       ulSize,        // The objects new size in bytes
            PASYNCCTLSTRUCT pAsyncCtl,     // asynchronous control block
            PRCSTRUCT   pRC);          // pointer to return data structure


ULONG SIMENTRY SimLibReadObject(
            HSESSION    hSession,      // handle to a session
            HOBJACC     hObjAcc,       // object acess handle
            PHBUF       pBuffer,       // application data buffer
            ULONG       ulBytesToRead, // maximum number of bytes to read
            PASYNCCTLSTRUCT pAsyncCtl,     // asynchronous control block
            PRCSTRUCT   pRC);          // pointer to return data structure


ULONG SIMENTRY SimLibWriteObject(
            HSESSION    hSession,       // handle to a session
            HOBJACC     hObjAcc,        // objects acess handle
            PHBUF       pBuffer,        // pointer to the users data buffer
            ULONG       ulBytesToWrite, // max number if bytes to write
            PASYNCCTLSTRUCT pAsyncCtl,      // asynchronous control block
            PRCSTRUCT   pRC);           // pointer to return data structure


ULONG SIMENTRY SimLibSeekObject(
            HSESSION    hSession,      // handle to a session
            HOBJACC     hObjAcc,       // object acess handle
            ULONG       ulOrigin,      // inital position of filepointer
            LONG        lOffset,       // number of bytes to offset file pointer
            PASYNCCTLSTRUCT pAsyncCtl,     // asynchronous control block
            PRCSTRUCT   pRC);          // pointer to return data structure


ULONG SIMENTRY SimLibCatalogObject (
            HSESSION    hSession,       // handle to a session
            HOBJ        hObj,           // object acess handle
            ULONG       ulConCls,       // object content class
            PSMS        pSMS,           // pointer to SMS info struct
            PSZ         pszFullFileName,// Name of Object Being Cataloged
            ULONG       ulPriority,     // priority for servicing object
            BITS        fCreateControl, // object residence access mode
            ULONG       ulVersion,      // version control info
            LONG        lSeqAfterPart,  // part's sequence order
            ULONG       ulAffiliatedType,// type of part to create
            PVOID       pAffiliatedData, // additional data
            PASYNCCTLSTRUCT pAsyncCtl,      // asynchronous control block
            PRCSTRUCT   pRC);           // ptr to return code structure


ULONG SIMENTRY SimLibCreateObject (
            HSESSION    hSession,      // handle to a session
            HOBJ        hObj,          // object acess handle
            ULONG       ulConCls,      // content class
            PSMS        pSMS,          // pointer to SMS info struct
            ULONG       ulPriority,    // Priority
            BITS        fCreateControl,// option bits
            ULONG       ulVersion,     // version control info
            LONG        lSeqAfterPart, // part's sequence order
            ULONG       ulAffiliatedType, // type of object
            PVOID       pAffiliatedData, // additional data
            PASYNCCTLSTRUCT pAsyncCtl,     // asynchronous control block
            PRCSTRUCT   pRC);          // ptr to RCSTRUCT


ULONG SIMENTRY SimLibDeleteObject (
            HSESSION    hSession,      // handle to a session
            HOBJ        hObj,          // object handle to delete
            ULONG       ulDeleteOption, // delete option - not supported
            PASYNCCTLSTRUCT pAsyncCtl,     // asynchronous control block
            PRCSTRUCT   pRC);          // ptr to RCSTRUCT


ULONG SIMENTRY SimLibDeleteObjectReference (
            HSESSION    hSession,       // handle to a session
            HOBJ        hObj,           // object handle
            PSZ         pszFullFileName,// volume name
            PASYNCCTLSTRUCT pAsyncCtl,      // asynchronous control block
            PRCSTRUCT   pRC);           // ptr to return code structure


ULONG SIMENTRY SimLibStageObject(
            HSESSION    hSession,      // handle to a session
            HOBJ        hObj,          // object handle to delete
            ULONG       ulPriority,    // Priority
            BITS        fStageControl, // options for staging operations
            PASYNCCTLSTRUCT pAsyncCtl,     // asynchronous control block
            PRCSTRUCT   pRC);          // ptr to RCSTRUCT

ULONG SIMENTRY SimLibStoreNewObject(
      HSESSION        hSession,        // Handle to a SIM session.
      HOBJ            hObj,            //
      ULONG           ulConCls,        // Object content class
      PSMS            pSMS,            // Pointer to SMS info struct
      PVOID           pBuffer,         // Pointer to object data buffer
      ULONG           ulSize,          // Buffer size.
      LONG            lSeqAfterPart,   // Part's sequence order
      ULONG           ulAffiliatedType,  // Type of part to create.
      PVOID           pAffiliatedData, // Additional data affiliated with an object.
      PASYNCCTLSTRUCT pAsyncCtl,       // Pointer to asynchronous control block.
      PRCSTRUCT       pRC);            // Pointer to return data structure.

ULONG SIMENTRY SimLibQueryObject (
            HSESSION    hSession,      // handle to a session
            HOBJ        hObj,          // Object handle to query
            PASYNCCTLSTRUCT pAsyncCtl,     // asynchronous control block
            PRCSTRUCT   pRC);          // pointer to return struct


ULONG SIMENTRY Ip2GetObjectFileName(
            HSESSION        hSession,  // Handle to a SIM session.
            HOBJACC         hObjAcc,   // Handle to an open object
            PASYNCCTLSTRUCT  pAsyncCtl, // Pointer to asynchronous control block.
            PRCSTRUCT       pRC);      // Pointer to return data structure.

/* unpublished helper routine */
SHORT CDECL PurgeCacheElement(SESSION_P pSession,   // handle to session
                              POBJ          pObj,   // pointer to object
                              REP_TYPE     cReptype, // reptype
                              USHORT       usCallerRC, // caller's return code
                              PRCSTRUCT      pRC );
/*
 * structure packing default
 */
#pragma pack()

/*
 * end support for C++
 */
#ifdef __cplusplus
   }
#endif

#endif // End of FRNPFO.H
