/*BEGINPROLOGUE*************************************************/
/*                                                             */
/* MODULE: FRNPLLXX.H                       VisualInfo         */
/*                                                             */
/*     5697-250, 5655-A01, 5655-A02,                           */
/*     5621-326, 5655-036, 5622-213, 5655-071 and 5655-072 (C) */
/*         Copyright IBM Corp. 1993,1996. All Rights Reserved. */
/*         US Government Users Restricted Rights -             */
/*         Use, duplication or disclosure restricted by GSA    */
/*         ADP Schedule Contract with IBM Corp.                */
/*                                                             */
/*     Licensed Materials - Property of IBM                    */
/*                                                             */
/*                                                             */
/* Date: December 1992                                         */
/*                                                             */
/* Status: Version 2 Release 1 Modification 0                  */
/*                                                             */
/* Description: FRNPLLXX.H - this include is used by programs  */
/*                           calling the Library Client APIs   */
/*                                                             */
/* Dependencies:                                               */
/* Restrictions:                                               */
/*                                                             */
/*                                                             */
/* Notes:                                                      */
/*                                                             */
/*ENDPROLOGUE***************************************************/


#ifdef __cplusplus
     extern "C" {
#endif

#ifndef FRNPLLXX_INCLUDED

#define FRNPLLXX_INCLUDED

#ifndef CICS_ENV
#pragma pack(1)
#endif

/************************************************************************
 # Description    : common declarations for FRNPLLUX.C                  *
 #                  1. Common C data type definitions                   *
 #                  2. Command codes   - These are the constant IDs     *
 #                                       that map to APIs.              *
 #                  3. Action  codes   - These are the action types     *
 #                                       that describe the action       *
 #                                       within an API.                 *
 #                  4. Return Indicator- These are output parameters    *
 #                                       from the user-exits that       *
 #                                       determine whether to grant/    *
 #                                       deny the API request or        *
 #                                       let normal access control      *
 #                                       continue processing its own    *
 #                                       decision                       *
 #                  5. Library Server  - These are the error codes that *
 #                     error codes       can be input to the user-exits *
 #                                       when the Library Server intends*
 #                                       to deny the API request        *
 #                  6. Reference Mon.  - This indicates what decision   *
 #                     decision          the calling routine intends to *
 #                                       make concerning the current    *
 #                                       API request                    *
 #                  7. Info type parm  - This indicates whether the call*
 #                     values            is item-related, view-related, *
 #                                       or both for purposes of knowing*
 #                                       which input parameters are     *
 #                                       valid                          *
 #**********************************************************************/

/***************************************************/
/* COMMON C RE-DEFINITIONS OF DATA TTYPES          */
/***************************************************/
#define CHAR          char                // ch
#define SHORT         short               // s
#define LONG          long                // l
#define FALSE         0
#define TRUE          1

typedef unsigned LONG    BOOL;            /* f   */
typedef unsigned CHAR    UCHAR;           /* uch */
typedef unsigned CHAR    BYTE;            /* b   */
typedef unsigned SHORT   USHORT;          /* us  */

/********************************************************/
/* COMMAND CODES   These are the identifiers for APIs   */
/*   - usAPIClass input parameter: both exits           */
/********************************************************/
typedef enum {
      CHECKIN_ORDER_CL            = 1012,     /* LibCheckIn()                 */
      CHECKOUT_ORDER_CL           = 1023,     /* LibCheckOut()                */
      CONNECT_ORDER_CL            = 1034,     /* LibConnectLibrary()          */
      DESCRIBE_ORDER_CL           = 1045,     /* LibDescribeItem()            */
      DEFPATRON_ORDER_CL          = 1056,     /* LibDefinePatron()            */
      DEFGROUP_ORDER_CL           = 1089,     /* LibDefinePatronGroup()       */
      DISCARD_ORDER_CL            = 1112,     /* LibDiscardBobs()             */
      ENDTRANS_ORDER_CL           = 1134,     /* LibEndTransaction()          */
      ITEMATTR_ORDER_CL           = 1212,     /* LibSetItemAttributes()       */
      LINK_ORDER_CL               = 1223,     /* LibLinkItem()                */
      MOVEBLOBS_ORDER_CL          = 1234,     /* LibMoveBlobs()               */
      NAME_ORDER_CL               = 1312,     /* LibNameItem()                */
      PARTATTR_ORDER_CL           = 1323,     /* LibSetPartAttributes()       */
      PROPERTY_ORDER_CL           = 1345,     /* LibItemProperty()            */
      SQUERY_ORDER_CL             = 1356,     /* LibStaticQuery()             */
      DQUERY_ORDER_CL             = 1367,     /* LibDynamicQuery()            */
      RECORDEVENT_ORDER_CL        = 1423,     /* LibRecordEvent()             */
      RETRIEVE_ORDER_CL           = 1512,     /* LibRetrieveItemPart()        */
      RETRNAME_ORDER_CL           = 1523,     /* LibRetrieveByName()          */
      RETRLABEL_ORDER_CL          = 1534,     /* LibRetrieveByLabel()         */
      STORE_ORDER_CL              = 1612,     /* LibStoreItemPart()           */
      SMS_ORDER_CL                = 1812,     /*                              */
      OBJ_ORDER_CL                = 1823,     /*                              */
      DEFATTRIBUTE_ORDER_CL       = 1912,     /*                              */
      DEFINDEXCLASS_ORDER_CL      = 1923,     /* LibDefineIndexClass()        */
      DEFCLASSVIEW_ORDER_CL       = 1934,     /* LibDefineIndexClassView()    */
      SETATTRVALUES_ORDER_CL      = 1954,     /* LibSetAttrValues()           */
      VIEWSEARCH_ORDER_CL         = 1965,     /* LibItemSearch()              */
      DEFCLASSDBMSINDEX_ORDER_CL  = 1976,     /* LibDefineIndexOnIndexClass() */
      DEFNLSLANGUAGE_ORDER_CL     = 1987,     /* LibDefineNLSLanguage()       */
      DEFNLSKEYWORD_ORDER_CL      = 1998,     /* LibDefineNLSKeyword()        */
      STOREITEM_ORDER_CL          = 2012,     /* LibStoreItemOnly()           */
      DEFWORKSLIP_ORDER_CL        = 2023,     /* LibDefineWorkSlip()          */
      DEFSUSPEND_ORDER_CL         = 2034,     /* LibDefineSuspendedItem()     */
      DEFPRIVS_ORDER_CL           = 2112,     /* LibDefinePrivileges()        */
      QUERYPRIVS_ORDER_CL         = 2123,     /* LibQueryPrivileges()         */
      SETACL_ORDER_CL             = 2134,     /* LibSetAccessList()           */
      DEFCONTROL_ORDER_CL         = 2145,     /* LibDefineControlParams()     */
      DISCARDEVENTS_ORDER_CL      = 2156,     /* LibDiscardEvents()           */
      UPDATESMS_ORDER_CL          = 2176,     /* LibUpdateSMSInfo()           */
      LOGOFFPATRON_ORDER_CL       = 2196,     /* LibDisconnectPatron()        */
      UPDATEPARTLOC_ORDER_CL      = 2221      /* LibUpdatePartLocation()      */
} COMMAND_CODES;

/******************************************************************************/
/* NOTE: For static queries the command code is actually the static query     */
/*       class.  These are enumerated as follows:                             */
/******************************************************************************/
typedef enum {
   STATICQUERY_QUERYITEM         =    1,  // Query the SBTITEMS row for a ...
                                          // ... specified item ID
   STATICQUERY_QUERYATTRIBUTES   =    2,  // Query rows from the ...
                                          // SBTATTRDEFS table
   STATICQUERY_QUERYINDEXCLASSES =    3,  // Query rows from the ...
                                          // SBTCLASSDEFS table
   STATICQUERY_QUERYCLASSVIEWS   =    4,  // Query rows from the ...
                                          // SBTVIEWDEFS table
   STATICQUERY_QUERYOBJ          =    5,  // Query one row from ...
                                          // ... the SBTOBJECTSERVER table
   STATICQUERY_QUERYOBJS         =    6,  // Query all rows from ...
                                          // ... the SBTOBJECTSERVER table
   STATICQUERY_QUERYONESMSFOROBJ =    7,  // Query one row from ...
                                          // ... the SBTCOLLNAME table
   STATICQUERY_QUERYALLSMSFOROBJ =    8,  // Query all rows from ...
                                          // ... the SBTCOLLNAME table ...
                                          // ... for a given OBJECTSERVER
   STATICQUERY_QUERYALLSMS       =    9,  // Query all rows from ...
                                          // ... the SBTCOLLNAME table
   STATICQUERY_QUERYPART         =   10,  // Query one ore more rows from ...
                                          // ... the SBTVIEWDEFS table
   STATICQUERY_QUERYDBMSINDEXES  =   11,  // Query information about ...
                                          // ... database indexes defined
                                          // ... on a specific index class
   STATICQUERY_QUERY_PATRONPRIVS =   12,  // Query an individual patrons
                                          // ... basic privileges
   STATICQUERY_QUERYCLASSATTRS   =   13,  // Query rows from the ...
                                          // SBTCLASSDEFS and the ...
                                          // SBTATTRDEFS tables
   STATICQUERY_QUERYVIEWATTRS    =   14,  // Query rows from the ...
                                          // SBTVIEWDEFS and the
                                          // SBTATTRDEFS tables
   STATICQUERY_QRYNLSLANGUAGES   =   15,  // Query a list of supported ...
                                          // ... NLS languages
   STATICQUERY_QRYNLSKEYWORDS    =   16,  // Query NLS keywords
   STATICQUERY_QRYSUSPITEMS      =   17,  // Query NLS keywords
   STATICQUERY_QRYCNTLINFO       =   18,  // Query SBTCNTL info
   STATICQUERY_QRYCHECKEDOUTINFO =   19,  // Query Checked Out items
   STATICQUERY_QRYEVENTINFO =        20,  // Query event info
   STATICQUERY_QRYITEMINFO_ITEM  =   21,  // Query item info (item table)
   STATICQUERY_QRYITEMINFO_ACL   =   22,  // Query item info (ACL table)
   STATICQUERY_QRYITEMINFO_LINK  =   23,  // Query item info (link table)
   STATICQUERY_QRYITEMINFO_PROP  =   24,  // Query item info (prop table)
   STATICQUERY_QRYITEMINFO_DESC  =   25,  // Query item info (desc table)
   STATICQUERY_QRYITEMINFO_NAME  =   26,  // Query item info (name table)
   STATICQUERY_QRYITEMINFO_PARTS =   27   // Query item info (parts table)
} LIBSTATICQUERY_CLASS;

/***************************************************************/
/* User-defined static queries should be in the range 257-1000 */
/***************************************************************/
#define LIB_MIN_USER_QUERY_CLASS   257
#define LIB_MAX_USER_QUERY_CLASS  1000

/**************************/
/* END OF COMMAND CODES   */
/**************************/

/**************************************************/
/* Generic action description associated with     */
/* the API class.                                 */
/* Note that most APIs involve insert, update,    */
/* or delete actions.  In certain cases, APIs     */
/* may involve special types of actions.          */
/* 0,1, and 2 map to insert, update, and delete   */
/* respectively for all API's.  3..n map to the   */
/* special actions for specific API's.            */
/*                                                */
/*   - bAPIAction input parameter: both exits     */
/**************************************************/
#define LIB_ACTION_INSERT               '0'
#define LIB_ACTION_UPDATE               '1'
#define LIB_ACTION_DELETE               '2'

/* LibLinkItem() */
#define LIB_DELETE_PARENTS              '3'
#define LIB_DELETE_CHILDREN             '4'

/* LibDescribeItem() */
#define LIB_UPDATE_DESC                 '0'  // These two are swapped for
#define LIB_APPEND_DESC                 '1'  // this API only.
#define LIB_DELETE_DESC                 '2'
#define LIB_DELETE_REST                 '3'

/* LibDiscardBlobs() */
#define LIB_DELETE_ITEM                 '6'
#define LIB_DELETE_PART                 '7'
#define LIB_DELETE_TREE                 '8'
#define LIB_DELETE_FORM                 '9'

/* LibRetrieveItemPart() */
#define LIB_GET_IT                      '0'
#define LIB_NO_MOUNT                    '1'
#define LIB_STAGE_IT                    '2'
#define LIB_DATE_ONLY                   '3'

/* LibCheckIn() */
#define LIB_CHECKIN_PATRON              '0'
#define LIB_CHECKIN_GROUP               '1'
#define LIB_CHECKIN_ITEM                '2'

/* LibNameItem() */
#define LIB_DELETE_CONTEXT              '3'
#define LIB_DELETE_CONTEXT_ALL          '4'
#define LIB_DELETE_FOR_PATRON           '5'
#define LIB_DELETE_FOR_PATRON_ALL       '6'

/* LibItemProperty() */
#define LIB_DELETE_PROP_TYPE            '3'

/* LibMoveBlobs() */
#define LIB_MOVE_PART                   '0'
#define LIB_MOVE_REP                    '1'
#define LIB_MOVE_WHOLE                  '2'
#define LIB_MOVE_TREE                   '3'

/* LibStoreItemPart() */
#define LIB_ADD_PART                    '2'
#define LIB_REPLACE_PART                '3'

/************************************************/
/* End of action descriptors for API actions.   */
/************************************************/

/****************************************************/
/* Library Server Access Control Return Codes       */
/*   - bRefMonDecReason input parameter: both exits */
/*   - Find these in FRNPERR.H                      */
/*   - Value Range: 7064-7094, 7116-7117            */
/****************************************************/

/**************************************************/
/* Return Indicators to Library Server            */
/*   - pbACDirective output parameter: both exits */
/**************************************************/
#define  DECISION_CONTINUE_PROCESSING   '0'
#define  DECISION_GRANT_API_REQUEST     '1'
#define  DECISION_DENY_API_REQUEST      '2'

/***************************************************/
/* REFERENCE MONITOR DECISION                      */
/*   - bRefMonDecision parameter: both exits       */
/***************************************************/
#define  REFMON_GRANT_REQUEST            1
#define  REFMON_DENY_REQUEST             0

/***************************************************/
/* INFO TYPE VALUES                                */
/*   - bInfoType input parameter: exit two         */
/***************************************************/
#define  ITEM_RELATED                   10
#define  VIEW_RELATED                   11
#define  ITEM_VIEW_RELATED              12

/***************************************************/
/* SYSTEM ITEM FLAGS                               */
/*   - sItemFlags parameter: exit two              */
/***************************************************/
#define ITEMFLAGS_ACL_IDENTIFIER     0x0002  /* bit 2 - AccessListCode column */
                                             /*         holds ID of an access */
                                             /*         list                  */
#define ITEMFLAGS_INTERNAL_REFMON    0x0010  /* bit 5 - internal ref. mon.    */
                                             /*         others not supported  */
#define ITEMFLAGS_OWNER_ENABLED      0x0040  /* bit 7 - owner-enabled item    */
#define ITEMFLAGS_AC_PRIVS           0x0080  /* bit 8 - indicates that the    */
                                             /*         item's access control */
                                             /*         columns can be changed*/

/***************************************************/
/* SYSTEM VIEW FLAGS                               */
/*   - sViewFlags parameter: exit two              */
/***************************************************/
#define VIEWFLAGS_ACL_IDENTIFIER     0x0002  /* bit 2 - AccessListCode column */
                                             /*         holds ID of an access */
                                             /*         list                  */
#define VIEWFLAGS_INTERNAL_REFMON    0x0010  /* bit 5 - internal ref. mon.    */
                                             /*         others not supported  */
#define VIEWFLAGS_OWNER_ENABLED      0x0040  /* bit 7 - owner-enabled view    */
#define VIEWFLAGS_AC_PRIVS           0x0080  /* bit 8 - indicates that the    */

#ifndef CICS_ENV
#pragma pack()
#endif

#endif


#ifdef __cplusplus
     }
#endif
