/*BEGINPROLOGUE***************************************************/
/*                                                               */
/* COPYRIGHT:                                                    */
/* ----------                                                    */
/* Digital Library Version 2 - 5765-C86.                         */
/* VisualInfo Version 2 Release 3.0 - 5697-250.                  */
/* (C) Copyright IBM Corp., 1994,1998.  All Rights Reserved.     */
/*                                                               */
/* US Government Users Restricted Rights                         */
/* Use, duplication or disclosure restricted by GSA ADP Schedule */
/* Contract with IBM Corp.  Licensed Materials - Property of IBM */
/*                                                               */
/* MODULE: frnplw.h                                              */
/*                                                               */
/* Description: frnplw.h - this include is used by programs      */
/*                         calling the Library Object Mgr APIs   */
/*                         on OS/2 and by programs calling the   */
/*                         client's OLE APIs on Windows          */
/*                                                               */
/* Dependencies:                                                 */
/* Restrictions:                                                 */
/*                                                               */
/*                                                               */
/* Notes:                                                        */
/*                                                               */
/*ENDPROLOGUE*****************************************************/

#ifdef __cplusplus
   extern "C" {
#endif

#ifndef FRNPLW
#define FRNPLW 1

/*-----------------------------------*/
/*  constants                        */
/*-----------------------------------*/

/*
** Library Object Open constants.
*/
#define LOO_USECURRENT     0
#define LOO_DISPLAY        1
#define LOO_HIDE           2
#define LOO_DISALLOW       3

#define LOO_SHAREDREAD     0x0000  /* Open item in read only mode     */
#define LOO_EXCLWRITE      0x0001  /* Open item in update mode        */
#define LOO_LIST           0x0002  /* Open UIDs into a list window    */
#define LOO_NOFOCUS        0x0004  /* Don't give focus when opening   */

/*
** Library Object Create constants for  the initial window size.
*/
#define LOC_PMDEFAULT      0

#define LOC_DEFAULT        0
#define LOC_MAXIMIZE       1
#define LOC_MINIMIZE       2

/*
** Library Object Open API defines for disabling menu choices
*/
#define IP2_DISABLE_CHECKINOUT                  0x0001
#define IP2_DISABLE_DELETE                      0x0002
#define IP2_DISABLE_EXPORT                      0x0004
#define IP2_DISABLE_FAXOUT                      0x0008
#define IP2_DISABLE_FOLDER_FUNCTIONS            0x0010
#define IP2_DISABLE_INDEX_CLASS_CHANGE          0x0020
#define IP2_DISABLE_INDEX_VALUE_CHANGE          0x0040
#define IP2_DISABLE_NOTE_EDIT                   0x0080
#define IP2_DISABLE_NOTE_APPEND                 0x0100
#define IP2_DISABLE_PRINT                       0x0200
#define IP2_DISABLE_WORKBASKET_ACTIVATE         0x0400
#define IP2_DISABLE_WORKBASKET_REMOVAL          0x0800
#define IP2_DISABLE_WORKBASKET_SUSPEND          0x1000
#define IP2_DISABLE_WORKFLOW                    0x2000
#define IP2_DISABLE_SEARCH                      0x4000
#define IP2_DISABLE_OPTIONS                     0x8000

/* Library messages posted to calling application */
#define LW_CLOSE           WM_USER + 15000 + 100

/* Library Object API error codes. */
#define LO_SUCCESS           0
#define LO_WRN_NOUPDATE      1
#define LO_ERR_BASE          100
#define LO_ERR_ALLOCMEM      LO_ERR_BASE + 1
#define LO_ERR_THREAD        LO_ERR_BASE + 2
#define LO_ERR_GETMEM        LO_ERR_BASE + 3
#define LO_ERR_RESOURCE      LO_ERR_BASE + 4
#define LO_ERR_OIMSTART      LO_ERR_BASE + 5
#define LO_ERR_WINCREATE     LO_ERR_BASE + 6
#define LO_ERR_CHILDCREATE   LO_ERR_BASE + 7
#define LO_ERR_BUSY          LO_ERR_BASE + 8
#define LO_ERR_OIMOPEN       LO_ERR_BASE + 9
#define LO_ERR_OIMACCESS     LO_ERR_BASE + 10
#define LO_ERR_CONFIG        LO_ERR_BASE + 11
#define LO_ERR_CLOSEERR      LO_ERR_BASE + 12
#define LO_ERR_CANCEL        LO_ERR_BASE + 13
#define LO_ERR_CHILDCLOSE    LO_ERR_BASE + 14
#define LO_ERR_SECURITY      LO_ERR_BASE + 15
#define LO_ERR_OIMOPENNEXT   LO_ERR_BASE + 16
#define LO_ERR_INVALIDUID    LO_ERR_BASE + 17
#define LO_ERR_GENERAL       LO_ERR_BASE + 18
#define LO_ERR_LOWLIMIT      LO_ERR_BASE + 19
#define LO_ERR_CANCELLIST    LO_ERR_BASE + 20


/*-----------------------------------*/
/*  typedefs                         */
/*-----------------------------------*/

typedef struct _LIBOBJRET     /* Return structure for API calls   */
   {
   SHORT       rc;            /* Return code                      */
   HWND        hwndLibObj;    /* Window handle of Lib Obj window  */
   ITEMID      uidLibObj;     /* UID of the Library Object        */
   HERR        hErrLog;       /* Error Log handle                 */
   } LIBOBJRET;

typedef LIBOBJRET FAR *   PLIBOBJRET;


/* Library Object Window item structure for Ip2LibObjOpenObject API */
typedef struct _LOWITEMSTRUCT {
   ULONG       ulStruct;        /* the size of this data structure   */
   USHORT      usIndexClass;    /* Index class of the Library Object */
   USHORT      usObjectType;    /* Object type of the Library Object */
   ITEMID      szItemID;        /* UID of the Library Object         */
}  LOWITEMSTRUCT;

typedef LOWITEMSTRUCT *PLOWITEMSTRUCT;


/*-----------------------------------*/
/*  prototypes                       */
/*-----------------------------------*/

ULONG SIMENTRY Ip2LibObjCreateWin(
       HSESSION  hSession,              /* session handle                   */
       HWND      hwndCaller,            /* Calling program's window handle  */
       PSZ       pszUserID,             /* User ID                          */
       USHORT    usX,                   /* Library obj window horiz offset  */
       USHORT    usY,                   /* Library obj window vert offset   */
       USHORT    usCX,                  /* Library obj window horiz size    */
       USHORT    usCY,                  /* Library obj window vert size     */
       USHORT    usMode,                /* Library obj window create size   */
       ULONG     ulResultMsg,           /* Message ID to post to caller prog*/
       PRCSTRUCT pRC );                 /* pointer to return data structure */

ULONG SIMENTRY Ip2LibObjOpenObject(
       HSESSION  hSession,              /* session handle                   */
       HWND      hwndCaller,            /* Calling program's window handle  */
       HWND      hwndLOW,               /* Library obj window handle        */
       PLOWITEMSTRUCT pLowItemInfo,     /* Pointer to a LOW item structure  */
       USHORT    usOpenMode,            /* Library obj window open mode     */
       USHORT    usViewWin,             /* View window                      */
       USHORT    usNoteWin,             /* Note window                      */
       USHORT    usIndexWin,            /* Index window                     */
       USHORT    usPageNum,             /* Page number for view window      */
       BOOL      fTOCMode,              /* TOC mode                         */
       BITS      fDisable,              /* Reserved                         */
       ULONG     ulResultMsg,           /* Message ID to post to caller prog*/
       PRCSTRUCT pRC );                 /* pointer to return data structure */

ULONG SIMENTRY Ip2LibObjCloseObject(
       HSESSION  hSession,              /* session handle                   */
       HWND      hwndCaller,            /* Calling program's window handle  */
       HWND      hwndLOW,               /* Library obj window handle        */
       PITEMID   pszItemID,             /* Pointer to an item ID            */
       ULONG     ulResultMsg,           /* Message ID to post to caller prog*/
       PRCSTRUCT pRC );                 /* pointer to return data structure */

#endif

#ifdef __cplusplus
   }
#endif

