/***************************************************************************/
/*                                                                         */
/*      5621-326 (C) Copyright IBM Corp. 1993, 1994.                       */
/*      All Rights Reserved.                                               */
/*                                                                         */
/*      US Government Users Restricted Rights                              */
/*      - Use, duplication or disclosure                                   */
/*      restricted by GSA ADP Schedule Con-                                */
/*      tract with IBM Corp.                                               */
/*                                                                         */
/*      Licensed Materials - Property of IBM                               */
/*                                                                         */
/*                                                                         */
/* MODULE: frnpusrx.h                                                      */
/*                                                                         */
/* Date: November 1993                                                     */
/*                                                                         */
/*                                                                         */
/* Description: frnpusrx.h - this include is used by programs              */
/*                           calling user exits                            */
/*                                                                         */
/*                                                                         */
/* Notes:                                                                  */
/*  - includes necessary definitions for creating a user exit              */
/*                                                                         */
/***************************************************************************/

#ifdef __cplusplus
   extern "C" {
#endif

#ifndef FRNPUSRX
#define FRNPUSRX 1

/*
** include common data defines
*/
#ifndef FRNP
#define FRN_INCL_FI
#include "frnp.h"
#endif

#define UX_PRIV_READ       1  /* User has read-only privileges          */
#define UX_PRIV_WRITE      2  /* User has read/write privileges         */

/*
** These are used in the Determine Next Workbasket user exit
*/
#define UX_SAVE_ITEM       1  /* Called during a save operation         */
#define UX_ROUTE           2  /* Called during a route to operation     */
#define UX_START_WORKFLOW  3  /* Called during a start workflow         */
#define UX_CHANGE_WORKFLOW 4  /* Called during a change workflow        */
#define UX_IMPORT_ITEM     5  /* Called during an import operation      */
#define UX_SCAN_ITEM       6  /* Called during a scan operation         */

/*
** The following common structures are used by most of the user exits
*/

typedef struct _FIELDVALUE
   {
   USHORT      usFieldId;     /* user defined attribute (field) id      */
   USHORT      usDataType;    /* Form manager data type of attribute id */
   USHORT      usMaxLength;   /* Maximum number of bytes for field      */
   BOOL        fIsReq;        /* TRUE if field is required              */
   PSZ         pBuffer;       /* Current value of the field in display  */
                              /* format (ASCIIZ).  The buffer size is   */
                              /* usMaxLength + 1.                       */
   }           FIELDVALUE;

typedef FIELDVALUE * PFIELDVALUE;

typedef struct _USEREXITSTRUCT
   {
   HSESSION    hSession;      /* session handle from SimLibLogon        */
   ITEMID      uidItem;       /* Uid of currently opened item           */
   ITEMID      itemidWorkflowId;
                              /* WorkflowID of currently opened item    */
   BOOL        fIsUnindexed;  /* TRUE if original item was unindexed    */
   USHORT      hOrigClass;    /* Original class id of the item          */
   USHORT      hClass;        /* Current class id of the item           */
   CHAR        szUserId[LST_USERID_LEN + 1];
                              /* User id of user accessing item         */
   CHAR        szUserHandle[LST_USERID_LEN + 1];
                              /* User handle of user accessing item     */
   USHORT      usAccessLevel; /* UX_PRIV_READ or UX_PRIV_WRITE          */
   SHORT       sFields;       /* Number of fields in pFields            */
   FIELDVALUE *pFields;       /* Array of index field values & info.    */
   }
               USEREXITSTRUCT;


/*
** Query Sort User Exit Definitions:
*/

#define  SF_HIDE  0x0001

typedef struct _ATINFO
   {
   USHORT          atid;
   PATTRINFOSTRUCT pai;
   }
               ATINFO;

typedef ATINFO * PATINFO;

typedef struct _ATLIST
   {
   USHORT      usClass;       /* Class of this item                      */
   USHORT      usCount;       /* # of attributes in patinfo list         */
   ATINFO *    patinfo;       /* List of attributes                      */
   USHORT      usUserCount;   /* # of attributes in patid list           */
   USHORT *    patidUserList; /* List of user attributes                 */
   }
               ATLIST;

typedef ATLIST * PATLIST;

typedef struct _USERSORTSTRUCT
   {
   USHORT      usType;        /* SIM_FOLDER or SIM_DOCUMENT              */
   USHORT      usClass;       /* Class of this item                      */
   ITEMID      uid;           /* ITEMID of this item                     */
   USHORT      usPriority;    /* Priority of this item                   */
   PCHAR *     pszVals;       /* Array of values for this item           */
   PCHAR *     pszWbVals;     /* Workbasket-view values for item         */
   ATLIST *    pAttrList;     /* Attribute list for this item            */
   BOOL        fCheckedOut;   /* TRUE if item is checked out             */
   USHORT      usFlags;       /* Sort flags: SF_HIDE =don't display item */
   CHAR        reserved[6];   /* Reserved for system use                 */
   }
               USERSORTSTRUCT;

typedef USERSORTSTRUCT * PUSERSORTSTRUCT;


#endif

#ifdef __cplusplus
   }
#endif

