/* REXX */
/*============================================================================*\
 *  FRNOWFFM.CMD  -  VHLPI - FlowMark/2 Command Line Execution                *
 *                                                                            *
 * 5697-250, 5621-326                                                         *
 * (C) Copyright IBM Corporation 1995, 1996.  All Rights Reserved.            *
 *                                                                            *
 * DERIVATIVE RIGHTS:                                                         *
 * ------------------                                                         *
 * This program is provided for the customer's use and the customer is        *
 * granted permission to copy this program to the extent reasonably           *
 * required for such use.  All title, ownership, and rights to this           *
 * program and any copies remain with IBM, irrespective of the ownership      *
 * of the media on which the program resides.  The customer is permitted      *
 * to create derivative works to this program.  However, all copies of        *
 * the program and its derivative works must contain the IBM copyright        *
 * notice.  The customer understands and agrees that this program in and      *
 * of itself is not to be sold or distributed.  The customer is free to       *
 * sell, distribute, and commercially exploit any derivative works            *
 * created from this program.                                                 *
 *                                                                            *
 * DISCLAIMER OF WARRANTIES:                                                  *
 * -------------------------                                                  *
 * The following [enclosed] code is sample code created by IBM                *
 * Corporation.  This sample code is not part of any standard IBM product     *
 * and is provided to you solely for the purpose of assisting you in the      *
 * development of your applications.  The code is provided "AS IS",           *
 * without warranty of any kind.  IBM shall not be liable for any damages     *
 * arising out of your use of the sample code, even if they have been         *
 * advised of the possibility of such damages.                                *
 *                                                                            *
 *----------------------------------------------------------------------------*
 *                                                                            *
 *  This REXX program enables a FlowMark workflow process to invoke the       *
 *  VHLPI REXX functions through command line parameters.                     *
 *                                                                            *
 *  The function API input fields can be specified in the FlowMark program    *
 *  notebook settings as literal constants or coming from the FlowMark        *
 *  input data container variables using the "%xxx%" feature of FlowMark      *
 *  where xxx = the input data container name.                                *
 *                                                                            *
 *  The function API output fields, on the other hand, is specified in the    *
 *  command line as the FlowMark output data container name.                  *
 *  For example:                                                              *
 *      "OUT.Item_ID"           -  a field or array of character strings      *
 *                                                                            *
 *  This program's parms can be separated by blanks or comma.   Single        *
 *  or double quotes can be used to imbed blanks or commas within parms.      *
 *                                                                            *
 *  The first parameter is the name of VHLPI REXX function API to be          *
 *  to be invoked, which are:                                                 *
 *   1.  RxVhlAddFolderItem        -  add an item to a folder                 *
 *   2.  RxVhlAdminItemNoteLog     -  create, delete, replace, list or        *
 *                                    export document notes                   *
 *   3.  RxVhlChangeItemIndex      -  change the index class of an item to    *
 *                                    another index class                     *
 *   4.  RxVhlCheckInItem          -  checks-in  Item                         *
 *   5.  RxVhlCheckOutItem         -  checks-out Item for exclusive use       *
 *   6.  RxVhlCloseDocViews        -  close all document display windows      *
 *   7.  RxVhlCopyDoc              -  create a document and copies an         *
 *                                    existing document contents to it        *
 *   8.  RxVhlCreateFolder         -  create a new folder                     *
 *   9.  RxVhlCreateFolderAddItem  -  create a new folder and add a specified *
 *                                    item to it                              *
 *  10.  RxVhlDeleteItem           -  delete the item from the VI system      *
 *  11.  RxVhlDisplayDocView       -  display a document image specifying     *
 *                                    window initial position and size        *
 *  12.  RxVhlDisplayVIItem        -  display the image, notes & attributes   *
 *  13.  RxVhlExportDocObj         -  create an external file from a document *
 *  14.  RxVhlGetVIUserID          -  returns UserId logged onto VisualInfo   *
 *  15.  RxVhlImportDocObj         -  create a document from an external file *
 *  16.  RxVhlListContClasses      -  list all content classes                *
 *  17.  RxVhlListFolderItems      -  list all items in a given folder        *
 *  18.  RxVhlListFolderItemsAttr  -  list all items & specified attributes   *
 *                                    that are contained in a given folder    *
 *  19.  RxVhlListFolderXRefItem   -  list all folders containing an item     *
 *  20.  RxVhlListIndexClassAttr   -  list all attributes and its properties  *
 *                                    for a specified Index Class             *
 *  21.  RxVhlListIndexClasses     -  list all Index Classes                  *
 *  22.  RxVhlListItemCC           -  list the content class of an item       *
 *  23.  RxVhlListItemInfo         -  list all item's type, index class type, *
 *                                    index attributes & values               *
 *  24.  RxVhlListWBItems          -  list all items in a work basket         *
 *  25.  RxVhlListWorkBaskets      -  list all work baskets                   *
 *  26.  RxVhlRemoveFolderItem     -  delete the item from a folder but NOT   *
 *                                    from the VI system                      *
 *  27.  RxVhlScanDoc              -  invoke VI scan facility                 *
 *  28.  RxVhlSearchAdv            -  list all items matching the conditions  *
 *                                    specified by the user                   *
 *  29.  RxVhlSearchItem           -  list all items matching the index class *
 *                                    & index attribute specifications        *
 *                                                                            *
 *  The subsequent parms follow the syntax and conventions of the function    *
 *  API specified in the first parm.   The parms are positional.   Some       *
 *  of the parms maybe optional and can be ommitted by specifying "" or       *
 *  '' or ,, (equivalent to nulls).   For example,                            *
 *                                                                            *
 *  RxVhlSearchItem "OUT.DocID","%IndexClass%","%AttrName%","LIKE '%'"        *
 *  RxVhlSearchItem  OUT.DocID   %IndexClass%   %AttrName%  "== NULL"         *
 *  RxVhlScanDoc     OUT.DocID, "NOINDEX", "Userid", , "Source", "Scan"       *
 *                                                                            *
\*============================================================================*/

/*=========================================================================*\
 *  Start of Main program                                                  *
\*=========================================================================*/

/*-------------------------------------------------------------------------*/
/*  VHLPI prep routines:                                                   */
/*  -  Load DLL                                                            */
/*-------------------------------------------------------------------------*/
Call LoadDll "SysLoadFuncs",    "REXXUTIL"
Call LoadDll "RxVhlLoadFuncs",  "FRNOWFRX"

/*-------------------------------------------------------------------------*/
/*  FlowMark/2 prep routines:                                              */
/*  -  Load DLL                                                            */
/*  -  Get  input data container                                           */
/*  -  Copy input to output data container                                 */
/*-------------------------------------------------------------------------*/
Call LoadDll "ExmLoadFuncs",    "EXMPOREX"

If FmGetContainer()                    =  0                              then
   Call FmCopyContainer
Else
   Signal ExitMain

/*-------------------------------------------------------------------------*/
/*  Save arguments passed and parse/validate each parm                     */
/*-------------------------------------------------------------------------*/
Parse Arg ArgVar

If ExtractArgs()                                                         then
   /*----------------------------------------------------------------------*/
   /*  Error in arguments passed                                           */
   /*----------------------------------------------------------------------*/
   Signal CloseFM

/*-------------------------------------------------------------------------*/
/*  Construct API parms and call the API                                   */
/*-------------------------------------------------------------------------*/
Call ConstructApiParms

Interpret "rc                          =  "Parm.1"("FunctionCallParms")"

CloseFM:
/*-------------------------------------------------------------------------*/
/*  Save RC before call to set Flowmark data container                     */
/*-------------------------------------------------------------------------*/
saveRC                                 =  rc

/*-------------------------------------------------------------------------*/
/*  Set FlowMark output data container                                     */
/*-------------------------------------------------------------------------*/
Call FmSetContainer

/*-------------------------------------------------------------------------*/
/*  Restore RC after call from set Flowmark data container                 */
/*-------------------------------------------------------------------------*/
rc                                     =  saveRC

ExitMain:
Exit rc

/*=========================================================================*/
 *  End of Main program                                                    */
\*=========================================================================*/



/*-------------------------------------------------------------------------*/
/* FRNOWFFM common/shared subroutines.                                     */
/*-------------------------------------------------------------------------*/
/*  1.  ExtractArgs        -  parse and validate arguments                 */
/*  2.  Test4Quote         -  test for single/double quotes & extract parm */
/*  3.  ValidateFuncName   -  validate function name specified in parm 1   */
/*  4.  ConstructApiParms  -  construct the VHLPI function call parameters */
/*  5.  LoadDll            -  load VHLPI and FlowMark/2 DLLs               */
/*  6.  FmGetContainer     -  get FlowMark input data container            */
/*  7.  FmCopyContainer    -  copy FlowMark metain to metaout data contain.*/
/*  8.  FmCheckContainer   -  check FlowMark metaout data container type   */
/*  9.  FmSetContainer     -  set Flowmark output data container           */
/*-------------------------------------------------------------------------*/

/*-------------------------------------------------------------------------*/
ExtractArgs:
   /*----------------------------------------------------------------------*/
   /*  Parse and validate arguments from varstring place holder            */
   /*----------------------------------------------------------------------*/

   J                                   =  0
   Do while ArgVar                    \=  ""

      J                                =  J + 1

      /*-------------------------------------------------------------------*/
      /*  Test for single or double quotes and extract parm inside quotes  */
      /*-------------------------------------------------------------------*/
      rc                               =  Test4Quote()
      Select
         When rc                       =  0                              then
              Nop
         When rc                       =  1                              then
              Iterate
         Otherwise
              Return 1
      End

      /*-------------------------------------------------------------------*/
      /*  No single or double quotes, argument = next word                 */
      /*  Remove comma or blank separator                                  */
      /*-------------------------------------------------------------------*/
      Parse Var ArgVar Parm.J " " ArgVar
      Parse Var Parm.J Parm.J "," ArgVarJ
      ArgVar                           =  Strip(ArgVarj ArgVar)

   End

   Parm.0                              =  J

   Return ValidateFuncName()
/*-------------------------------------------------------------------------*/



/*-------------------------------------------------------------------------*/
Test4Quote:
   /*----------------------------------------------------------------------*/
   /*  Test for single/double quotes & extract parm inside the quotes      */
   /*----------------------------------------------------------------------*/

   Quote.1                             =  "'"
   Quote.2                             =  '"'

   Do I = 1 to 2

      If Left(ArgVar,1)               \=  Quote.I                        then
         rc                            =  0
      Else
         Do
            Quote2Pos                  =  Pos(Quote.I,ArgVar,2)
            I                          =  2
            If Quote2Pos               =  0                              then
               rc                      =  2
            Else
               Do
                  rc                   =  1
                  Parm.J               =  Substr(ArgVar,2,Quote2Pos-2)
                  ArgVar               =  Substr(ArgVar,Quote2Pos+1)
                  /*-------------------------------------------------------*/
                  /*  Test for comma separator and remove                  */
                  /*-------------------------------------------------------*/
                  If Left(ArgVar,1)    =  ","                            then
                     ArgVar            =  Strip(Substr(ArgVar,2))
                  Else
                     ArgVar            =  Strip(ArgVar)
               End
         End

   End

   Return rc
/*-------------------------------------------------------------------------*/



/*-------------------------------------------------------------------------*/
ValidateFuncName:
   /*----------------------------------------------------------------------*/
   /*  Validate VHLPI Function name specified in parm 1                    */
   /*----------------------------------------------------------------------*/
   Select
      When Parm.1                   =  "RxVhlAddFolderItem"              then
           Return 0
      When Parm.1                   =  "RxVhlAdminItemNoteLog"           then
           Return 0
      When Parm.1                   =  "RxVhlChangeItemIndex"            then
           Return 0
      When Parm.1                   =  "RxVhlCheckInItem"                then
           Return 0
      When Parm.1                   =  "RxVhlCheckOutItem"               then
           Return 0
      When Parm.1                   =  "RxVhlCloseDocViews"              then
           Return 0
      When Parm.1                   =  "RxVhlCopyDoc"                    then
           Return 0
      When Parm.1                   =  "RxVhlCreateFolder"               then
           Return 0
      When Parm.1                   =  "RxVhlCreateFolderAddItem"        then
           Return 0
      When Parm.1                   =  "RxVhlDeleteItem"                 then
           Return 0
      When Parm.1                   =  "RxVhlDisplayDocView"             then
           Return 0
      When Parm.1                   =  "RxVhlDisplayVIItem"              then
           Return 0
      When Parm.1                   =  "RxVhlExportDocObj"               then
           Return 0
      When Parm.1                   =  "RxVhlGetVIUserID"                then
           Return 0
      When Parm.1                   =  "RxVhlImportDocObj"               then
           Return 0
      When Parm.1                   =  "RxVhlListContClasses"            then
           Return 0
      When Parm.1                   =  "RxVhlListFolderItems"            then
           Return 0
      When Parm.1                   =  "RxVhlListFolderItemsAttr"        then
           Return 0
      When Parm.1                   =  "RxVhlListFolderXrefItem"         then
           Return 0
      When Parm.1                   =  "RxVhlListIndexClassAttr"         then
           Return 0
      When Parm.1                   =  "RxVhlListIndexClasses"           then
           Return 0
      When Parm.1                   =  "RxVhlListItemCC"                 then
           Return 0
      When Parm.1                   =  "RxVhlListItemInfo"               then
           Return 0
      When Parm.1                   =  "RxVhlListWBItems"                then
           Return 0
      When Parm.1                   =  "RxVhlListWorkBaskets"            then
           Return 0
      When Parm.1                   =  "RxVhlRemoveFolderItem"           then
           Return 0
      When Parm.1                   =  "RxVhlScanDoc"                    then
           Return 0
      When Parm.1                   =  "RxVhlSearchAdv"                  then
           Return 0
      When Parm.1                   =  "RxVhlSearchItem"                 then
           Return 0
      Otherwise
           Return 1
   End

   Return 0
/*-------------------------------------------------------------------------*/



/*-------------------------------------------------------------------------*/
ConstructApiParms:
   /*----------------------------------------------------------------------*/
   /*  Construct the VHLPI function call parameters                        */
   /*----------------------------------------------------------------------*/
   If Parm.0                           <  2                              then
      Do
         FunctionCallParms             =  ""
      End
   Else
      Do I = 2 to Parm.0
         If I                          =  2                              then
            Do
               FunctionCallParms       =  "Parm."I
            End
         Else
            Do
               FunctionCallParms       =  FunctionCallParms", Parm."I
            End
      End

   Return
/*-------------------------------------------------------------------------*/



/*-------------------------------------------------------------------------*/
LoadDll:
   /*----------------------------------------------------------------------*/
   /* Load DLL and call LoadFuncs API to load all other APIs               */
   /*----------------------------------------------------------------------*/

   If RxFuncQuery(Arg(1))              >  0                              then
      Do
        rc                             =  RxFuncAdd(Arg(1),Arg(2),Arg(1))
        If rc                          =  0                              then
           Interpret "rc               =  "Arg(1)"()"
      end

   Return rc
/*-------------------------------------------------------------------------*/



/*-------------------------------------------------------------------------*/
FmGetContainer:
   /*----------------------------------------------------------------------*/
   /* Get Flowmark input container                                         */
   /*----------------------------------------------------------------------*/
   rc                                  =  ExmGetAllContainerItems()
   If rc                               =  0                              then
      ExmRCMessage                     =  "successful completion"

   Return rc
/*-------------------------------------------------------------------------*/



/*-------------------------------------------------------------------------*/
FmCopyContainer:
   /*----------------------------------------------------------------------*/
   /* Copies all metain (IN...) to metaout (OUT...) variables              */
   /*----------------------------------------------------------------------*/

   /*----------------------------------------------------------------------*/
   /* Loop through all the members in the output data container            */
   /*----------------------------------------------------------------------*/
   Do I = 1 to MetaOut.0

      /*-------------------------------------------------------------------*/
      /* Exclude all predefined data structure members                     */
      /*-------------------------------------------------------------------*/
      If MetaOut.I.0Name               =  "OUT._PROCESS"                 |,
         MetaOut.I.0Name               =  "OUT._ACTIVITY"                |,
         MetaOut.I.0Name               =  "OUT._RC"                      then
         Iterate

      /*-------------------------------------------------------------------*/
      /* Test for array                                                    */
      /*-------------------------------------------------------------------*/
      If MetaOut.I.0Size                          >  0                   then

         Do
           /*--------------------------------------------------------------*/
           /* Loop through all the array elements                          */
           /*--------------------------------------------------------------*/
           Do J = 1 to MetaOut.I.0Size
              /*-----------------------------------------------------------*/
              /* Reset meta data output container variable to its value    */
              /*-----------------------------------------------------------*/
              Call FmCheckContainer MetaOut.I.0Name||"."||J, MetaOut.I.0Type
           End
         End

      Else

         /*----------------------------------------------------------------*/
         /* Reset meta data output container variable to its value         */
         /*----------------------------------------------------------------*/
         Call FmCheckContainer MetaOut.I.0Name, MetaOut.I.0Type

   End

   Return
/*-------------------------------------------------------------------------*/



/*-------------------------------------------------------------------------*/
FmCheckContainer:
   /*----------------------------------------------------------------------*/
   /* Check metaout data container type                                    */
   /*----------------------------------------------------------------------*/

   OUT_ContainerVar                    =  arg(1)
   OUT_ContainerType                   =  arg(2)

   IN_ContainerVar                     =  "IN."||substr(OUT_ContainerVar,5)

   /*----------------------------------------------------------------------*/
   /* Check if input data container is uninitialized                       */
   /*----------------------------------------------------------------------*/
   If symbol(IN_ContainerVar)          =  "VAR"                          then
      OUT_ContainerValue               =  value(IN_ContainerVar)
   Else
      Do
        Select
           When OUT_ContainerType      =  0                              then
                OUT_ContainerValue     =  0
           When OUT_ContainerType      =  1                              then
                OUT_ContainerValue     =  ""
           When OUT_ContainerType      =  2                              then
                OUT_ContainerValue     =  0.00 + .000001 - .000001
           Otherwise
                OUT_ContainerValue     =  ""
        End
      End

   Interpret OUT_ContainerVar         "=  OUT_ContainerValue"

   Return
/*-------------------------------------------------------------------------*/



/*-------------------------------------------------------------------------*/
FmSetContainer:
   /*----------------------------------------------------------------------*/
   /* Set Flowmark output container                                        */
   /*----------------------------------------------------------------------*/
   rc                                  =  ExmSetAllContainerItems()
   If rc                               =  0                              then
      ExmRCMessage                     =  "successful completion"

   Return rc
/*-------------------------------------------------------------------------*/
