/****************************************************************************/
/* 5697-250                                                                 */
/* (C) Copyright IBM Corporation 1996.  All Rights Reserved.                */
/*                                                                          */
/* DERIVATIVE RIGHTS:                                                       */
/* ------------------                                                       */
/* This program is provided for the customer's use and the customer is      */
/* granted permission to copy this program to the extent reasonably         */
/* required for such use.  All title, ownership, and rights to this         */
/* program and any copies remain with IBM, irrespective of the ownership    */
/* of the media on which the program resides.  The customer is permitted    */
/* to create derivative works to this program.  However, all copies of      */
/* the program and its derivative works must contain the IBM copyright      */
/* notice.  The customer understands and agrees that this program in and    */
/* of itself is not to be sold or distributed.  The customer is free to     */
/* sell, distribute, and commercially exploit any derivative works          */
/* created from this program.                                               */
/*                                                                          */
/* DISCLAIMER OF WARRANTIES:                                                */
/* -------------------------                                                */
/* The following "enclosed" code is sample code created by IBM              */
/* Corporation.  This sample code is not part of any standard IBM product   */
/* and is provided to you solely for the purpose of assisting you in the    */
/* development of your applications.  The code is provided "AS IS",         */
/* without warranty of any kind.  IBM shall not be liable for any damages   */
/* arising out of your use of the sample code, even if they have been       */
/* advised of the possibility of such damages.                              */
/*                                                                          */
/****************************************************************************/
/*  System Header Files                                                     */
/****************************************************************************/
#ifdef _Windows
#include <windows.h>
#include "post.h"
#else
#include <os2.h>                        /* Main OS/2 header files            */
#endif
#include <stdio.h>                      /* Standard I/O header files         */
#include <stdlib.h>                     /* Standard Library header files     */
#include <string.h>                     /* String manipulation               */

/*****************************************************************************/
/*  VisualInfo Header Files                                                  */
/*****************************************************************************/

#define   FRN_INCL_FI                   /* Include frnpfi.h & frnpfi2.h      */
#include "frnp.h"                       /* Global types                      */
#include "frnpcapi.h"                   /* Structures and constants          */

/*****************************************************************************/
/*  frnoexcc Header File                                                     */
/*****************************************************************************/

#include "frnoexcc.h"                   /* Application header file           */

/*****************************************************************************/
/*  Global Variables                                                         */
/*****************************************************************************/

HSESSION hSession;                      /* Folder Manager session handle     */
ULONG    ulMemoryBlock;                 /* Generic pointer for SimLibFree    */
ITEMID   FolderItemID;                  /* ItemID of new folder              */


#ifdef _Windows
int fnFrnoexcc ( void )
#else
INT main ( void )
#endif
{
     ULONG ulretcode;

    /*************************************************************************/
    /*  Call Logon to establish a Folder Manager Session.                    */
    /*************************************************************************/

     ulretcode = Logon();

    /*************************************************************************/
    /* If successful, call FreeMemory to free the memory for structure       */
    /* USERLOGONINFOSTRUC returned from SimLibLogon.                         */
    /*************************************************************************/

     if (ulretcode == SIM_RC_OK)
           {
           FreeMemory();

    /*************************************************************************/
    /*  Call CreateFolderItemID to create a new folder ItemID.               */
    /*************************************************************************/

           ulretcode = CreateContentClasses();


    /*************************************************************************/
    /* Call Logoff to terminate the Folder Manager session.                  */
    /*************************************************************************/
           if (ulretcode == SIM_RC_OK)
               ulretcode = Logoff();
           else
               Logoff();
           }

    /*************************************************************************/
    /* Print return code.                                                    */
    /*************************************************************************/

    printf ("RETURN CODE = %lu\n", ulretcode);

    /*************************************************************************/
    /* Exit main() with the return code.                                     */
    /*************************************************************************/

    return ( ulretcode );
}

ULONG Logon ( void )
{
     PSZ      pszDBName;                /* Pointer to Database name          */
     PSZ      pszUserId;                /* Pointer to User Id                */
     PSZ      pszPassword;              /* Pointer to Password for User Id   */
     RCSTRUCT RCStruct;                 /* RC data structure                 */

    /*************************************************************************/
    /* Reserve and initialize storage for SimLibLogon parameters.            */
    /* Print error message if sufficient storage is not available.           */
    /*************************************************************************/

     RCStruct.ulRC = SIM_RC_OK;
     pszDBName = (PSZ) malloc (SIM_SERVER_NAME_LENGTH + 1);
     if (pszDBName == NULL)
        {
        printf("Memory allocation error for pszDBName.\n");
        RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
        }
     else
        {
        memset (pszDBName, '\0', SIM_SERVER_NAME_LENGTH + 1);
        pszUserId = (PSZ) malloc (OIM_MAXIMUM_USERID_LENGTH + 1);
        if (pszUserId == NULL)
            {
            printf("Memory allocation error for pszUserId.\n");
            RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
            }
        else
            {
            memset (pszUserId, '\0', OIM_MAXIMUM_USERID_LENGTH + 1);
            pszPassword = (PSZ) malloc (OIM_MAX_PASSWORD_LENGTH + 1);
            if (pszPassword == NULL)
                {
                printf("Memory allocation error for pszPassword.\n");
                RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
                }
            else
                {
                memset (pszPassword, '\0', OIM_MAX_PASSWORD_LENGTH + 1);

    /*************************************************************************/
    /* Initialize SimLibLogon parameters.                                    */
    /*************************************************************************/

                strcpy (pszDBName,          PSZDBNAME);
                strcpy (pszUserId,          PSZUSERID);
                strcpy (pszPassword,        PSZPASSWORD);
                }
            }
        }
    if (RCStruct.ulRC == SIM_RC_OK)
    {
    /*************************************************************************/
    /* Call SimLibLogon to establish a Folder Manager session.               */
    /*************************************************************************/

     SimLibLogon( pszDBName,               /* Pointer to Database name       */
                  (PSZ) "",                /* Reserved for future use        */
                  pszUserId,               /* Pointer to User Id             */
                  pszPassword,             /* Pointer to Password for User Id*/
                  (PSZ) NULL,              /* Logon without new password     */
                  (PSZ) NULL,              /* Reserved for future use        */
                  (PSZ) NULL,              /* Reserved for future use        */
                  SIM_SS_NORMAL,           /* Non-configuration session logon*/
                  (PASYNCCTLSTRUCT) NULL,  /* Request synchronous processing */
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

     if ((RCStruct.ulRC == SIM_RC_OK)  ||
         (RCStruct.ulRC == SIM_RC_GRACE_PERIOD_UNDER_LIMIT) ||
         (RCStruct.ulRC == SIM_RC_GRACE_PERIOD_OVER_LIMIT))

    /*************************************************************************/
    /* If successful, save the Folder Manager session handle for subsequent  */
    /* Folder Manager API calls.                                             */
    /*************************************************************************/

         {
         RCStruct.ulRC = SIM_RC_OK;
         hSession = RCStruct.ulParam1;

    /*************************************************************************/
    /* Save the pointer to the USERLOGONINFOSTRUCT data structure in order   */
    /* to free the memory.                                                   */
    /*************************************************************************/

         ulMemoryBlock = RCStruct.ulParam2;
         }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }
    }

    /*************************************************************************/
    /*  Free storage reserved with malloc and return to main() with a return */
    /*  code.                                                                */
    /*************************************************************************/

    free (pszDBName);
    free (pszUserId);
    free (pszPassword);

return( RCStruct.ulRC );
}

VOID FreeMemory (void)
{
     RCSTRUCT RCStruct;                    /* RC data structure              */

     SimLibFree  ( hSession,               /* Folder Manager session handle  */
                  (PVOID) ulMemoryBlock,   /* Pointer to memory block to free*/
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

return;
}


ULONG CreateContentClasses ( VOID )
{
//   CONTENTCLASSINFO cc;                  /* Folder Attributes array        */
     RCSTRUCT         RCStruct;            /* RC data structure              */
     USHORT           count;               /* Loop counter                   */

    /*************************************************************************/
    /* Call Ip2SetReserve                                                    */
    /*************************************************************************/

     Ip2SetReserve( hSession,              /* Folder Manager session handle  */
          (PRCSTRUCT) &RCStruct );         /* Pointer to RC data structure   */

    /******************************************************/
    /* Print Content Class Info.                          */
    /******************************************************/

     printf ("Content Class :\n\n");
     for ( count = 0 ;
           count < USNEWCCS;
           count ++
         )
         {
//       cc.ulStruct         = sizeof(CONTENTCLASSINFO);
//       cc.usContentClsID   = ccnew[count].usContentClsID;
//       strcpy(cc.szContentClsName, ccnew[count].szContentClsName);
//       strcpy(cc.szContentClsDesc, ccnew[count].szce");
         printf("CC ID           = %hu\n",
                 cc[count].usContentClsID);
         printf("CC Name         = %s\n",
                 cc[count].szContentClsName);
         printf("CC Description  = %s\n",
                 cc[count].szContentClsDesc);

    /*************************************************************************/
    /* Call Ip2AddContentClass                                               */
    /*************************************************************************/

#ifdef _Windows
     if(iCreateFlag)
        Ip2AddContentClass( hSession,         /* Folder Manager session handle  */
             (PCONTENTCLASSINFO) &cc[count],  /* Content Class to create        */
             (PASYNCCTLSTRUCT) NULL,          /* Request synchronous processing */
             (PRCSTRUCT) &RCStruct );         /* Pointer to RC data structure   */
     else {
        printf("Deleting...\n");
        Ip2DeleteContentClass( hSession,      /* Folder Manager session handle  */
              cc[count].usContentClsID,       /* Content Class to delete        */
             (PASYNCCTLSTRUCT) NULL,          /* Request synchronous processing */
             (PRCSTRUCT) &RCStruct );         /* Pointer to RC data structure   */
     }
#else
     Ip2AddContentClass( hSession,         /* Folder Manager session handle  */
          (PCONTENTCLASSINFO) &cc[count],  /* Content Class to create        */
          (PASYNCCTLSTRUCT) NULL,          /* Request synchronous processing */
          (PRCSTRUCT) &RCStruct );         /* Pointer to RC data structure   */
#endif

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

         printf("ulRC = %ld\n", RCStruct.ulRC);
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;

         }
    /*************************************************************************/
    /*  Return to main() with a return code from SimLibCreateItem.           */
    /*************************************************************************/

     return( RCStruct.ulRC );
}

ULONG Logoff ( void )
{
     RCSTRUCT RCStruct;                     /* RC data structure             */

    /*************************************************************************/
    /* Call SimLibLogoff to terminate the Folder Manager session.            */
    /*************************************************************************/

     SimLibLogoff( hSession,                /* Folder Manager session handle */
                  (PASYNCCTLSTRUCT) NULL,   /* Request synchronous processing*/
                  (PRCSTRUCT) &RCStruct );  /* Pointer to RC data structure  */

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
         RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
         RCStruct.ulRC =  RCStruct.ulExtRC;

    /*************************************************************************/
    /*  Return to main() with the return code from SimLibLogoff.             */
    /*************************************************************************/

     return( RCStruct.ulRC );
}

/*****************************************************************************/
/* End of frnoexcc.C                                                         */
/*****************************************************************************/



