/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/* MODULE: FRNOEXDI.C                                         VisualInfo     */
/*                                                                           */
/* 5697-250                                                                  */
/* 5621-326, 5655-036, 5622-213, 5655-071, 5655-072                          */
/*                                                                           */
/* (C) Copyright IBM Corporation 1993, 1996.                                 */
/* All Rights Reserved.                                                      */
/*                                                                           */
/* DERIVATIVE RIGHTS:                                                        */
/* ------------------                                                        */
/* This program is provided for the customer's use and the customer is       */
/* granted permission to copy this program to the extent reasonably          */
/* required for such use.  All title, ownership, and rights to this          */
/* program and any copies remain with IBM, irrespective of the ownership     */
/* of the media on which the program resides.  The customer is permitted     */
/* to create derivative works to this program.  However, all copies of       */
/* the program and its derivative works must contain the IBM copyright       */
/* notice.  The customer understands and agrees that this program in and     */
/* of itself is not to be sold or distributed.  The customer is free to      */
/* sell, distribute, and commercially exploit any derivative works           */
/* created from this program.                                                */
/*                                                                           */
/*                                                                           */
/* DISCLAIMER OF WARRANTIES:                                                 */
/* -------------------------                                                 */
/* The following [enclosed] code is sample code created by IBM               */
/* Corporation.  This sample code is not part of any standard IBM product    */
/* and is provided to you solely for the purpose of assisting you in the     */
/* development of your applications.  The code is provided "AS IS",          */
/* without warranty of any kind.  IBM shall not be liable for any damages    */
/* arising out of your use of the sample code, even if they have been        */
/* advised of the possibility of such damages.                               */
/*                                                                           */
/* Status: Version 2 Release 1 Modification 0                                */
/*                                                                           */
/*****************************************************************************/
/* Description : FRNOEXDI.C - Sample application code to display a document. */
/*               Folder Manager APIs used are : SimLibLogon, SimLibFree,     */
/*               SimLibGetItemAffiliatedTOC, and SimLibLogoff.               */
/*               Image Services APIs used are: SimOpsInitEnv,                */
/*               SimWsLoadObj, SimDspCreateWin, and SimWsDeleteObj.          */
/*                                                                           */
/*                                                                           */
/* Dependencies: To run this sample code without modification:               */
/*               - A document item with one Base part must exist.            */
/*                 Specify the ItemID of this document in FRNOEXDI.H.        */
/*               - This sample code must be used in conjunction with a       */
/*                 modified version of Image Services user exit FIWSXCLS.C   */
/*                 which will post a WM_QUIT message to FRNOEXDI.C when the  */
/*                 the display window is closed.  This version of FIWSXCLS.C */
/*                 is provided in the sample directory along with FRNOEXDI.C */
/*                                                                           */
/* Restrictions: None                                                        */
/*                                                                           */
/* Entry Points: main                                                        */
/*               InitializePM                                                */
/*               CreateMsgQueue                                              */
/*               Logon                                                       */
/*               FreeMemory                                                  */
/*               GetDocumentTOC                                              */
/*               DisplayDocument                                             */
/*               InitEnvironment                                             */
/*               LoadWorkingSet                                              */
/*               CreateDispWindow                                            */
/*               FreeWorkingSet                                              */
/*               Logoff                                                      */
/*               ShowMessageBox                                              */
/*               DestroyMsgQueue                                             */
/*               Terminate                                                   */
/*                                                                           */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

/*****************************************************************************/
/* Presentation Manager and OS/2 Control Program definitions                 */
/*****************************************************************************/

#define INCL_WINWINDOWMGR
#define INCL_WINMESSAGEMGR
#define INCL_WINDIALOGS
#define INCL_DOSMEMMGR

/*****************************************************************************/
/*  System Header Files                                                      */
/*****************************************************************************/

#include <os2.h>                        /* Main OS/2 header files            */
#include <stdio.h>                      /* Standard I/O header files         */
#include <stdlib.h>                     /* Standard Library header files     */
#include <string.h>                     /* String manipulation               */

/*****************************************************************************/
/*  VisualInfo Header Files                                                  */
/*****************************************************************************/

#define   FRN_INCL_FI                   /* Include frnpfi.h & frnpfi2.h      */
#define   FRN_INCL_FO                   /* Include frnpfo.h                  */
#include "frnp.h"                       /* Global types                      */
#include "frnpcapi.h"                   /* Structures and constants          */

/*****************************************************************************/
/*  Image Services Header Files                                              */
/*****************************************************************************/

#define   FIWS_SERVER                   /* Required to read from a server    */
#include "fiws.h"                       /* Base Image Services               */
#include "fiwsenv.h"                    /* Environment prototypes            */
#include "fiwsws.h"                     /* Working Set prototypes            */
#include "fiwsdsp.h"                    /* Display prototypes                */

/*****************************************************************************/
/*  FRNOEXDI Header File                                                     */
/*****************************************************************************/

#include "frnoexdi.h"                   /* Application header file           */

/*****************************************************************************/
/*  Global Variables                                                         */
/*****************************************************************************/

CHAR      szMessage[100];               /* Message for message box window    */
HSESSION  hSession;                     /* Folder Manager session handle     */
ULONG     ulMemoryBlock;                /* Generic pointer for SimLibFree    */
ITEMID    DocItemID;                    /* Document to display               */
BOOL      fPartExists;                  /* Does a part exist for the document*/
OBJ       Obj;                          /* Document part to display          */
ULONG     ulObjConCls;                  /* Document content class            */
HAB       habPManchor;                  /* Anchor block handle               */
HMQ       hmqPMmq;                      /* Message queue handle              */
HMQ *     pMemory;                      /* Pointer for shared named memory   */
QMSG      qMsg;                         /* Message structure                 */
SIMWSOBJ  hWsObj;                       /* Working set object handle         */
SIMWIN    hWin;                         /* Display window handle             */

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : main                                                  */
/*                                                                           */
/*  Description      : main() function of a sample application to display    */
/*                     a document.                                           */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions:                                    */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  INT.                                                 */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  INT main ( void ).                                   */
/*                                                                           */
/*  Return values    :  If all functions are successful, the return code     */
/*                      from Logoff() is returned.  Otherwise, the return    */
/*                      code from InitializePM(), CreateMsgQueue(), Logon(), */
/*                      GetDocumentTOC(), or DisplayDocument() is returned.  */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Initialize Presentation Manager.                                 */
/*      2.  If the initialization is successful:                             */
/*          - Create a Presentation Manager message queue.  If the queue is  */
/*            successfully created, allocate named shared memory and         */
/*            store the message queue handle. If successful:                 */
/*            - Establish a session with the Folder Manager. If logon was    */
/*              successful:                                                  */
/*              - Free the memory containing the USERLOGONINFOSTRUC structure*/
/*                and get the table of contents for all base objects         */
/*                associated with an existing document.                      */
/*                If the table of contents is successfully created and base  */
/*                objects exist for the document :                           */
/*                - Save the Obj structure of the first document part as     */
/*                  the document that will be displayed.  Save the content   */
/*                  class of the document part.  Free the memory             */
/*                  containing the array of PAFFTOCENTRYSTRUCT structures    */
/*                - Display the document.                                    */
/*                - Logoff from the Folder Manager session.                  */
/*                - Display a message box window with the return code.       */
/*            Destroy the Presentation Manager message queue.                */
/*          Terminate the use of Presentation Manager.                       */
/*          Logoff from the Folder Manager session.                          */
/*      3.  Exit main() with a return code.                                  */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

INT main ( void )
{
     ULONG ulretcode;
     sprintf(szMessage, "FRNOEXDI ended with:");

    /*************************************************************************/
    /* Call InitializePM to initialize Presentation Manager.                 */
    /*************************************************************************/

     ulretcode = InitializePM();

    /*************************************************************************/
    /* If successful, call CreateMsgQueue to create a PM message queue.      */
    /* If the queue is created, allocate named shared memory and store the   */
    /* message queue handle.  The named shared memory will be used by        */
    /* Image Services user exit FIWSXCLS to post a WM_QUIT message to        */
    /* FRNOEXDI when the display window is closed.                           */
    /*************************************************************************/

     if (ulretcode == SIM_RC_OK)
         {
         ulretcode = CreateMsgQueue();

    /*************************************************************************/
    /*  If successful, call Logon to establish a Folder Manager Session.     */
    /*************************************************************************/

         if (ulretcode == SIM_RC_OK)
             {
             ulretcode = Logon();

    /*************************************************************************/
    /* If successful, call FreeMemory to free the memory for structure       */
    /* USERLOGONINFOSTRUC returned from SimLibLogon.                         */
    /*************************************************************************/

             if (ulretcode == SIM_RC_OK)
                 {
                 FreeMemory();

    /*************************************************************************/
    /*  Call GetDocumentTOC to find the document parts.  If base parts       */
    /*  exist for the document, the content class of the document part to    */
    /*  be displayed will be obtained.                                       */
    /*************************************************************************/

                 ulretcode = GetDocumentTOC();

    /*************************************************************************/
    /*  If successful, and base parts exist for the document, call           */
    /*  FreeMemory to free the memory for an array of AFFTOCENTRYSTRUCT      */
    /*  structures returned from SimLibGetItemAffiliatedTOC.                 */
    /*************************************************************************/

                 if ( (ulretcode == SIM_RC_OK) && (fPartExists == TRUE) )
                     {
                     FreeMemory();

    /*************************************************************************/
    /* Call DisplayDocument to display the document.                         */
    /*************************************************************************/

                     ulretcode = DisplayDocument();

    /*************************************************************************/
    /*  Call Logoff to terminate the Folder Manager Session.                 */
    /*  Display a message box window with return code. Call DestroyMsgQueue  */
    /*  to destroy the Presentation Manager message queue.                   */
    /*  Call Terminate to end the use of Presentation Manager.               */
    /*************************************************************************/

                     if (ulretcode == SIM_RC_OK)
                         ulretcode = Logoff();
                     else
                         Logoff();

                     ShowMessageBox(ulretcode);
                     DestroyMsgQueue();
                     Terminate();
                     }
                 else
                     {
                     Logoff();
                     ShowMessageBox(ulretcode);
                     DestroyMsgQueue();
                     Terminate();
                     }
                 }
             else
                {
                ShowMessageBox(ulretcode);
                DestroyMsgQueue();
                Terminate();
                }
             }
         else
             Terminate();
         }

    /*************************************************************************/
    /* Exit main() with the return code.                                     */
    /*************************************************************************/

    return ( ulretcode );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : InitializePM                                          */
/*                                                                           */
/*  Description      : This function is called from main to obtain an        */
/*                     anchor block and initialize Presentation Manager.     */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions:                                    */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG InitializePM ( void ).                         */
/*                                                                           */
/*  Return values    :  SIM_RC_OK or return code 12.                         */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Initialize Presentation Manager facilities by calling            */
/*          WinInitialize.                                                   */
/*      2.  Return to main() with either SIM_RC_OK or return code 12.        */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG InitializePM ( void )
{
     ULONG   ulRC;

    /*************************************************************************/
    /* Call WinInitialize to initialize Presentation Manager and obtain an   */
    /* anchor block handle.                                                  */
    /*************************************************************************/

     habPManchor = WinInitialize(0);
     if (habPManchor == NULLHANDLE)
         ulRC = 12;
     else
         ulRC = SIM_RC_OK;

    /*************************************************************************/
    /*  Return to main() with the return code from InitializePM.             */
    /*************************************************************************/

return( ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : CreateMsgQueue                                        */
/*                                                                           */
/*  Description      : This function is called from main to create a         */
/*                     Presentation Manager message queue.                   */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions:                                    */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG CreateMsgQueue ( void ).                       */
/*                                                                           */
/*  Return values    :  SIM_RC_OK, return code 16, or the return code        */
/*                      from DosAllocSharedMem.                              */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Create a Presentation Manager message queue by calling           */
/*          WinCreateMsgQueue.                                               */
/*      2.  Allocate named shared memory and store the message queue handle. */
/*      3.  Return to main() with either SIM_RC_OK, return code 16, or the   */
/*          return code from DosAllocSharedMem.                              */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG CreateMsgQueue ( void )
{
     ULONG   ulRC;

    /*************************************************************************/
    /* Call WinCreateMsgQueue to create a message queue.                     */
    /*************************************************************************/

     hmqPMmq = WinCreateMsgQueue((HAB) habPManchor, 1500);
     if (hmqPMmq == NULLHANDLE)
         ulRC = 16;
     else
         {
         ulRC = DosAllocSharedMem ((PVOID) &pMemory,
                                   (PSZ) PSZMEMNAME,
                                   (ULONG) sizeof(hmqPMmq),
                                   (ULONG) PAG_WRITE | PAG_COMMIT);
         if (ulRC == SIM_RC_OK)
            *pMemory = hmqPMmq;
         else
             {
             sprintf(szMessage, "DosAllocSharedMem failure.");
             ShowMessageBox(ulRC);
             }
         }

    /*************************************************************************/
    /*  Return to main() with the return code from CreateMsgQueue.           */
    /*************************************************************************/

return( ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : Logon                                                 */
/*                                                                           */
/*  Description      : This function is called from main() to logon to       */
/*                     VisualInfo Folder Manager.                            */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibLogon                        */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG Logon ( void ).                                */
/*                                                                           */
/*  Return values    :  SIM_RC_OUT_OF_MEMORY or the return code from         */
/*                      SimLibLogon.                                         */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Reserve storage for and initialize SimLibLogon parameters.       */
/*      2.  If sufficient storage is available, establish a session          */
/*           with the Folder Manager by calling SimLibLogon.                 */
/*      3.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG Logon ( void )
{
     PSZ      pszDBName;                /* Pointer to Database name          */
     PSZ      pszUserId;                /* Pointer to User Id                */
     PSZ      pszPassword;              /* Pointer to Password for User Id   */
     RCSTRUCT RCStruct;                 /* RC data structure                 */

    /*************************************************************************/
    /* Reserve and initialize storage for SimLibLogon parameters.            */
    /* Print error message if sufficient storage is not available.           */
    /*************************************************************************/

     RCStruct.ulRC      = SIM_RC_OK;

     pszDBName = (PSZ) malloc ( SIM_SERVER_NAME_LENGTH + 1);
     if (pszDBName == NULL)
        {
        sprintf(szMessage, "Memory allocation error for pszDBName.");
        RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
        }
     else
        {
        memset (pszDBName, '\0', SIM_SERVER_NAME_LENGTH + 1);
        pszUserId = (PSZ) malloc ( OIM_MAXIMUM_USERID_LENGTH + 1);
        if (pszUserId == NULL)
            {
            sprintf(szMessage, "Memory allocation error for pszUserId.");
            RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
            }
        else
            {
            memset (pszUserId, '\0', OIM_MAXIMUM_USERID_LENGTH + 1);
            pszPassword = (PSZ) malloc ( OIM_MAX_PASSWORD_LENGTH + 1);
            if (pszPassword == NULL)
                {
                sprintf(szMessage,"Memory allocation error for pszPassword.");
                RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
                }
            else
                {
                memset (pszPassword, '\0', OIM_MAX_PASSWORD_LENGTH + 1);

    /*************************************************************************/
    /* Initialize SimLibLogon parameters.                                    */
    /*************************************************************************/

                strcpy (pszDBName,            PSZDBNAME);
                strcpy (pszUserId,            PSZUSERID);
                strcpy (pszPassword,          PSZPASSWORD);
                }
            }
        }
    if (RCStruct.ulRC == SIM_RC_OK)
    {
    /*************************************************************************/
    /* Call SimLibLogon to establish a Folder Manager session.               */
    /*************************************************************************/

     SimLibLogon( pszDBName,               /* Pointer to Database name       */
                  (PSZ) "",                /* Reserved for future use        */
                  pszUserId,               /* Pointer to User Id             */
                  pszPassword,             /* Pointer to Password for User Id*/
                  (PSZ) NULL,              /* Logon without new password     */
                  (PSZ) NULL,              /* Logon without proxy            */
                  (PSZ) NULL,              /* Logon without proxy scope      */
                  SIM_SS_NORMAL,           /* Non-configuration session logon*/
                  (PASYNCCTLSTRUCT) NULL,  /* Request synchronous processing */
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

     if ((RCStruct.ulRC == SIM_RC_OK) ||
         (RCStruct.ulRC == SIM_RC_GRACE_PERIOD_UNDER_LIMIT))

    /*************************************************************************/
    /* If successful, save the Folder Manager session handle for subsequent  */
    /* Folder Manager API calls.                                             */
    /*************************************************************************/

         {
         RCStruct.ulRC = SIM_RC_OK;
         hSession = RCStruct.ulParam1;

    /*************************************************************************/
    /* Save the pointer to the USERLOGONINFOSTRUCT data structure in order   */
    /* to free the memory.                                                   */
    /*************************************************************************/

         ulMemoryBlock = RCStruct.ulParam2;
         }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC = RCStruct.ulExtRC;
         }
    }

    /*************************************************************************/
    /*  Free storage reserved with malloc and return to main() with a        */
    /*  return code.                                                         */
    /*************************************************************************/

    free (pszDBName);
    free (pszUserId);
    free (pszPassword);

return( RCStruct.ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function        : FreeMemory                                             */
/*                                                                           */
/*  Description     : This function is called from main() to free memory     */
/*                    allocated as the result of a Folder Manager            */
/*                    SimLibLogon, or SimLibGetItemAffiliatedTOC call.       */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibFree                         */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  VOID.                                                */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  VOID FreeMemory ( void ).                            */
/*                                                                           */
/*  Return values    :  None.                                                */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call SimLibFree to free memory allocated by the Folder Manager   */
/*          as a result of SimLibLogon, or SimLibGetItemAffiliatedTOC.       */
/*      2.  Return to main().                                                */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

VOID FreeMemory ( void )
{
     RCSTRUCT RCStruct;                    /* RC data structure              */

     SimLibFree  ( hSession,               /* Folder Manager session handle  */
                  (PVOID) ulMemoryBlock,   /* Pointer to memory block to free*/
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

return;

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : GetDocumentTOC                                        */
/*                                                                           */
/*  Description      : This function is called from main() to retrieve       */
/*                     the table of contents for a document.  The first      */
/*                     document part will be displayed.                      */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibGetItemAffiliatedTOC         */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG GetDocumentTOC ( void ).                       */
/*                                                                           */
/*  Return values    :  The return code from SimLibGetItemAffiliatedTOC.     */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Initialize SimLibGetItemAffiliatedTOC parameters.                */
/*      2.  Call the SimLibGetItemAffiliatedTOC Folder Manager API.          */
/*      3.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG GetDocumentTOC ( void )
{
     PAFFTOCENTRYSTRUCT DocuTOC;           /* TOC data structure             */
     RCSTRUCT           RCStruct;          /* RC data structure              */
     USHORT             count;             /* Loop counter                   */

    /*************************************************************************/
    /* Initialize SimLibGetItemAffiliatedTOC parameters.                     */
    /*************************************************************************/

     strncpy ( (PSZ)DocItemID, (PSZ)DOCITEMID, DOC_ID_SIZE);

    /*************************************************************************/
    /* Call SimLibGetItemAffiliatedTOC to get the table of contents for      */
    /* a document.                                                           */
    /*************************************************************************/

     SimLibGetItemAffiliatedTOC(hSession,/* Folder Manager session handle    */
          (PITEMID) DocItemID,           /* Get TOC for this Item ID         */
          SIM_BASE,                      /* Define object type as base       */
          (PASYNCCTLSTRUCT) NULL,        /* Request synchronous processing   */
          (PRCSTRUCT) &RCStruct );       /* Pointer to RC data structure     */

    /*************************************************************************/
    /* If parts exist for the document, save the pointer to the array        */
    /* of AFFTOCENTRYSTRUCT structures in order to free the memory.          */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
         {
         if ((PAFFTOCENTRYSTRUCT)RCStruct.ulParam2 == (PAFFTOCENTRYSTRUCT)NULL)
             {
             fPartExists = FALSE;
             sprintf(szMessage, "There are no parts for ItemID %s",
                     (PSZ)DocItemID);
             }
         else
             {
             ulMemoryBlock = RCStruct.ulParam1;
             fPartExists = TRUE;
             DocuTOC = (PAFFTOCENTRYSTRUCT)RCStruct.ulParam1;

    /*************************************************************************/
    /* Save the Obj structure of the first part associated with the          */
    /* document as the part that will be displayed. Also save the content    */
    /* class of the part.                                                    */
    /*************************************************************************/

             count = 0;
             Obj = DocuTOC[count].Obj;
             ulObjConCls = DocuTOC[count].ulObjConCls;
             }
         }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC = RCStruct.ulExtRC;
         }


return( RCStruct.ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : DisplayDocument                                       */
/*                                                                           */
/*  Description      : This function is called from main() to perform the    */
/*                     functions necessary to display the document.          */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions:                                    */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG DisplayDocument ( void ).                      */
/*                                                                           */
/*  Return values    :  If all functions are successful, SIM_RC_OK is        */
/*                      returned.  Otherwise the return code from            */
/*                      InitEnviroment(), LoadWorkingSet(),                  */
/*                      CreateDispWindow(), or FreeWorkingSet is returned.   */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Initialize the Image Services Environment.  If the               */
/*          initialization is successful:                                    */
/*          - Load the document into the working set. If the load is         */
/*            successful:                                                    */
/*            - Create a display window.  If the window creation is          */
/*              successful:                                                  */
/*            - Retrieve messages from the message queue until a WM_QUIT     */
/*              message is received.  Free the working set. Free the named   */
/*              shared memory.                                               */
/*      2.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG DisplayDocument ( void )
{
     ULONG       ulRC;

    /*************************************************************************/
    /*  Call InitEnvironment to initialize the Image Services environment.   */
    /*************************************************************************/

     ulRC = InitEnvironment();

    /*************************************************************************/
    /*  If successful, load the document into a working set.                 */
    /*************************************************************************/

     if (ulRC == SIM_RC_OK)
         {
         ulRC = LoadWorkingSet();

    /*************************************************************************/
    /*  If successful, create a display window to view the working set.      */
    /*************************************************************************/

         if (ulRC == SIM_RC_OK)
             {
             ulRC = CreateDispWindow();

    /*************************************************************************/
    /*  Get messages from the message queue until a WM_QUIT message          */
    /*  is received.                                                         */
    /*************************************************************************/


             while ( WinGetMsg(habPManchor, &qMsg, (HWND)0, 0, 0) )
                     {
                     WinDispatchMsg(habPManchor, &qMsg);
                     }

    /*************************************************************************/
    /*  Delete the working set.                                              */
    /*************************************************************************/

             if (ulRC == SIM_RC_OK)
                 ulRC = FreeWorkingSet();
             else
                 FreeWorkingSet();
             }
         }

    /*************************************************************************/
    /*  Free the named shared memory allocated in CreateMsgQueue(). This     */
    /*  will also decrement the reference count for the shared memory object.*/
    /*************************************************************************/

     DosFreeMem(pMemory);

    /*************************************************************************/
    /*  Return to main() with a return code.                                 */
    /*************************************************************************/

return( ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : InitEnvironment                                       */
/*                                                                           */
/*  Description      : This function is called from DisplayDocument to       */
/*                     initialize the Image Services environment.  This      */
/*                     function must be called before making any other Image */
/*                     Services API calls.                                   */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimOpsInitEnv                      */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG InitEnvironment ( void ).                      */
/*                                                                           */
/*  Return values    :  SIM_RC_OUT_OF_MEMORY or the return code from         */
/*                      SimOpsInitEnv.                                       */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Reserve storage for and initialize SimOpsInitEnv parameters.     */
/*      2.  If sufficient storage is available, call the SimOpsInitEnv       */
/*          Image Services API.                                              */
/*      3.  Return to DisplayDocument() with a return code.                  */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG InitEnvironment ( void )
{
     PSZ                pszApplDesc;       /* Application description        */
     PSZ                pszWorkingDir;     /* Image Services working dir     */
     PSZ                pszExitDir;        /* User exit directory            */
     PSZ                pszOManager;       /* Object Manager DLL             */
     RCSTRUCT           RCStruct;          /* RC data structure              */

    /*************************************************************************/
    /* Reserve and initialize storage for SimOpsInitEnv parameters.          */
    /* Print error message if sufficient storage is not available.           */
    /*************************************************************************/

     RCStruct.ulRC     = SIM_RC_OK;
     RCStruct.ulStruct = sizeof(RCSTRUCT);

     pszApplDesc = (PSZ) malloc (MAXDESC + 1);
     if (pszApplDesc == NULL)
         {
         sprintf(szMessage, "Memory allocation error for pszApplDesc.");
         RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
         }
     else
         {
         memset (pszApplDesc, '\0', MAXDESC + 1);
         pszWorkingDir = (PSZ) malloc (MAXDIRNAME + 1);
         if (pszWorkingDir == NULL)
             {
             sprintf(szMessage, "Memory allocation error for pszWorkingDir.");
             RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
             }
         else
             {
             memset (pszWorkingDir, '\0', MAXDIRNAME + 1);
             pszExitDir = (PSZ) malloc (MAXDIRNAME + 1);
             if (pszExitDir == NULL)
                 {
                 sprintf(szMessage, "Memory allocation error for pszExitDir.");
                 RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
                 }
             else
                 {
                 memset (pszExitDir, '\0', MAXDIRNAME + 1);
                 pszOManager = (PSZ) malloc (MAXDIRNAME + 1);
                 if (pszOManager == NULL)
                     {
                     sprintf(szMessage, "Memory allocation error for pszOManager.");
                     RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
                     }
                 else
                     {
                     memset (pszOManager, '\0', MAXDIRNAME + 1);

    /*************************************************************************/
    /* Initialize SimOpsInitEnv parameters.                                  */
    /*************************************************************************/

                     strcpy ( pszApplDesc,   PSZAPPLDESC );
                     strcpy ( pszWorkingDir, PSZWORKINGDIR );
                     strcpy ( pszExitDir,    PSZEXITDIR    );
                     strcpy ( pszOManager,   PSZOMANAGER );
                     }
                 }
             }
         }

    if (RCStruct.ulRC == SIM_RC_OK)
    {
    /*************************************************************************/
    /* Call SimOpsInitEnv to initialize the environment.                     */
    /*************************************************************************/

     SimOpsInitEnv(pszApplDesc,          /* Application description          */
          FALSE,                         /* Is this instance unattended?     */
          (PSZ)pszWorkingDir,            /* Working directory for application*/
          (PSZ)pszExitDir,               /* User exit directory              */
          (PSZ)NULL,                     /* Reserved for future use          */
          (PSZ)pszOManager,              /* Folder Mgr Object Manager DLL    */
          (PSZ)NULL,                     /* No additional help files         */
          (PRCSTRUCT) &RCStruct );       /* Pointer to RC data structure     */

    }

    /*************************************************************************/
    /*  Free storage reserved with malloc and return to DisplayDocument()    */
    /*  with a return code.                                                  */
    /*************************************************************************/

    free (pszApplDesc);
    free (pszWorkingDir);
    free (pszExitDir);
    free (pszOManager);

return( RCStruct.ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : LoadWorkingSet                                        */
/*                                                                           */
/*  Description      : This function is called from DisplayDocument to load  */
/*                     a document into the Image Services working set.       */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimWsLoadObj                       */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */

/*                                                                           */
/*  Synopsis         :  ULONG LoadWorkingSet ( void ).                       */
/*                                                                           */
/*  Return values    :  The return code from SimWsLoadObj.                   */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Initialize SimWsLoadObj parameters.                              */
/*      2.  Call the SimWsLoadObj Image Services API.                        */
/*      3.  Return to DisplayDocument() with a return code.                  */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG LoadWorkingSet ( void )
{
     SIMCONTROL_BASE    pControl;          /* Object load control information*/
     SIMSRCSERVEROBJ    pDataSrc;          /* Source from which to load data */
     SIMLOAD            pLoadID;           /* Pointer to load handle         */
     RCSTRUCT           RCStruct;          /* RC data structure              */


    /*************************************************************************/
    /* Initialize SimWsLoadObj parameters.                                   */
    /*************************************************************************/

     RCStruct.ulStruct = sizeof(RCSTRUCT);

    /****************************************/
    /* SIMCONTROL_BASE structure.           */
    /****************************************/

     pControl.ulStruct     = sizeof(SIMCONTROL_BASE);
     pControl.fReserved    = FALSE;
     pControl.pszDesc      = NULL;
     pControl.pImport      = NULL;
     pControl.ulImportLen  = 0;

    /***********************************/
    /* All attributes are visible.     */
    /***********************************/

     pControl.ulHideFrom   = SIMUSER_NONE;

    /***********************************/
    /* Annotation and mask control.    */
    /***********************************/

     pControl.ulDocControl = SIMDOCCTRL_ALLOW_ANNOTATIONS   |
                             SIMDOCCTRL_DISPLAY_ANNOTATIONS |
                             SIMDOCCTRL_PRINT_ANNOTATIONS   |
                             SIMDOCCTRL_ALLOW_MASKS         |
                             SIMDOCCTRL_HIDE_MASKS          |
                             SIMDOCCTRL_PRINT_MASKS;
     pControl.ulOptions    = SIMDOCCTRL_ALLOW_ANNOTATIONS;

    /****************************************/
    /* SIMSRCSERVEROBJ structure.           */
    /****************************************/

     pDataSrc.hSession     = hSession;
     pDataSrc.Obj          = Obj;
     pDataSrc.ulAccess     = SIM_ACCESS_SHARED_READ;
     pDataSrc.ulPriority   = OM_NORMAL_PRIORITY;

    /*************************************************************************/
    /* Call SimWsLoadObj to load a working set object.                       */
    /*************************************************************************/

     SimWsLoadObj(SIMTYPE_BASE,       /* Load object as base document        */
          (ULONG)ulObjConCls,         /* Document content class              */
          SIMREF_NONE,                /* Load as 1st object in working set   */
          (SIMWSOBJ)NULL,             /* Handle to working set object        */
          (PVOID)&pControl,           /* Load control information            */
          SIMSRC_SERVER_OBJ,          /* Document read from object server    */
          (PVOID)&pDataSrc,           /* Server object access description    */
          (PSIMWSOBJ)&hWsObj,         /* Handle of working set object loaded */
          (PSIMLOAD)&pLoadID,         /* Pointer to load handle              */
          (PRCSTRUCT) &RCStruct );    /* Pointer to RC data structure        */


return( RCStruct.ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : CreateDispWindow                                      */
/*                                                                           */
/*  Description      : This function is called from DisplayDocument to create*/
/*                     an Image Services display window.                     */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimDspCreateWin                    */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG CreateDispWindow ( void ).                     */
/*                                                                           */
/*  Return values    :  SIM_RC_OUT_OF_MEMORY or the return code from         */
/*                      SimDspCreateWin.                                     */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Reserve storage for and initialize SimDspCreateWin parameters.   */
/*      2.  If sufficient storage is available, call the SimDspCreateWin     */
/*          Image Services API.                                              */
/*      3.  Return to DisplayDocument() with a return code.                  */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG CreateDispWindow ( void )
{
     PSZ                pszTitle;          /* Display window title           */
     ULONG              ulCreateFlags;     /* Window frame controls          */
     SIMPOSSIZE         PosSize;           /* Initial window position, size  */
     RCSTRUCT           RCStruct;          /* RC data structure              */

    /*************************************************************************/
    /* Initialize SimDspCreateWin parameters.                                */
    /*************************************************************************/

     RCStruct.ulRC     = SIM_RC_OK;
     RCStruct.ulStruct = sizeof(RCSTRUCT);

    /*************************************************************************/
    /* Create the window with all standard frame features.                   */
    /*************************************************************************/

     ulCreateFlags = SIMDSP_FRAME_BORDER |
                     SIMDSP_FRAME_MINMAX |
                     SIMDSP_FRAME_RESIZE |
                     SIMDSP_FRAME_SYSTEM |
                     SIMDSP_FRAME_TITLE;

    /*************************************************************************/
    /* Specify the window origin.  The origin is taken from the top/left.    */
    /*************************************************************************/

     PosSize.ulStruct                =  sizeof(SIMPOSSIZE);
     PosSize.uomType                 =  SIMUOM_PIXEL;
     PosSize.ratOriginX.lNumerator   =  0L;
     PosSize.ratOriginX.lDenominator =  1;
     PosSize.ratOriginY.lNumerator   =  0L;
     PosSize.ratOriginY.lDenominator =  1;
     PosSize.ratWidth.lNumerator     =  400;
     PosSize.ratWidth.lDenominator   =  1;
     PosSize.ratHeight.lNumerator    =  600;
     PosSize.ratHeight.lDenominator  =  1;

    /*************************************************************************/
    /* Setup window title bar.                                               */
    /*************************************************************************/

     pszTitle       = (PSZ) malloc (MAXDESC + 1);
     if (pszTitle == NULL)
         {
         sprintf(szMessage, "Memory allocation error for pszTitle.");
         RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
         }
     else
         {
         memset (pszTitle, '\0', MAXDESC + 1);
         strcpy (pszTitle, "Display of ItemID ");
         strcat (pszTitle, (PSZ)DocItemID);
         }

    if (RCStruct.ulRC == SIM_RC_OK)
    {

    /*************************************************************************/
    /* Call SimDspCreateWin to create a new display window in order to       */
    /* view the working set data.                                            */
    /*************************************************************************/

     SimDspCreateWin(HWND_DESKTOP,    /* Parent window is the desktop        */
          HWND_DESKTOP,               /* Owner window is the desktop         */
          (HPOINTER)NULL,             /* Use Image Services display icon     */
          (PSZ)pszTitle,              /* Display window title                */
          (SIMWSOBJ)hWsObj,           /* Working set object handle           */
          (PSIMPOSSIZE)&PosSize,      /* Window's initial position and size  */
          (ULONG)ulCreateFlags,       /* Window frame controls               */
          TRUE,                       /* Create window as visible            */
          (PSIMWIN)&hWin,             /* Pointer to display window handle    */
          (PRCSTRUCT) &RCStruct );    /* Pointer to RC data structure        */

    }

    /*************************************************************************/
    /*  Free storage reserved with malloc and return to DisplayDocument()    */
    /*  with a return code.                                                  */
    /*************************************************************************/

    free (pszTitle);

return( RCStruct.ulRC );

}


/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : FreeWorkingSet                                        */
/*                                                                           */
/*  Description      : This function is called from DisplayDocument to free  */
/*                     the Image Services working set.                       */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimWsDeleteObj                     */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG FreeWorkingSet ( void ).                       */
/*                                                                           */
/*  Return values    :  The return code from SimWsDeleteObj.                 */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Initialize SimWsDeleteObj parameters.                            */
/*      2.  Call the SimWsDeleteObj Image Services API.                      */
/*      3.  Return to DisplayDocument().                                     */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG FreeWorkingSet ( void )
{
     RCSTRUCT           RCStruct;          /* RC data structure              */

    /*************************************************************************/
    /* Initialize SimWsDeleteObj parameters.                                 */
    /*************************************************************************/

     RCStruct.ulStruct = sizeof(RCSTRUCT);

    /*************************************************************************/
    /* Call SimWsDeleteObj to delete the working set.                        */
    /*************************************************************************/

     SimWsDeleteObj((SIMWSOBJ)hWsObj, /* Handle to working set object        */
          SIMPURGE_ALL,               /* Delete entire working set           */
          (PRCSTRUCT) &RCStruct );    /* Pointer to RC data structure        */

return( RCStruct.ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : Logoff                                                */
/*                                                                           */
/*  Description      : This function is called from main() to logoff from    */
/*                     the VisualInfo Folder Manager.                        */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibLogoff                       */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG Logoff ( void ).                               */
/*                                                                           */
/*  Return values    :  Return code from SimLibLogoff.                       */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Terminate the session with the Folder Manager by calling         */
/*          SimLibLogoff.                                                    */
/*      2.  Return to main() with return code from SimLibLogoff.             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG Logoff ( void )
{
     RCSTRUCT RCStruct;                     /* RC data structure             */

    /*************************************************************************/
    /* Call SimLibLogoff to terminate the Folder Manager session.            */
    /*************************************************************************/

     SimLibLogoff( hSession,                /* Folder Manager session handle */
                  (PASYNCCTLSTRUCT)NULL,    /* Request synchronous processing*/
                  (PRCSTRUCT) &RCStruct );  /* Pointer to RC data structure  */

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;

    /*************************************************************************/
    /*  Return to main() with the return code from SimLibLogoff.             */
    /*************************************************************************/

return( RCStruct.ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : ShowMessageBox                                        */
/*                                                                           */
/*  Description      : This function is called from main() to display a      */
/*                     message box window containing message text and a      */
/*                     return code.                                          */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions:                                    */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  VOID.                                                */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  VOID ShowMessageBox ( ULONG ulreturn ).              */
/*                                                                           */
/*  Return values    :  None.                                                */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Display a message box by calling WinMessageBox.                  */
/*      2.  Return to main().                                                */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

VOID ShowMessageBox ( ULONG ulreturn )
{

     CHAR      szRetCode[20];                /* Return code for message box  */

     sprintf(szRetCode, "\nReturn Code = %ld", ulreturn);
     strcat (szMessage, szRetCode);

    /*************************************************************************/
    /* Call WinMessageBox to display a message and return code.              */
    /*************************************************************************/

      WinMessageBox( HWND_DESKTOP,
                     HWND_DESKTOP,
                     (PSZ)szMessage,
                     (PSZ) "Sample program FRNOEXDI has ended.",
                     (ULONG)NULL,
                     MB_CANCEL | MB_INFORMATION | MB_MOVEABLE);

    /*************************************************************************/
    /*  Return to main().                                                    */
    /*************************************************************************/

return;

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : DestroyMsgQueue                                       */
/*                                                                           */
/*  Description      : This function is called from DisplayDocument() to     */
/*                     destroy the Presentation Manager message queue.       */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions:                                    */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  VOID.                                                */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  VOID DestroyMsgQueue ( void ).                       */
/*                                                                           */
/*  Return values    :  None.                                                */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Destroy the Presentation Manager message queue by calling        */
/*          WinDestroyMsgQueue.                                              */
/*      2.  Return to main().                                                */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

VOID DestroyMsgQueue ( void )
{

    /*************************************************************************/
    /* Call WinDestroyMsgQueue to destroy the message queue.                 */
    /*************************************************************************/

     WinDestroyMsgQueue(hmqPMmq);

    /*************************************************************************/
    /*  Return to main().                                                    */
    /*************************************************************************/

return;

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : Terminate                                             */
/*                                                                           */
/*  Description      : This function is called from DisplayDocument() to     */
/*                     terminate the use of Presentation Manager.            */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions:                                    */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  VOID.                                                */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  VOID Terminate ( void ).                             */
/*                                                                           */
/*  Return values    :  None.                                                */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Terminate use of Presentation Manager by calling WinTerminate.   */
/*      2.  Return to main().                                                */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

VOID Terminate ( void )
{

    /*************************************************************************/
    /* Call WinTerminate to end the use of Presentation Manager.             */
    /*************************************************************************/

     WinTerminate(habPManchor);

    /*************************************************************************/
    /*  Return to main().                                                    */
    /*************************************************************************/

return;

}

/*****************************************************************************/
/* End of FRNOEXDI.C                                                         */
/*****************************************************************************/
