/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/* MODULE:  frnoexdo.c                                        VisualInfo     */
/*                                                                           */
/* 5697-250                                                                  */
/* 5621-326, 5655-036, 5622-213, 5655-071, 5655-072                          */
/*                                                                           */
/* (C) Copyright IBM Corporation 1993, 1996.                                 */
/* All Rights Reserved.                                                      */
/*                                                                           */
/* DERIVATIVE RIGHTS:                                                        */
/* ------------------                                                        */
/* This program is provided for the customer's use and the customer is       */
/* granted permission to copy this program to the extent reasonably          */
/* required for such use.  All title, ownership, and rights to this          */
/* program and any copies remain with IBM, irrespective of the ownership     */
/* of the media on which the program resides.  The customer is permitted     */
/* to create derivative works to this program.  However, all copies of       */
/* the program and its derivative works must contain the IBM copyright       */
/* notice.  The customer understands and agrees that this program in and     */
/* of itself is not to be sold or distributed.  The customer is free to      */
/* sell, distribute, and commercially exploit any derivative works           */
/* created from this program.                                                */
/*                                                                           */
/*                                                                           */
/* DISCLAIMER OF WARRANTIES:                                                 */
/* -------------------------                                                 */
/* The following [enclosed] code is sample code created by IBM               */
/* Corporation.  This sample code is not part of any standard IBM product    */
/* and is provided to you solely for the purpose of assisting you in the     */
/* development of your applications.  The code is provided "AS IS",          */
/* without warranty of any kind.  IBM shall not be liable for any damages    */
/* arising out of your use of the sample code, even if they have been        */
/* advised of the possibility of such damages.                               */
/*                                                                           */
/*                                                                           */
/* Status: Version 2 Release 1 Modification 0                                */
/*                                                                           */
/*                                                                           */
/*****************************************************************************/
/* Description : frnoexdo.c - Sample application code using Folder Manager   */
/*               APIs to create a folder ItemID, create a document ItemID,   */
/*               store an object as part of the document, and add the        */
/*               document to the newly created folder.                       */
/*               The APIs used are SimLibLogon, SimLibFree, SimLibCreateItem,*/
/*               SimLibCatalogObject, SimLibAddFolderItem, and SimLibLogoff. */
/*                                                                           */
/* Dependencies: To run this sample code without modification, file          */
/*               OS2LOGO.BMP must exist in directory C:\OS2\BITMAP.          */
/*               (For Windows, user C:\CONFIG.SYS).                          */
/*               (For AIX, user /usr/lpp/frn/bin/FRNOLINT.TBL).              */
/*                                                                           */
/* Restrictions: None                                                        */
/*                                                                           */
/* Entry Points: main                                                        */
/*               Logon                                                       */
/*               FreeMemory                                                  */
/*               CreateFolderItemID                                          */
/*               CreateDocumentItemID                                        */
/*               StoreObject                                                 */
/*               AddToFolder                                                 */
/*               Logoff                                                      */
/*                                                                           */
/* Change History:                                                           */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

/*****************************************************************************/
/*  System Header Files                                                      */
/*****************************************************************************/
/* The following changes for AIX Porting - Ivy */
#ifdef _Windows
 #include <windows.h>
#else
 #ifdef AIX
   #include <frnptype.h>
 #else
  #include <os2.h>
 #endif
#endif
/* end of Ivy's change */

#include <stdio.h>                      /* Standard I/O header files         */
#include <stdlib.h>                     /* Standard Library header files     */
#include <string.h>                     /* String manipulation               */

/*****************************************************************************/
/*  VisualInfo Header Files                                                  */
/*****************************************************************************/

#define   FRN_INCL_FI                   /* Include frnpfi.h & frnpfi2.h      */
#define   FRN_INCL_FO                   /* Include frnpfo.h                  */
#include "frnp.h"                       /* Global types                      */
#include "frnpcapi.h"                   /* Structures and constants          */

/*****************************************************************************/
/*  FRNOEXDO Header File                                                     */
/*****************************************************************************/

#include "frnoexdo.h"                   /* Application header file           */

/*****************************************************************************/
/*  Global Variables                                                         */
/*****************************************************************************/

HSESSION hSession;                      /* Folder Manager session handle     */
ULONG    ulMemoryBlock;                 /* Generic pointer for SimLibFree    */
ITEMID   FolderItemID;                  /* ItemID of new folder              */
ITEMID   DocumentItemID;                /* ItemID of new document            */

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : main                                                  */
/*                                                                           */
/*  Description      : main() function of a sample application that uses     */
/*                     Folder Manager APIs to create a folder, create a      */
/*                     a document, store an object as part of the document,  */
/*                     and store the document in the newly created folder.   */
/*                     To run this sample code without modification,         */
/*                     the object must have a content class of OS/2          */
/*                     Version 2 bitmap.                                     */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions:                                    */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  INT.                                                 */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  INT main ( void ).                                   */
/*                                                                           */
/*  Return values    :  If all functions are successful, the return code     */
/*                      from Logoff() is returned.  Otherwise, the return    */
/*                      code from Logon(), CreateFolderItemID(),             */
/*                      CreateDocumentItemID(), StoreObject(), or            */
/*                      AddToFolder() is returned.                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Establish a session with the Folder Manager.                     */
/*      2.  If logon was successful:                                         */
/*           - Free the memory containing the USERLOGONINFOSTRUC structure   */
/*             and create a folder ItemID.                                   */
/*             If the folder ItemID is successfully created:                 */
/*             - Free the memory containing the ItemID and create a document */
/*               ItemID.                                                     */
/*               If the document ItemID is successfully created:             */
/*               - Free the memory containing the ItemID and store an object */
/*                 as part of the document.  The object must exist as a file */
/*                 and have a content class of OS/2 Version 2 bitmap.        */
/*                 If the object is successfully stored:                     */
/*                 - Free the memory containing the object handle and add    */
/*                   the document to the newly created folder.               */
/*          Logoff from the Folder Manager session.                          */
/*      3.  Exit main() with a return code.                                  */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

#ifdef _Windows
int SIMENTRY fnFrnoexdo ( void )
#else
INT main ( void )
#endif
{
     ULONG ulretcode;

    /*************************************************************************/
    /*  Call Logon to establish a Folder Manager Session.                    */
    /*************************************************************************/

     ulretcode = Logon();

    /*************************************************************************/
    /* If successful, call FreeMemory to free the memory for structure       */
    /* USERLOGONINFOSTRUC returned from SimLibLogon.                         */
    /*************************************************************************/

     if (ulretcode == SIM_RC_OK)
           {
           FreeMemory();

    /*************************************************************************/
    /*  Call CreateFolderItemID to create a new folder ItemID.               */
    /*************************************************************************/

           ulretcode = CreateFolderItemID();

    /*************************************************************************/
    /* If successful, call FreeMemory to free the memory containing the      */
    /* folder ItemID.                                                        */
    /*************************************************************************/

           if (ulretcode == SIM_RC_OK)
                 {
                 FreeMemory();

    /*************************************************************************/
    /*  Call CreateDocumentItemID to create a new document ItemID.           */
    /*************************************************************************/

                 ulretcode = CreateDocumentItemID();

    /*************************************************************************/
    /* If successful, call FreeMemory to free the memory containing the      */
    /* document ItemID.                                                      */
    /*************************************************************************/

                 if (ulretcode == SIM_RC_OK)
                       {
                       FreeMemory();

    /*************************************************************************/
    /*  Call StoreObject to create a new object using an existing file.      */
    /*  The new object will be stored as part of the newly created document. */
    /*************************************************************************/

                       ulretcode = StoreObject();

    /*************************************************************************/
    /* If successful, call FreeMemory to free the memory containing the      */
    /* object handle.                                                        */
    /*************************************************************************/

                       if (ulretcode == SIM_RC_OK)
                             {
                             FreeMemory();

    /*************************************************************************/
    /* Call AddToFolder to store the document in the previously created      */
    /* folder.                                                               */
    /*************************************************************************/

                             ulretcode = AddToFolder();

    /*************************************************************************/
    /* Call Logoff to terminate the Folder Manager session.                  */
    /*************************************************************************/

                             if (ulretcode == SIM_RC_OK)
                                   ulretcode = Logoff();
                             else
                                    Logoff();
                             }
                       else
                             Logoff();
                       }
                 else
                       Logoff();
                 }
             else
                  Logoff();
           }

    /*************************************************************************/
    /* Print return code.                                                    */
    /*************************************************************************/

    printf ("RETURN CODE = %lu\n", ulretcode);

    /*************************************************************************/
    /* Exit main() with the return code.                                     */
    /*************************************************************************/

    return ( ulretcode );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : Logon                                                 */
/*                                                                           */
/*  Description      : This function is called from main() to logon to       */
/*                     VisualInfo Folder Manager.                            */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibLogon                        */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG Logon ( void ).                                */
/*                                                                           */
/*  Return values    :  SIM_RC_OUT_OF_MEMORY or the return code from         */
/*                      SimLibLogon.                                         */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Reserve storage for and initialize SimLibLogon parameters.       */
/*      2.  If sufficient storage is available, establish a session          */
/*          session with the Folder Manager by calling SimLibLogon.          */
/*      3.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG Logon ( void )
{
     PSZ      pszDBName;                /* Pointer to Database name          */
     PSZ      pszUserId;                /* Pointer to User Id                */
     PSZ      pszPassword;              /* Pointer to Password for User Id   */
     RCSTRUCT RCStruct;                 /* RC data structure                 */

    /*************************************************************************/
    /* Reserve and initialize storage for SimLibLogon parameters.            */
    /* Print error message if sufficient storage is not available.           */
    /*************************************************************************/

     RCStruct.ulRC = SIM_RC_OK;
     pszDBName = (PSZ) malloc ( SIM_SERVER_NAME_LENGTH + 1);
     if (pszDBName == NULL)
        {
        printf("Memory allocation error for pszDBName.\n");
        RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
        }
     else
        {
        memset (pszDBName, '\0', SIM_SERVER_NAME_LENGTH + 1);
        pszUserId = (PSZ) malloc ( OIM_MAXIMUM_USERID_LENGTH + 1);
        if (pszUserId == NULL)
            {
            printf("Memory allocation error for pszUserId.\n");
            RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
            }
        else
            {
            memset (pszUserId, '\0', OIM_MAXIMUM_USERID_LENGTH + 1);
            pszPassword = (PSZ) malloc ( OIM_MAX_PASSWORD_LENGTH + 1);
            if (pszPassword == NULL)
                {
                printf("Memory allocation error for pszPassword.\n");
                RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
                }
            else
                {
                memset (pszPassword, '\0', OIM_MAX_PASSWORD_LENGTH + 1);

    /*************************************************************************/
    /* Initialize SimLibLogon parameters.                                    */
    /*************************************************************************/

                                         strcpy (pszDBName,          PSZDBNAME);
                strcpy (pszUserId,          PSZUSERID);
                strcpy (pszPassword,        PSZPASSWORD);
                }
            }
        }
    if (RCStruct.ulRC == SIM_RC_OK)
    {
    /*************************************************************************/
    /* Call SimLibLogon to establish a Folder Manager session.               */
    /*************************************************************************/

     SimLibLogon( pszDBName,               /* Pointer to Database name       */
                  (PSZ) "",                /* Reserved for future use        */
                  pszUserId,               /* Pointer to User Id             */
                  pszPassword,             /* Pointer to Password for User Id*/
                  (PSZ) NULL,              /* Logon without new password     */
                  (PSZ) NULL,              /* Reserved for future use        */
                  (PSZ) NULL,              /* Reserved for future use        */
                  SIM_SS_NORMAL,           /* Non-configuration session logon*/
                  (PASYNCCTLSTRUCT) NULL,  /* Request synchronous processing */
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

     if ((RCStruct.ulRC == SIM_RC_OK) ||
         (RCStruct.ulRC == SIM_RC_GRACE_PERIOD_UNDER_LIMIT))

    /*************************************************************************/
    /* If successful, save the Folder Manager session handle for subsequent  */
    /* Folder Manager API calls.                                             */
    /*************************************************************************/

         {
         RCStruct.ulRC = SIM_RC_OK;
         hSession = RCStruct.ulParam1;

    /*************************************************************************/
    /* Save the pointer to the USERLOGONINFOSTRUCT data structure in order   */
    /* to free the memory.                                                   */
    /*************************************************************************/

         ulMemoryBlock = RCStruct.ulParam2;
         }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }
    }

    /*************************************************************************/
    /*  Free storage reserved with malloc and return to main() with a return */
    /*  code.                                                                */
    /*************************************************************************/

    free (pszDBName);
    free (pszUserId);
    free (pszPassword);

return( RCStruct.ulRC );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function        : FreeMemory                                             */
/*                                                                           */
/*  Description     : This function is called from main() to free memory     */
/*                    allocated as the result of a Folder Manager            */
/*                    SimLibLogon, SimLibCreateItem, or SimLibCatalogObject. */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibFree                         */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  VOID.                                                */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  VOID FreeMemory ( void ).                            */
/*                                                                           */
/*  Return values    :  None.                                                */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call SimLibFree to free memory allocated by the Folder Manager   */
/*          as a result of SimLibLogon, SimLibCreateItem, or                 */
/*          SimLibCatalogObject.                                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

VOID FreeMemory (void)
{
     RCSTRUCT RCStruct;                    /* RC data structure              */

     SimLibFree  ( hSession,               /* Folder Manager session handle  */
                  (PVOID) ulMemoryBlock,   /* Pointer to memory block to free*/
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

return;
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : CreateFolderItemID                                    */
/*                                                                           */
/*  Description      : This function is called from main() to create a       */
/*                     folder with specified attributes.                     */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibCreateItem                   */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG CreateFolderItemID ( void ).                   */
/*                                                                           */
/*  Return values    :  Return code from SimLibCreateItem.                   */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Initialize SimLibCreateItem parameters.                          */
/*      2.  Call SimLibCreateItem Folder Manager API.                        */
/*      3.  Return to main() with the return code from SimLibCreateItem.     */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG CreateFolderItemID ( VOID )
{
     USHORT         usFoldAttrs;           /* Number of ATTRLISTSTRUCTs      */
     ATTRLISTSTRUCT Folder [USFOLDATTRS];  /* Folder Attributes array        */
     USHORT         usIndexClass;          /* Index class for folder         */
     RCSTRUCT       RCStruct;              /* RC data structure              */
     USHORT         count;                 /* Loop counter                   */

    /*************************************************************************/
    /* Initialize SimLibCreateItem Parameters.                               */
    /*************************************************************************/

     usFoldAttrs  = USFOLDATTRS;
     usIndexClass = SIM_INDEX_NOINDEX;

    /******************************************************/
    /* Initialize and print Folder Attribute structure.   */
    /******************************************************/

     memset (Folder, '\0', sizeof(Folder));
     printf ("Folder   attribute list :\n\n");
     for ( count = 0 ;
           count < usFoldAttrs;
           count ++
         )
         {
         Folder[count] = FOLDER[count];
         printf("Attribute value = %s\n",
                 Folder[count].pszAttributeValue);
         printf("Attribute ID    = %hu\n",
                 Folder[count].usAttrId);
         printf("Attribute type  = %hu\n",
                 Folder[count].usAttrType);
         printf("Attribute flags = %u\n\n",
                 Folder[count].fAttrFlags);
         }

    /*************************************************************************/
    /* Call SimLibCreateItem to create a new folder ItemID.                  */
    /*************************************************************************/

     SimLibCreateItem( hSession,           /* Folder Manager session handle  */
          SIM_FOLDER,                      /* Create a folder                */
          (USHORT) usIndexClass,           /* Index class of folder          */
          (USHORT) usFoldAttrs,            /* Number of AttributeLists       */
          (PATTRLISTSTRUCT) &Folder,       /* Pointer to AttributeList       */
          (ULONG)NULL,                     /* Reserved for future use        */
          (PASYNCCTLSTRUCT) NULL,          /* Request synchronous processing */
          (PRCSTRUCT) &RCStruct );         /* Pointer to RC data structure   */

    /*************************************************************************/
    /* Save the new folder ItemId for use in SimLibAddFolderItem API call    */
    /* and to free the memory. Print the new folder ItemID.                  */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
         {
         strncpy ((PSZ)FolderItemID, (PSZ)RCStruct.ulParam1, DOC_ID_SIZE);
         printf("New Folder ItemID         = %s\n\n", (PSZ)FolderItemID);
         ulMemoryBlock        = RCStruct.ulParam1;
         }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }

    /*************************************************************************/
    /*  Return to main() with a return code from SimLibCreateItem.           */
    /*************************************************************************/

     return( RCStruct.ulRC );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : CreateDocumentItemID                                  */
/*                                                                           */
/*  Description      : This function is called from main() to create a       */
/*                     document with specified attributes.                   */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibCreateItem                   */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG CreateDocumentItemID ( void ).                 */
/*                                                                           */
/*  Return values    :  Return code from SimLibCreateItem.                   */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Initialize SimLibCreateItem parameters.                          */
/*      2.  Call SimLibCreateItem Folder Manager API.                        */
/*      3.  Return to main() with the return code from SimLibCreateItem.     */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG CreateDocumentItemID ( VOID )
{
     USHORT         usDocuAttrs;                /* Number of ATTRLISTSTRUCTs */
     ATTRLISTSTRUCT Docu [USDOCUATTRS];         /* Document Attributes       */
     USHORT         usIndexClass;               /* Index class id for docu   */
     RCSTRUCT       RCStruct;                   /* RC data structure         */
     USHORT         count;                      /* Loop counter              */

    /*************************************************************************/
    /* Initialize SimLibCreateItem Parameters.                               */
    /*************************************************************************/

     usDocuAttrs  = USDOCUATTRS;
     usIndexClass = SIM_INDEX_NOINDEX;

    /******************************************************/
    /* Initialize and print Document Attribute structure. */
    /******************************************************/

     memset (Docu, '\0', sizeof(Docu));
     printf ("Document attribute list :\n\n");
     for ( count = 0 ;
           count < usDocuAttrs;
           count ++
         )
         {
         Docu[count] = DOCU[count];
         printf("Attribute value = %s\n",
                 Docu[count].pszAttributeValue);
         printf("Attribute ID    = %hu\n",
                 Docu[count].usAttrId);
         printf("Attribute type  = %hu\n",
                 Docu[count].usAttrType);
         printf("Attribute flags = %u\n\n",
                 Docu[count].fAttrFlags);
         }

    /*************************************************************************/
    /* Call SimLibCreateItem to create a document ItemID.                    */
    /*************************************************************************/

     SimLibCreateItem( hSession,           /* Folder Manager session handle  */
          SIM_DOCUMENT,                    /* Create a document              */
          (USHORT) usIndexClass,           /* Index class of document        */
          (USHORT) usDocuAttrs,            /* Number of AttributeLists       */
          (PATTRLISTSTRUCT) &Docu,         /* Pointer to AttributeList       */
          (ULONG)NULL,                     /* Reserved for future use        */
          (PASYNCCTLSTRUCT) NULL,          /* Request synchronous processing */
          (PRCSTRUCT) &RCStruct );         /* Pointer to RC data structure   */

    /*************************************************************************/
    /* Save the new document ItemId for use in SimLibAddFolderItem API call  */
    /* and to free the memory. Print the new document ItemID.                */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
         {
                        strncpy ((PSZ)DocumentItemID, (PSZ)RCStruct.ulParam1, DOC_ID_SIZE);
                        printf("New Document ItemID       = %s\n\n", (PSZ)DocumentItemID);
#ifdef _Windows
                        SetItemId((PSZ)DocumentItemID);
#endif
         ulMemoryBlock     = RCStruct.ulParam1;
         }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }

    /*************************************************************************/
    /*  Return to main() with the return code from SimLibCreateItem.         */
    /*************************************************************************/

     return( RCStruct.ulRC );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : StoreObject                                           */
/*                                                                           */
/*  Description      : This function is called from main() to store a new    */
/*                     object using an existing file.  The new object will be*/
/*                     stored as a part of the previously created document.  */
/*                     To run this sample code without modification,         */
/*                     the object must have a content class of OS/2          */
/*                     Version 2 bitmap.                                     */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibCatalogObject                */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG StoreObject (void ).                           */
/*                                                                           */
/*  Return values    :  SIM_RC_OUT_OF_MEMORY or the return code from         */
/*                      SimLibCatalogObject.                                 */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Reserve storage for and initialize SimLibCatalogObject           */
/*          parameters.                                                      */
/*      2.  If sufficient storage is available, call the SimLibCatalogObject */
/*          API.                                                             */
/*      3.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG StoreObject ( VOID )
{
     OBJ      Obj;                         /* Object data structure          */
     PSZ      pszFullFileName;             /* Path & file name of object     */
     RCSTRUCT RCStruct;                    /* RC data structure              */

    /*************************************************************************/
    /* Initialize SimLibCatalogObject Parameters.                            */
    /*************************************************************************/

     RCStruct.ulRC = SIM_RC_OK;

     /********************************/
     /* Object structure.            */
     /********************************/

     memset (&Obj, '\0', sizeof(OBJ));
     Obj.ulStruct  = sizeof(Obj);
     Obj.ulPart    = ULPARTID;

     /*********************************************************/
     /* Create object as part of previously created document. */
     /*********************************************************/

     strcpy (Obj.szItemID, DocumentItemID);

    /*************************************************************************/
    /* Reserve and initialize storage for pszFullFileName parameter.         */
    /* Print error message is sufficient storage is not available.           */
    /*************************************************************************/

     pszFullFileName = (PSZ) malloc (MAXFULLFILENAME);
     if (pszFullFileName == NULL)
        {
        printf("Memory allocation error for pszFullFileName.\n");
        RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
        }
     else
        {
        memset (pszFullFileName, '\0', MAXFULLFILENAME);
        strcpy (pszFullFileName, PSZFULLFILENAME);
        printf("File to be stored         = %s\n\n", pszFullFileName);
        }

     if (RCStruct.ulRC == SIM_RC_OK)
     {

    /*************************************************************************/
    /* Call SimLibCatalogObject to create a new object using an existing file*/
    /*************************************************************************/

     SimLibCatalogObject( hSession,      /* Folder Manager session handle    */
          (HOBJ) &Obj,                   /* Pointer to object handle block   */
#ifdef _Windows
          SIM_CC_TEXT,                   /* Text content class               */
#else
 #ifndef AIX
          SIM_CC_OS2V2_BMP,              /* OS/2 V2 bitmap content class     */
 #endif
#endif
          (PSMS) NULL,                   /* Pointer to SMS object structure  */
          (PSZ) pszFullFileName,         /* Name of existing file            */
          SIM_PRI_NORMAL,                /* Medium servicing priority        */
          SIM_CLOSE,                     /* Close object upon completion     */
          (ULONG)NULL,                   /* Reserved for future use          */
          (LONG)NULL,                    /* Reserved for future use          */
          SIM_BASE,                      /* Define object type as base       */
          (PVOID)NULL,                   /* No affiliated data               */
          (PASYNCCTLSTRUCT) NULL,        /* Request synchronous processing   */
          (PRCSTRUCT) &RCStruct );       /* Pointer to RC data structure     */

    /*************************************************************************/
    /* Save the pointer to the object handle in order to free the memory.    */
    /* If subsequent references to the object are required, ulParam1 must    */
    /* be saved.                                                             */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
         {
         printf("New Object Handle  = %lu\n\n", (HOBJ)RCStruct.ulParam1);
         ulMemoryBlock = RCStruct.ulParam1;
         }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }
     }

    /*************************************************************************/
    /*  Free storage reserved with malloc and return to main() with a return */
    /*  code.                                                                */
    /*************************************************************************/

     free (pszFullFileName);

     return( RCStruct.ulRC );
}


/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : AddToFolder                                           */
/*                                                                           */
/*  Description      : This function is called from main() to add the new    */
/*                     document to the new folder.                           */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibAddFolderItem                */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG AddToFolder (void ).                           */
/*                                                                           */
/*  Return values    :  Return code from SimLibAddFolderItem.                */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call SimLibAddFolderItem Folder Manager API.                     */
/*      2.  Return to main() with the return code from SimLibAddFolderItem.  */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG AddToFolder ( VOID )
{
     RCSTRUCT RCStruct;                    /* RC data structure              */

    /*************************************************************************/
    /* Call SimLibAddFolderItem to place the document in the folder.         */
    /*************************************************************************/

     SimLibAddFolderItem( hSession,      /* Folder Manager session handle    */
          (PITEMID) &FolderItemID,       /* Pointer to folder ItemID         */
                         (PITEMID) &DocumentItemID,     /* Pointer to document ItemID       */
          (PASYNCCTLSTRUCT) NULL,        /* Request synchronous processing   */
          (PRCSTRUCT) &RCStruct );       /* Pointer to RC data structure     */

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
         RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
         RCStruct.ulRC =  RCStruct.ulExtRC;

    /*************************************************************************/
    /*  Return to main() with the return code from SimLibAddFolderItem.      */
    /*************************************************************************/

     return( RCStruct.ulRC );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : Logoff                                                */
/*                                                                           */
/*  Description      : This function is called from main() to logoff from    */
/*                     the VisualInfo Folder Manager.                        */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibLogoff()                     */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG Logoff ( void ).                               */
/*                                                                           */
/*  Return values    :  Return code from SimLibLogoff.                       */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Terminate the session with the Folder Manager by calling         */
/*          SimLibLogoff.                                                    */
/*      2.  Return to main() with return code from SimLibLogoff.             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG Logoff ( void )
{
     RCSTRUCT RCStruct;                     /* RC data structure             */

    /*************************************************************************/
    /* Call SimLibLogoff to terminate the Folder Manager session.            */
    /*************************************************************************/

     SimLibLogoff( hSession,                /* Folder Manager session handle */
                  (PASYNCCTLSTRUCT) NULL,   /* Request synchronous processing*/
                  (PRCSTRUCT) &RCStruct );  /* Pointer to RC data structure  */

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
         RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
         RCStruct.ulRC =  RCStruct.ulExtRC;

    /*************************************************************************/
    /*  Return to main() with the return code from SimLibLogoff.             */
    /*************************************************************************/

     return( RCStruct.ulRC );
}

/*****************************************************************************/
/* End of FRNOEXDO.C                                                         */
/*****************************************************************************/


