/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/* MODULE: FRNOEXNO.C                                         VisualInfo     */
/*                                                                           */
/* 5697-250                                                                  */
/* 5621-326, 5655-036, 5622-213, 5655-071, 5655-072                          */
/*                                                                           */
/* (C) Copyright IBM Corporation 1993, 1996.                                 */
/* All Rights Reserved.                                                      */
/*                                                                           */
/* DERIVATIVE RIGHTS:                                                        */
/* ------------------                                                        */
/* This program is provided for the customer's use and the customer is       */
/* granted permission to copy this program to the extent reasonably          */
/* required for such use.  All title, ownership, and rights to this          */
/* program and any copies remain with IBM, irrespective of the ownership     */
/* of the media on which the program resides.  The customer is permitted     */
/* to create derivative works to this program.  However, all copies of       */
/* the program and its derivative works must contain the IBM copyright       */
/* notice.  The customer understands and agrees that this program in and     */
/* of itself is not to be sold or distributed.  The customer is free to      */
/* sell, distribute, and commercially exploit any derivative works           */
/* created from this program.                                                */
/*                                                                           */
/*                                                                           */
/* DISCLAIMER OF WARRANTIES:                                                 */
/* -------------------------                                                 */
/* The following [enclosed] code is sample code created by IBM               */
/* Corporation.  This sample code is not part of any standard IBM product    */
/* and is provided to you solely for the purpose of assisting you in the     */
/* development of your applications.  The code is provided "AS IS",          */
/* without warranty of any kind.  IBM shall not be liable for any damages    */
/* arising out of your use of the sample code, even if they have been        */
/* advised of the possibility of such damages.                               */
/*                                                                           */
/*                                                                           */
/* Status: Version 2 Release 1 Modification 0                                */
/*                                                                           */
/*****************************************************************************/
/* Description : frnoexno.c - Sample application code to add a note to       */
/*               a document.  The APIs used are SimLibLogon, SimLibFree,     */
/*               SimLibGetItemAffiliatedTOC, SimLibOpenObject,               */
/*               SimLibSeekObject, SimLibCreateObject, SimLibWriteObject,    */
/*               SimLibCloseObject, and SimLibLogoff.                        */
/*                                                                           */
/* Dependencies: To run this sample code without modification:               */
/*               - The document to which the note will be added must         */
/*                 already exist.  Specify the ItemID of this document in    */
/*                 frnoexno.c                                                */
/*               - The note must be of content class ASCII.                  */
/*                                                                           */
/* Restrictions: None                                                        */
/*                                                                           */
/* Entry Points: main                                                        */
/*               Logon                                                       */
/*               FreeMemory                                                  */
/*               GetNoteTOC                                                  */
/*               OpenNote                                                    */
/*               PositionAtNoteEnd                                           */
/*               CreateNote                                                  */
/*               WriteNote                                                   */
/*               CloseNote                                                   */
/*               Logoff                                                      */
/*                                                                           */
/* Change History:                                                           */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

/*****************************************************************************/
/*  System Header Files                                                      */
/*****************************************************************************/
/* the following changes had made for AIX porting   Ivy */
#ifdef _Windows
 #include <windows.h>
#else
 #ifdef AIX
  #include <frnptype.h>
 #else
  #include <os2.h>
 #endif
#endif
/* end of ivy's change */

#include <stdio.h>                      /* Standard I/O header files         */
#include <stdlib.h>                     /* Standard Library header files     */
#include <string.h>                     /* String manipulation               */

/*****************************************************************************/
/*  VisualInfo Header Files                                                  */
/*****************************************************************************/

#define   FRN_INCL_FI                   /* Include frnpfi.h & frnpfi2.h      */
#define   FRN_INCL_FO                   /* Include frnpfo.h                  */
#include "frnp.h"                       /* Global types                      */
#include "frnpcapi.h"                   /* Structures and constants          */

/*****************************************************************************/
/*  FRNOEXNO Header File                                                     */
/*****************************************************************************/

#include "frnoexno.h"                   /* Application header file           */

/*****************************************************************************/
/*  Global Variables                                                         */
/*****************************************************************************/

HSESSION hSession;                      /* Folder Manager session handle     */
ULONG    ulMemoryBlock;                 /* Generic pointer for SimLibFree    */
BOOL     fNoteExists;                   /* Does a note object already exist? */
OBJ      Obj;                           /* Existing note to which to append  */
HOBJACC  ObjectAccessHandle;            /* Object access handle for note     */
BOOL     fCommit;                       /* Update commit flag                */

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : main                                                  */
/*                                                                           */
/*  Description      : main() function of a sample application which creates */
/*                     a note for an existing document.  If the document     */
/*                     already has notes associated with it, the note will   */
/*                     be appended to the last note in the table of contents.*/
/*                     The note must have a content class of ASCII.          */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions:                                    */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  INT.                                                 */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  INT main ( void ).                                   */
/*                                                                           */
/*  Return values    :  If all functions are successful, the return code     */
/*                      from Logoff() is returned.  Otherwise, the return    */
/*                      code from Logon(), GetNoteTOC(), OpenNote(),         */
/*                      PositionAtNoteEnd(), CreateNote(), WriteNote(), or   */
/*                      CloseNote() is returned.                             */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Establish a session with the Folder Manager.                     */
/*      2.  If logon was successful:                                         */
/*           - Free the memory containing the USERLOGONINFOSTRUC structure   */
/*             and get the table of contents for all note objects associated */
/*             with an existing document.                                    */
/*             If the table of contents is successfully created:             */
/*             - If notes exist for document :                               */
/*               - Free the memory containing the array of                   */
/*                 AFFTOCENTRYSTRUCT structures.                             */
/*               - Open the last note in the table of contents,              */
/*                 position the object pointer at the end of the note,       */
/*                 append the new note text to the end of the note, and      */
/*                 close the note.                                           */
/*             - If notes do not exist for the document:                     */
/*               - Create a note object, write the note text to the note,    */
/*                 and close the note.                                       */
/*          Logoff from the Folder Manager session.                          */
/*      3.  Exit main() with a return code.                                  */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

#ifdef _Windows
int SIMENTRY fnFrnoexno ( void )  /* code synd - ivyyu 9/18/95 */
#else
INT main ( void )
#endif
{
     ULONG ulretcode;

    /*************************************************************************/
    /*  Call Logon to establish a Folder Manager Session.                    */
    /*************************************************************************/

     ulretcode = Logon();

    /*************************************************************************/
    /* If successful, call FreeMemory to free the memory for structure       */
    /* USERLOGONINFOSTRUC returned from SimLibLogon.                         */
    /*************************************************************************/

     if (ulretcode == SIM_RC_OK)
         {
         FreeMemory();

    /*************************************************************************/
    /*  Call GetNoteTOC to find out whether a note already exists for        */
    /*  this document.                                                       */
    /*************************************************************************/

         ulretcode = GetNoteTOC();

    /*************************************************************************/
    /*  If successful:                                                       */
    /*  If a note already exists for this document:                          */
    /*      - Call FreeMemory to free the memory for an array of             */
    /*        AFFTOCENTRYSTRUCT structures returned from                     */
    /*        SimLibGetItemAffiliatedTOC.                                    */
    /*      - call OpenNote to open the last note listed in the table of     */
    /*        contents.  If successful, call PositionAtNoteEnd to adjust     */
    /*        the object pointer to the end of the object so that the new    */
    /*        note can be appended to the existing note. If the pointer      */
    /*        positioning is not successful, close the note.                 */
    /*  If a note does not already exist for this document:                  */
    /*      - call CreateNote to create a note object, leaving the note      */
    /*        open in update mode.  If successful, call FreeMemory to        */
    /*        free the memory for the object handle.                         */
    /*************************************************************************/

         if (ulretcode == SIM_RC_OK)
             {
             if (fNoteExists == TRUE)
                 {
                 FreeMemory();
                 ulretcode = OpenNote();
                 if (ulretcode == SIM_RC_OK)
                     {
                     ulretcode = PositionAtNoteEnd();
                     if (ulretcode != SIM_RC_OK)
                         CloseNote();
                     }
                 }
             else
                 {
                 ulretcode = CreateNote();
                 if (ulretcode == SIM_RC_OK)
                     FreeMemory();
                 }

    /*************************************************************************/
    /*  If successful, the object is open for update.  Call WriteNote to     */
    /*  update the note object with the note text.                           */
    /*************************************************************************/

             if (ulretcode == SIM_RC_OK)
                 {
                 ulretcode = WriteNote();
                 if (ulretcode == SIM_RC_OK)

    /*************************************************************************/
    /*  Call CloseNote to close the open note object.  Call Logoff to        */
    /*  terminate the Folder Manager Session.                                */
    /*************************************************************************/

                     {
                     ulretcode = CloseNote();
                     if (ulretcode == SIM_RC_OK)
                         ulretcode = Logoff();
                     else
                         Logoff();
                     }
                 else
                     {
                     CloseNote();
                     Logoff();
                     }
                 }
             else
                 Logoff();
             }
         else
             Logoff();
         }

    /*************************************************************************/
    /* Print return code.                                                    */
    /*************************************************************************/

    printf ("RETURN CODE = %lu\n", ulretcode);

    /*************************************************************************/
    /* Exit main() with the return code.                                     */
    /*************************************************************************/

    return ( ulretcode );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : Logon                                                 */
/*                                                                           */
/*  Description      : This function is called from main() to logon to       */
/*                     VisualInfo Folder Manager.                            */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibLogon                        */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG Logon ( void ).                                */
/*                                                                           */
/*  Return values    :  SIM_RC_OUT_OF_MEMORY or the return code from         */
/*                      SimLibLogon.                                         */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Reserve storage for and initialize SimLibLogon parameters.       */
/*      2.  If sufficient storage is available, establish a session          */
/*           with the Folder Manager by calling SimLibLogon.                 */
/*      3.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG Logon ( void )
{
     PSZ      pszDBName;                /* Pointer to Database name          */
     PSZ      pszUserId;                /* Pointer to User Id                */
     PSZ      pszPassword;              /* Pointer to Password for User Id   */
     RCSTRUCT RCStruct;                 /* RC data structure                 */

    /*************************************************************************/
    /* Reserve and initialize storage for SimLibLogon parameters.            */
    /* Print error message if sufficient storage is not available.           */
    /*************************************************************************/

     RCStruct.ulRC = SIM_RC_OK;

     pszDBName = (PSZ) malloc (SIM_SERVER_NAME_LENGTH + 1);
     if (pszDBName == NULL)
        {
        printf("Memory allocation error for pszDBName.\n");
        RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
        }
     else
        {
        memset (pszDBName, '\0', SIM_SERVER_NAME_LENGTH + 1);
        pszUserId = (PSZ) malloc (OIM_MAXIMUM_USERID_LENGTH + 1);
        if (pszUserId == NULL)
            {
            printf("Memory allocation error for pszUserId.\n");
            RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
            }
        else
            {
            memset (pszUserId, '\0', OIM_MAXIMUM_USERID_LENGTH + 1);
            pszPassword = (PSZ) malloc (OIM_MAX_PASSWORD_LENGTH + 1);
            if (pszPassword == NULL)
                {
                printf("Memory allocation error for pszPassword.\n");
                RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
                }
            else
                {
                memset (pszPassword, '\0', OIM_MAX_PASSWORD_LENGTH + 1);

    /*************************************************************************/
    /* Initialize SimLibLogon parameters.                                    */
    /*************************************************************************/

                strcpy (pszDBName,            PSZDBNAME);
                strcpy (pszUserId,            PSZUSERID);
                strcpy (pszPassword,          PSZPASSWORD);
                }
            }
        }
    if (RCStruct.ulRC == SIM_RC_OK)
    {
    /*************************************************************************/
    /* Call SimLibLogon to establish a Folder Manager session.               */
    /*************************************************************************/

     SimLibLogon( pszDBName,               /* Pointer to Database name       */
                  (PSZ) "",                /* Reserved for future use        */
                  pszUserId,               /* Pointer to User Id             */
                  pszPassword,             /* Pointer to Password for User Id*/
                  (PSZ) NULL,              /* Logon without new password     */
                  (PSZ) NULL,              /* Reserved for future use        */
                  (PSZ) NULL,              /* Reserved for future use        */
                  SIM_SS_NORMAL,           /* Non-configuration session logon*/
                  (PASYNCCTLSTRUCT) NULL,  /* Request synchronous processing */
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

     if ((RCStruct.ulRC == SIM_RC_OK) ||
         (RCStruct.ulRC == SIM_RC_GRACE_PERIOD_UNDER_LIMIT))

    /*************************************************************************/
    /* If successful, save the Folder Manager session handle for subsequent  */
    /* Folder Manager API calls.                                             */
    /*************************************************************************/

         {
         RCStruct.ulRC = SIM_RC_OK;
         hSession = RCStruct.ulParam1;

    /*************************************************************************/
    /* Save the pointer to the USERLOGONINFOSTRUCT data structure in order   */
    /* to free the memory.                                                   */
    /*************************************************************************/

         ulMemoryBlock = RCStruct.ulParam2;
         }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }
    }

    /*************************************************************************/
    /*  Free storage reserved with malloc and return to main() with a        */
    /*  return code.                                                         */
    /*************************************************************************/

    free (pszDBName);
    free (pszUserId);
    free (pszPassword);

return( RCStruct.ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function        : FreeMemory                                             */
/*                                                                           */
/*  Description     : This function is called from main() to free memory     */
/*                    allocated as the result of a Folder Manager            */
/*                    SimLibLogon, SimLibGetItemAffiliatedTOC, or            */
/*                    SimLibCreateObject.                                    */
/*                                                                           */
/*  Dependencies    : Global Variables :                                     */
/*                    Static External  :                                     */
/*                    Includes         :                                     */
/*                    Product Functions: SimLibFree                          */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  VOID.                                                */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  VOID FreeMemory ( void ).                            */
/*                                                                           */
/*  Return values    :  None.                                                */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call SimLibFree to free memory allocated by the Folder Manager   */
/*          as a result of SimLibLogon, SimLibGetItemAffiliatedTOC,          */
/*          or SimLibCreateObject.                                           */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

VOID FreeMemory (void)
{
     RCSTRUCT RCStruct;                    /* RC data structure              */

     SimLibFree  ( hSession,               /* Folder Manager session handle  */
                  (PVOID) ulMemoryBlock,   /* Pointer to memory block to free*/
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

return;

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : GetNoteTOC                                            */
/*                                                                           */
/*  Description      : This function is called from main() to determine      */
/*                     whether a note already exists for a specified         */
/*                     document.                                             */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibGetItemAffiliatedTOC         */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG GetNoteTOC ( void ).                           */
/*                                                                           */
/*  Return values    :  The return code from SimLibGetItemAffiliatedTOC.     */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Initialize SimLibGetItemAffiliatedTOC parameters.                */
/*      2.  Call SimLibGetItemAffiliatedTOC Folder Manager API.              */
/*      3.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG GetNoteTOC ( VOID )
{
     ITEMID             DocItemID;         /* Document to receive note       */
     PAFFTOCENTRYSTRUCT NoteTOC;           /* TOC data structure             */
     RCSTRUCT           RCStruct;          /* RC data structure              */
     USHORT             count;             /* Loop counter                   */

    /*************************************************************************/
    /* Initialize SimLibGetItemAffiliatedTOC parameters.                     */
    /*************************************************************************/

     strncpy ( (PSZ)DocItemID, (PSZ)DOCITEMID, DOC_ID_SIZE);

    /*************************************************************************/
    /* Call SimLibGetItemAffiliatedTOC to see if a note already exists.      */
    /*************************************************************************/

     SimLibGetItemAffiliatedTOC(hSession,/* Folder Manager session handle    */
          (PITEMID) DocItemID,           /* Get TOC for this Item ID         */
          SIM_NOTE,                      /* Define object type as note       */
          (PASYNCCTLSTRUCT) NULL,        /* Request synchronous processing   */
          (PRCSTRUCT) &RCStruct );       /* Pointer to RC data structure     */

    /*************************************************************************/
    /* If notes already exist for the document, save the pointer to the      */
    /* array of AFFTOCENTRYSTRUCT structures in order to free the memory.    */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
         {
         if ((PAFFTOCENTRYSTRUCT)RCStruct.ulParam2 == (PAFFTOCENTRYSTRUCT)NULL)
             {
             fNoteExists = FALSE;
             printf("The are no existing notes for ItemID %s\n",
                     (PSZ)DocItemID);
             }
         else
             {
             ulMemoryBlock = RCStruct.ulParam1;
             fNoteExists = TRUE;
             printf("The number of notes for Itemid %s = %lu\n",
                       (PSZ)DocItemID, (ULONG)RCStruct.ulParam2);
             NoteTOC = (PAFFTOCENTRYSTRUCT)RCStruct.ulParam1;
             printf("\nNote Table of Contents =\n\n");
             for ( count = 0 ;
                   count < RCStruct.ulParam2;
                   count ++
                 )
                 {
                 printf("Part ID = %lu\n",
                         NoteTOC[count].Obj.ulPart);
                 }

    /*************************************************************************/
    /* Save the Obj structure of the last note listed in the table of        */
    /* contents.  The new note text will be appended to this note.           */
    /*************************************************************************/

             count --;
             Obj = NoteTOC[count].Obj;
             }
         }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }

return( RCStruct.ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : OpenNote                                              */
/*                                                                           */
/*  Description      : This function is called from main() to open an        */
/*                     existing note, so that additional note text can       */
/*                     be appended.                                          */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibOpenObject                   */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG OpenNote ( void ).                             */
/*                                                                           */
/*  Return values    :  Return code from SimLibOpenObject.                   */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call SimLibOpenObject Folder Manager API using the Obj           */
/*          structure returned from SimLibGetItemAffiliatedTOC.              */
/*      2.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG OpenNote ( VOID )
{
     RCSTRUCT RCStruct;                 /* RC data structure                 */

     /**********************************************************/
     /* Print Part ID to receive note.                         */
     /**********************************************************/

     printf("\nPart number of document to receive note = %lu\n", Obj.ulPart);

    /*************************************************************************/
    /* Call SimLibOpenObject to open the object.                             */
    /*************************************************************************/

        SimLibOpenObject(hSession,         /* Folder Manager session handle  */
                   (HOBJ) &Obj,            /* ItemID of object to replace    */
                   SIM_ACCESS_READ_WRITE,  /* Open for reading and writing   */
                   (ULONG)NULL,            /* Reserved for future use        */
                   FALSE,                  /* Reserved for future use        */
                   SIM_OPEN_MEMORY,        /* Open object should be in memory*/
                   (PASYNCCTLSTRUCT)NULL,  /* Request synchronous processing */
                   (PRCSTRUCT) &RCStruct );/* Pointer to RC data structure  */

    /*************************************************************************/
    /* Save the object access handle for subsequent references to the object.*/
    /*************************************************************************/

        if (RCStruct.ulRC == SIM_RC_OK)
            {
            ObjectAccessHandle =  (HOBJACC)RCStruct.ulParam1;
            printf("Note Object Access Handle  = %lu\n\n", ObjectAccessHandle);
            }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

        else
            {
            if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
                RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
                RCStruct.ulRC =  RCStruct.ulExtRC;
            }

    /*************************************************************************/
    /*  Return to main() with a return code.                                 */
    /*************************************************************************/

return( RCStruct.ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : PositionAtNoteEnd                                     */
/*                                                                           */
/*  Description      : This function is called from main() to position the   */
/*                     object pointer at the end of the note object.         */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibSeekObject                   */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG PositionAtNoteEnd ( void).                     */
/*                                                                           */
/*  Return values    :  Return code from SimLibSeekObject.                   */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call SimLibSeekObject Folder Manager API.                        */
/*      2.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG PositionAtNoteEnd ( VOID )
{
     RCSTRUCT RCStruct;                 /* RC data structure                 */

    /*************************************************************************/
    /* Call SimLibSeekObject to position object pointer at the end of the    */
    /* note.                                                                 */
    /*************************************************************************/

        SimLibSeekObject(hSession,         /* Folder Manager session handle  */
             (HOBJACC)ObjectAccessHandle,  /* Object access handle           */
             SIM_POS_END,                  /* Position at the end of object  */
             0,                            /* Byte offset not specified      */
             (PASYNCCTLSTRUCT)NULL,        /* Request synchronous processing */
             (PRCSTRUCT) &RCStruct );      /* Pointer to RC data structure  */


        if (RCStruct.ulRC == SIM_RC_OK)
            {
            printf("Offset position for note append  = %lu\n\n",
                    RCStruct.ulParam1);
            }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

        else
            {
            if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
                RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
                RCStruct.ulRC =  RCStruct.ulExtRC;
            }

    /*************************************************************************/
    /*  Return to main() with a return code.                                 */
    /*************************************************************************/

return( RCStruct.ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : CreateNote                                            */
/*                                                                           */
/*  Description      : This function is called from main() to add a new note */
/*                     to an existing document.                              */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibCreateObject                 */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG CreateNote ( void ).                           */
/*                                                                           */
/*  Return values    :  The return code from SimLibCreateObject.             */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Initialize SimLibCreateObject parameters.                        */
/*      2.  Call SimLibCreateObject Folder Manager API.                      */
/*      3.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG CreateNote ( VOID )
{
     OBJ      NoteObj;                     /* Object data structure          */
     RCSTRUCT RCStruct;                    /* RC data structure              */

    /*************************************************************************/
    /* Initialize SimLibCreateObject Parameters.                             */
    /*************************************************************************/

     /********************************/
     /* Object structure.            */
     /********************************/

     memset (&NoteObj, '\0', sizeof(OBJ));
     NoteObj.ulStruct  = sizeof(NoteObj);

     /********************************/
     /* Use Part ID, and ItemID      */
     /* from header file FRNOEXNO.H  */
     /********************************/

     NoteObj.ulPart    = ULPARTID;
     strcpy (NoteObj.szItemID, DOCITEMID);

    /*************************************************************************/
    /* Call SimLibCreateObject to create an object as part of a previously   */
    /* created document.                                                     */
    /*************************************************************************/

     SimLibCreateObject( hSession,      /* Folder Manager session handle     */
          (HOBJ) &NoteObj,              /* Pointer to object handle block    */
          SIM_CC_ASCII,                 /* ASCII content class               */
          (PSMS)NULL,                   /* Pointer to SMS object structure   */
          (ULONG)NULL,                  /* Reserved for future use           */
          SIM_OPEN,                     /* Leave object open in update mode  */
          (ULONG)NULL,                  /* Reserved for future use           */
          (LONG)NULL,                   /* Reserved for future use           */
          SIM_NOTE,                     /* Define object type as note        */
          (PVOID)NULL,                  /* Affiliated data not used for notes*/
          (PASYNCCTLSTRUCT)NULL,        /* Request synchronous processing    */
          (PRCSTRUCT) &RCStruct );      /* Pointer to RC data structure      */

    /*************************************************************************/
    /* Save the pointer to the object handle in order to free the memory.    */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
         {
         printf("\nNew Note Object Handle  = %lu\n\n", (HOBJ)RCStruct.ulParam1);
         ulMemoryBlock = RCStruct.ulParam1;
         ObjectAccessHandle = (HOBJACC) RCStruct.ulParam2;
         printf("New Note Object Access Handle  = %lu\n\n", ObjectAccessHandle);
         }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }

return( RCStruct.ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : WriteNote                                             */
/*                                                                           */
/*  Description      : This function is called from main() to add note       */
/*                     text to the open note object. The note must have      */
/*                     a content class of ASCII.                             */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibWriteObject                  */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG WriteNote ( void ).                            */
/*                                                                           */
/*  Return values    :  SIM_RC_OUT_OF_MEMORY, or the return code from        */
/*                      SimLibWriteObject.                                   */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Reserve storage for and initialize SimLibWriteObject parameters. */
/*      2.  Call SimLibWriteObject Folder Manager API.                       */
/*      3.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG WriteNote ( VOID )
{
     PHBUF    pBuffer;                  /* Pointer to note text              */
     ULONG    ulBytesToWrite;           /* Size of replacement object file   */
     RCSTRUCT RCStruct;                 /* RC data structure                 */

    /*************************************************************************/
    /* Initialize SimLibWriteObject parameters.                              */
    /*************************************************************************/

     RCStruct.ulRC = SIM_RC_OK;

    /*************************************************************************/
    /* Reserve and initialize storage for pBuffer.  Print error message if   */
    /* sufficient storage is not available.                                  */
    /*************************************************************************/

     pBuffer = (PSZ) malloc (sizeof(PBUFFER) + 1);
     if (pBuffer == NULL)
        {
        printf("Memory allocation error for pBuffer.\n");
        RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
        }
     else
        {
        strcpy (pBuffer, PBUFFER);
        ulBytesToWrite = strlen(pBuffer);
        printf("Note Text = \" %s\"\n\n", pBuffer);
        }

     if (RCStruct.ulRC == SIM_RC_OK)
     {
    /*************************************************************************/
    /* Call SimLibWriteObject to replace the object.                         */
    /*************************************************************************/

     SimLibWriteObject(hSession,           /* Folder Manager session handle  */
             (HOBJACC) ObjectAccessHandle, /* Object access handle           */
             (PHBUF) pBuffer,              /* Pointer to data to write       */
             (ULONG) ulBytesToWrite,       /* Number of bytes to write       */
             (PASYNCCTLSTRUCT)NULL,        /* Request synchronous processing */
             (PRCSTRUCT) &RCStruct );      /* Pointer to RC data structure   */

    /*************************************************************************/
    /* Print the number of bytes actually written to the object.             */
    /*************************************************************************/

     printf("Number of bytes written to the note object  = %lu\n\n",
             RCStruct.ulParam1);

    /*************************************************************************/
    /* If the object was successfully replaced, set the update commit flag   */
    /* to TRUE.  Otherwise, set the update commit flag to FALSE.             */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
         fCommit = TRUE;

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         fCommit = FALSE;
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }

    /*************************************************************************/
    /*  Free storage reserved with malloc and return to main() with a        */
    /*  return code.                                                         */
    /*************************************************************************/

     free (pBuffer);
     }

    /*************************************************************************/
    /*  Return to main() with a return code.                                 */
    /*************************************************************************/

return( RCStruct.ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : CloseNote                                             */
/*                                                                           */
/*  Description      : This function is called from main() to close the      */
/*                     note object.                                          */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibCloseObject                  */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG CloseNote ( void ).                            */
/*                                                                           */
/*  Return values    :  The return code from SimLibCloseObject.              */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call SimLibCloseObject Folder Manager API.                       */
/*      2.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG CloseNote ( VOID )
{
     RCSTRUCT RCStruct;                 /* RC data structure                 */

    /*************************************************************************/
    /* Call SimLibCloseObject to close the object.                           */
    /*************************************************************************/


     SimLibCloseObject(hSession,           /* Folder Manager session handle  */
             (HOBJACC) ObjectAccessHandle, /* Object access handle           */
             (BOOL) fCommit,               /* Update commit flag             */
             (PASYNCCTLSTRUCT)NULL,        /* Request synchronous processing */
             (PRCSTRUCT) &RCStruct );      /* Pointer to RC data structure   */

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
         RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
         RCStruct.ulRC =  RCStruct.ulExtRC;

    /*************************************************************************/
    /*  Return to main() with a return code.                                 */
    /*************************************************************************/

return( RCStruct.ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : Logoff                                                */
/*                                                                           */
/*  Description      : This function is called from main() to logoff from    */
/*                     the VisualInfo Folder Manager.                        */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibLogoff()                     */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG Logoff ( void ).                               */
/*                                                                           */
/*  Return values    :  Return code from SimLibLogoff.                       */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Terminate the session with the Folder Manager by calling         */
/*          SimLibLogoff.                                                    */
/*      2.  Return to main() with return code from SimLibLogoff.             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG Logoff ( void )
{
     RCSTRUCT RCStruct;                     /* RC data structure             */

    /*************************************************************************/
    /* Call SimLibLogoff to terminate the Folder Manager session.            */
    /*************************************************************************/

     SimLibLogoff( hSession,                /* Folder Manager session handle */
                  (PASYNCCTLSTRUCT)NULL,    /* Request synchronous processing*/
                  (PRCSTRUCT) &RCStruct );  /* Pointer to RC data structure  */

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
         RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
         RCStruct.ulRC =  RCStruct.ulExtRC;

    /*************************************************************************/
    /*  Return to main() with the return code from SimLibLogoff.             */
    /*************************************************************************/

return( RCStruct.ulRC );

}

/*****************************************************************************/
/* End of FRNOEXNO.C                                                         */
/*****************************************************************************/

