/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/* MODULE: FRNOEXRE.C                                         VisualInfo     */
/*                                                                           */
/* 5697-250                                                                  */
/* 5621-326, 5655-036, 5622-213, 5655-071, 5655-072                          */
/*                                                                           */
/* (C) Copyright IBM Corporation 1993, 1996.                                 */
/* All Rights Reserved.                                                      */
/*                                                                           */
/* DERIVATIVE RIGHTS:                                                        */
/* ------------------                                                        */
/* This program is provided for the customer's use and the customer is       */
/* granted permission to copy this program to the extent reasonably          */
/* required for such use.  All title, ownership, and rights to this          */
/* program and any copies remain with IBM, irrespective of the ownership     */
/* of the media on which the program resides.  The customer is permitted     */
/* to create derivative works to this program.  However, all copies of       */
/* the program and its derivative works must contain the IBM copyright       */
/* notice.  The customer understands and agrees that this program in and     */
/* of itself is not to be sold or distributed.  The customer is free to      */
/* sell, distribute, and commercially exploit any derivative works           */
/* created from this program.                                                */
/*                                                                           */
/*                                                                           */
/* DISCLAIMER OF WARRANTIES:                                                 */
/* -------------------------                                                 */
/* The following [enclosed] code is sample code created by IBM               */
/* Corporation.  This sample code is not part of any standard IBM product    */
/* and is provided to you solely for the purpose of assisting you in the     */
/* development of your applications.  The code is provided "AS IS",          */
/* without warranty of any kind.  IBM shall not be liable for any damages    */
/* arising out of your use of the sample code, even if they have been        */
/* advised of the possibility of such damages.                               */
/*                                                                           */
/*                                                                           */
/* Status: Version 2 Release 1 Modification 0                                */
/*                                                                           */
/*****************************************************************************/
/* Description : frnoexre.c - Sample application code to replace a previously*/
/*               stored object.  The APIs used are SimLibLogon, SimLibFree,  */
/*               SimLibOpenObject, SimLibWriteObject, SimLibResizeObject,    */
/*               SimLibCloseObject, and SimLibLogoff.                        */
/*                                                                           */
/* Dependencies: To run this sample code without modification:               */
/*                - Part 1 of the document to be replaced must already       */
/*                  exist.  Specify the ItemID of this document in FRNOEXRE.H*/
/*                - Part 1 of the document to be replaced must be            */
/*                  of the same content class as the replacement file        */
/*                  defined in FRNOEXRE.H (OS/2 Version2 bitmap).            */
/*                - File OS2LOGO.BMP must exist in directory C:\OS2\BITMAP.  */
/*                  (c:\config.sys for Windows)                              */
/*                  (/usr/lpp/frn/bin/FRNOLINT.TBL)                          */ /*                                                                           */
/* Restrictions: None                                                        */
/*                                                                           */
/* Entry Points: main                                                        */
/*               Logon                                                       */
/*               FreeMemory                                                  */
/*               OpenObject                                                  */
/*               ReplaceObject                                               */
/*               ResizeObject                                                */
/*               CloseObject                                                 */
/*               Logoff                                                      */
/*                                                                           */
/* Change History:                                                           */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

/*****************************************************************************/
/*  System Header Files                                                      */
/*****************************************************************************/
/* the following changes for AIX Porting */
#ifdef _Windows
 #include <windows.h>
#else
 #ifdef AIX
  #include <frnptype.h>
 #else
  #include <os2.h>                        /* Main OS/2 header files           */
 #endif
#endif
/* end of ivy's change  */

#include <stdio.h>                      /* Standard I/O header files         */
#include <io.h>                         /* I/O header file                   */
#include <stdlib.h>                     /* Standard Library header files     */
#include <string.h>                     /* String manipulation               */

/*****************************************************************************/
/*  VisualInfo Header Files                                                  */
/*****************************************************************************/

#define   FRN_INCL_FI                   /* Include frnpfi.h & frnpfi2.h      */
#define   FRN_INCL_FO                   /* Include frnpfo.h                  */
#include "frnp.h"                       /* Global types                      */
#include "frnpcapi.h"                   /* Structures and constants          */

/*****************************************************************************/
/*  FRNOEXRE Header File                                                     */
/*****************************************************************************/

#include "frnoexre.h"                   /* Application header file           */

/*****************************************************************************/
/*  Global Variables                                                         */
/*****************************************************************************/

HSESSION hSession;                      /* Folder Manager session handle     */
ULONG    ulMemoryBlock;                 /* Generic pointer for SimLibFree    */
PSZ      DocItemID;                     /* Item ID of object to be replaced  */
HOBJACC  ObjectAccessHandle;            /* Handle of object to be replaced   */
BOOL     fCommit;                       /* Update commit flag                */

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : main                                                  */
/*                                                                           */
/*  Description      : main() function of a sample application that uses     */
/*                     Folder Manager APIs to replace an existing object.    */
/*                     The replacement object and existing document part     */
/*                     must have the same content class.                     */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions:                                    */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  INT.                                                 */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  INT main ( void ).                                   */
/*                                                                           */
/*  Return values    :  If all functions are successful, the return code     */
/*                      from Logoff() is returned.  Otherwise, the return    */
/*                      code from Logon(), OpenObject(), ReplaceObject(),    */
/*                      ResizeObject, or CloseObject() is returned.          */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Establish a session with the Folder Manager.                     */
/*      2.  If logon was successful:                                         */
/*          - Free the USERLOGONINFOSTRUC memory and open an existing object */
/*            with intent to update.                                         */
/*            - If the object is successfully opened, replace the object.    */
/*              - If the object is successfully replaced, resize the object. */
/*              Close the object.                                            */
/*          Logoff from the Folder Manager session.                          */
/*      3.  Exit main() with a return code.                                  */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

#ifdef _Windows
int SIMENTRY fnFrnoexre ( void )  /* code sync - ivy 9/18/95 */
#else
INT main ( void )
#endif
{
     ULONG ulretcode;

    /*************************************************************************/
    /*  Call Logon to establish a Folder Manager Session.                    */
    /*************************************************************************/

     ulretcode = Logon();

    /*************************************************************************/
    /* If successful, call FreeMemory to free the memory for structure       */
    /* USERLOGONINFOSTRUC returned from SimLibLogon.                         */
    /*************************************************************************/

     if (ulretcode == SIM_RC_OK)
         {
         FreeMemory();

    /*************************************************************************/
    /*  Call OpenObject to open a previously created object.                 */
    /*************************************************************************/

         ulretcode = OpenObject();

    /*************************************************************************/
    /*  If successful, call ReplaceObject to replace the object.             */
    /*************************************************************************/

         if (ulretcode == SIM_RC_OK)
             {
             ulretcode = ReplaceObject();

    /*************************************************************************/
    /*  If successful, call ResizeObject to truncate the object to the       */
    /*  new object size.  If the replacement object is smaller than the      */
    /*  original object, the SimLibResizeObject is required to truncate      */
    /*  the object at the replacement object size.  If the replacement       */
    /*  object is larger than the original object, this is optional.         */
    /*************************************************************************/

             if (ulretcode == SIM_RC_OK)
                 {
                 ulretcode = ResizeObject();
                 if (ulretcode == SIM_RC_OK)
                     {

    /*************************************************************************/
    /*  Call CloseObject to close the open object.  Call Logoff to terminate */
    /*  the Folder Manager Session.                                          */
    /*************************************************************************/

                     ulretcode = CloseObject();
                     if (ulretcode == SIM_RC_OK)
                         ulretcode = Logoff();
                     }
                 else
                     {
                     CloseObject();
                     Logoff();
                     }
                 }
             else
                 {
                 CloseObject();
                 Logoff();
                 }
             }
         else
             Logoff();
         }

    /*************************************************************************/
    /* Print return code.                                                    */
    /*************************************************************************/

    printf ("RETURN CODE = %lu\n", ulretcode);

    /*************************************************************************/
    /* Exit main() with the return code.                                     */
    /*************************************************************************/

    return ( ulretcode );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : Logon                                                 */
/*                                                                           */
/*  Description      : This function is called from main() to logon to       */
/*                     VisualInfo Folder Manager.                            */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibLogon                        */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG Logon ( void ).                                */
/*                                                                           */
/*  Return values    :  SIM_RC_OUT_OF_MEMORY or the return code from         */
/*                      SimLibLogon.                                         */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Reserve storage for and initialize SimLibLogon parameters.       */
/*      2.  If sufficient storage is available, establish a session          */
/*           with the Folder Manager by calling SimLibLogon.                 */
/*      3.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG Logon ( void )
{
     PSZ      pszDBName;                /* Pointer to Database name          */
     PSZ      pszUserId;                /* Pointer to User Id                */
     PSZ      pszPassword;              /* Pointer to Password for User Id   */
     RCSTRUCT RCStruct;                 /* RC data structure                 */

    /*************************************************************************/
    /* Reserve and initialize storage for SimLibLogon parameters.            */
    /* Print error message if sufficient storage is not available.           */
    /*************************************************************************/

     RCStruct.ulRC = SIM_RC_OK;

     pszDBName = (PSZ) malloc (SIM_SERVER_NAME_LENGTH + 1);
     if (pszDBName == NULL)
        {
        printf("Memory allocation error for pszDBName.\n");
        RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
        }
     else
        {
        memset (pszDBName, '\0', SIM_SERVER_NAME_LENGTH + 1);
        pszUserId = (PSZ) malloc (OIM_MAXIMUM_USERID_LENGTH + 1);
        if (pszUserId == NULL)
            {
            printf("Memory allocation error for pszUserId.\n");
            RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
            }
        else
            {
            memset (pszUserId, '\0', OIM_MAXIMUM_USERID_LENGTH + 1);
            pszPassword = (PSZ) malloc (OIM_MAX_PASSWORD_LENGTH + 1);
            if (pszPassword == NULL)
                {
                printf("Memory allocation error for pszPassword.\n");
                RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
                }
            else
                {
                memset (pszPassword, '\0', OIM_MAX_PASSWORD_LENGTH + 1);

    /*************************************************************************/
    /* Initialize SimLibLogon parameters.                                    */
    /*************************************************************************/

                strcpy (pszDBName,            PSZDBNAME);
                strcpy (pszUserId,            PSZUSERID);
                strcpy (pszPassword,          PSZPASSWORD);
                }
            }
        }
    if (RCStruct.ulRC == SIM_RC_OK)
    {
    /*************************************************************************/
    /* Call SimLibLogon to establish a Folder Manager session.               */
    /*************************************************************************/

     SimLibLogon( pszDBName,               /* Pointer to Database name       */
                  (PSZ) "",                /* Reserved for future use        */
                  pszUserId,               /* Pointer to User Id             */
                  pszPassword,             /* Pointer to Password for User Id*/
                  (PSZ) NULL,              /* Logon without new password     */
                  (PSZ) NULL,              /* Reserved for future use        */
                  (PSZ) NULL,              /* Reserved for future use        */
                  SIM_SS_NORMAL,           /* Non-configuration session logon*/
                  (PASYNCCTLSTRUCT) NULL,  /* Request synchronous processing */
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

     if ((RCStruct.ulRC == SIM_RC_OK) ||
         (RCStruct.ulRC == SIM_RC_GRACE_PERIOD_UNDER_LIMIT))

    /*************************************************************************/
    /* If successful, save the Folder Manager session handle for subsequent  */
    /* Folder Manager API calls.                                             */
    /*************************************************************************/

         {
         RCStruct.ulRC = SIM_RC_OK;
         hSession = RCStruct.ulParam1;

    /*************************************************************************/
    /* Save the pointer to the USERLOGONINFOSTRUCT data structure in order   */
    /* to free the memory.                                                   */
    /*************************************************************************/

         ulMemoryBlock = RCStruct.ulParam2;
         }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
                RCStruct.ulRC =  RCStruct.ulExtRC;
         }
    }

    /*************************************************************************/
    /*  Free storage reserved with malloc and return to main() with a        */
    /*  return code.                                                         */
    /*************************************************************************/

    free (pszDBName);
    free (pszUserId);
    free (pszPassword);

return( RCStruct.ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function        : FreeMemory                                             */
/*                                                                           */
/*  Description     : This function is called from main() to free memory     */
/*                    allocated as the result of a Folder Manager            */
/*                    SimLibLogon call.                                      */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibFree                         */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  VOID.                                                */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  VOID FreeMemory ( void ).                            */
/*                                                                           */
/*  Return values    :  None.                                                */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call SimLibFree to free memory allocated by the Folder Manager   */
/*          as a result of SimLibLogon.                                      */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

VOID FreeMemory (void)
{
     RCSTRUCT RCStruct;                    /* RC data structure              */

     SimLibFree  ( hSession,               /* Folder Manager session handle  */
                  (PVOID) ulMemoryBlock,   /* Pointer to memory block to free*/
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

return;
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : OpenObject                                            */
/*                                                                           */
/*  Description      : This function is called from main() to open the       */
/*                     object to be replaced.  The existing document part    */
/*                     and replacment object must have the same content class*/
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibOpenObject                   */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG OpenObject ( void ).                           */
/*                                                                           */
/*  Return values    :  Return code from SimLibOpenObject.                   */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Initialize SimLibOpenObject parameters.                          */
/*      2.  Call SimLibOpenObject Folder Manager API.                        */
/*      3.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG OpenObject ( VOID )
{
     OBJ      Obj;                      /* Object data structure             */
     RCSTRUCT RCStruct;                 /* RC data structure                 */

    /*************************************************************************/
    /* Initialize SimLibOpenObject parameters.                               */
    /*************************************************************************/

     /********************************/
     /* Object structure.            */
     /********************************/

     memset (&Obj, '\0', sizeof(OBJ));
     Obj.ulStruct  = sizeof(Obj);
     Obj.ulPart    = ULPARTID;
     strcpy (Obj.szItemID, DOCITEMID);

     /*****************************/
     /* Print Object information. */
     /*****************************/

     printf("Item ID of object to be replaced = %s\n", Obj.szItemID);
     printf("Part number of object to be replaced = %lu\n", Obj.ulPart);

    /*************************************************************************/
    /* Call SimLibOpenObject to open the object.                             */
    /*************************************************************************/

        SimLibOpenObject(hSession,         /* Folder Manager session handle  */
                   (HOBJ) &Obj,            /* ItemID of object to replace    */
                   SIM_ACCESS_READ_WRITE,  /* Open for reading and writing   */
                   (ULONG)NULL,            /* Reserved for future use        */
                   FALSE,                  /* Reserved for future use        */
                   SIM_OPEN_MEMORY,        /* Open object should be in memory*/
                   (PASYNCCTLSTRUCT) NULL, /* Request synchronous processing */
                   (PRCSTRUCT) &RCStruct );/* Pointer to RC data structure  */

    /*************************************************************************/
    /* Save the object access handle for subsequent references to the object.*/
    /*************************************************************************/

        if (RCStruct.ulRC == SIM_RC_OK)
            {
            ObjectAccessHandle =  (HOBJACC)RCStruct.ulParam1;
            printf("New Object Access Handle  = %lu\n\n", ObjectAccessHandle);
            }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

        else
            {
            if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
                RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
                RCStruct.ulRC =  RCStruct.ulExtRC;
            }

    /*************************************************************************/
    /*  Return to main() with a return code.                                 */
    /*************************************************************************/

return( RCStruct.ulRC );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : ReplaceObject                                         */
/*                                                                           */
/*  Description      : This function is called from main() to replace the    */
/*                     opened object.  The replacement object must have      */
/*                     the same content class as the existing document part. */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibWriteObject                  */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG ReplaceObject ( void ).                        */
/*                                                                           */
/*  Return values    :  SIM_RC_ERROR_READING_FROM_FILE, SIM_RC_OUT_OF_MEMORY,*/
/*                      or the return code from SimLibWriteObject.           */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Reserve storage for and initialize SimLibWriteObject parameters. */
/*      2.  Call SimLibWriteObject Folder Manager API.                       */
/*      3.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG ReplaceObject ( VOID )
{
     FILE     *pFile;                   /* Pointer to file containing object */
     LONG     lBytesToWrite;            /* Size of replacement object file   */
     PHBUF    pBuffer;                  /* Pointer to replacement object data*/
     RCSTRUCT RCStruct;                 /* RC data structure                 */

    /*************************************************************************/
    /* Initialize SimLibWriteObject parameters.                              */
    /*************************************************************************/

     RCStruct.ulRC = SIM_RC_OK;

     /************************************************************/
     /* Print full file name of the replacement object.          */
     /************************************************************/

     printf("File name of replacement object = %s\n",  PSZFILENAME);

     /***************************************************************/
     /* Open the file containing the replacement object. The file   */
     /* open parameters are "read, binary".                         */
     /***************************************************************/

     pFile = fopen(PSZFILENAME, "rb");
     if (pFile == NULL)
         {
         printf("The file containing the replacement object could not be opened.\n");
         RCStruct.ulRC = SIM_RC_ERROR_READING_FROM_FILE;
         }
     else

     /*****************************************************************/
     /* Get the length of the file containing the replacement object. */
     /*****************************************************************/

         {
         lBytesToWrite = filelength(fileno(pFile));
         if (lBytesToWrite == -1L)
             {
             printf("The file length of the replacement object could not be determined.\n");
             RCStruct.ulRC = SIM_RC_ERROR_READING_FROM_FILE;
             fclose(pFile);
             }
         else
             {

     /*******************************************************************/
     /* Print the length of the file containing the replacement object  */
     /* and reserve storage for the replacement object.                 */
     /*******************************************************************/

             printf("File size of replacement object = %lu\n\n", lBytesToWrite);
             pBuffer = (PHBUF) malloc ( lBytesToWrite );
             if (pBuffer == NULL)
                 {
                 printf("Memory allocation error for replacement object.\n");
                 RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
                 }
             else

     /*******************************************************************/
     /* Read the replacement object file.                               */
     /*******************************************************************/

                 {
                 if ( fread(pBuffer, lBytesToWrite, 1, pFile) != 1 )
                     {
                     printf("The file containing the replacement object could not be read.\n");
                     RCStruct.ulRC = SIM_RC_ERROR_READING_FROM_FILE;
                     fclose(pFile);
                     }
                 }
             }
         }

     if (RCStruct.ulRC == SIM_RC_OK)
     {
    /*************************************************************************/
    /* Call SimLibWriteObject to replace the object.                         */
    /*************************************************************************/

     SimLibWriteObject(hSession,           /* Folder Manager session handle  */
             (HOBJACC) ObjectAccessHandle, /* Object access handle           */
             (PHBUF) pBuffer,              /* Pointer to data to write       */
             (ULONG) lBytesToWrite,        /* Number of bytes to write       */
             (PASYNCCTLSTRUCT) NULL,       /* Request synchronous processing */
             (PRCSTRUCT) &RCStruct );      /* Pointer to RC data structure   */

    /*************************************************************************/
    /* Print the number of bytes actually written to the object.             */
    /*************************************************************************/

     printf("Number of bytes written to the object  = %lu\n\n",
             RCStruct.ulParam1);

    /*************************************************************************/
    /* If the object was successfully replaced, set the update commit flag   */
    /* to TRUE.  Otherwise, set the update commit flag to FALSE.             */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
         fCommit = TRUE;

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         fCommit = FALSE;
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }

    /*************************************************************************/
    /* Close the file containing the replacement object.                     */
    /*************************************************************************/

     if ( fclose(pFile) != 0 )
         printf("The file containing the replacement object could not be closed.\n");

    /*************************************************************************/
    /*  Free storage reserved with malloc and return to main() with a        */
    /*  return code.                                                         */
    /*************************************************************************/

    free (pBuffer);

     }

    /*************************************************************************/
    /*  Return to main() with a return code.                                 */
    /*************************************************************************/

return( RCStruct.ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : ResizeObject                                          */
/*                                                                           */
/*  Description      : This function is called from main() to truncate the   */
/*                     object to the size of the replacement object.         */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibResizeObject                 */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG ResizeObject ( void ).                         */
/*                                                                           */
/*  Return values    :  The return code from SimLibResizeObject.             */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call SimLibResizeObject Folder Manager API.                      */
/*      2.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG ResizeObject ( VOID )
{
     RCSTRUCT RCStruct;                 /* RC data structure                 */

    /*************************************************************************/
    /* Call SimLibResizeObject to truncate the object at the replacement     */
    /* object size.                                                          */
    /*************************************************************************/

     SimLibResizeObject(hSession,          /* Folder Manager session handle  */
             (HOBJACC) ObjectAccessHandle, /* Object access handle           */
             0,                            /* Truncate at current position   */
             (PASYNCCTLSTRUCT) NULL,       /* Request synchronous processing */
             (PRCSTRUCT) &RCStruct );      /* Pointer to RC data structure   */

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
         RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
         RCStruct.ulRC =  RCStruct.ulExtRC;

    /*************************************************************************/
    /*  Return to main() with a return code.                                 */
    /*************************************************************************/

return( RCStruct.ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : CloseObject                                           */
/*                                                                           */
/*  Description      : This function is called from main() to close the      */
/*                     object.                                               */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibCloseObject                  */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG CloseObject ( void ).                          */
/*                                                                           */
/*  Return values    :  The return code from SimLibCloseObject.              */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call SimLibCloseObject Folder Manager API.                       */
/*      2.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG CloseObject ( VOID )
{
     RCSTRUCT RCStruct;                 /* RC data structure                 */

    /*************************************************************************/
    /* Call SimLibCloseObject to close the object.                           */
    /*************************************************************************/

     SimLibCloseObject(hSession,           /* Folder Manager session handle  */
             (HOBJACC) ObjectAccessHandle, /* Object access handle           */
             (BOOL) fCommit,               /* Update commit flag             */
             (PASYNCCTLSTRUCT) NULL,       /* Request synchronous processing */
             (PRCSTRUCT) &RCStruct );      /* Pointer to RC data structure   */

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
         RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
         RCStruct.ulRC =  RCStruct.ulExtRC;

    /*************************************************************************/
    /*  Return to main() with a return code.                                 */
    /*************************************************************************/

return( RCStruct.ulRC );
}
/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : Logoff                                                */
/*                                                                           */
/*  Description      : This function is called from main() to logoff from    */
/*                     the VisualInfo Folder Manager.                        */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibLogoff()                     */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG Logoff ( void ).                               */
/*                                                                           */
/*  Return values    :  Return code from SimLibLogoff.                       */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Terminate the session with the Folder Manager by calling         */
/*          SimLibLogoff.                                                    */
/*      2.  Return to main() with return code from SimLibLogoff.             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG Logoff ( void )
{
     RCSTRUCT RCStruct;                     /* RC data structure             */

    /*************************************************************************/
    /* Call SimLibLogoff to terminate the Folder Manager session.            */
    /*************************************************************************/

     SimLibLogoff( hSession,                /* Folder Manager session handle */
                  (PASYNCCTLSTRUCT) NULL,   /* Request synchronous processing*/
                  (PRCSTRUCT) &RCStruct );  /* Pointer to RC data structure  */

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
         RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
         RCStruct.ulRC =  RCStruct.ulExtRC;

    /*************************************************************************/
    /*  Return to main() with the return code from SimLibLogoff.             */
    /*************************************************************************/

return( RCStruct.ulRC );

}
/*****************************************************************************/
/* End of FRNOEXRE.C                                                         */
/*****************************************************************************/

