/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/* MODULE: FRNOEXSE.C                                         VisualInfo     */
/*                                                                           */
/* 5697-250                                                                  */
/* 5621-326, 5655-036, 5622-213, 5655-071, 5655-072                          */
/*                                                                           */
/* (C) Copyright IBM Corporation 1993, 1996.                                 */
/* All Rights Reserved.                                                      */
/*                                                                           */
/* DERIVATIVE RIGHTS:                                                        */
/* ------------------                                                        */
/* This program is provided for the customer's use and the customer is       */
/* granted permission to copy this program to the extent reasonably          */
/* required for such use.  All title, ownership, and rights to this          */
/* program and any copies remain with IBM, irrespective of the ownership     */
/* of the media on which the program resides.  The customer is permitted     */
/* to create derivative works to this program.  However, all copies of       */
/* the program and its derivative works must contain the IBM copyright       */
/* notice.  The customer understands and agrees that this program in and     */
/* of itself is not to be sold or distributed.  The customer is free to      */
/* sell, distribute, and commercially exploit any derivative works           */
/* created from this program.                                                */
/*                                                                           */
/*                                                                           */
/* DISCLAIMER OF WARRANTIES:                                                 */
/* -------------------------                                                 */
/* The following [enclosed] code is sample code created by IBM               */
/* Corporation.  This sample code is not part of any standard IBM product    */
/* and is provided to you solely for the purpose of assisting you in the     */
/* development of your applications.  The code is provided "AS IS",          */
/* without warranty of any kind.  IBM shall not be liable for any damages    */
/* arising out of your use of the sample code, even if they have been        */
/* advised of the possibility of such damages.                               */
/*                                                                           */
/*                                                                           */
/* Status: Version 2 Release 1 Modification 0                                */
/*                                                                           */
/*                                                                           */
/*****************************************************************************/
/* Description : frnoexse.c - Sample application code to locate items in     */
/*               the database that match specified attributes.  The APIs     */
/*               used are SimLibLogon, SimLibFree, SimLibSearch, and         */
/*               SimLibLogoff.                                               */
/*                                                                           */
/* Dependencies: None                                                        */
/* Restrictions: None                                                        */
/*                                                                           */
/* Entry Points: main                                                        */
/*               Logon                                                       */
/*               FreeMemory                                                  */
/*               LibrarySearch                                               */
/*               Logoff                                                      */
/*                                                                           */
/* Change History:                                                           */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

/*****************************************************************************/
/*  System Header Files                                                      */
/*****************************************************************************/
/* the following changes for AIX PORTING - Ivy  */
#ifdef _Windows
 #include <windows.h>
#else
 #ifdef AIX
  #include <frnptype.h>
 #else
  #include <os2.h>                         /* Main OS/2 header files         */
 #endif
#endif
/* end of ivy's change   */

#include <stdio.h>                      /* Standard I/O header files         */
#include <stdlib.h>                     /* Standard Library header files     */
#include <string.h>                     /* String manipulation               */

/*****************************************************************************/
/*  VisualInfo Header Files                                                  */
/*****************************************************************************/

#define   FRN_INCL_FI                   /* Includes frnpfi.h & frnpfi2.h     */
#include "frnp.h"                       /* Global types                      */
#include "frnpcapi.h"                   /* Structures and constants          */

/*****************************************************************************/
/*  FRNOEXSE Header File                                                     */
/*****************************************************************************/

#include "frnoexse.h"                   /* Application header file           */

/*****************************************************************************/
/*  Global Variables                                                         */
/*****************************************************************************/

HSESSION hSession;                      /* Folder Manager session handle     */
ULONG    ulMemoryBlock;                 /* Generic pointer for SimLibFree    */

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : main                                                  */
/*                                                                           */
/*  Description      : main() function of a sample application of a library  */
/*                     search using the Folder Manager SimLibSearch API.     */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions:                                    */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  INT.                                                 */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  INT main ( void ).                                   */
/*                                                                           */
/*  Return values    :  If all functions are successful, the return code     */
/*                      from Logoff() is returned.  Otherwise, the return    */
/*                      code from Logon() or LibrarySearch() is returned.    */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Establish a session with the Folder Manager.                     */
/*      2.  If logon was successful, free the USERLOGONINFOSTRUC memory and  */
/*          perform the library search.  If the search was successful,       */
/*          free the memory containing the matching document and folder ids. */
/*          Logoff from the Folder Manager session.                          */
/*      3.  Exit main() with a return code.                                  */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

#ifdef _Windows
int SIMENTRY fnFrnoexse ( void )   /* code sync - ivy 9/18/95 */
#else
INT main ( void )
#endif
{
     ULONG ulretcode;

    /*************************************************************************/
    /*  Call Logon to establish a Folder Manager Session.                    */
    /*************************************************************************/

     ulretcode = Logon();

    /*************************************************************************/
    /* If successful, call FreeMemory to free the memory for structure       */
    /* USERLOGONINFOSTRUC returned from SimLibLogon.                         */
    /*************************************************************************/

     if (ulretcode == SIM_RC_OK)
           {
             FreeMemory();

    /*************************************************************************/
    /*  Call LibrarySearch to locate items that match specified attribute    */
    /*  values.                                                              */
    /*************************************************************************/

             ulretcode = LibrarySearch();
             if (ulretcode == SIM_RC_OK)

    /*************************************************************************/
    /* If matches were found, call FreeMemory to free the memory containing  */
    /* the ITEMIDS of matching documents and folders.                        */
    /*************************************************************************/

                  {
                  if ((PITEMID)ulMemoryBlock != (PITEMID)NULL)
                      FreeMemory();

    /*************************************************************************/
    /*  Call Logoff to terminate the Folder Manager Session.                 */
    /*************************************************************************/

                  ulretcode = Logoff();
                  }
             else
                  Logoff();
           }

    /*************************************************************************/
    /* Print return code.                                                    */
    /*************************************************************************/

    printf ("RETURN CODE = %lu\n", ulretcode);

    /*************************************************************************/
    /* Exit main() with the return code.                                     */
    /*************************************************************************/

    return ( ulretcode );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : Logon                                                 */
/*                                                                           */
/*  Description      : This function is called from main() to logon to       */
/*                     VisualInfo Folder Manager.                            */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibLogon                        */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG Logon ( void ).                                */
/*                                                                           */
/*  Return values    :  SIM_RC_OUT_OF_MEMORY or the return code from         */
/*                      SimLibLogon.                                         */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Reserve storage for and initialize SimLibLogon parameters.       */
/*      2.  If sufficient storage is available, establish a session          */
/*           with the Folder Manager by calling SimLibLogon.                 */
/*      3.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG Logon ( void )
{
     PSZ      pszDBName;                /* Pointer to Database name          */
     PSZ      pszUserId;                /* Pointer to User Id                */
     PSZ      pszPassword;              /* Pointer to Password for User Id   */
     RCSTRUCT RCStruct;                 /* RC data structure                 */

    /*************************************************************************/
    /* Reserve and initialize storage for SimLibLogon parameters.            */
    /* Print error message if sufficient storage is not available.           */
    /*************************************************************************/

     RCStruct.ulRC = SIM_RC_OK;

     pszDBName = (PSZ) malloc (SIM_SERVER_NAME_LENGTH + 1);
     if (pszDBName == NULL)
        {
        printf("Memory allocation error for pszDBName.\n");
        RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
        }
     else
        {
        memset (pszDBName, '\0', SIM_SERVER_NAME_LENGTH + 1);
        pszUserId = (PSZ) malloc (OIM_MAXIMUM_USERID_LENGTH + 1);
        if (pszUserId == NULL)
            {
            printf("Memory allocation error for pszUserId.\n");
            RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
            }
        else
            {
            memset (pszUserId, '\0', OIM_MAXIMUM_USERID_LENGTH + 1);
            pszPassword = (PSZ) malloc (OIM_MAX_PASSWORD_LENGTH + 1);
            if (pszPassword == NULL)
                {
                printf("Memory allocation error for pszPassword.\n");
                RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
                }
            else
                {
                memset (pszPassword, '\0', OIM_MAX_PASSWORD_LENGTH + 1);

    /*************************************************************************/
    /* Initialize SimLibLogon parameters.                                    */
    /*************************************************************************/

                strcpy (pszDBName,            PSZDBNAME);
                strcpy (pszUserId,            PSZUSERID);
                strcpy (pszPassword,          PSZPASSWORD);
                }
            }
        }
    if (RCStruct.ulRC == SIM_RC_OK)
    {

    /*************************************************************************/
    /* Call SimLibLogon to establish a Folder Manager session.               */
    /*************************************************************************/

     SimLibLogon( pszDBName,               /* Pointer to Database name       */
                  (PSZ) "",                /* Reserved for future use        */
                  pszUserId,               /* Pointer to User Id             */
                  pszPassword,             /* Pointer to Password for User Id*/
                  (PSZ) NULL,              /* Logon without new password     */
                  (PSZ) NULL,              /* Reserved for future use        */
                  (PSZ) NULL,              /* Reserved for future use        */
                  SIM_SS_NORMAL,           /* Non-configuration session logon*/
                  (PASYNCCTLSTRUCT) NULL,  /* Request synchronous processing */
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

     if ((RCStruct.ulRC == SIM_RC_OK) ||
         (RCStruct.ulRC == SIM_RC_GRACE_PERIOD_UNDER_LIMIT))

    /*************************************************************************/
    /* If successful, save the Folder Manager session handle for subsequent  */
    /* Folder Manager API calls.                                             */
    /*************************************************************************/

         {
         RCStruct.ulRC = SIM_RC_OK;
         hSession = RCStruct.ulParam1;

    /*************************************************************************/
    /* Save the pointer to the USERLOGONINFOSTRUCT data structure in order   */
    /* to free the memory.                                                   */
    /*************************************************************************/

         ulMemoryBlock = RCStruct.ulParam2;
         }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }
    }

    /*************************************************************************/
    /*  Free storage reserved with malloc and return to main() with a        */
    /*  return code.                                                         */
    /*************************************************************************/

    free (pszDBName);
    free (pszUserId);
    free (pszPassword);

return( RCStruct.ulRC );

}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function        : FreeMemory                                             */
/*                                                                           */
/*  Description     : This function is called from main() to free memory     */
/*                    allocated as the result of a Folder Manager            */
/*                    SimLibLogon or SimLibSearch call.                      */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibFree                         */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  VOID.                                                */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  VOID FreeMemory ( void ).                            */
/*                                                                           */
/*  Return values    :  None.                                                */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call SimLibFree to free memory allocated by the Folder Manager   */
/*          as a result of SimLibLogon or SimLibSearch.                      */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

VOID FreeMemory (void)
{
     RCSTRUCT RCStruct;                    /* RC data structure              */

     SimLibFree  ( hSession,               /* Folder Manager session handle  */
                  (PVOID) ulMemoryBlock,   /* Pointer to memory block to free*/
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

return;
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : LibrarySearch                                         */
/*                                                                           */
/*  Description      : This function is called from main() to locate folders */
/*                     and documents that match specified criteria.          */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibSearch                       */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG LibrarySearch ( void ).                        */
/*                                                                           */
/*  Return values    :  Return code from SimLibSearch.                       */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Initialize SimLibSearch parmeters.                               */
/*      2.  Call SimLibSearch Folder Manager API.                            */
/*      3.  Return to main() with the return code from SimLibSearch.         */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG LibrarySearch ( VOID )
{
     USHORT   usNumCriteria;            /* Number of elements in Criteria    */
                                        /* Search criteria structure         */
     LIBSEARCHCRITERIASTRUCT Criteria [USNUMCRITERIA];
     RCSTRUCT RCStruct;                 /* RC data structure                 */
     USHORT   count;                    /* Loop counter                      */
     PITEMID  pSearchResults;           /* Pointer to search results         */

    /*************************************************************************/
    /* Initialize SimLibSearch parameters.                                   */
    /*************************************************************************/

     usNumCriteria = USNUMCRITERIA;
     memset (Criteria, '\0', sizeof(Criteria));

     /******************************************/
     /* Initialize and print Search Criteria.  */
     /******************************************/

     printf("Search for folders and documents with the following attributes:\n\n");
     for ( count = 0 ;
           count < usNumCriteria;
           count ++
         )
         {
         Criteria[count] = CRITERIA[count];
         printf("Maximum number of matches to return = %lu\n",
                 Criteria[count].ulReturnLimit);
         printf("View to search = %hu\n",
                 Criteria[count].usViewID);
         printf("Search flags = %u\n",
                 Criteria[count].fSearch);
         printf("Search string = %s\n\n",
                 Criteria[count].pszSearchString);
         }

    /*************************************************************************/
    /* Call SimLibSearch to locate items matching the specified criteria.    */
    /*************************************************************************/

     SimLibSearch( hSession,               /* Folder Manager session handle  */
                   (PITEMID) NULL,         /* Reserved for future use        */
                   (PVOID)NULL,            /* Reserved for future use        */
                   SIM_SEARCH_STATIC,      /* Use static SQL if available    */
                   SIM_FOLDER_DOC,         /* Item can be folder or document */
                   OIM_ALL,                /* Ignore work-in-process status  */
                   OIM_ALL,                /* Ignore work-in-process status  */
                   (USHORT)0,              /* Not used - fMemListRequest used*/
                   usNumCriteria,          /* Number of elements in Criteria */
                   (PLIBSEARCHCRITERIASTRUCT) &Criteria,/*Pointer to Criteria*/
                   SIM_SEARCH_MEMLIST,     /* Results returned in memory list*/
                   (PASYNCCTLSTRUCT) NULL, /* Request synchronous processing */
                   (PRCSTRUCT) &RCStruct );/* Pointer to RC data structure   */

    /*************************************************************************/
    /* If successful, save the pointer to the array of matching document     */
    /* and folder item ids in order to free the memory. If no matches are    */
    /* found, set the generic memory pointer to NULL, so that FreeMemory()   */
    /* will not be called in main().                                         */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
          {
          ulMemoryBlock = RCStruct.ulParam1;
          if ( ( (PITEMID) RCStruct.ulParam1 == (PITEMID) 0) )
              printf("No matches were found for the specified criteria.\n\n");

     /*******************************************/
     /* Print matching document and folder ids. */
     /*******************************************/

          else
              {
              printf("The number of matches found for the specified criteria = %lu\n",
                      (ULONG)RCStruct.ulParam2);
              pSearchResults = (PITEMID)RCStruct.ulParam1;
              printf("\nSearch Results =\n\n");
              for ( count = 0 ;
                    count < RCStruct.ulParam2;
                    count ++
                  )
                  {
                  printf("ItemID = %s\n", (PSZ)pSearchResults[count]);
                  }
              }
          }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }

    /*************************************************************************/
    /*  Return to main() with the return code from SimLibSearch.             */
    /*************************************************************************/

return( RCStruct.ulRC );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : Logoff                                                */
/*                                                                           */
/*  Description      : This function is called from main() to logoff from    */
/*                     the VisualInfo Folder Manager.                        */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibLogoff()                     */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG Logoff ( void ).                               */
/*                                                                           */
/*  Return values    :  Return code from SimLibLogoff.                       */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Terminate the session with the Folder Manager by calling         */
/*          SimLibLogoff.                                                    */
/*      2.  Return to main() with return code from SimLibLogoff.             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG Logoff ( void )
{
     RCSTRUCT RCStruct;                     /* RC data structure             */

    /*************************************************************************/
    /* Call SimLibLogoff to terminate the Folder Manager session.            */
    /*************************************************************************/

     SimLibLogoff( hSession,                /* Folder Manager session handle */
                  (PASYNCCTLSTRUCT) NULL,   /* Request synchronous processing*/
                  (PRCSTRUCT) &RCStruct );  /* Pointer to RC data structure  */

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
         RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
         RCStruct.ulRC =  RCStruct.ulExtRC;

    /*************************************************************************/
    /*  Return to main() with the return code from SimLibLogoff.             */
    /*************************************************************************/

return( RCStruct.ulRC );

}

/*****************************************************************************/
/* End of FRNOEXSE.C                                                         */
/*****************************************************************************/

