/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/* MODULE:  FRNOEXWF.C                                        VisualInfo     */
/*                                                                           */
/* 5697-250                                                                  */
/* 5621-326, 5655-036, 5622-213, 5655-071, 5655-072                          */
/*                                                                           */
/* (C) Copyright IBM Corporation 1993, 1996.                                 */
/* All Rights Reserved.                                                      */
/*                                                                           */
/* DERIVATIVE RIGHTS:                                                        */
/* ------------------                                                        */
/* This program is provided for the customer's use and the customer is       */
/* granted permission to copy this program to the extent reasonably          */
/* required for such use.  All title, ownership, and rights to this          */
/* program and any copies remain with IBM, irrespective of the ownership     */
/* of the media on which the program resides.  The customer is permitted     */
/* to create derivative works to this program.  However, all copies of       */
/* the program and its derivative works must contain the IBM copyright       */
/* notice.  The customer understands and agrees that this program in and     */
/* of itself is not to be sold or distributed.  The customer is free to      */
/* sell, distribute, and commercially exploit any derivative works           */
/* created from this program.                                                */
/*                                                                           */
/*                                                                           */
/* DISCLAIMER OF WARRANTIES:                                                 */
/* -------------------------                                                 */
/* The following [enclosed] code is sample code created by IBM               */
/* Corporation.  This sample code is not part of any standard IBM product    */
/* and is provided to you solely for the purpose of assisting you in the     */
/* development of your applications.  The code is provided "AS IS",          */
/* without warranty of any kind.  IBM shall not be liable for any damages    */
/* arising out of your use of the sample code, even if they have been        */
/* advised of the possibility of such damages.                               */
/*                                                                           */
/*                                                                           */
/* Status: Version 2 Release 1 Modification 0                                */
/*                                                                           */
/*                                                                           */
/*****************************************************************************/
/*                                                                           */
/*                                                                           */
/* Description : frnoexwf.c - Sample application code using Folder Manager   */
/*               APIs. This program:                                         */
/*                -  Reads a mortgage number from stdin                      */
/*                -  Establishes a session with the Folder Manager           */
/*                -  Gets a list of all existing index classes               */
/*                -  Gets information about the MORGTAGE index class         */
/*                -  Gets a list of all existing workflows                   */
/*                -  Gets information about the MORTGAGEWF workflow          */
/*                -  Creates a document with index class SIM_INDEX_NOINDEX   */
/*                -  Stores an existing file as part 1 of the document       */
/*                -  Adds the document to the first workbasket in MORTGAGEWF */
/*                -  Opens the attributes for the document                   */
/*                -  Indexes the document into the MORTGAGE Index Class      */
/*                -  Assigns a value to the MORTGAGENUMBER attribute         */
/*                -  Closes the attributes for the document                  */
/*                -  Gets a copy of the attributes to verify the changes     */
/*                -  Routes the document from workbasket 1 to workbasket 2   */
/*                -  Completes the workflow                                  */
/*                -  Gets the table of contents for workbasket 2             */
/*                -  Closes the table of contents for workbasket 2           */
/*                -  Logs off from the Folder Manager                        */
/*                                                                           */
/*                                                                           */
/*               The APIs used are SimLibLogon, SimLibFree,                  */
/*               SimLibListClasses, SimLibGetClassInfo, SimLibGetAttrInfo,   */
/*               Ip2ListWorkFlows, Ip2GetWorkFlowInfo, SimLibCreateItem,     */
/*               SimLibCatalogObject, Ip2StartWorkFlow,                      */
/*               SimLibOpenItemAttr, SimLibChangeIndexClass,                 */
/*               SimLibWriteAttr, SimLibCloseAttr, SimLibGetItemSnapshot,    */
/*               Ip2RouteWipItem, Ip2CompleteWorkFlow, SimLibGetTOC,         */
/*               Ip2CloseTOC, and SimLibLogoff.                              */
/*                                                                           */
/* Dependencies: To run this sample code without modification, there are     */
/*               several prerequisites.                                      */
/*               - A workflow named "MORTGAGEWF" containing 2 workbaskets    */
/*                 must have been created outside of this program.           */
/*               - An index class called "MORTGAGE" containing an            */
/*                 attribute (key field) named "MORTGAGENUMBER" (defined     */
/*                 as a fixed length character alphanumeric or extended      */
/*                 alphanumeric field with a maximum length of 6) has also   */
/*                 been created outside of this program.  The MORTGAGENUMBER */
/*                 attribute may be defined as a required field if desired.  */
/*                 If additional attributes are defined for the MORTGAGE     */
/*                 index class, they must not be defined as required key     */
/*                 fields.  If a unique database index is created for the    */
/*                 MORTGAGE index class (via the VisualInfo System           */
/*                 Administration function), and it contains the             */
/*                 MORTGAGENUMBER key field, this sample program will fail   */
/*                 if a duplicate MORTGAGENUMBER is provided as input.       */
/*               - File OS2LOGO.BMP must exist in directory C:\OS2\BITMAP.   */
/*                 C:\config.sys is used for Windows.                        */
/*                 For AIX /usr/lpp/frn/bin/FRNOLINT.TBL                     */
/*                                                                           */
/* Restrictions: None                                                        */
/*                                                                           */
/* Entry Points: main                                                        */
/*               GetInput                                                    */
/*               Logon                                                       */
/*               FreeMemory                                                  */
/*               ListIndexClasses                                            */
/*               GetClassInfo                                                */
/*               ListWorkFlows                                               */
/*               ListWorkBaskets                                             */
/*               StoreDocument                                               */
/*               StartWorkFlow                                               */
/*               ChangeDocAttributes                                         */
/*               RouteDocument                                               */
/*               Logoff                                                      */
/*                                                                           */
/* Change History:                                                           */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

/*****************************************************************************/
/*  System Header Files                                                      */
/*****************************************************************************/
#ifdef _Windows
 #include <windows.h>
#else
 #ifdef AIX
  #include <frnptype.h>
 #else
  #include <os2.h>                      /* Main OS/2 header files         */
 #endif
#endif

#include <stdio.h>                      /* Standard I/O header files         */
#include <stdlib.h>                     /* Standard Library header files     */
#include <string.h>                     /* String manipulation               */

/*****************************************************************************/
/*  VisualInfo Header Files                                                  */
/*****************************************************************************/

#define   FRN_INCL_FI                   /* Include frnpfi.h & frnpfi2.h      */
#define   FRN_INCL_FO                   /* Include frnpfo.h                  */
#include "frnp.h"                       /* Global types                      */
#include "frnpcapi.h"                   /* Structures and constants          */

/*****************************************************************************/
/*  FRNOEXWF Header File                                                     */
/*****************************************************************************/

#include "frnoexwf.h"                   /* Application header file           */

/*****************************************************************************/
/*  Global Variables                                                         */
/*****************************************************************************/

HSESSION hSession;                      /* Folder Manager session handle     */
ULONG    ulMemoryBlock;                 /* Generic pointer for SimLibFree    */
BOOL     fPrereqError=FALSE;            /* Error with program prerequisites  */
USHORT   usMortgageICID;                /* MORTGAGE index class id           */
USHORT   usNbrAttrs;                    /* Nbr of attributes for MORTGAGE    */
USHORT   usMortgageAttrID;              /* MORTGAGENUMBER attribute id       */
PSZ      pszMortgageNumber;             /* MORTGAGENUMBER attribute value    */
ITEMID   WorkFlowItemID;                /* MORTAGEWF ItemID                  */
ITEMID   WBasket2;                      /* MORTGAGEWF workbasket 2 ItemID    */
ITEMID   DocItemID;                     /* ItemID of new document            */

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : main                                                  */
/*                                                                           */
/*  Description      : main() function of a sample application that uses     */
/*                     Folder Manager APIs to create a document, change      */
/*                     the document attributes, and route the document       */
/*                     through workflow.                                     */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions:                                    */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  INT.                                                 */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  INT main ( void ).                                   */
/*                                                                           */
/*  Return values    :  If all functions are successful, the return code     */
/*                      from Logoff() is returned.  Otherwise, the return    */
/*                      code from GetInput(), Logon(), ListIndexClasses(),   */
/*                      GetClassInfo(), ListWorkFlows(), ListWorkBaskets(),  */
/*                      StoreDocument(), StartWorkFlow(),                    */
/*                      ChangeDocAttributes(), or RouteDocument() is         */
/*                      returned.                                            */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Get the value for the MORTGAGENUMBER attribute from stdin.       */
/*      2.  If successful, establish a session with the Folder Manager.      */
/*      3.  If logon was successful:                                         */
/*           - List all index classes in the system and verify that the      */
/*             MORTGAGE index class exists. If successful:                   */
/*             - Get information about the MORTGAGE index class and verify   */
/*               that an attribute named MORTGAGENUMBER has been created as  */
/*               a 6 position alphanumeric field. If successful:             */
/*               - List all workflows in the system and verify that the      */
/*                 MORTGAGEWF exists. If successful:                         */
/*                 - List all workbaskets in the MORTGAGEWF workflow and     */
/*                   verify that at least 2 workbaskets exist. If successful:*/
/*                   - Create a document ItemID and store a document part    */
/*                     from an existing file (C:\OS2\BITMAP\OS2LOGO.BMP)     */
/*                     or (C:\CONFIG.SYS using Windows).                     */
/*                     If successful:                                        */
/*                     - Start the new document in the workflow.  If         */
/*                       successful:                                         */
/*                     - Index the document into the MORTGAGE index class and*/
/*                       assign the value supplied via user input to the     */
/*                       MORTGAGENUMBER attribute of the MORTGAGE index      */
/*                       class. Verify that the changes were made.           */
/*                       If successful:                                      */
/*                       - Route the document to the second workbasket in    */
/*                         the workflow, complete the workflow, and get      */
/*                         information about the contents of the second      */
/*                         workbasket in the MORTGAGEWF workflow.            */
/*          Logoff from the Folder Manager session.                          */
/*      3.  Exit main() with a return code.                                  */
/*                                                                           */
/*  Notes            : None.                                                 */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

#ifdef _Windows
int SIMENTRY fnFrnoexwf ( void )
#else
INT main ( void )
#endif
{
     ULONG ulretcode;

    /*************************************************************************/
    /* Get input from stdin.  When a new document is indexed into the        */
    /* MORTGAGE index class, this input will be used as the value of the     */
    /* MORTGAGENUMBER attribute of the MORTGAGE index class.                 */
    /*************************************************************************/

     ulretcode = GetInput();

    /*************************************************************************/
    /*  If successful, call Logon to establish a Folder Manager Session.     */
    /*************************************************************************/

     if ((ulretcode == SIM_RC_OK) && (!fPrereqError))
         {
         ulretcode = Logon();

    /*************************************************************************/
    /* If successful, call ListIndexClasses to list all existing index       */
    /* classes.  Verify that the MORTGAGE index class has been created       */
    /* outside of this program.                                              */
    /*************************************************************************/

         if (ulretcode == SIM_RC_OK)
             {
             ulretcode = ListIndexClasses();

    /*************************************************************************/
    /* If successful, call GetClassInfo to get detailed information for the  */
    /* MORTGAGE index class.  Verify that the MORTGAGENUMBER attribute       */
    /* has been created outside of this program.                             */
    /*************************************************************************/

             if ((ulretcode == SIM_RC_OK) && (!fPrereqError))
                 {
                 ulretcode = GetClassInfoInt();

    /*************************************************************************/
    /* If successful, call ListWorkFlows to list all existing workflows.     */
    /* Verify that the MORTGAGEWF workflow has been created outside of       */
    /* this program.                                                         */
    /*************************************************************************/

                 if ((ulretcode == SIM_RC_OK) && (!fPrereqError))
                     {
                     ulretcode = ListWorkFlows();

    /**************************************************************************/
    /* If successful, call ListWorkBaskets to get the workbasket IDs of the   */
    /* workbaskets in the MORTGAGEWF workflow.  Verify that the MORTGAGEWF    */
    /* workflow contains at least two workbaskets.                            */
    /**************************************************************************/

                     if ((ulretcode == SIM_RC_OK) && (!fPrereqError))
                         {
                         ulretcode = ListWorkBaskets();

    /*************************************************************************/
    /*  If successful, call StoreDocument to create a new document ItemID    */
    /*  and store a document part using an existing file.                    */
    /*************************************************************************/

                         if ((ulretcode == SIM_RC_OK) && (!fPrereqError))
                             {
                             ulretcode = StoreDocument();

     /*************************************************************************/
     /* If successful, call StartWorkFlow to put the new document in the      */
     /* first workbasket in the workflow.                                     */
     /*************************************************************************/

                             if (ulretcode == SIM_RC_OK)
                                 {
                                 ulretcode = StartWorkFlow();

    /*************************************************************************/
    /* If successful, call ChangeDocAttributes to change the index class     */
    /* of the new document from SIM_INDEX_NOINDEX to the MORTGAGE            */
    /* index class.  Assign the value supplied via user input to the         */
    /* MORTGAGENUMBER attribute of the MORTGAGE index class. Verify that     */
    /* the MORTGAGENUMBER attribute and the index class for the document     */
    /* have been changed.                                                    */
    /*************************************************************************/

                                 if (ulretcode == SIM_RC_OK)
                                     {
                                     ulretcode = ChangeDocAttributes();

    /*************************************************************************/
    /* If successful, call RouteDocument to route the new document from      */
    /* the first workbasket to the second workbasket in the MORTGAGEWF       */
    /* workflow. If successful, complete the workflow and get information    */
    /* about the contents of the second workbasket.                          */
    /*************************************************************************/

                                     if (ulretcode == SIM_RC_OK)
                                         ulretcode = RouteDocument();
                                     }
                                 }
                             }
                         }
                     }
                 }

    /*************************************************************************/
    /* Call Logoff to terminate the Folder Manager session.                  */
    /*************************************************************************/

             if (ulretcode == SIM_RC_OK)
                 ulretcode = Logoff();
             else
                 Logoff();
             }
         }

    /*************************************************************************/
    /* Print return code.                                                    */
    /*************************************************************************/

    if (ulretcode == SIM_RC_OK)
        printf ("\nVisualInfo Sample Program FRNOEXWF has completed.\n");
    else
        printf ("\nRETURN CODE = %lu\n", ulretcode);

    /*************************************************************************/
    /* Exit main() with the return code.                                     */
    /*************************************************************************/

    return ( ulretcode );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : GetInput                                              */
/*                                                                           */
/*  Description      : This function is called from main() to get input from */
/*                     stdin.  When a new document is indexed into the       */
/*                     MORTGAGE index class, this input will be used as the  */
/*                     value of the MORTGAGENUMBER attribute of the MORTGAGE */
/*                     index class.                                          */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: None                               */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG GetInput ( void ).                             */
/*                                                                           */
/*  Return values    :  SIM_RC_OUT_OF_MEMORY or return code 0.               */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Reserve storage for and initialize variable pszMortgageNumber.   */
/*      2.  If sufficient storage is available, get the value of             */
/*          pszMortgageNumber from stdin. If a mortgage number is not        */
/*          entered, or if a mortgage number with more than 6 characters     */
/*          is entered, set an error flag.                                   */
/*      3.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG GetInput ( void )
{
     ULONG  ulRC=0;                     /* Return code                       */
     CHAR   pszInput[257];              /* User input for MORTGAGENUMBER     */
     CHAR   *pszResult=NULL;            /* Result of gets function           */

    /*************************************************************************/
    /* Reserve and initialize storage for pszMortgageNumber.                 */
    /* Print error message if sufficient storage is not available.           */
    /*************************************************************************/

     pszMortgageNumber = (PSZ) malloc (7);
     if (pszMortgageNumber == NULL)
         {
         printf("Memory allocation error for pszMortgageNumber.\n");
         ulRC = SIM_RC_OUT_OF_MEMORY;
         }
     else
         {
         memset (pszMortgageNumber, '\0', 7);

    /*************************************************************************/
    /*  Get a mortgage number from stdin.  This mortgage number will be      */
    /*  used as the value of the MORTGAGENUMBER attribute of the MORTGAGE    */
    /*  index class for the document that will be stored later.              */
    /*************************************************************************/

#ifdef _Windows
         pszResult = fnPrompt(pszInput, 6+1, "Mortgage Number",
            "Enter a 6 position alphanumeric Mortgage Number");
#else
         printf("Enter a 6 position alphanumeric Mortgage Number :\n");
         pszResult = gets(pszInput);
#endif
         if ( *pszResult == (CHAR)NULL )
             {
             printf("\nError - Mortgage Number was not entered. \n");
             fPrereqError = TRUE;
             }
         else
             {
             if ( (strlen(pszInput)) > 6)
                 {
                 printf("\nThe Mortgage Number entered is greater than 6 characters.\n");
                 fPrereqError = TRUE;
                 }
             else
                 strcpy(pszMortgageNumber, pszInput);
             }
         }

    /*************************************************************************/
    /*  Return to main() with a return code.                                 */
    /*************************************************************************/

return(ulRC);
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : Logon                                                 */
/*                                                                           */
/*  Description      : This function is called from main() to logon to       */
/*                     VisualInfo Folder Manager.                            */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibLogon                        */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG Logon ( void ).                                */
/*                                                                           */
/*  Return values    :  SIM_RC_OUT_OF_MEMORY or the return code from         */
/*                      SimLibLogon.                                         */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Reserve storage for and initialize SimLibLogon parameters.       */
/*      2.  If sufficient storage is available, establish a session          */
/*          session with the Folder Manager by calling SimLibLogon.          */
/*      3.  If SimLibLogon is successful, call FreeMemory() to free the      */
/*          memory for the USERLOGONINFOSTRUCT data structure.               */
/*      4.  Return to main() with a return code.                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG Logon ( void )
{
     PSZ      pszDBName;                /* Pointer to Database name          */
     PSZ      pszUserId;                /* Pointer to User Id                */
     PSZ      pszPassword;              /* Pointer to Password for User Id   */
     RCSTRUCT RCStruct;                 /* RC data structure                 */

    /*************************************************************************/
    /* Reserve and initialize storage for SimLibLogon parameters.            */
    /* Print error message if sufficient storage is not available.           */
    /*************************************************************************/

     RCStruct.ulRC = SIM_RC_OK;
     pszDBName = (PSZ) malloc ( SIM_SERVER_NAME_LENGTH + 1);
     if (pszDBName == NULL)
        {
        printf("\nMemory allocation error for pszDBName.\n");
        RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
        }
     else
        {
        memset (pszDBName, '\0', SIM_SERVER_NAME_LENGTH + 1);
        pszUserId = (PSZ) malloc ( OIM_MAXIMUM_USERID_LENGTH + 1);
        if (pszUserId == NULL)
            {
            printf("\nMemory allocation error for pszUserId.\n");
            RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
            }
        else
            {
            memset (pszUserId, '\0', OIM_MAXIMUM_USERID_LENGTH + 1);
            pszPassword = (PSZ) malloc ( OIM_MAX_PASSWORD_LENGTH + 1);
            if (pszPassword == NULL)
                {
                printf("\nMemory allocation error for pszPassword.\n");
                RCStruct.ulRC = SIM_RC_OUT_OF_MEMORY;
                }
            else
                {
                memset (pszPassword, '\0', OIM_MAX_PASSWORD_LENGTH + 1);

    /*************************************************************************/
    /* Initialize SimLibLogon parameters.                                    */
    /*************************************************************************/

                strcpy (pszDBName,          PSZDBNAME);
                strcpy (pszUserId,          PSZUSERID);
                strcpy (pszPassword,        PSZPASSWORD);
                }
            }
        }
    if (RCStruct.ulRC == SIM_RC_OK)
    {
    /*************************************************************************/
    /* Call SimLibLogon to establish a Folder Manager session.               */
    /*************************************************************************/

     SimLibLogon( pszDBName,               /* Pointer to Database name       */
                  (PSZ) "",                /* Reserved for future use        */
                  pszUserId,               /* Pointer to User Id             */
                  pszPassword,             /* Pointer to Password for User Id*/
                  (PSZ) NULL,              /* Logon without new password     */
                  (PSZ) NULL,              /* Reserved for future use        */
                  (PSZ) NULL,              /* Reserved for future use        */
                  SIM_SS_NORMAL,           /* Non-configuration session logon*/
                  (PASYNCCTLSTRUCT) NULL,  /* Request synchronous processing */
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

     if ((RCStruct.ulRC == SIM_RC_OK) ||
         (RCStruct.ulRC == SIM_RC_GRACE_PERIOD_UNDER_LIMIT))

    /*************************************************************************/
    /* If successful, save the Folder Manager session handle for subsequent  */
    /* Folder Manager API calls.                                             */
    /*************************************************************************/

         {
         RCStruct.ulRC = SIM_RC_OK;
         hSession = RCStruct.ulParam1;

    /*************************************************************************/
    /* Save the pointer to the USERLOGONINFOSTRUCT data structure in order   */
    /* to free the memory.                                                   */
    /*************************************************************************/

         ulMemoryBlock = RCStruct.ulParam2;
         }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }
    }

    /*************************************************************************/
    /* If successful, call FreeMemory to free the memory for the             */
    /* USERLOGONINFOSTRUCT structure returned from SimLibLogon.              */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
           FreeMemory();

    /*************************************************************************/
    /*  Free storage reserved with malloc and return to main() with a return */
    /*  code.                                                                */
    /*************************************************************************/

    free (pszDBName);
    free (pszUserId);
    free (pszPassword);

return( RCStruct.ulRC );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function        : FreeMemory                                             */
/*                                                                           */
/*  Description     : This function is called from main() to free memory     */
/*                    allocated as the result of a Folder Manager            */
/*                    SimLibLogon, SimLibListClasses, SimLibGetAttrInfo,     */
/*                    SimLibGetClassInfo, Ip2ListWorkFlows,                  */
/*                    Ip2GetWorkFlowInfo, SimLibCreateItem,                  */
/*                    SimLibCatalogObject, or SimLibGetItemSnapshot.         */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibFree                         */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  VOID.                                                */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  VOID FreeMemory ( void ).                            */
/*                                                                           */
/*  Return values    :  None.                                                */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call SimLibFree to free memory allocated by the Folder Manager as*/
/*          a result of SimLibLogon, SimLibListClasses, SimLibGetAttrInfo,   */
/*          SimLibGetClassInfo, Ip2ListWorkFlows, Ip2GetWorkFlowInfo,        */
/*          SimLibCreateItem, SimLibCatalogObject, or SimLibGetItemSnapshot. */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

VOID FreeMemory (void)
{
     RCSTRUCT RCStruct;                    /* RC data structure              */

     SimLibFree  ( hSession,               /* Folder Manager session handle  */
                  (PVOID) ulMemoryBlock,   /* Pointer to memory block to free*/
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

return;
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : ListIndexClasses                                      */
/*                                                                           */
/*  Description      : This function is called from main() to list all       */
/*                     existing index classes in order to verify that the    */
/*                     MORTGAGE index class has been created.                */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibListClasses                  */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG ListIndexClasses ( void ).                     */
/*                                                                           */
/*  Return values    :  Return code from SimLibListClasses.                  */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call the SimLibListClasses Folder Manager API.                   */
/*      2.  Verify the existence of the MORTGAGE index class.                */
/*      3.  Call FreeMemory() to free the memory for the array of NAMESTRUCT */
/*          data structures returned from SimLibListClasses.                 */
/*      4.  Return to main() with the return code from SimLibListClasses.    */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG ListIndexClasses ( void )
{
     RCSTRUCT       RCStruct;              /* RC data structure              */
     ULONG          ulNbrClasses;          /* Number of defined index classes*/
     PNAMESTRUCT    pNameStruct;           /* Pointer to NAMESTRUCT array    */
     USHORT         i;                     /* Loop counter                   */

    /**********************************************************************/
    /* Call SimLibListClasses to list all existing index classes.         */
    /**********************************************************************/

     SimLibListClasses( hSession,           /* Folder Manager session handle */
                    (BITS) NULL,            /* Reserved for future use       */
                    (PASYNCCTLSTRUCT) NULL, /* Request synchronous processing*/
                    (PRCSTRUCT) &RCStruct );/* Pointer to RC data structure  */

    /*************************************************************************/
    /* Save and print the number of existing index classes.                  */
    /* Save the pointer to the array of NAMESTRUCT data structures which     */
    /* contain information for each index class.  This pointer will be used  */
    /* to free the memory for the structures.                                */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
           {
           ulNbrClasses = RCStruct.ulParam2;
           pNameStruct = (PNAMESTRUCT)RCStruct.ulParam1;
           ulMemoryBlock = RCStruct.ulParam1;
           }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }

    /**********************************************************************/
    /*  Verify that the MORTGAGE Index Class was defined outside of       */
    /*  this program.  Convert the index class name to uppercase for      */
    /*  the purpose of comparison. If the MORTGAGE Index Class exists,    */
    /*  save the index class id.                                          */
    /**********************************************************************/

     if ((RCStruct.ulRC == SIM_RC_OK) && (ulNbrClasses > 0))
         {
         for (i=0;
    #ifdef WIDE_CHAR
             ((i<ulNbrClasses) &&
             (strcmp (wc_strupr(pNameStruct[i].szName), "MORTGAGE") != 0) );
    #else
             ((i<ulNbrClasses) &&
             (strcmp (strupr(pNameStruct[i].szName), "MORTGAGE") != 0) );
    #endif
             i++ )
             {
             ;
             }

         if (i >= ulNbrClasses)
             {
             printf ("\nThe MORTGAGE Index Class is not defined in the system.\n");
             fPrereqError = TRUE;
             }
         else
             {
             printf ("\nThe MORTGAGE Index Class is defined in the system.\n");
             usMortgageICID = pNameStruct[i].usID;
             }
         }

    /*************************************************************************/
    /* Call FreeMemory to free the memory containing the array of            */
    /* NAMESTRUCT structures returned from SimLibListClasses.                */
    /*************************************************************************/

     if ((RCStruct.ulRC == SIM_RC_OK) && (ulNbrClasses > 0))
         FreeMemory();

    /*************************************************************************/
    /*  Return to main() with a return code from SimLibListClasses.          */
    /*************************************************************************/

     return( RCStruct.ulRC );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : GetClassInfo                                          */
/*                                                                           */
/*  Description      : This function is called from main() to get detailed   */
/*                     information about the MORTGAGE index class in order   */
/*                     to verify that the MORTGAGENUMBER attribute has been  */
/*                     created.                                              */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibGetClassInfo                 */
/*                                        SimLibGetAttrInfo                  */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG GetClassInfo ( void ).                         */
/*                                                                           */
/*  Return values    :  Return code from SimLibGetClassInfo or               */
/*                                       SimLibGetAttrInfo.                  */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call the SimLibGetClassInfo Folder Manager API.                  */
/*      2.  Call SimLibGetAttrInfo Folder Manager API for each attribute of  */
/*          the MORTGAGE index class.                                        */
/*      3.  Verify the existence of a MORTGAGENUMBER attribute for the       */
/*          MORTGAGE index class.                                            */
/*      4.  Call FreeMemory() to free the memory for each ATTRINFOSTRUCT     */
/*          data structure returned from the SimLibGetAttrInfo call.         */
/*      5.  Call FreeMemory() to free the memory for the CLASSINFOSTRUCT     */
/*          data structure returned from the SimLibGetClassInfo call.        */
/*      6.  Return to main() with the return code from SimLibGetClassInfo    */
/*          or SimLibGetAttrInfo.                                            */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG GetClassInfoInt ( void )
{
     RCSTRUCT         RCStruct;           /* RC data structure               */
     PCLASSINFOSTRUCT pClassInfo;         /* Pointer to CLASSINFOSTRUCT      */
     ULONG            ulClassInfo;        /* Pointer for SimLibFree          */
     PCLASSATTRSTRUCT pClassAttrStruct;   /* Pointer to CLASSATTRSTRUCT array*/
     PATTRINFOSTRUCT  pAttrInfoStruct;    /* Pointer to ATTRINFOSTRUCT       */
     BOOL             fFound=FALSE;       /* MORTGAGENUMBER found flag       */
     USHORT           i;                  /* Loop counter                    */

    /**********************************************************************/
    /* Call SimLibGetClassInfo to get detailed information for the        */
    /* MORTGAGE index class.                                              */
    /**********************************************************************/

     SimLibGetClassInfo ( hSession,         /* Folder Manager session handle  */
                  SIM_INDEXCLASSID,         /* Get info for an index class    */
                  usMortgageICID,           /* MORTGAGE Index class ID        */
                  (PASYNCCTLSTRUCT) NULL,   /* Request synchronous processing */
                  (PRCSTRUCT) &RCStruct);   /* Pointer to RC data structure   */

    /*************************************************************************/
    /* Save the pointer to the CLASSINFOSTRUCT data structure in order to    */
    /* free the memory.                                                      */
    /* Save the number of attributes for the MORTGAGE index class.           */
    /* Save the pointer to the array of CLASSATTRSTRUCT data structures for  */
    /* use in the SimLibGetAttrInfo call.                                    */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
         {
         pClassInfo  = (PCLASSINFOSTRUCT)RCStruct.ulParam1;
         ulClassInfo = RCStruct.ulParam1;
         usNbrAttrs = pClassInfo->usNbrAttrIds;
         pClassAttrStruct = pClassInfo->pClassAttrStruct;
         }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }

    /**********************************************************************/
    /* Call SimLibGetAttrInfo to get detailed information for each        */
    /* attribute of the MORTGAGE index class.                             */
    /**********************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
        {
        for (i=0;
             ( (i<usNbrAttrs) && (!fFound) && (RCStruct.ulRC == SIM_RC_OK) );
             i++
            )
        {
        SimLibGetAttrInfo ( hSession,       /* Folder Manager session handle  */
             pClassAttrStruct[i].usAttrId,  /* Attribute ID                   */
             (PASYNCCTLSTRUCT) NULL,        /* Request synchronous processing */
             (PRCSTRUCT) &RCStruct);        /* Pointer to RC data structure   */

    /**********************************************************************/
    /*  Save the pointer to the ATTRINFOSTRUCT data structure in order    */
    /*  to free the memory.                                               */
    /*  Verify that the MORTGAGENUMBER attribute was defined outside of   */
    /*  this program.  Convert the attribute name to uppercase for        */
    /*  the purpose of comparison. If the MORTGAGENUMBER attribute exists,*/
    /*  save the associated attribute id.                                 */
    /**********************************************************************/

        if (RCStruct.ulRC == SIM_RC_OK)
            {
            pAttrInfoStruct = (PATTRINFOSTRUCT)RCStruct.ulParam1;
            ulMemoryBlock   = RCStruct.ulParam1;

        #ifdef WIDE_CHAR
            if ((strcmp (wc_strupr(pAttrInfoStruct->szAttributeName),
                 "MORTGAGENUMBER") == 0)                            &&
        #else
            if ((strcmp (strupr(pAttrInfoStruct->szAttributeName),
                 "MORTGAGENUMBER") == 0)                            &&
        #endif
                (pAttrInfoStruct->usAttrType == SIM_ATTR_FSTRING)   &&
                (pAttrInfoStruct->lMax == 6)                        &&
                ((pAttrInfoStruct->fTypeFlags == SIM_ATTR_ALPHANUM) ||
                (pAttrInfoStruct->fTypeFlags == SIM_ATTR_ALPHANUM_EXT)))
                {
                usMortgageAttrID = pClassAttrStruct[i].usAttrId;
                fFound = TRUE;
                }

     /*************************************************************************/
     /*  Call FreeMemory to free memory containing the ATTRINFOSTRUCT         */
     /*  structure returned from SimLibGetAttrInfo.                           */
     /*************************************************************************/

            FreeMemory();
            }
        else

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

            {
            if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
                RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
                RCStruct.ulRC =  RCStruct.ulExtRC;
            }
        }

        if (!fFound)
            {
            printf ("\nThe MORTGAGENUMBER Attribute is not defined for the \
MORTGAGE index class, or is not defined as a fixed length character \
alphanumeric or extended alphanumeric   attribute with a maximum length of 6.\n");

            fPrereqError = TRUE;
            }

     /*************************************************************************/
     /*  Call FreeMemory to free memory containing the CLASSINFOSTRUCT        */
     /*  structure returned from SimLibGetClassInfo.                          */
     /*************************************************************************/

        ulMemoryBlock = ulClassInfo;
        FreeMemory();
        }

    /*************************************************************************/
    /*  Return to main() with a return code from SimLibGetClassInfo or       */
    /*  SimLibGetAttrInfo.                                                   */
    /*************************************************************************/

     return( RCStruct.ulRC );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : ListWorkFlows                                         */
/*                                                                           */
/*  Description      : This function is called from main() to list all       */
/*                     existing workflows in order to verify that the        */
/*                     MORTGAGEWF workflow has been created.                 */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: Ip2ListWorkFlows                   */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG ListWorkFlows ( void ).                        */
/*                                                                           */
/*  Return values    :  Return code from Ip2ListWorkFlows.                   */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call the Ip2ListWorkFlows Folder Manager API.                    */
/*      2.  Verify the existence of a MORTGAGEWF workflow.                   */
/*      3.  Call FreeMemory() to free the memory for the array of            */
/*          ITEMNAMESTRUCT data structures returned from the                 */
/*          Ip2ListWorkFlows call.                                           */
/*      4.  Return to main() with the return code from Ip2ListWorkFlows.     */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG ListWorkFlows ( void )
{
     RCSTRUCT        RCStruct;             /* RC data structure              */
     ULONG           ulNbrWFs;             /* Number of defined workflows    */
     PITEMNAMESTRUCT pItemNameStruct;      /* Pointer to ITEMNAMESTRUCT array*/
     USHORT          i;                    /* Loop counter                   */

    /**************************************************************************/
    /* Call Ip2ListWorkFlows to get the WorkFlow ItemID for the "MORTGAGEWF"  */
    /* workflow.                                                              */
    /**************************************************************************/

     Ip2ListWorkFlows( hSession,            /* Folder Manager session handle  */
                  (PASYNCCTLSTRUCT) NULL,   /* Request synchronous processing */
                  (PRCSTRUCT) &RCStruct);   /* Pointer to RC data structure   */

    /*************************************************************************/
    /* Save and print the number of existing workflows.                      */
    /* Save the pointer to the array of ITEMNAMESTRUCT data structures in    */
    /* order to free the memory.                                             */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
           {
           ulNbrWFs = RCStruct.ulParam2;
           printf ("\nThere are %lu Workflows defined in the system.\n",
                   ulNbrWFs);
           pItemNameStruct = (PITEMNAMESTRUCT)RCStruct.ulParam1;
           ulMemoryBlock = RCStruct.ulParam1;
           }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
           {
           if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
               RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
               RCStruct.ulRC =  RCStruct.ulExtRC;
           }

    /**********************************************************************/
    /*  Verify that the MORTGAGEWF workflow was defined outside of        */
    /*  this program.  Convert the workflow name to uppercase for         */
    /*  the purpose of comparison. If the MORTGAGEWF workflow exists,     */
    /*  save the ItemId for the workflow.                                 */
    /**********************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
         {
         for (i=0;
             ((i<ulNbrWFs) &&
     #ifdef WIDE_CHAR
             (strcmp (wc_strupr(pItemNameStruct[i].szIDName), "MORTGAGEWF") != 0));
     #else
             (strcmp (strupr(pItemNameStruct[i].szIDName), "MORTGAGEWF") != 0));
     #endif
             i++)
             {
             ;
             }

         if (i >= ulNbrWFs)
             {
             printf ("\nThe MORTGAGEWF WorkFlow is not defined in the system.\n");
             fPrereqError = TRUE;
             }
         else
             {
             printf ("\nThe MORTGAGEWF WorkFlow is defined in the system.\n");
             strncpy ((PSZ)WorkFlowItemID, (PSZ)pItemNameStruct[i].WItemID,
                       DOC_ID_SIZE);
             }
         }

    /*************************************************************************/
    /* Call FreeMemory to free the memory containing the array of            */
    /* ITEMNAMESTRUCT structures returned from Ip2ListWorkFlows.             */
    /*************************************************************************/

     if ((RCStruct.ulRC == SIM_RC_OK) && (ulNbrWFs > 0))
         FreeMemory();

    /*************************************************************************/
    /*  Return to main() with a return code from Ip2ListWorkFlows.           */
    /*************************************************************************/

     return( RCStruct.ulRC );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : ListWorkBaskets                                       */
/*                                                                           */
/*  Description      : This function is called from main() to list all       */
/*                     workbaskets in the MORTGAGEWF workflow.               */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: Ip2GetWorkFlowInfo                 */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG ListWorkBaskets ( void ).                      */
/*                                                                           */
/*  Return values    :  Return code from Ip2GetWorkFlowInfo.                 */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call the Ip2GetWorkFlowInfo Folder Manager API.                  */
/*      2.  Verify that two workbaskets have been defined for the            */
/*          MORTGAGEWF workflow.                                             */
/*      3.  Call FreeMemory() to free the memory for the array of            */
/*          workbaskets returned from the Ip2GetWorkFlowInfo call.           */
/*      4.  Call FreeMemory() to free the memory for the WFINFOSTRUCT        */
/*          data structure returned from the Ip2GetWorkFlowInfo call.        */
/*      5.  Return to main() with the return code from Ip2GetWorkFlowInfo.   */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG ListWorkBaskets ( void )
{
     RCSTRUCT        RCStruct;             /* RC data structure              */
     USHORT          usNbrWBs;             /* Nbr workbaskets in MORTGAGEWF  */
     PWFINFOSTRUCT   pWFInfoStruct;        /* Pointer to WFINFOSTRUCT        */
     ULONG           ulWFInfoStruct;       /* Pointer for SimLibFree         */
     PITEMID         pulWbIds;             /* Pointer for SimLibFree         */
     ITEMID          WBasket1;             /* 1st workbasket in MORTGAGEWF   */

   /**************************************************************************/
   /* Call Ip2GetWorkFlowInfo to get the workbasket IDs of the workbaskets   */
   /* in the MORTGAGEWF workflow.                                            */
   /**************************************************************************/

    Ip2GetWorkFlowInfo( hSession,          /* Folder Manager session handle  */
                   &WorkFlowItemID,        /* Pointer to MORTGAGEWF ItemID   */
                   FALSE,                  /* Do not count items in workflow */
                   (PASYNCCTLSTRUCT) NULL, /* Request synchronous processing */
                   (PRCSTRUCT) &RCStruct); /* Pointer to RC data structure   */

    /**********************************************************************/
    /*  Save the pointer to the WFINFOSTRUCT data structure containing the*/
    /*  workflow definition information in order to free the memory.      */
    /*  Save the number of workbaskets in the MORTGAGEWF workflow.        */
    /*  Save the pointer to the array of workbasket IDs contained in the  */
    /*  workflow in order to free the memory.                             */
    /*  Verify that at least 2 workbaskets are defined for MORTGAGEWF.    */
    /**********************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
         {
         pWFInfoStruct  = (PWFINFOSTRUCT)RCStruct.ulParam1;
         ulWFInfoStruct = RCStruct.ulParam1;
         usNbrWBs = pWFInfoStruct->usNbrWbIds;
         pulWbIds = pWFInfoStruct->pWbIds;
         if (usNbrWBs < 2)
             {
             printf ("\nThere must be at least 2 WorkBaskets defined \
for the MORTGAGEWF WorkFlow.\n");
             fPrereqError = TRUE;
             }
         else
             {
           /***************************************************************/
           /* Save the ItemIds for the first two workbaskets in the       */
           /* workflow.                                                   */
           /***************************************************************/
           strncpy((PSZ)WBasket1, (PSZ)pWFInfoStruct->pWbIds[0], DOC_ID_SIZE);
           strncpy((PSZ)WBasket2, (PSZ)pWFInfoStruct->pWbIds[1], DOC_ID_SIZE);
             }
         }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }

    /*************************************************************************/
    /* If successful, call FreeMemory to free the memory containing the      */
    /* array of workbasket IDs returned from Ip2GetWorkFlowInfo. Call        */
    /* FreeMemory to free the WFINFOSTRUCT data structure returned from      */
    /* Ip2GetWorkFlowInfo.                                                   */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
         {
         if (usNbrWBs > 0)
             {
             ulMemoryBlock = (ULONG)pulWbIds;
             FreeMemory();
             }
         ulMemoryBlock = ulWFInfoStruct;
         FreeMemory();
         }

    /*************************************************************************/
    /*  Return to main() with a return code from Ip2GetWorkFlowInfo.         */
    /*************************************************************************/

     return( RCStruct.ulRC );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : StoreDocument                                         */
/*                                                                           */
/*  Description      : This function is called from main() to create a       */
/*                     document ItemID and store a new document part         */
/*                     using an existing file.                               */
/*                     To run this sample code without modification,         */
/*                     the object must have a content class of OS/2          */
/*                     Version 2 bitmap, and file OS2LOGO.BMP must exist     */
/*                     in directory C:\OS2\BITMAP.                           */
/*                     (C:\CONFIG.SYS is used for Windows)                   */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibCreateItem                   */
/*                                        SimLibCatalogObject                */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG StoreDocument ( void ).                        */
/*                                                                           */
/*  Return values    :  Return code from SimLibCreateItem or                 */
/*                      SimLibCatalogObject.                                 */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Initialize SimLibCatalogObject parameters.                       */
/*      2.  Call the SimLibCreateItem Folder Manager API.                    */
/*      3.  Call FreeMemory() to free the memory containing the new          */
/*          document ItemID returned from the SimLibCreateItem call.         */
/*      4.  Call the SimLibCatalogObject Folder Manager API.                 */
/*      5.  Call FreeMemory() to free the memory containing the object       */
/*          handle block returned from the SimLibCatalogObject call.         */
/*      6.  Return to main() with the return code from SimLibCreateItem or   */
/*          SimLibCatalogObject.                                             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG StoreDocument ( void )
{
     RCSTRUCT RCStruct;                    /* RC data structure              */
     OBJ      Obj;                         /* Object data structure          */

    /*************************************************************************/
    /* Initialize SimLibCatalogObject Parameters.                            */
    /*************************************************************************/

     /********************************/
     /* Object structure.            */
     /********************************/

     memset (&Obj, '\0', sizeof(OBJ));
     Obj.ulStruct  = sizeof(Obj);
     Obj.ulPart    = 0;

    /*************************************************************************/
    /* Call SimLibCreateItem to create a document ItemID.                    */
    /*************************************************************************/

     SimLibCreateItem( hSession,           /* Folder Manager session handle  */
          SIM_DOCUMENT,                    /* Create a document              */
          SIM_INDEX_NOINDEX,               /* Index class of document        */
          0,                               /* Number of AttributeLists       */
          (PATTRLISTSTRUCT) NULL,          /* Pointer to AttributeList       */
          (ULONG)NULL,                     /* Reserved for future use        */
          (PASYNCCTLSTRUCT) NULL,          /* Request synchronous processing */
          (PRCSTRUCT) &RCStruct );         /* Pointer to RC data structure   */

    /*************************************************************************/
    /*  Save and print the new document ItemID.                              */
    /*  Call FreeMemory to free memory containing the document ItemID        */
    /*  returned from SimLibCreateItem.                                      */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
         {
         strncpy ((PSZ)DocItemID, (PSZ)RCStruct.ulParam1, DOC_ID_SIZE);
         printf("\nNew Document ItemID       = %s\n", (PSZ)DocItemID);
         ulMemoryBlock     = RCStruct.ulParam1;
         FreeMemory();
         /*********************************************************/
         /* Create object as part of previously created document. */
         /*********************************************************/
         strcpy (Obj.szItemID, DocItemID);
         }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }

     if (RCStruct.ulRC == SIM_RC_OK)
         {
    /*************************************************************************/
    /* Call SimLibCatalogObject to create a new object using an existing file*/
    /*************************************************************************/

     SimLibCatalogObject( hSession,      /* Folder Manager session handle    */
          (HOBJ) &Obj,                   /* Pointer to object handle block   */
#if defined (_Windows) && defined (AIX)
          SIM_CC_TEXT,                   /* Text content class               */
#else
          SIM_CC_OS2V2_BMP,
#endif
          (PSMS) NULL,                   /* Pointer to SMS object structure  */
#ifdef _Windows
          "C:\\config.sys",              /* Name of existing file (windows)  */
#else
 #ifdef AIX
          "//usr//lpp//frn//bin//FRNOLINT.TBL", /* Name of existing file(AIX) */
 #else
          "C:\\OS2\\BITMAP\\OS2LOGO.BMP", /* Name of existing file            */
 #endif
#endif

          SIM_PRI_NORMAL,                /* Medium servicing priority        */
          SIM_CLOSE,                     /* Close object upon completion     */
          (ULONG)NULL,                   /* Reserved for future use          */
          (LONG)NULL,                    /* Reserved for future use          */
          SIM_BASE,                      /* Define object type as base       */
          (PVOID)NULL,                   /* No affiliated data               */
          (PASYNCCTLSTRUCT) NULL,        /* Request synchronous processing   */
          (PRCSTRUCT) &RCStruct );       /* Pointer to RC data structure     */
         }

    /*************************************************************************/
    /* Save the pointer to the object handle in order to free the memory.    */
    /* If subsequent references to the object are required, ulParam1 must    */
    /* be saved.                                                             */
    /* Call FreeMemory to free memory containing the object handle block.    */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
         {
         ulMemoryBlock = RCStruct.ulParam1;
         Obj  = *(HOBJ)RCStruct.ulParam1;
         printf("\nFile stored as Part = %lu\n", Obj.ulPart);
         FreeMemory();
         }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }


    /*************************************************************************/
    /*  Return to main() with the return code from SimLibCreateItem or       */
    /*  SimLibCatalogObject.                                                 */
    /*************************************************************************/

     return( RCStruct.ulRC );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : StartWorkFlow                                         */
/*                                                                           */
/*  Description      : This function is called from main() to add the new    */
/*                     document to the first workbasket in the MORTGAGEWF    */
/*                     workflow.                                             */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: Ip2StartWorkFlow                   */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG StartWorkFlow (void ).                         */
/*                                                                           */
/*  Return values    :  Return code from Ip2StartWorkFlow.                   */
/*                                                                           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call the Ip2StartWorkFlow Folder Manager API.                    */
/*      2.  Return to main() with the return code from Ip2StartWorkFlow.     */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG StartWorkFlow ( void )
{
     RCSTRUCT RCStruct;                    /* RC data structure              */

     /************************************************************************/
     /* Call Ip2StartWorkFlow to put the document in the first workbasket    */
     /* in the workflow.                                                     */
     /************************************************************************/

     Ip2StartWorkFlow( hSession,        /* Folder Manager session handle     */
             (PITEMID)&DocItemID,       /* Pointer to document ItemID        */
             (PITEMID)&WorkFlowItemID,  /* Pointer to MORTGAGEWF ItemID      */
             NULL,                      /* Put Item in first WorkBasket      */
             TRUE,                      /* Add regardless of overload trigger*/
             OIM_WIP_DEFAULT_PRIORITY,  /* Use default index class priority  */
             (PASYNCCTLSTRUCT) NULL,    /* Request synchronous processing    */
             (PRCSTRUCT) &RCStruct );   /* Pointer to RC data structure      */

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
         RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
         RCStruct.ulRC =  RCStruct.ulExtRC;

    /*************************************************************************/
    /*  Return to main() with the return code from Ip2StartWorkFlow.         */
    /*************************************************************************/

     return( RCStruct.ulRC );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : ChangeDocAttributes                                   */
/*                                                                           */
/*  Description      : This function is called from main() to:               */
/*                     - Open the attributes for the new document.           */
/*                     - Change the document index class from                */
/*                       SIM_INDEX_NOINDEX to MORTGAGE.                      */
/*                     - Assign a value to the MORTGAGENUMBER attribute.     */
/*                     - Close the document attributes.                      */
/*                     - Verify that the attributes have been changed.       */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibOpenItemAttr                 */
/*                                        SimLibChangeIndexClass             */
/*                                        SimLibWriteAttr                    */
/*                                        SimLibCloseAttr                    */
/*                                        SimLibGetItemSnapshot              */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG ChangeDocAttributes (void ).                   */
/*                                                                           */
/*  Return values    :  Return code from SimLibOpenItemAttr,                 */
/*                      SimLibChangeIndexClass, SimLibWriteAttr,             */
/*                      SimLibCloseAttr, or SimLibGetItemSnapshot.           */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call the SimLibOpenItemAttr Folder Manager API.                  */
/*      2.  Call the SimLibChangeIndexClass Folder Manager API.              */
/*      3.  Call the SimLibWriteAttr Folder Manager API.                     */
/*      4.  Call the SimLibCloseAttr Folder Manager API.                     */
/*      5.  Call the SimLibGetItemSnapshot Folder Manager API.               */
/*      6.  Free the memory containing the SNAPSHOTSTRUCT structure returned */
/*          from the SimLibGetItemSnapshot call.                             */
/*      7.  Return to main() with the return code from SimLibOpenItemAttr,   */
/*          SimLibChangeIndexClass, SimLibWriteAttr, SimLibCloseAttr, or     */
/*          SimLibGetItemSnapshot.                                           */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG ChangeDocAttributes ( void )
{
    RCSTRUCT         RCStruct;            /* RC data structure               */
    HITEM            hitemItemID;         /* Handle to the open ItemID       */
    PSNAPSHOTSTRUCT  pSnap;               /* Pointer to SNAPSHOTSTRUCT       */
    PICVIEWSTRUCT    pICView;             /* Pointer to ICVIEWSTRUCT         */
    PATTRLISTSTRUCT  pAttr;               /* Pointer to ATTRLISTSTRUCT array */
    USHORT           i;                   /* Loop counter                    */

    /*************************************************************************/
    /* Call SimLibOpenItemAttr to open the attributes of the new document    */
    /* in order to change the index class and assign a value to the          */
    /* MORTGAGENUMBER attribute.                                             */
    /*************************************************************************/

    SimLibOpenItemAttr( hSession,          /* Folder Manager session handle  */
                    (PITEMID)&DocItemID,   /* Pointer to document ItemID     */
                    SIM_INDEX_NOINDEX,     /* Index class of document        */
                    SIM_ACCESS_READ_WRITE, /* Open for read/write access     */
                    (PASYNCCTLSTRUCT) NULL,/* Request synchronous processing */
                    (PRCSTRUCT)&RCStruct); /* Pointer to RC data structure   */

    /*************************************************************************/
    /* Save the item handle for use in subsequent API calls.                 */
    /*************************************************************************/

    if (RCStruct.ulRC == SIM_RC_OK)
        hitemItemID = (HITEM)RCStruct.ulParam1;

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

    else
        {
        if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
            RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
            RCStruct.ulRC =  RCStruct.ulExtRC;
        }

    if (RCStruct.ulRC == SIM_RC_OK)
    {

    /*************************************************************************/
    /* Call SimLibChangeIndexClass to change the index class of the document */
    /* to the MORTGAGE index class.                                          */
    /*************************************************************************/

    SimLibChangeIndexClass( hSession,      /* Folder Manager session handle  */
                    (HITEM)hitemItemID,    /* Item handle                    */
                    (USHORT)usMortgageICID,/* MORTGAGE index class ID        */
                    (PASYNCCTLSTRUCT) NULL,/* Request synchronous processing */
                    (PRCSTRUCT)&RCStruct); /* Pointer to RC data structure   */

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

    if (RCStruct.ulRC != SIM_RC_OK)
        {
        if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
            RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
            RCStruct.ulRC =  RCStruct.ulExtRC;
        }
    }

    if (RCStruct.ulRC == SIM_RC_OK)
    {
    /*************************************************************************/
    /* Call SimLibWriteAttr to assign a value to the MORTGAGENUMBER          */
    /* attribute.                                                            */
    /*************************************************************************/

    SimLibWriteAttr( hSession,             /* Folder Manager session handle  */
                  (HITEM)hitemItemID,      /* Item handle                    */
                  (USHORT)usMortgageAttrID,/* Attribute ID                   */
                  (PSZ)pszMortgageNumber,  /* Pointer to attribute value     */
                  (PASYNCCTLSTRUCT) NULL,  /* Request synchronous processing */
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

    if (RCStruct.ulRC != SIM_RC_OK)
        {
        if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
            RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
            RCStruct.ulRC =  RCStruct.ulExtRC;
        }
    }

    if (RCStruct.ulRC == SIM_RC_OK)
    {
    /*************************************************************************/
    /* Call SimLibCloseAttr to save the new attributes for the document.     */
    /*************************************************************************/

    SimLibCloseAttr( hSession,             /* Folder Manager session handle  */
                  (HITEM)hitemItemID,      /* Item handle                    */
                  SIM_OPT_SAVE,            /* Save the attributes            */
                  (PASYNCCTLSTRUCT) NULL,  /* Request synchronous processing */
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

    if (RCStruct.ulRC != SIM_RC_OK)
        {
        if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
            RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
            RCStruct.ulRC =  RCStruct.ulExtRC;
        }
    }

    if (RCStruct.ulRC == SIM_RC_OK)
    {
    /*************************************************************************/
    /* Call SimLibGetItemSnapshot to verify that the MORTGAGENUMBER          */
    /* attribute and the index class for the document have been changed.     */
    /*************************************************************************/

    SimLibGetItemSnapshot(hSession,        /* Folder Manager session handle  */
                  (PITEMID)&DocItemID,     /* Pointer to document ItemID     */
                  SIM_USER_ATTR,           /* Return user-defined attributes */
                  (PASYNCCTLSTRUCT) NULL,  /* Request synchronous processing */
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

    /*************************************************************************/
    /*  Save the pointer to the SNAPSHOTSTRUCT structure in order to free    */
    /*  the memory.                                                          */
    /*  Print the index class and associated attribute IDs and values for    */
    /*  the document.                                                        */
    /*  Call FreeMemory to free memory containing the SNAPSHOTSTRUCT data    */
    /*  structure returned from SimLibGetItemSnapshot.                       */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_OK)
         {
         pSnap      = (PSNAPSHOTSTRUCT)RCStruct.ulParam1;
         ulMemoryBlock = RCStruct.ulParam1;
         pICView    = pSnap->pICView;
         usNbrAttrs = pICView->usNumAttributes;
         pAttr      = pICView->pAttr;
         printf("\nResults of SimLibGetItemSnapshot:\n");
         printf("Attributes for document = %s\n\n", (PSZ)DocItemID);
         printf("The index class = %u\n", (USHORT)pICView->usIndexClass);
         for (i=0; i<usNbrAttrs; i++)
             {
             printf("Attribute ID    = %u\n", (USHORT)pAttr[i].usAttrId);
             printf("Attribute Value = %s\n\n", (PSZ)pAttr[i].pszAttributeValue);
             }
         FreeMemory();
         }

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     else
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }
    }

    /*************************************************************************/
    /*  Free storage reserved for pszMortgageNumber with malloc.             */
    /*************************************************************************/

     free (pszMortgageNumber);

    /*************************************************************************/
    /*  Return to main() with the return code from SimLibOpenItemAttr,       */
    /*  SimLibChangeIndexClass, SimLibWriteAttr, SimLibCloseAttr, or         */
    /*  SimLibGetItemSnapshot.                                               */
    /*************************************************************************/

     return( RCStruct.ulRC );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : RouteDocument                                         */
/*                                                                           */
/*  Description      : This function is called from main() to:               */
/*                     - Route the document to the second workbasket in the  */
/*                       MORTGAGEWF workflow.                                */
/*                     - Complete the workflow.                              */
/*                     - Get information about the contents of the second    */
/*                       workbasket in the workflow.                         */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: Ip2RouteWipItem                    */
/*                                        Ip2CompleteWorkFlow                */
/*                                        SimLibGetTOC                       */
/*                                        Ip2CloseTOC                        */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG RouteDocument (void ).                         */
/*                                                                           */
/*  Return values    :  Return code from Ip2RouteWipItem,                    */
/*                      Ip2CompleteWorkFlow, SimLibGetTOC, or Ip2CloseTOC.   */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Call the Ip2RouteWipItem Folder Manager API.                     */
/*      2.  Call the Ip2CompleteWorkFlow Folder Manager API.                 */
/*      3.  Call the SimLibGetTOC Folder Manager API.                        */
/*      4.  Call the Ip2CloseTOC Folder Manager API.                         */
/*      5.  Return to main() with the return code from Ip2RouteWipItem,      */
/*          Ip2CompleteWorkFlow, SimLibGetTOC, or Ip2CloseTOC.               */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG RouteDocument ( void )
{
    RCSTRUCT         RCStruct;            /* RC data structure               */
    PTOCENTRYSTRUCT  pToc;                /* Pointer to TOCENTRYSTRUCT array */
    HTOC             hToc;                /* Table of contents handle        */
    USHORT           i;                   /* Loop counter                    */

    /*************************************************************************/
    /* Call Ip2RouteWipItem to route the document from workbasket1 to        */
    /* workbasket2 in the MORTGAGEWF workflow.                               */
    /*************************************************************************/

    Ip2RouteWipItem (hSession,             /* Folder Manager session handle  */
                  (PITEMID)&DocItemID,     /* Pointer to document ItemID     */
                  (PITEMID)&WBasket2,      /* Pointer to workbasket2         */
                  TRUE,                    /* Add regardless of overload     */
                  OIM_NO_PRIORITY_CHANGE,  /* Retain current priority        */
                  (PASYNCCTLSTRUCT) NULL,  /* Request synchronous processing */
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

    if (RCStruct.ulRC != SIM_RC_OK)
         {
         if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
             RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
             RCStruct.ulRC =  RCStruct.ulExtRC;
         }

    if (RCStruct.ulRC == SIM_RC_OK)
    {
    /*************************************************************************/
    /* Call Ip2Complete WorkFlow to complete the workflow. This leaves the   */
    /* the document in workbasket2.                                          */
    /*************************************************************************/

    Ip2CompleteWorkFlow (hSession,         /* Folder Manager session handle  */
                  (PITEMID)&DocItemID,     /* Pointer to document ItemID     */
                  (PASYNCCTLSTRUCT) NULL,  /* Request synchronous processing */
                  (PRCSTRUCT) &RCStruct ); /* Pointer to RC data structure   */

    if (RCStruct.ulRC != SIM_RC_OK)
        {
        if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
            RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
            RCStruct.ulRC =  RCStruct.ulExtRC;
        }
    }

    if (RCStruct.ulRC == SIM_RC_OK)
    {
    /*************************************************************************/
    /* Call SimLibGetTOC to get a complete table of contents for workbasket2 */
    /* in the MORTGAGEWF workflow.                                           */
    /*************************************************************************/

    SimLibGetTOC( hSession,                 /* Folder Manager session handle */
               (PITEMID)&WBasket2,          /* Pointer to workbasket2 ItemID */
               SIM_ALL,                     /* Return folders and documents  */
               OIM_ALL,                     /* Ignore work-in-process status */
               OIM_ALL,                     /* Ignore suspension status      */
               (USHORT)0,                   /* Index class is not a criterion*/
               (PUSHORT)NULL,               /* Index class is not a criterion*/
               (PVOID) NULL,                /* Reserved for future use       */
               (PASYNCCTLSTRUCT) NULL,      /* Request synchronous processing*/
               (PRCSTRUCT) &RCStruct );     /* Pointer to RC data structure  */

    if (RCStruct.ulRC == SIM_RC_OK)
        {
        if ((PTOCENTRYSTRUCT)RCStruct.ulParam1 == (PTOCENTRYSTRUCT)NULL)
            printf ("\nThere are no items that satisfy the SimLibGetTOC request.\n");
        else
            {
            hToc = (HTOC)RCStruct.ulParam2;
            pToc = (PTOCENTRYSTRUCT)RCStruct.ulParam1;

    /**************************************************************/
    /* Print document and folder ids in the TOC for workbasket 2. */
    /**************************************************************/

            printf("Results of SimLibGetTOC\n\n");
            printf("The number of items in the second workbasket of MORTGAGEWF : %u\n",
                    (USHORT)RCStruct.usParam);
            printf("\nItemIDs in Workbasket2 =\n\n");
            for (i= 0 ;
                (i < RCStruct.usParam);
                i++
                )
                {
                printf("ItemID = %s\n", pToc[i].szItemID);
                }
            }
        }

    else
        {
        if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
            RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
            RCStruct.ulRC =  RCStruct.ulExtRC;
        }
    }

    if (RCStruct.ulRC == SIM_RC_OK)
    {
    /*************************************************************************/
    /* Call Ip2CloseTOC to close the table of contents and release the       */
    /* table of contents handle.                                             */
    /*************************************************************************/

    Ip2CloseTOC( hSession,                 /* Folder Manager session handle */
               (HTOC)hToc,                 /* Table of contents handle      */
               (PASYNCCTLSTRUCT) NULL,     /* Request synchronous processing*/
               (PRCSTRUCT) &RCStruct );    /* Pointer to RC data structure  */

    if (RCStruct.ulRC != SIM_RC_OK)
        {
        if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
            RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
            RCStruct.ulRC =  RCStruct.ulExtRC;
        }
    }

    /*************************************************************************/
    /*  Return to main() with the return code from Ip2RouteWipItem,          */
    /*  Ip2CompleteWorkFlow, SimLibGetTOC or Ip2CloseTOC.                    */
    /*************************************************************************/

     return( RCStruct.ulRC );
}

/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/*  Function         : Logoff                                                */
/*                                                                           */
/*  Description      : This function is called from main() to logoff from    */
/*                     the VisualInfo Folder Manager.                        */
/*                                                                           */
/*  Dependencies     : Global Variables :                                    */
/*                     Static External  :                                    */
/*                     Includes         :                                    */
/*                     Product Functions: SimLibLogoff()                     */
/*                                                                           */
/*  Restrictions     :  None.                                                */
/*                                                                           */
/*  Function type    :  ULONG.                                               */
/*                                                                           */
/*  Input Parameters :  None.                                                */
/*                                                                           */
/*  Output Parameters:  None.                                                */
/*                                                                           */
/*  Synopsis         :  ULONG Logoff ( void ).                               */
/*                                                                           */
/*  Return values    :  Return code from SimLibLogoff.                       */
/*                                                                           */
/*  Process Flow     :                                                       */
/*                                                                           */
/*      1.  Terminate the session with the Folder Manager by calling         */
/*          SimLibLogoff.                                                    */
/*      2.  Return to main() with return code from SimLibLogoff.             */
/*                                                                           */
/*  Notes            :  None.                                                */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

ULONG Logoff ( void )
{
     RCSTRUCT RCStruct;                     /* RC data structure             */

    /*************************************************************************/
    /* Call SimLibLogoff to terminate the Folder Manager session.            */
    /*************************************************************************/

     SimLibLogoff( hSession,                /* Folder Manager session handle */
                  (PASYNCCTLSTRUCT) NULL,   /* Request synchronous processing*/
                  (PRCSTRUCT) &RCStruct );  /* Pointer to RC data structure  */

    /*************************************************************************/
    /* If RCStruct.ulRC indicates a library or server error, get more        */
    /* detailed diagnostic information.                                      */
    /*************************************************************************/

     if (RCStruct.ulRC == SIM_RC_LIB_CLIENT_ERROR ||
         RCStruct.ulRC == SIM_RC_DOCSS_ERROR)
         RCStruct.ulRC =  RCStruct.ulExtRC;

    /*************************************************************************/
    /*  Return to main() with the return code from SimLibLogoff.             */
    /*************************************************************************/

     return( RCStruct.ulRC );
}

/*****************************************************************************/
/* End of FRNOEXWF.C                                                         */
/*****************************************************************************/

