/*BEGINPROLOGUE**************************************************************/
/*                                                                          */
/* MODULE: FRNOICSE.C                   VisualInfo                          */
/*                                                                          */
/* 5697-250, 5621-326, 5655-036, 5622-213, 5655-071, 5655-072               */
/*                                                                          */
/* (C) Copyright IBM Corporation 1993, 1994.                                */
/* All Rights Reserved.                                                     */
/*                                                                          */
/* DERIVATIVE RIGHTS:                                                       */
/* ------------------                                                       */
/* This program is provided for the customer's use and the customer is      */
/* granted permission to copy this program to the extent reasonably         */
/* required for such use.  All title, ownership, and rights to this         */
/* program and any copies remain with IBM, irrespective of the ownership    */
/* of the media on which the program resides.  The customer is permitted    */
/* to create derivative works to this program.  However, all copies of      */
/* the program and its derivative works must contain the IBM copyright      */
/* notice.  The customer understands and agrees that this program in and    */
/* of itself is not to be sold or distributed.  The customer is free to     */
/* sell, distribute, and commercially exploit any derivative works          */
/* created from this program.                                               */
/*                                                                          */
/*                                                                          */
/* DISCLAIMER OF WARRANTIES:                                                */
/* -------------------------                                                */
/* The following [enclosed] code is sample code created by IBM              */
/* Corporation.  This sample code is not part of any standard IBM product   */
/* and is provided to you solely for the purpose of assisting you in the    */
/* development of your applications.  The code is provided "AS IS",         */
/* without warranty of any kind.  IBM shall not be liable for any damages   */
/* arising out of your use of the sample code, even if they have been       */
/* advised of the possibility of such damages.                              */
/*                                                                          */
/*                                                                          */
/* Programmer: Mark S. Raine                                                */
/*                                                                          */
/* Date: May      1993                                                      */
/*                                                                          */
/* Status: Version 1 Release 1 Modification 0                               */
/*                                                                          */
/* Description: FRNOICSE.C - this module contains a                         */
/*    sample export function using Interchange APIs                         */
/*                                                                          */
/* Dependencies:                                                            */
/* Restrictions:                                                            */
/*                                                                          */
/* Entry Points:                                                            */
/*                                                                          */
/*                                                                          */
/* Change History:                                                          */
/*                                                                          */
/*                                                                          */
/* Notes:                                                                   */
/*                                                                          */
/* Assumptions for EXPORT:                                                  */
/*                                                                          */
/*   Pass NULL for pAsyncCtl                                                */
/*                                                                          */
/*   Only Folders and Documents are handled, not workbaskets                */
/*                                               workflows                  */
/*                                               annotations                */
/*                                               events                     */
/*                                                                          */
/*   Since Notes are passed to Ip2InsExportItem for a document              */
/*      notes are not retrieved when issuing the affiliated TOC for         */
/*      the same document and will not included through Ip2InsExportObject  */
/*                                                                          */
/*   pICView returned from snapshot API is assumed to be the only one       */
/*      and is the base view (or the lowest level view for this user).      */
/*                                                                          */
/*   Object Description is always set to " ". I could use chRepType.        */
/*                                                                          */
/*   Note's content class is NULL                                           */
/*   Note's userid will be USERID                                           */
/*                                                                          */
/*   An object is considered to be part of a multipart document if the      */
/*     document has more than one Affiliated Object.  What about the notes  */
/*     that were not queried?                                               */
/*                                                                          */
/*   See defaults used in SimLibOpenObject.                                 */
/*                                                                          */
/*   TOC changes are not queried during this export sample.                 */
/*                                                                          */
/*   Limitation of 4096 Items within the Item ID passed.                    */
/*ENDPROLOGUE****************************************************************/


#include   <stdio.h>
#include   <stdlib.h>
#include   <string.h>
#include   <ctype.h>
#include   <os2.h>

#define    FRN_INCL_FO           // include folder manager includes
#define    FRN_INCL_FI           // include folder manager includes
#include   <FRNP.H>             // Include global public structures
typedef    ULONG    HMTX;


#include "FRNOICGD.H"
#include "FRNOICFP.H"
#include "FRNOICSP.H"  // Sample code internal prototypes
#ifdef  INTRPROD
#include "UTOFFST.H"          // Include FFST prototypes
#endif


/*BEGINPROLOGUE*************************************************/
/*  Function  : Ip2Export                  Date:    May      93*/
/*  Module    : FRNOICSE.C                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                            stdio.h                          */
/*                            stdlib.h                         */
/*                Product Functions:                           */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG                                       */
/*                                                             */
/*  Input Parameters:                                          */
/*      HSESSION        hSession          session handle       */
/*      PSZ             pItemID           Item ID pointer      */
/*      PRCSTRUCT       prcStruct                              */
/*                                                             */
/*  Output Parameters:                                         */
/*      None                              output is file       */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Process Flow:                                              */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

  ULONG  _Optlink Ip2Export(HSESSION              hSession,
                            PSZ                   pszCIFFileName,
                            ULONG                 ulCCSID,
                            PSZ                   pszLanguage,
                            PSZ                   pszSourceType,
                            PSZ                   pszSourceID,
                            PSZ                   pszSinkType,
                            PSZ                   pszSinkID,
                            ULONG                 ulItemCount,
                            PINTEXPORTITEMSTRUCT  pItemList,
                            PRCSTRUCT             prcStruct)

{
   ULONG                  ulRC=0;           // return code
   HCIF                   hCIF;
   ULONG                  ulNumClasses;
   ULONG                  ulNumAttrs;
   PINTEXPORTITEMSTRUCT   pSaveItemList=NULL;
   SHORT                  sIndex;
   HCIF                   hCIFTemp;

   hCIFTemp = malloc(sizeof(CIF));
#ifdef  INTRPROD
   hCIFTemp->ulLogType = LOG_ERR;
#endif

   if (hCIFTemp == NULL)
   {
     call_FFST(ulRC,
               INT_ALLOCATE_ATTRIBUTE_MEMORY,
               hCIFTemp,
               prcStruct);
     return(INT_ALLOCATE_ATTRIBUTE_MEMORY);
   }

/*------------------------------------------------------------------------*/
/*  Allocate shared memory area to allow recurvise calling sequence to    */
/*  fill in all the user attributes for every item within the item being  */
/*  exported.                                                             */
/*------------------------------------------------------------------------*/

   hCIFTemp->pUserAttrBlock = malloc(4096*sizeof(INTUSERATTRSTRUCT));

   if (hCIFTemp->pUserAttrBlock == NULL)
   {
     call_FFST(ulRC,
               INT_ALLOCATE_ATTRIBUTE_MEMORY,
               hCIFTemp,
               prcStruct);
     free(hCIFTemp);
     return(INT_ALLOCATE_ATTRIBUTE_MEMORY);
   }


/*------------------------------------------------------------------------*/
/*  Allocate shared memory area to allow recurvise calling sequence to    */
/*  fill in all the user Index Classes for every item within the item     */
/*  being exported.                                                       */
/*------------------------------------------------------------------------*/

   hCIFTemp->pClassMemoryBlock = malloc(4096*sizeof(INTINDCLASSSTRUCT));


   if (hCIFTemp->pClassMemoryBlock == NULL)
   {
     call_FFST(ulRC,
               INT_ALLOCATE_NOTE_MEMORY,
               hCIFTemp,
               prcStruct);
     free(hCIFTemp->pUserAttrBlock);
     free(hCIFTemp);
     return(INT_ALLOCATE_NOTE_MEMORY);
   }

   ulNumClasses = 0;
   ulNumAttrs = 0;
   hCIFTemp->pAttrMemoryBlock = NULL;
   hCIFTemp->pNoteMemoryBlock = NULL;
   hCIFTemp->ulParentsIndex   = 0;

   pSaveItemList = pItemList;

/*------------------------------------------------------------------------*/
/* For each item ID passed, call the routine to set up the header for     */
/* opening the export file.                                               */
/*------------------------------------------------------------------------*/
   for (sIndex = 0; sIndex < ulItemCount; sIndex++)
   {
     if (pItemList->pItemID == NULL)
     {
       prcStruct->ulRC = INT_INCORRECT_DATA;
       ulRC            = INT_INCORRECT_DATA;
       free(hCIFTemp->pClassMemoryBlock);
       free(hCIFTemp->pUserAttrBlock);
       free(hCIFTemp);
       return(ulRC);
     }
     if (*pItemList->pItemID == "")
     {
       prcStruct->ulRC = INT_INCORRECT_DATA;
       ulRC            = INT_INCORRECT_DATA;
       free(hCIFTemp->pClassMemoryBlock);
       free(hCIFTemp->pUserAttrBlock);
       free(hCIFTemp);
       return(ulRC);
     }
     ulRC = setup_export_CIF_Header(hSession,
                                    hCIFTemp,
                                    pItemList->pItemID,
                                    &ulNumAttrs,
                                    &ulNumClasses,
                                    prcStruct);


     if (ulRC != SUCCESS)
     {
       /*  Free up the allocated memory areas we set up before.                  */
       free(hCIFTemp->pClassMemoryBlock);
       free(hCIFTemp->pUserAttrBlock);
       free(hCIFTemp);
       return(ulRC);
     }
     pItemList++;
   }

   ulRC = Ip2OpenExportCIF(pszCIFFileName,
                           ulCCSID,
                           pszLanguage,
                           pszSourceType,
                           pszSourceID,
                           pszSinkType,
                           pszSinkID,
                           ulNumAttrs,
                           ulNumClasses,
                           hCIFTemp->pUserAttrBlock,
                           hCIFTemp->pClassMemoryBlock,
                           prcStruct);


   hCIF = (HCIF) prcStruct->ulParam1;
   hCIF->ulLogType         = hCIFTemp->ulLogType;
   hCIF->pUserAttrBlock    = hCIFTemp->pUserAttrBlock;
   hCIF->pClassMemoryBlock = hCIFTemp->pClassMemoryBlock;
   hCIF->pAttrMemoryBlock  = hCIFTemp->pAttrMemoryBlock;
   hCIF->pNoteMemoryBlock  = hCIFTemp->pNoteMemoryBlock;
   free(hCIFTemp);

   if (ulRC != SUCCESS)
   {
     call_FFST(ulRC,
               ulRC,
               hCIF,
               prcStruct);
     if (ulRC != INT_OPEN_FAILURE)
       Ip2CloseExportCIF(hCIF, prcStruct);

     free(hCIF->pClassMemoryBlock);
     free(hCIF->pUserAttrBlock);
     free(hCIF);
     return(ulRC);
   }


   if (ulNumClasses > 4096)
   {
     call_FFST(ulRC,
               INT_TOO_MANY_CLASSES,
               hCIF,
               prcStruct);
     Ip2CloseExportCIF(hCIF, prcStruct);
     free(hCIF->pClassMemoryBlock);
     free(hCIF->pUserAttrBlock);
     free(hCIF);
     return(INT_TOO_MANY_CLASSES);
   }
   if (ulNumAttrs > 4096)
   {
     call_FFST(ulRC,
               INT_TOO_MANY_ATTRIBUTES,
               hCIF,
               prcStruct);
     Ip2CloseExportCIF(hCIF, prcStruct);
     free(hCIF->pClassMemoryBlock);
     free(hCIF->pUserAttrBlock);
     free(hCIF);
     return(INT_TOO_MANY_ATTRIBUTES);
   }

   hCIF->pSaveItems = NULL;
   hCIF->pSaveItemsPtr = NULL;
   hCIF->usItemCount = 0;
   pItemList = pSaveItemList;

/*------------------------------------------------------------------------*/
/* For each item ID passed, call the routines to export the item and its  */
/* contents into the CIU.                                                 */
/*------------------------------------------------------------------------*/
   for (sIndex = 0; sIndex < ulItemCount; sIndex++)
   {
     ulRC = Ip2OpenExportCIU (hCIF, prcStruct);

     /*------------------------------------------------------------------------*/
     /*  Now that the CIF header has been set up, we can now parse through     */
     /*  the items within the item being exported and create the necessary     */
     /*  CIUs.                                                                 */
     /*------------------------------------------------------------------------*/
     if (ulRC == SUCCESS)
     {
       ulRC = Ip2ExportToCIF(hSession,
                             hCIF,
                             pItemList->pItemID,
                             prcStruct);
       if (ulRC == SUCCESS)
       {
         ulRC = Ip2CloseExportCIU(hCIF, prcStruct);
         if (ulRC != SUCCESS)
         {
           call_FFST(ulRC,
                     ulRC,
                     hCIF,
                     prcStruct);
           Ip2CloseExportCIF(hCIF, prcStruct);
           if (hCIF->pSaveItemsPtr != NULL)
              free(hCIF->pSaveItemsPtr);
           free(hCIF->pClassMemoryBlock);
           free(hCIF->pUserAttrBlock);
           free(hCIF);
           return(ulRC);
         }
       }
       else
       {
         Ip2CloseExportCIU(hCIF, prcStruct);
         Ip2CloseExportCIF(hCIF, prcStruct);
         if (hCIF->pSaveItemsPtr != NULL)
            free(hCIF->pSaveItemsPtr);
         free(hCIF->pClassMemoryBlock);
         free(hCIF->pUserAttrBlock);
         free(hCIF);
         return(ulRC);
       }
     }
     else
     {
       call_FFST(ulRC,
                 ulRC,
                 hCIF,
                 prcStruct);
       if (ulRC != INT_OPEN_FAILURE)
         Ip2CloseExportCIU(hCIF, prcStruct);

       Ip2CloseExportCIF(hCIF, prcStruct);
       free(hCIF->pClassMemoryBlock);
       free(hCIF->pUserAttrBlock);
       if (hCIF->pSaveItemsPtr != NULL)
          free(hCIF->pSaveItemsPtr);
       free(hCIF);
       return(ulRC);
     }
     pItemList++;
   } /* End for each item ID passed loop */

/*------------------------------------------------------------------------*/
/*  All Done - close the CIF.                                             */
/*------------------------------------------------------------------------*/
   if (ulRC == SUCCESS)
   {
     ulRC = Ip2CloseExportCIF(hCIF, prcStruct);
     if (ulRC != SUCCESS)
     {
       call_FFST(ulRC,
                 ulRC,
                 hCIF,
                 prcStruct);
       if (hCIF->pSaveItemsPtr != NULL)
          free(hCIF->pSaveItemsPtr);
       free(hCIF->pClassMemoryBlock);
       free(hCIF->pUserAttrBlock);
       free(hCIF);
       return(ulRC);
     }
   }
   else
     Ip2CloseExportCIF(hCIF, prcStruct);

   /*------------------------------------------------------------------------*/
   /* PMR 93866 - big ol' memory leak here!                                  */
   /* free up all the cool stuff we allocated plus the some things allocated */
   /* in other routines - get_export_item_attr(), get_export_item_note()     */
   /*------------------------------------------------------------------------*/
   if (hCIF != NULL) {
      ULONG ulIndex;

      if (hCIF->pUserAttrBlock != NULL) {
         for (ulIndex = 0; ulIndex < ulNumAttrs ; ulIndex++) {
            free(hCIF->pUserAttrBlock->aAttributes[ulIndex].pszAttrName);
         } /* endfor */
      } /* endif */

      if (hCIF->pClassMemoryBlock != NULL) {
         for (ulIndex = 0; ulIndex < ulNumClasses ; ulIndex++) {
            free(hCIF->pClassMemoryBlock->aClasses[ulIndex].pszClassName);
         } /* endfor */
      } /* endif */

      if (hCIF->pClassMemoryBlock != NULL) {
         free(hCIF->pClassMemoryBlock);
         hCIF->pClassMemoryBlock = NULL;
      } /* endif */

      if (hCIF->pSaveItemsPtr != NULL) {
         free(hCIF->pSaveItemsPtr);
         hCIF->pSaveItemsPtr = NULL;
      } /* endif */

      if (hCIF->pUserAttrBlock != NULL) {
         free(hCIF->pUserAttrBlock);
         hCIF->pUserAttrBlock = NULL;
      } /* endif */

      if (hCIF->pAttrMemoryBlock != NULL) {
         free(hCIF->pAttrMemoryBlock);
         hCIF->pAttrMemoryBlock = NULL;
      } /* endif */

   } /* endif */

  prcStruct->ulRC    = ulRC;
  return(ulRC);
}

/*BEGINPROLOGUE*************************************************/
/*  Function  : Ip2ExportToCIF             Date:    May      93*/
/*  Module    : FRNOICSE.C                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                            stdio.h                          */
/*                            stdlib.h                         */
/*                Product Functions:                           */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG                                       */
/*                                                             */
/*  Input Parameters:                                          */
/*      HSESSION        hSession          session handle       */
/*      HCIF            hCIF              CIF File handle      */
/*      PSZ             pItemID           Item ID pointer      */
/*      PRCSTRUCT       prcStruct                              */
/*                                                             */
/*  Output Parameters:                                         */
/*      None                              output is file       */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Process Flow:                                              */
/*     SimLibGetItemType()                                     */
/*     Get_Item_Attributes()                                   */
/*     Get_Item_Notes()                                        */
/*     Ip2InsertExportItem()                                   */
/*     If item is a folder                                     */
/*          Process_Folder()                                   */
/*     If item is a document                                   */
/*          Process_document()                                 */
/*     Ip2EndExportItem()                                      */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

  ULONG  _Optlink Ip2ExportToCIF(
                          HSESSION hSession,
                          HCIF hCIF,
                          PITEMID pItemID,
                          PRCSTRUCT prcStruct)

{
   USHORT                 usItemType;       // Item type from SimLibGetItemType
   ULONG                  ulRC=0;           // return code
   ULONG                  ulNumAttrs=0;
   ULONG                  ulNumNotes=0;
   USHORT                 usItemIndex;
   USHORT                 usIndexClass;
   PITEMINFOSTRUCT        pItemInfo=NULL;
   RCSTRUCT               RCStruct;
   ULONG ulIndex;


/*------------------------------------------------------------------------*/
/*  Check the current list of item IDs that we have encountered so far.   */
/*  If we find a duplicate, call the duplicate export function.           */
/*------------------------------------------------------------------------*/
   hCIF->pSaveItems = hCIF->pSaveItemsPtr;
   for (usItemIndex = 0; usItemIndex < hCIF->usItemCount; usItemIndex++)
   {
     if (strcmp((CHAR *)pItemID, (CHAR *)&hCIF->pSaveItems->szItemID) == 0)
     {
       ulRC = Ip2InsExportDuplicate(hCIF,
                                    hCIF->pSaveItems->ulUID,
                                    prcStruct);
       if (ulRC != SUCCESS)
       {
           call_FFST(ulRC,
                     ulRC,
                     hCIF,
                     prcStruct);
           return(ulRC);
       }
       prcStruct->ulRC    = 0;
       return(0);
     }
     else
       hCIF->pSaveItems++;
   }

/*------------------------------------------------------------------------*/
/*  Get the type of item being exported.  If it is a folder, there are    */
/*  probably items within it.                                             */
/*------------------------------------------------------------------------*/
   ulRC = SimLibGetItemInfo( hSession,
                             pItemID,
                             0,
                             NULL,            // synchronous processing
                             &RCStruct);
   if ( ulRC != SUCCESS )
   {
       call_FFST(ulRC,
                 INT_GET_ITEM_TYPE_FAILED,
                 hCIF,
                 prcStruct);
       *prcStruct = RCStruct;
       return(INT_GET_ITEM_TYPE_FAILED);
   }

    pItemInfo = (PITEMINFOSTRUCT) RCStruct.ulParam1;  // get Item Type
    usItemType = pItemInfo->usItemType;
    usIndexClass = pItemInfo->usIndexClass;

/*------------------------------------------------------------------------*/
/*  Get the attributes for this item.                                     */
/*------------------------------------------------------------------------*/

    ulRC = get_export_item_attributes(hSession,
                                      hCIF,
                                      pItemID,
                                      usItemType,
                                      usIndexClass,
                                      &ulNumAttrs,
                                      prcStruct);

/*------------------------------------------------------------------------*/
/*  Get the notes for this item.                                          */
/*------------------------------------------------------------------------*/
    if ( ulRC == SUCCESS)
      ulRC = get_export_item_notes(hSession,
                                   hCIF,
                                   pItemID,
                                   &ulNumNotes,
                                   prcStruct);

    if ( ulRC != SUCCESS)
    {

/*------------------------------------------------------------------------*/
/*  Free the areas used to hold all the attributes and notes for this     */
/*  item.                                                                 */
/*------------------------------------------------------------------------*/

      //freeup_export_mallocs(hCIF, ulNumAttrs, ulNumNotes);
      return(ulRC);
    }
    else
    {

/*------------------------------------------------------------------------*/
/*  Call the Interchange API to put this item in the CIF data stream.     */
/*------------------------------------------------------------------------*/

      ulRC = Ip2InsExportItem(hCIF,
                          usItemType,
                          ulNumNotes,
                          ulNumAttrs,
                          hCIF->pNoteMemoryBlock,
                          hCIF->pAttrMemoryBlock,
                          prcStruct);

      if ( ulRC != SUCCESS)
      {
          call_FFST(ulRC,
                    ulRC,
                    hCIF,
                    prcStruct);
          return(ulRC);
      }

      if (hCIF->pSaveItems == NULL)
      {
        hCIF->pSaveItems = (PSAVEITEMS) malloc(4096 * sizeof(SAVEITEMS));
        if (hCIF->pSaveItems == NULL)
        {
          call_FFST(ulRC,
                    INT_ALLOCATE_SAVEITEMS,
                    hCIF,
                    prcStruct);
          return(INT_ALLOCATE_SAVEITEMS);
        }
        hCIF->pSaveItemsPtr = hCIF->pSaveItems;
      }
      strcpy((CHAR *)&hCIF->pSaveItems->szItemID,  (CHAR *)pItemID);
      hCIF->pSaveItems->ulUID = prcStruct->ulParam1;
      hCIF->usItemCount++;

/*------------------------------------------------------------------------*/
/*  Free the areas used to hold all the attributes and notes for this     */
/*  item.                                                                 */
/*------------------------------------------------------------------------*/

      for (ulIndex = 0; ulIndex < ulNumAttrs; ulIndex++)
      {
        if (hCIF->pAttrMemoryBlock != NULL)
        if ((PVOID) hCIF->pAttrMemoryBlock->aAttributes[ulIndex].pAttrValue != NULL)
            free(hCIF->pAttrMemoryBlock->aAttributes[ulIndex].pAttrValue);
      }

      if (hCIF->pAttrMemoryBlock) {
         free(hCIF->pAttrMemoryBlock);
         hCIF->pAttrMemoryBlock = NULL;
      } /* endif */

      if (hCIF->pNoteMemoryBlock) {
         free(hCIF->pNoteMemoryBlock);
         hCIF->pNoteMemoryBlock = NULL;
      } /* endif */

/*------------------------------------------------------------------------*/
/*  Call the routine to further handle this item.  If it a folder, there  */
/*  are probably more items.  If it a document, there are probably        */
/*  objects in it.                                                        */
/*------------------------------------------------------------------------*/

      switch(usItemType)
      {
         case  SIM_FOLDER:
            /* this may recursively call THIS function (Ip2ExportToCIF) */
            ulRC = process_export_folder(hSession,
                                  pItemID,
                                  hCIF,
                                  prcStruct);
            if ( ulRC != SUCCESS)
            {
                call_FFST(ulRC,
                          ulRC,
                          hCIF,
                          prcStruct);
                return(ulRC);
            }
            break;

         case  SIM_DOCUMENT:
            ulRC = process_export_document(hSession,
                                    pItemID,
                                    hCIF,
                                    prcStruct);
            if ( ulRC != SUCCESS)
            {
                call_FFST(ulRC,
                          ulRC,
                          hCIF,
                          prcStruct);
                return(ulRC);
            }
            break;

         default:
            call_FFST(0,
                      INT_INVALID_ITEM_TYPE,
                      hCIF,
                      prcStruct);
             return(INT_INVALID_ITEM_TYPE);
      } /* End the switch (ulItemType) */
    } /* End the if SUCCESS */


/*------------------------------------------------------------------------*/
/*  Call the interchange API to put the END ITEM delimiter in the CIF     */
/*  data stream.                                                          */
/*------------------------------------------------------------------------*/

   ulRC = Ip2EndExportItem(hCIF,
                           prcStruct);
   if ( ulRC != SUCCESS)
   {
       call_FFST(ulRC,
                 ulRC,
                 hCIF,
                 prcStruct);
       return(ulRC);
   }



  prcStruct->ulRC    = ulRC;
  return(ulRC);
}



/*BEGINPROLOGUE*************************************************/
/*  Function  : get_export_item_attributes   Date:  May      93*/
/*  Module    : FRNOICSE.C                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                            stdio.h                          */
/*                            stdlib.h                         */
/*                Product Functions:                           */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG                                       */
/*                                                             */
/*  Input Parameters:                                          */
/*      HSESSION        hSession          session handle       */
/*      PITEMID         pItemID           Item ID pointer      */
/*                                                             */
/*  Output Parameters:                                         */
/*      None                              output is file       */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Process Flow:                                              */
/*      SimLibGetItemSnapshot(OIM_USER)                        */
/*      for each attribute in ICView Attribute array           */
/*         add to PINTITEMATTRINFOSTRUCT array                 */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

  ULONG  _Optlink get_export_item_attributes(
                                      HSESSION hSession,
                                      HCIF     hCIF,
                                      PITEMID pItemID,
                                      USHORT  usItemType,
                                      USHORT  usIndexClass,
                                      ULONG *pulNumAttrs,
                                      PRCSTRUCT prcStruct)

{
   ULONG                  ulRC = 0;
   USHORT                 usIndex    = 0;            // loop counter
   USHORT                 usNumUserAttrs = 0;
   PSNAPSHOTSTRUCT        pUserSnapshot=NULL;    // snapshot of user attributes
   PATTRLISTSTRUCT        pUserAttrs=NULL;       // list of user attributes
   ULONG                  ulNumObjects;
   PAFFTOCENTRYSTRUCT     pObjects=NULL;
   POBJINFOSTRUCT         pObjectInfo=NULL;
   CHAR                   szClassBuffer[33];
   ULONG                  ulContentClass;
   CHAR                  *pulContentClass;
   RCSTRUCT               RCStruct;
   SHORT                  sTemp;
   LONG                   lTemp;

//-----------------------------------------------------------------------
//  Get the item user attributes from the item snapshot
//-----------------------------------------------------------------------

   ulRC = SimLibGetItemSnapshot(hSession,
                                pItemID,
                                SIM_USER_ATTR,
                                NULL,
                                &RCStruct);   /* This only returns user
                                                 defined attributes! */
   if ( ulRC != SUCCESS )
   {
     call_FFST(ulRC,
               INT_GET_USER_SNAPSHOT_FAILED,
               hCIF,
               prcStruct);
     *prcStruct = RCStruct;
     return(INT_GET_USER_SNAPSHOT_FAILED);
   }

   pUserSnapshot = (PSNAPSHOTSTRUCT) RCStruct.ulParam1;  /* get pointer
                                                         to snapshot */
   pUserAttrs = pUserSnapshot->pICView->pAttr; /* pointer to first IC View
                                                      attributes */
   usNumUserAttrs = pUserSnapshot->pICView->usNumAttributes;
   *pulNumAttrs = usNumUserAttrs + 1;  // Add index class attribute

   if (usItemType == SIM_DOCUMENT)
   {
//-----------------------------------------------------------------
//  Get the objects for this document.
//-----------------------------------------------------------------

    ulRC =  SimLibGetItemAffiliatedTOC(hSession,
                                       pItemID,
                                       SIM_BASE,
                                       NULL,
                                       &RCStruct);
    if ( ulRC != SUCCESS )
    {
        call_FFST(ulRC,
                  INT_GET_DOCUMENT_TOC_FAILED,
                  hCIF,
                  prcStruct);
        *prcStruct = RCStruct;
        return(INT_GET_DOCUMENT_TOC_FAILED);
    }

    ulNumObjects =  RCStruct.ulParam2;
    pObjects = (PAFFTOCENTRYSTRUCT) RCStruct.ulParam1;
    if (ulNumObjects == 1)
      *pulNumAttrs = *pulNumAttrs + 1; // Add content class attribute
    else
      if ((PVOID) pObjects != NULL)
         SimLibFree(hSession, (PVOID) pObjects, prcStruct);
   }

   hCIF->pAttrMemoryBlock = (PINTITEMATTRINFOSTRUCT)
                      malloc(*pulNumAttrs * sizeof(INTITEMATTRSTRUCT));
   if (hCIF->pAttrMemoryBlock == NULL)
   {
     call_FFST(0,
               INT_ALLOCATE_ATTRIBUTE_MEMORY,
               hCIF,
               prcStruct);
     SimLibFree(hSession, (PVOID) pUserSnapshot, &RCStruct);
     return(INT_ALLOCATE_ATTRIBUTE_MEMORY);
   }

//-----------------------------------------------------------------------
//  Set up the Index Class attribute value of this item for exporting
//  to the CIF later.
//-----------------------------------------------------------------------
   hCIF->pAttrMemoryBlock->aAttributes[0].fAttrSys  = TRUE;
   hCIF->pAttrMemoryBlock->aAttributes[0].usAttrType= USER_ATTR_INTEGER;
   hCIF->pAttrMemoryBlock->aAttributes[0].usAttrID  = 14;
   hCIF->pAttrMemoryBlock->aAttributes[0].ulLen     = 2;
   hCIF->pAttrMemoryBlock->aAttributes[0].pAttrValue = (PVOID)
                                     malloc(sizeof(usIndexClass));
   memcpy(hCIF->pAttrMemoryBlock->aAttributes[0].pAttrValue,
          &usIndexClass,
          sizeof(usIndexClass));

//-----------------------------------------------------------------------
//  For each USER attribute returned from the snapshot,
//     1.  Fill in the PINTITEMATTRINFOSTRUCT array for Item Export
//     2.  Free the snapshot area for this attribute
//-----------------------------------------------------------------------
   for (usIndex = 0; usIndex < usNumUserAttrs; usIndex++)
   {
     hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].fAttrSys  = FALSE;
     hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].usAttrID  =
                                  pUserAttrs[usIndex].usAttrId;
     switch(pUserAttrs[usIndex].usAttrType)
     {
       case    SIM_ATTR_TIMESTAMP:
       case    SIM_ATTR_DATE:
               hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].usAttrType =
                                                      USER_ATTR_TIMESTAMP;
               break;

       case    SIM_ATTR_TIME:
               hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].usAttrType =
                                                      USER_ATTR_TIME;
               break;

       case    SIM_ATTR_LONG:
       case    SIM_ATTR_SHORT:
               hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].usAttrType =
                                                      USER_ATTR_INTEGER;
               break;

       case    SIM_ATTR_DECIMAL:
               hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].usAttrType =
                                                      USER_ATTR_DECIMAL;
               break;

       case    SIM_ATTR_VSTRING:
               hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].usAttrType =
                                                      USER_ATTR_STRING;
               break;

       case    SIM_ATTR_FSTRING:
               hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].usAttrType =
                                                      USER_ATTR_STRING;
               break;

       case    SIM_ATTR_FLOAT:
               hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].usAttrType =
                                                      USER_ATTR_NUMBER;
               break;

       default:
               hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].usAttrType =
                                                      USER_ATTR_UNSPEC;
               break;

     }
     if (pUserAttrs[usIndex].pszAttributeValue != NULL)
     {
       if (pUserAttrs[usIndex].usAttrType == SIM_ATTR_SHORT)
         hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].pAttrValue = (PVOID)
                                                         malloc(sizeof(sTemp));
       else
         if (pUserAttrs[usIndex].usAttrType == SIM_ATTR_LONG)
           hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].pAttrValue = (PVOID)
                                                         malloc(sizeof(lTemp));
         else
           hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].pAttrValue = (PVOID)
                      malloc(strlen((char *)pUserAttrs[usIndex].pszAttributeValue)+1);
       if (hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].pAttrValue == NULL)
       {
         call_FFST(0,
                   INT_ALLOCATE_ATTRIBUTE_MEMORY,
                   hCIF,
                   prcStruct);
         SimLibFree(hSession, (PVOID) pUserSnapshot, &RCStruct);
         return(INT_ALLOCATE_ATTRIBUTE_MEMORY);
       }
       if (pUserAttrs[usIndex].usAttrType == SIM_ATTR_SHORT)
       {
         sTemp = atoi(pUserAttrs[usIndex].pszAttributeValue);
         memcpy(hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].pAttrValue,
                &sTemp, sizeof(sTemp));
         memcpy(&sTemp,
                hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].pAttrValue,
                sizeof(sTemp));
         hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].ulLen = sizeof(sTemp);
       }
       else
         if (pUserAttrs[usIndex].usAttrType == SIM_ATTR_LONG)
         {
           lTemp = atol(pUserAttrs[usIndex].pszAttributeValue);
           memcpy(hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].pAttrValue,
                  &lTemp, sizeof(lTemp));
           hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].ulLen = sizeof(lTemp);
         }
         else
         {
           strcpy(hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].pAttrValue,
                  (char *)pUserAttrs[usIndex].pszAttributeValue);
           hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].ulLen = strlen((char *)
                          hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].pAttrValue);
         }
     }
     else
     {
       hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].pAttrValue = NULL;
       hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].ulLen = 0;
     }

   } /* End for number of user attributes loop */

   SimLibFree(hSession, (PVOID) pUserSnapshot, prcStruct);

   if ((usItemType == SIM_DOCUMENT) && (ulNumObjects == 1))
   {

  /*------------------------------------------------------------------------*/
  //      1.  Query the object to get its content class
  //      2.  Open the object to get its file name
  //      3.  Export the item to the CIF
  //      4.  Close the object
  /*------------------------------------------------------------------------*/

     hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].fAttrSys = TRUE;
     hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].usAttrID = 6;

     ulRC =  SimLibQueryObject(hSession,
                              (HOBJ)&pObjects->Obj,
                              NULL,
                              &RCStruct);
     pObjectInfo = (POBJINFOSTRUCT) RCStruct.ulParam1;
     if ((PVOID) pObjects != NULL)
        SimLibFree(hSession, (PVOID) pObjects, prcStruct);

     if ( ulRC != SUCCESS )
     {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

         call_FFST(ulRC,
                   INT_QUERY_OBJECT_FAILED,
                   hCIF,
                   prcStruct);
         *prcStruct = RCStruct;
         return(INT_QUERY_OBJECT_FAILED);
     }

     hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].pAttrValue =
                                 malloc(sizeof(pObjectInfo->ulObjConCls));
     memcpy(hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].pAttrValue,
            &pObjectInfo->ulObjConCls,
            sizeof(pObjectInfo->ulObjConCls));
     hCIF->pAttrMemoryBlock->aAttributes[usIndex+1].ulLen =
                             sizeof(pObjectInfo->ulObjConCls);

   }

   prcStruct->ulRC    = ulRC;
   return(ulRC);
}


/*BEGINPROLOGUE*************************************************/
/*  Function  : get_export_item_notes      Date:    May      93*/
/*  Module    : FRNOICSE.C                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                            stdio.h                          */
/*                            stdlib.h                         */
/*                Product Functions:                           */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG                                       */
/*                                                             */
/*  Input Parameters:                                          */
/*      HSESSION        hSession          session handle       */
/*      PITEMID         pItemID           Item ID pointer      */
/*                                                             */
/*  Output Parameters:                                         */
/*      None                              output is file       */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*         0 = SUCCESS                                         */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Process Flow:                                              */
/*     SimLibGetItemAffiliatedTOC(OIM_NOTE)                    */
/*     for each object in AFFTOCENTRYSTRUCT.Obj                */
/*        add to PINTORNOTESTRUCT array                        */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

  ULONG  _Optlink get_export_item_notes(
                                 HSESSION hSession,
                                 HCIF     hCIF,
                                 PITEMID pItemID,
                                 ULONG *pulNumNotes,
                                 PRCSTRUCT prcStruct)

{
   ULONG               ulRC = 0;
   ULONG               ulIndex    = 0;            // loop counter
   PAFFTOCENTRYSTRUCT  pNotes;
   PAFFTOCENTRYSTRUCT  pSaveNotesPtr= NULL;
   POBJINFOSTRUCT      pObjectInfo=NULL;
   HOBJACC             hObjAcc;
   RCSTRUCT            RCStruct;

//----------------------------------------------------------------------
//   Get the NOTE type affiliated TOC
//----------------------------------------------------------------------

   ulRC = SimLibGetItemAffiliatedTOC(hSession,
                                     pItemID,
                                     SIM_NOTE,
                                     NULL,
                                     &RCStruct);  /* This only returns Notes */
   if ( ulRC != SUCCESS )
   {
       call_FFST(ulRC,
                 INT_GET_NOTES_FAILED,
                 hCIF,
                 prcStruct);
       *prcStruct = RCStruct;
       return(INT_GET_NOTES_FAILED);
   }

   *pulNumNotes = RCStruct.ulParam2;


//-----------------------------------------------------------------------
//  For each NOTE returned from the the affiliated TOC
//     1.  Fill in the PINTNOTEINFOSTRUCT array for Item Export
//-----------------------------------------------------------------------
   if (*pulNumNotes > 0)
   {
     pNotes = (PAFFTOCENTRYSTRUCT) RCStruct.ulParam1;  /* get pointer TOC
                                                           structure */
     pSaveNotesPtr = pNotes;
     hCIF->pNoteMemoryBlock = (PINTNOTEINFOSTRUCT)
                        malloc(*pulNumNotes * sizeof(INTNOTEINFOSTRUCT));
     if (hCIF->pNoteMemoryBlock == NULL)
     {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

       call_FFST(0,
                 INT_ALLOCATE_NOTE_MEMORY,
                 hCIF,
                 prcStruct);
       if ((PVOID)pSaveNotesPtr != NULL)
         SimLibFree(hSession, (PVOID) pSaveNotesPtr, &RCStruct);
       return(INT_ALLOCATE_NOTE_MEMORY);
     }
   }


   for (ulIndex = 0; ulIndex < *pulNumNotes; ulIndex++)
   {
     /* Fill in the PINTNOTESTRUCT */
     memcpy(hCIF->pNoteMemoryBlock->aNote[ulIndex].tsCreated,
                       pNotes->tsCreate,
                       sizeof(hCIF->pNoteMemoryBlock->aNote[ulIndex].tsCreated));
     hCIF->pNoteMemoryBlock->aNote[ulIndex].pszUserID = NULL;
     hCIF->pNoteMemoryBlock->aNote[ulIndex].pszNoteDesc = NULL;
     hCIF->pNoteMemoryBlock->aNote[ulIndex].ulLength = 0;
//----------------------------------------------------------------------
//  Now we need to fill in the content of the note.  To do this we will:
//      1.  Get the size of the note object
//      2.  Allocate memory for the note object's content
//      3.  Open the note object
//      4.  Read the note object content into the memory allocated
//      5.  Close the object
//
//      The memory for each object will have to be freed by the caller to this
//      routine.
//----------------------------------------------------------------------
     ulRC =  SimLibQueryObject(hSession,
                              (HOBJ)&pNotes->Obj,
                              NULL,
                              &RCStruct);
     if ( ulRC != SUCCESS )
     {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

         call_FFST(ulRC,
                   INT_QUERY_OBJECT_FAILED,
                   hCIF,
                   prcStruct);
         if ((PVOID)pSaveNotesPtr != NULL)
           SimLibFree(hSession, (PVOID) pSaveNotesPtr, prcStruct);
         *prcStruct = RCStruct;
         return(INT_QUERY_OBJECT_FAILED);
     }

     pObjectInfo = (POBJINFOSTRUCT) RCStruct.ulParam1;

     hCIF->pNoteMemoryBlock->aNote[ulIndex].ulLength = pObjectInfo->ulObjSize;
     if (pObjectInfo->ulObjSize > 0)
     {
       hCIF->pNoteMemoryBlock->aNote[ulIndex].pContent = malloc(pObjectInfo->ulObjSize+1);
       if (hCIF->pNoteMemoryBlock->aNote[ulIndex].pContent == NULL)
       {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

         call_FFST(0,
                   INT_ALLOCATE_OBJECT_BUFFER,
                   hCIF,
                   prcStruct);
         if ((PVOID) pSaveNotesPtr != NULL)
           SimLibFree(hSession, (PVOID) pSaveNotesPtr, &RCStruct);

         if ((PVOID) pObjectInfo != NULL)
           SimLibFree(hSession, (PVOID) pObjectInfo, &RCStruct);

         prcStruct->ulRC = INT_ALLOCATE_OBJECT_BUFFER;
         return(INT_ALLOCATE_OBJECT_BUFFER);
       }

       memset(hCIF->pNoteMemoryBlock->aNote[ulIndex].pContent, '\0',
              (pObjectInfo->ulObjSize)+1);
       ulRC =  SimLibOpenObject(hSession,
                                (HOBJ)&pNotes->Obj,
                                SIM_ACCESS_SHARED_READ,
                                SIM_PRI_NORMAL,
                                1,
                                SIM_OPEN_DISK,
                                NULL,
                                &RCStruct);
       if ( ulRC != SUCCESS )
       {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

           call_FFST(ulRC,
                     INT_OPEN_OBJECT_FAILED,
                     hCIF,
                     prcStruct);
           if ((PVOID) pSaveNotesPtr != NULL)
             SimLibFree(hSession, (PVOID) pSaveNotesPtr, prcStruct);

           if ((PVOID) pObjectInfo != NULL)
              SimLibFree(hSession, (PVOID) pObjectInfo, prcStruct);

           *prcStruct = RCStruct;
           return(INT_OPEN_OBJECT_FAILED);
       }

       hObjAcc = (HOBJACC) RCStruct.ulParam1;
       ulRC =  SimLibReadObject(hSession,
                                hObjAcc,
                                hCIF->pNoteMemoryBlock->aNote[ulIndex].pContent,
                                pObjectInfo->ulObjSize,
                                NULL,
                                &RCStruct);
       if ( ulRC != SUCCESS )
       {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

           call_FFST(ulRC,
                     INT_READ_OBJECT_FAILED,
                     hCIF,
                     prcStruct);
           if ((PVOID) pSaveNotesPtr != NULL)
             SimLibFree(hSession, (PVOID) pSaveNotesPtr, prcStruct);

           if ((PVOID) pObjectInfo != NULL)
             SimLibFree(hSession, (PVOID) pObjectInfo, prcStruct);

           SimLibCloseObject(hSession,
                             hObjAcc,
                             0,
                             NULL,
                             prcStruct);
           *prcStruct = RCStruct;
           prcStruct->ulRC = INT_READ_OBJECT_FAILED;
           return(INT_READ_OBJECT_FAILED);
       }


       ulRC =  SimLibCloseObject(hSession,
                                hObjAcc,
                                0,
                                NULL,
                                &RCStruct);

       if ( ulRC != SUCCESS )
       {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

           call_FFST(ulRC,
                     INT_CLOSE_OBJECT_FAILED,
                     hCIF,
                     prcStruct);
           if ((PVOID) pSaveNotesPtr != NULL)
             SimLibFree(hSession, (PVOID) pSaveNotesPtr, prcStruct);

           if ((PVOID) pObjectInfo != NULL)
             SimLibFree(hSession, (PVOID) pObjectInfo, prcStruct);

           *prcStruct = RCStruct;
           return(INT_CLOSE_OBJECT_FAILED);
       }
       if ((PVOID) pObjectInfo != NULL)
         SimLibFree(hSession, (PVOID) pObjectInfo, &RCStruct);

     }  /* End the if note object size > 0 */
     pNotes++;
   }  /* End the for ulNumNotes loop */

   if ((PVOID) pSaveNotesPtr != NULL)
     SimLibFree(hSession, (PVOID) pSaveNotesPtr, prcStruct);

   prcStruct->ulRC = ulRC;
   return(ulRC);
}

/*BEGINPROLOGUE*************************************************/
/*  Function  : process_export_folder      Date:    May      93*/
/*  Module    : FRNOICSE.C                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                            stdio.h                          */
/*                            stdlib.h                         */
/*                Product Functions:                           */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG                                       */
/*                                                             */
/*  Input Parameters:                                          */
/*      HSESSION        hSession          session handle       */
/*      HCIF            hCIF              CIF file handle      */
/*      PITEMID         pItemID           Item ID pointer      */
/*                                                             */
/*  Output Parameters:                                         */
/*      None                              output is file       */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*         0 = SUCCESS                                         */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Process Flow:                                              */
/*    4.   SimLibGetTOC     - get items in this folder         */
/*    5.   for each item in this folder's toc                  */
/*    6.     Export_Item - calls this recursively              */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

  USHORT _Optlink process_export_folder(HSESSION hSession,
                                 PITEMID pItemID,
                                 HCIF hCIF,
                                 PRCSTRUCT prcStruct)

{
 ULONG         ulRC = 0;
 USHORT        usIndex =0;             // loop counter
 HTOC          hTOC;
 PTOCENTRYSTRUCT pItemsPtr=NULL;
 USHORT        usNumItems;
 RCSTRUCT      RCStruct;

//------------------------------------------------------------------
//  Get the TOC for this item.  If there are items within this item,
//   recursively call Ip2ExportToCIF for each item in the TOC.
//------------------------------------------------------------------

 ulRC = SimLibGetTOC( hSession,
                      pItemID,
                      SIM_ALL,
                      OIM_ALL,
                      OIM_ALL,
                      0,
                      NULL,
                      NULL,
                      NULL,
                      &RCStruct );

  if ( ulRC != SUCCESS )
  {
      call_FFST(ulRC,
                INT_GET_FOLDER_TOC_FAILED,
                hCIF,
                prcStruct);
      *prcStruct = RCStruct;
      return(INT_GET_FOLDER_TOC_FAILED);
  }

  pItemsPtr = (PTOCENTRYSTRUCT) RCStruct.ulParam1;
  usNumItems = RCStruct.usParam;
  hTOC = (HTOC) RCStruct.ulParam2;

  for (usIndex = 0; usIndex < usNumItems; usIndex++)
  {
     ulRC = Ip2ExportToCIF(hSession,
                           hCIF,
                           (PITEMID) pItemsPtr->szItemID,
                           prcStruct);
     if (ulRC != SUCCESS)
     {
         call_FFST(ulRC,
                   ulRC,
                   hCIF,
                   prcStruct);
         Ip2CloseTOC(hSession,
                     hTOC,
                     NULL,
                     &RCStruct);
         return(ulRC);
     }
     pItemsPtr++;
   } /* End the for usNumItems loop */

   ulRC = Ip2CloseTOC(hSession,
                      hTOC,
                      NULL,
                      prcStruct);
   if (ulRC != SUCCESS)
   {
       call_FFST(ulRC,
                 INT_CLOSE_TOC_FAILED,
                 hCIF,
                 prcStruct);
       return(INT_CLOSE_TOC_FAILED);
   }
  prcStruct->ulRC    = ulRC;
  return(ulRC);

}

/*BEGINPROLOGUE*************************************************/
/*  Function  : process_export_document    Date:    May      93*/
/*  Module    : FRNOICSE.C                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                            stdio.h                          */
/*                            stdlib.h                         */
/*                Product Functions:                           */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG                                       */
/*                                                             */
/*  Input Parameters:                                          */
/*      HSESSION        hSession          session handle       */
/*      PITEMID         pItemID           Item ID pointer      */
/*                                                             */
/*  Output Parameters:                                         */
/*      None                              output is file       */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*         0 = SUCCESS                                         */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Process Flow:                                              */
/*    SimLibGetItemAffiliatedTOC(OIM_BASE)                     */
/*    for each object in AFFTOCENTRYSTRUCT.Obj                 */
/*      SimLibOpenObject(SIM_OPEN_DISK, SIM_ACCESS_SHARED_READ)*/
/*      Ip2GetObjObjectFileName                                */
/*      Ip2InsExportObject using AFFTOCENTRYSTRUCT.Obj         */
/*      SimLibCloseObject                                      */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

  USHORT _Optlink process_export_document(HSESSION hSession,
                                 PITEMID pItemID,
                                 HCIF hCIF,
                                 PRCSTRUCT prcStruct)

{
 ULONG                  ulRC=0;           // return code
 ULONG                  ulIndex =0;             // loop counter
 ULONG                  ulNumObjects;
 PAFFTOCENTRYSTRUCT     pObjects=NULL;
 PAFFTOCENTRYSTRUCT     pSaveObjectsPtr=NULL;
 POBJINFOSTRUCT         pObjectInfo=NULL;
 HOBJACC                hObjAcc;
 BOOL                   fSubDoc;
 char                   szClassBuffer[33];
 PINTITEMATTRINFOSTRUCT pObjectAttrs = NULL;
 PSZ                    pszObjectFileName;
 RCSTRUCT               RCStruct;


//-----------------------------------------------------------------
//  Get the objects for this document.
//-----------------------------------------------------------------

  ulRC =  SimLibGetItemAffiliatedTOC(hSession,
                                     pItemID,
                                     SIM_BASE,
                                     NULL,
                                     &RCStruct);
  if ( ulRC != SUCCESS )
  {
      call_FFST(ulRC,
                INT_GET_DOCUMENT_TOC_FAILED,
                hCIF,
                prcStruct);
      *prcStruct = RCStruct;
      return(INT_GET_DOCUMENT_TOC_FAILED);
  }

  ulNumObjects =  RCStruct.ulParam2;
  pObjects = (PAFFTOCENTRYSTRUCT) RCStruct.ulParam1;  /* get pointer TOC
                                                        structure */
  pSaveObjectsPtr = pObjects;
  pObjectAttrs = (PINTITEMATTRINFOSTRUCT)
                  malloc(sizeof(INTITEMATTRINFOSTRUCT));
  if (pObjectAttrs == NULL)
  {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

     call_FFST(0,
               INT_ALLOCATE_OBJECT_ATTRIBUTE,
               hCIF,
               prcStruct);
     if ((PVOID) pSaveObjectsPtr != NULL)
        SimLibFree(hSession, (PVOID) pSaveObjectsPtr, &RCStruct);

     prcStruct->ulRC = INT_ALLOCATE_OBJECT_ATTRIBUTE;
     return(INT_ALLOCATE_OBJECT_ATTRIBUTE);
  }

  if (ulNumObjects > 1)
    fSubDoc = TRUE;

/*------------------------------------------------------------------------*/
//      1.  Query the object to get its content class
//      2.  Open the object to get its file name
//      3.  Export the item to the CIF
//      4.  Close the object
/*------------------------------------------------------------------------*/

  pObjectAttrs->aAttributes[0].fAttrSys = TRUE;
  pObjectAttrs->aAttributes[0].usAttrID = 6;
  for (ulIndex = 0; ulIndex < ulNumObjects; ulIndex++)
  {
     ulRC =  SimLibQueryObject(hSession,
                              (HOBJ)&pObjects->Obj,
                              NULL,
                              &RCStruct);
     if ( ulRC != SUCCESS )
     {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

         call_FFST(ulRC,
                   INT_QUERY_OBJECT_FAILED,
                   hCIF,
                   prcStruct);
         if ((PVOID) pSaveObjectsPtr != NULL)
           SimLibFree(hSession, (PVOID) pSaveObjectsPtr, &RCStruct);

         if ((PVOID) pObjectAttrs != NULL)
           free((PVOID) pObjectAttrs);
         *prcStruct = RCStruct;
         return(INT_QUERY_OBJECT_FAILED);
     }

     pObjectInfo = (POBJINFOSTRUCT) RCStruct.ulParam1;
     pObjectAttrs->aAttributes[0].pAttrValue =
                                 malloc(sizeof(pObjectInfo->ulObjConCls));
     memcpy(pObjectAttrs->aAttributes[0].pAttrValue,
            &pObjectInfo->ulObjConCls,
            sizeof(pObjectInfo->ulObjConCls));
     pObjectAttrs->aAttributes[0].ulLen =
                             sizeof(pObjectInfo->ulObjConCls);

     ulRC =  SimLibOpenObject(hSession,
                              (HOBJ)&pObjects->Obj,
                              SIM_ACCESS_SHARED_READ,
                              SIM_PRI_NORMAL,
                              1,
                              SIM_OPEN_DISK,
                              NULL,
                              &RCStruct);
     if ( ulRC != SUCCESS )
     {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

         call_FFST(ulRC,
                   INT_OPEN_OBJECT_FAILED,
                   hCIF,
                   prcStruct);
         if ((PVOID) pSaveObjectsPtr != NULL)
           SimLibFree(hSession, (PVOID) pSaveObjectsPtr, prcStruct);

         if ((PVOID) pObjectInfo != NULL)
           SimLibFree(hSession, (PVOID) pObjectInfo, prcStruct);

         if ((PVOID) pObjectAttrs != NULL) {
            if (pObjectAttrs->aAttributes[0].pAttrValue != NULL)
               free(pObjectAttrs->aAttributes[0].pAttrValue);
            free((PVOID) pObjectAttrs);
         }
         *prcStruct = RCStruct;
         return(INT_OPEN_OBJECT_FAILED);
     }

     hObjAcc = (HOBJACC) RCStruct.ulParam1;
     ulRC = Ip2GetObjectFileName(hSession,
                                    hObjAcc,
                                    NULL,
                                    &RCStruct);
     if ( ulRC != SUCCESS )
     {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

        call_FFST(ulRC,
                  INT_GET_OBJECT_FILENAME_FAILED,
                  hCIF,
                  prcStruct);
        if ((PVOID) pSaveObjectsPtr != NULL)
          SimLibFree(hSession, (PVOID) pSaveObjectsPtr, prcStruct);

        if ((PVOID) pObjectInfo != NULL)
          SimLibFree(hSession, (PVOID) pObjectInfo, prcStruct);

        if ((PVOID) pObjectAttrs != NULL)
           free((PVOID) pObjectAttrs);
        SimLibCloseObject(hSession,
                          hObjAcc,
                          0,
                          NULL,
                          prcStruct);
        *prcStruct = RCStruct;
        return(INT_GET_OBJECT_FILENAME_FAILED);
     }

     pszObjectFileName =  (PSZ)RCStruct.ulParam1;


//-------------------------------------------------------------------
//  I need to write code here to look for matching object file names,
//  then get the corresponding UID and pass it properly to Ip2InsExportObject
//-------------------------------------------------------------------
     ulRC = Ip2InsExportObject(hCIF,
                               fSubDoc,
                               1L,
                               pObjectAttrs,
                               pszObjectFileName,
                               prcStruct);

     if ( ulRC != SUCCESS)
     {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

        call_FFST(ulRC,
                  ulRC,
                  hCIF,
                  prcStruct);
        if ((PVOID) pSaveObjectsPtr != NULL)
          SimLibFree(hSession, (PVOID) pSaveObjectsPtr, &RCStruct);

        if ((PVOID) pObjectInfo != NULL)
          SimLibFree(hSession, (PVOID) pObjectInfo, &RCStruct);

        SimLibCloseObject(hSession,
                          hObjAcc,
                          0,
                          NULL,
                          &RCStruct);
        return(ulRC);
     }


    if ((PVOID) pszObjectFileName != NULL)
      SimLibFree(hSession, (PVOID) pszObjectFileName, prcStruct);

    ulRC =  SimLibCloseObject(hSession,
                             hObjAcc,
                             0,
                             NULL,
                             &RCStruct);

    if ( ulRC != SUCCESS )
    {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

        call_FFST(ulRC,
                  INT_CLOSE_OBJECT_FAILED,
                  hCIF,
                  prcStruct);
        if ((PVOID) pSaveObjectsPtr != NULL)
          SimLibFree(hSession, (PVOID) pSaveObjectsPtr, prcStruct);

        if ((PVOID) pObjectInfo != NULL)
          SimLibFree(hSession, (PVOID) pObjectInfo, prcStruct);

        if ((PVOID) pObjectAttrs != NULL)
           free((PVOID) pObjectAttrs);
        *prcStruct = RCStruct;
        return(INT_CLOSE_OBJECT_FAILED);
     }

    if ((PVOID) pObjectInfo != NULL)
       SimLibFree(hSession, (PVOID) pObjectInfo, prcStruct);


    pObjects++;                       // Point to next object
  } /* end for usNumObjects loop */

  if ((PVOID) pSaveObjectsPtr != NULL)
    SimLibFree(hSession, (PVOID) pSaveObjectsPtr, prcStruct);

  if ((PVOID) pObjectAttrs != NULL) {
     if (pObjectAttrs->aAttributes[0].pAttrValue != NULL)
        free(pObjectAttrs->aAttributes[0].pAttrValue);
     free((PVOID) pObjectAttrs);
  }

  prcStruct->ulRC    = ulRC;
  return(ulRC);
}

/*BEGINPROLOGUE*************************************************/
/*  Function  : setup_export_CIF_Header    Date:    May      93*/
/*  Module    : FRNOICSE.C                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                            stdio.h                          */
/*                            stdlib.h                         */
/*                Product Functions:                           */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG                                       */
/*                                                             */
/*  Input Parameters:                                          */
/*      HSESSION        hSession          session handle       */
/*      HCIF            hCIF              CIF file handle      */
/*      PITEMID         pItemID           Item ID pointer      */
/*                                                             */
/*  Output Parameters:                                         */
/*      None                              output is file       */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*         0 = SUCCESS                                         */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Process Flow:                                              */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

  USHORT _Optlink setup_export_CIF_Header(HSESSION hSession,
                                          HCIF     hCIF,
                                 PITEMID pItemID,
                                 ULONG  *pulNumAttrs,
                                 ULONG  *pulNumClasses,
                                 PRCSTRUCT prcStruct)

{
 ULONG         ulRC = 0;
 USHORT       *pusNumItems=0;
 USHORT        usIndex =0;             // loop counter
 USHORT        usItemType;
 HTOC          hTOC;
 PTOCENTRYSTRUCT pItemsPtr=NULL;
 USHORT           usNumItems;
 RCSTRUCT       RCStruct;

/*-------------------------------------------------------------*/
//  Call the routine to get this item's attributes and index
//  classes.  All index classes and attributes for each item
//  going into a CIF must be defined at the beginning of the CIF.
/*-------------------------------------------------------------*/

  ulRC = get_export_item_info(hSession,
                              hCIF,
                              pItemID,
                              pulNumAttrs,
                              pulNumClasses,
                              prcStruct);

  if ( ulRC != SUCCESS)
  {
    return(ulRC);
  }

/*-------------------------------------------------------------*/
// Get the Item Type.  If it is a folder, then gets its TOC to
//  export the folder contents.
/*-------------------------------------------------------------*/
  ulRC = SimLibGetItemType( hSession,
                            pItemID,
                            NULL,            // synchronous processing
                            &RCStruct);

  if ( ulRC != SUCCESS)
  {
    *prcStruct = RCStruct;
    return(INT_GET_ITEM_TYPE_FAILED);
  }

  usItemType = (USHORT) RCStruct.ulParam1;  // get Item Type

  if (usItemType == SIM_FOLDER)
  {
    ulRC = SimLibGetTOC( hSession,
                         pItemID,
                         SIM_ALL,
                         OIM_ALL,
                         OIM_ALL,
                         0,
                         NULL,
                         NULL,
                         NULL,
                         &RCStruct );

    if ( ulRC != SUCCESS )
    {
      *prcStruct = RCStruct;
      return(INT_GET_FOLDER_TOC_FAILED);
    }

    pItemsPtr = (PTOCENTRYSTRUCT) RCStruct.ulParam1;
    usNumItems = RCStruct.usParam;
    hTOC = (HTOC) RCStruct.ulParam2;

    // NO ONE has 40 levels of folders -- this must be an infinite loop
    if (++hCIF->ulParentsIndex > 40)
       {
           Ip2CloseTOC(hSession,
                       hTOC,
                       NULL,
                       &RCStruct);
           call_FFST(INT_INCORRECT_DATA,
                     INT_INCORRECT_DATA,
                     hCIF,
                     prcStruct);
           return(INT_INCORRECT_DATA);
       } /* endif */

    for (usIndex = 0; usIndex < usNumItems; usIndex++)
    {
       /* this is recursively calling itself! */
       ulRC = setup_export_CIF_Header(hSession,
                                      hCIF,
                                      (PITEMID) pItemsPtr->szItemID,
                                      pulNumAttrs,
                                      pulNumClasses,
                                      prcStruct);
       if (ulRC != SUCCESS)
       {
           hCIF->ulParentsIndex--;
           Ip2CloseTOC(hSession,
                       hTOC,
                       NULL,
                       &RCStruct);
           return(ulRC);
       }
       pItemsPtr++;
    } /* End the for usNumItems loop */

    hCIF->ulParentsIndex--;
    ulRC = Ip2CloseTOC(hSession,
                       hTOC,
                       NULL,
                       &RCStruct);
    if (ulRC != SUCCESS)
    {
      *prcStruct = RCStruct;
      return(INT_CLOSE_TOC_FAILED);
    }
  } /* End if type == folder */

  prcStruct->ulRC    = ulRC;
  return(ulRC);

}


/*BEGINPROLOGUE*************************************************/
/*  Function  : get_export_item_info       Date:    May      93*/
/*  Module    : FRNOICSE.C                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                            stdio.h                          */
/*                            stdlib.h                         */
/*                Product Functions:                           */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG                                       */
/*                                                             */
/*  Input Parameters:                                          */
/*      HSESSION        hSession          session handle       */
/*      PITEMID         pItemID           Item ID pointer      */
/*                                                             */
/*  Output Parameters:                                         */
/*      None                              output is file       */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Process Flow:                                              */
/*      SimLibGetItemSnapshot(OIM_USER)                        */
/*      for each attribute in ICView Attribute array           */
/*         add to PINTITEMATTRINFOSTRUCT array                 */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

  ULONG  _Optlink get_export_item_info(HSESSION hSession,
                                       HCIF     hCIF,
                                 PITEMID pItemID,
                                 ULONG   *pulAttrIndex,
                                 ULONG   *pulClassIndex,
                                 PRCSTRUCT prcStruct)

{
   ULONG                  ulTemp = 0;
   ULONG                  ulRC = 0;
   ULONG                  ulReqIndex;
   ULONG                  ulOptIndex;
   USHORT                 ulNumAttrs = 0;
   USHORT                 usIndex    = 0;            // loop counter
   ULONG                  ulIndex    = 0;
   BOOL                   fAttrFound;
   BOOL                   fClassFound;
   PCLASSINFOSTRUCT       pClassInfo=NULL;
   PICVIEWSTRUCT          pCurrentView=NULL;
   PSNAPSHOTSTRUCT        pUserSnapshot=NULL;    // snapshot of user attributes
   PATTRLISTSTRUCT        pUserAttrs=NULL;       // list of user attributes
   PCLASSATTRSTRUCT       pClassAttrs=NULL;
   PATTRINFOSTRUCT        pAttrInfo=NULL;
   RCSTRUCT               RCStruct;


/*-------------------------------------------------------------*/
// Get the item's user defines attributes to be defined at the
//  beginning of the CIF header.
/*-------------------------------------------------------------*/

   ulRC = SimLibGetItemSnapshot(hSession,
                                pItemID,
                                SIM_USER_ATTR,
                                NULL,
                                &RCStruct);   /* This only returns user
                                                 defined attributes! */
   if ( ulRC != SUCCESS )
   {
       call_FFST(ulRC,
                 INT_GET_USER_SNAPSHOT_FAILED,
                 hCIF,
                 prcStruct);
       *prcStruct = RCStruct;
       return(INT_GET_USER_SNAPSHOT_FAILED);
   }

   pUserSnapshot = (PSNAPSHOTSTRUCT) RCStruct.ulParam1;  /* get pointer
                                                         to snapshot */
   pCurrentView = pUserSnapshot->pICView;
   pUserAttrs = pUserSnapshot->pICView->pAttr; /* pointer to first IC View
                                                      attributes */
   ulNumAttrs = pUserSnapshot->pICView->usNumAttributes;

/*-------------------------------------------------------------*/
//  Check the classes that we have encountered so far.  Duplicates
//  should not be defined in the header.
/*-------------------------------------------------------------*/
   for (usIndex = 0; usIndex < pUserSnapshot->usNumViews; usIndex++)
   {
     fClassFound = FALSE;
     if (*pulClassIndex > 0)
     {
       for (ulIndex = 0;
            ulIndex < *pulClassIndex;
            ulIndex++)
       {
         if (hCIF->pClassMemoryBlock->aClasses[ulIndex].usClassID ==
             pCurrentView->usIndexClass)
           fClassFound = TRUE;
       }
     }

/*-------------------------------------------------------------*/
//  If the class was not found, get the ID, name, and attributes
//   to set up the class definition structure for export.
/*-------------------------------------------------------------*/
     if (!fClassFound)
     {
       ulRC = SimLibGetClassInfo(hSession,
                          SIM_INDEXCLASSID,
                          pCurrentView->usIndexClass,
                          NULL,
                          &RCStruct);
       if ( ulRC != SUCCESS )
       {
           call_FFST(ulRC,
                     INT_GET_USER_SNAPSHOT_FAILED,
                     hCIF,
                     prcStruct);
           *prcStruct = RCStruct;
           return(INT_GET_USER_SNAPSHOT_FAILED);
       }
       pClassInfo = (PCLASSINFOSTRUCT) RCStruct.ulParam1;
       hCIF->pClassMemoryBlock->aClasses[*pulClassIndex].usClassID =
                                      pCurrentView->usIndexClass;
       hCIF->pClassMemoryBlock->aClasses[*pulClassIndex].pszClassName =
                                      malloc(SIM_CLASS_NAME_LENGTH+1);
       strcpy(hCIF->pClassMemoryBlock->aClasses[*pulClassIndex].pszClassName,
              pClassInfo->szClassName);
       hCIF->pClassMemoryBlock->aClasses[*pulClassIndex].pszClassDesc = NULL;
       pClassAttrs = pClassInfo->pClassAttrStruct;
       hCIF->pClassMemoryBlock->aClasses[*pulClassIndex].ulNumReqAttr = 0;
       hCIF->pClassMemoryBlock->aClasses[*pulClassIndex].ulNumOptAttr = 0;
       ulReqIndex = 0;
       ulOptIndex = 0;
       for (ulIndex = 0; ulIndex < pClassInfo->usNbrAttrIds; ulIndex++)
       {
         if (ulIndex > 50)
         {
           call_FFST(ulRC,
                     INT_CLASS_ATTRS_LIMIT_EXCEEDED,
                     hCIF,
                     prcStruct);
           return(INT_CLASS_ATTRS_LIMIT_EXCEEDED);
         }
         if (pClassAttrs->fAttrRequiredField)
         {
           hCIF->pClassMemoryBlock->aClasses[*pulClassIndex].ausReqAttr[ulReqIndex] =
                                                      pClassAttrs->usAttrId;
           hCIF->pClassMemoryBlock->aClasses[*pulClassIndex].ulNumReqAttr++;
           ulReqIndex++;
         }
         else
         {
           hCIF->pClassMemoryBlock->aClasses[*pulClassIndex].ausOptAttr[ulOptIndex] =
                                                      pClassAttrs->usAttrId;
           hCIF->pClassMemoryBlock->aClasses[*pulClassIndex].ulNumOptAttr++;
           ulOptIndex++;
         }
         pClassAttrs++;
       }
       *pulClassIndex = *(pulClassIndex)+1;
     } /* End if !fClassFound */

     pCurrentView = pCurrentView->pNextView;
   }


//-----------------------------------------------------------------------
//  For each USER attribute returned from the snapshot,
//     1.  Fill in the PINTUSERATTRINFOSTRUCT array for Item Export
//     2.  Free the snapshot area for this attribute
//-----------------------------------------------------------------------
   for (usIndex = 0; usIndex < ulNumAttrs; usIndex++)
   {
      fAttrFound = FALSE;
      if (*pulAttrIndex > 0)
      {
         for (ulIndex = 0;
            ulIndex < *pulAttrIndex;
            ulIndex++)
            {
            if (hCIF->pUserAttrBlock->aAttributes[ulIndex].usAttrID ==
                pUserAttrs[usIndex].usAttrId)
                fAttrFound = TRUE;
            }
      }

//-----------------------------------------------------------------------
//  If the attribute was not encountered already, then convert its type
//  from VisualInfo to CIF equivalent.
//-----------------------------------------------------------------------
     if (!fAttrFound)
     {
       hCIF->pUserAttrBlock->aAttributes[*pulAttrIndex].usAttrID  =
                                    pUserAttrs[usIndex].usAttrId;
       switch(pUserAttrs[usIndex].usAttrType)
       {
         case    SIM_ATTR_TIMESTAMP:
         case    SIM_ATTR_DATE:
                 hCIF->pUserAttrBlock->aAttributes[*pulAttrIndex].usAttrType =
                                                        USER_ATTR_TIMESTAMP;
                 break;

         case    SIM_ATTR_TIME:
                 hCIF->pUserAttrBlock->aAttributes[*pulAttrIndex].usAttrType =
                                                        USER_ATTR_TIME;
                 break;

         case    SIM_ATTR_LONG:
         case    SIM_ATTR_SHORT:
                 hCIF->pUserAttrBlock->aAttributes[*pulAttrIndex].usAttrType =
                                                        USER_ATTR_INTEGER;
                 break;

         case    SIM_ATTR_DECIMAL:
                 hCIF->pUserAttrBlock->aAttributes[*pulAttrIndex].usAttrType =
                                                        USER_ATTR_DECIMAL;
                 break;

         case    SIM_ATTR_VSTRING:
                 hCIF->pUserAttrBlock->aAttributes[*pulAttrIndex].usAttrType =
                                                        USER_ATTR_STRING;
                 break;

         case    SIM_ATTR_FSTRING:
                 hCIF->pUserAttrBlock->aAttributes[*pulAttrIndex].usAttrType =
                                                        USER_ATTR_STRING;
                 break;

         case    SIM_ATTR_FLOAT:
                 hCIF->pUserAttrBlock->aAttributes[*pulAttrIndex].usAttrType =
                                                        USER_ATTR_NUMBER;
                 break;

         default:
                 hCIF->pUserAttrBlock->aAttributes[*pulAttrIndex].usAttrType =
                                                        USER_ATTR_UNSPEC;
                 break;

       }
//-----------------------------------------------------------------------
//     Get the attribute name from its ID.
//-----------------------------------------------------------------------
       ulRC = SimLibGetAttrInfo(hSession,
                                pUserAttrs[usIndex].usAttrId,
                                NULL,
                                &RCStruct);
       if (ulRC != SUCCESS)
       {
         call_FFST(ulRC,
                   INT_GET_ATTR_INFO_FAILED,
                   hCIF,
                   prcStruct);
         *prcStruct = RCStruct;
         return(INT_GET_ATTR_INFO_FAILED);
       }

       pAttrInfo = (PATTRINFOSTRUCT) RCStruct.ulParam1;
       ulTemp =        strlen((char *)pAttrInfo->szAttributeName);
       hCIF->pUserAttrBlock->aAttributes[*pulAttrIndex].pszAttrName = malloc(
                       SIM_ATTR_NAME_LENGTH+1);
       if (hCIF->pUserAttrBlock->aAttributes[*pulAttrIndex].pszAttrName == NULL)
       {
         call_FFST(0,
                   INT_ALLOCATE_ATTRIBUTE_MEMORY,
                   hCIF,
                   prcStruct);
         SimLibFree(hSession, pUserSnapshot, &RCStruct);
         return(INT_ALLOCATE_ATTRIBUTE_MEMORY);
       }

       strcpy(hCIF->pUserAttrBlock->aAttributes[*pulAttrIndex].pszAttrName,
              (char *)pAttrInfo->szAttributeName);
       hCIF->pUserAttrBlock->aAttributes[*pulAttrIndex].pszAttrDesc = NULL;

       if ((PVOID) pAttrInfo != NULL)
         SimLibFree(hSession, (PVOID) pAttrInfo, prcStruct);

       *pulAttrIndex = *(pulAttrIndex)+1;
     } /* end if !fAttrFound */
   }  /* end for ulNumAttrs loop */


   SimLibFree(hSession, (PVOID) pUserSnapshot, prcStruct);
   prcStruct->ulRC    = ulRC;
   return(ulRC);
}


/*BEGINPROLOGUE*************************************************/
/*  Function  : call_FFST                  Date:    May      93*/
/*  Module    : FRNOICSE.C                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                            stdio.h                          */
/*                            stdlib.h                         */
/*                Product Functions:                           */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG                                       */
/*                                                             */
/*  Input Parameters:                                          */
/*                                                             */
/*  Output Parameters:                                         */
/*      None                              output is file       */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Process Flow:                                              */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

  ULONG  _Optlink call_FFST(ULONG ulAPI_RC,
                            ULONG ulFailRC,
                            HCIF  hCIF,
                            PRCSTRUCT prcStruct)
{
ULONG    ulRC=0;
SHORT    sResult = 0;

     prcStruct->ulExtRC = (USHORT) ulAPI_RC;
     prcStruct->ulRC    = (USHORT) ulFailRC;
     ulRC = ulFailRC;                   // Return this API's rc.
#ifdef  INTRPROD
     UtlEpwStrt("FRNIC", &hCIF->ulLogType);
     UtlEpwMsg(ulFailRC,
               LOG_ERR,
               "FRNIC",
               __FILE__,
               __LINE__,
               sResult,
               NULL);
     UtlEpwStop();
#endif
     return(ulRC);
}
