/*BEGINPROLOGUE**************************************************************/
/*                                                                          */
/* MODULE: FRNOICSI.C                   VisualInfo                          */
/*                                                                          */
/*                                                                          */
/* 5697-250, 5621-326, 5655-036, 5622-213, 5655-071, 5655-072               */
/* (C) Copyright IBM Corp. 1993, 1994. All Rights Reserved.                 */
/*                                                                          */
/* DERIVATIVE RIGHTS:                                                       */
/* ------------------                                                       */
/* This program is provided for the customer's use and the customer is      */
/* granted permission to copy this program to the extent reasonably         */
/* required for such use.  All title, ownership, and rights to this         */
/* program and any copies remain with IBM, irrespective of the ownership    */
/* of the media on which the program resides.  The customer is permitted    */
/* to create derivative works to this program.  However, all copies of      */
/* the program and its derivative works must contain the IBM copyright      */
/* notice.  The customer understands and agrees that this program in and    */
/* of itself is not to be sold or distributed.  The customer is free to     */
/* sell, distribute, and commercially exploit any derivative works          */
/* created from this program.                                               */
/*                                                                          */
/*                                                                          */
/* DISCLAIMER OF WARRANTIES:                                                */
/* -------------------------                                                */
/* The following [enclosed] code is sample code created by IBM              */
/* Corporation.  This sample code is not part of any standard IBM product   */
/* and is provided to you solely for the purpose of assisting you in the    */
/* development of your applications.  The code is provided "AS IS",         */
/* without warranty of any kind.  IBM shall not be liable for any damages   */
/* arising out of your use of the sample code, even if they have been       */
/* advised of the possibility of such damages.                              */
/*                                                                          */
/*                                                                          */
/* Programmer: Mark S. Raine                                                */
/*                                                                          */
/* Date: May      1993                                                      */
/*                                                                          */
/* Status: Version 1 Release 1 Modification 0                               */
/*                                                                          */
/* Description: FRNOICSI.C - this module contains a                         */
/*    sample import function using Interchange APIs                         */
/*                                                                          */
/* Dependencies:                                                            */
/* Restrictions:                                                            */
/*                                                                          */
/* Entry Points:                                                            */
/*                                                                          */
/*                                                                          */
/* Change History:                                                          */
/*                                                                          */
/*                                                                          */
/* Notes:                                                                   */
/*                                                                          */
/* Assumptions for EXPORT:                                                  */
/*                                                                          */
/*   Pass NULL for pAsyncCtl                                                */
/*                                                                          */
/*   Only Folders and Documents are handled, not workbaskets                */
/*                                               workflows                  */
/*                                               annotations                */
/*                                               events                     */
/*                                                                          */
/*   Since Notes are passed to Ip2InsExportItem for a document              */
/*      notes are not retrieved when issuing the affiliated TOC for         */
/*      the same document and will not included through Ip2InsExportObject  */
/*                                                                          */
/*   pICView returned from snapshot API is assumed to be the only one       */
/*      and is the base view (or the lowest level view for this user).      */
/*                                                                          */
/*   Object Description is always set to " ". I could use chRepType.        */
/*                                                                          */
/*   Note's content class is NULL                                           */
/*   Note's userid will be USERID                                           */
/*                                                                          */
/*   An object is considered to be part of a multipart document if the      */
/*     document has more than one Affiliated Object.  What about the notes  */
/*     that were not queried?                                               */
/*                                                                          */
/*   See defaults used in SimLibOpenObject.                                 */
/*                                                                          */
/*   TOC changes are not queried during this export sample.                 */
/*                                                                          */
/*   Limitation of 4096 Items within the Item ID passed.                    */
/*ENDPROLOGUE****************************************************************/


#define INCL_DOSNLS
#define INCL_WINCOUNTRY   /* Include Code Page functions */
#define INCL_WINERRORS
#include   <stdio.h>
#include   <stdlib.h>
#include   <string.h>
#include   <ctype.h>
#include   <os2.h>
#include   <fcntl.h>
#include   <sys\types.h>
#include   <sys\stat.h>
#include   <io.h>


#define    FRN_INCL_FO           // include folder manager includes
#define    FRN_INCL_FI           // include folder manager includes
#include   <FRNP.H>             // Include global public structures
typedef    ULONG    HMTX;

#ifdef  INTRPROD
#include "UTOFFST.H"          // Include FFST prototypes
#endif

#include "FRNOICGD.H"
#include "FRNOICFP.H"
#include "FRNOICSP.H"   // Sample code internal prototypes
#include "FRNOICXT.H"   // Sample code internal prototypes


/***************************************************************/
/*   BEGIN GLOBAL VARIABLE DECLARATION SECTION                 */
/***************************************************************/
#ifdef  INTRPROD
  ULONG                  ulLogType = LOG_ERR;
#endif

  USHORT                   ausAttrType[] = {
                                            SIM_ATTR_UNDEFINED,
                                            SIM_ATTR_UNDEFINED,
                                            SIM_ATTR_TIMESTAMP,
                                            SIM_ATTR_TIME,
                                            SIM_ATTR_LONG,
                                            SIM_ATTR_DECIMAL,
                                            SIM_ATTR_UNDEFINED,
                                            SIM_ATTR_UNDEFINED,
                                            SIM_ATTR_VSTRING,
                                            SIM_ATTR_FSTRING,
                                            SIM_ATTR_FSTRING,
                                            SIM_ATTR_FSTRING
                                                     };
/* FUNCTION PROTOTYPES */
void FreeStuff(HCIF hCIF);


/*BEGINPROLOGUE*************************************************/
/*  Function  : Ip2Import                    Date:    May      93*/
/*  Module    : FRNOICSI.C                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                            stdio.h                          */
/*                            stdlib.h                         */
/*                Product Functions:                           */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG                                       */
/*                                                             */
/*  Input Parameters:                                          */
/*      HCIF            hCIF              CIF File handle      */
/*                                                             */
/*  Output Parameters:                                         */
/*      None                              output is file       */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Process Flow:                                              */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

  ULONG  _Optlink Ip2Import(HSESSION hSession,
                            PSZ pszCIFFileName,
                            BOOL fCreateFlag,
                            PRCSTRUCT prcStruct)

{
  ULONG                  ulRC = 0;

/*-----------------------------------------------------------*/
/*  If the flag to allow dynamic creates for index class or  */
/*  attributes is true, then Ip2ImportCIUHeader will be      */
/*  called first to create any index classes or attributes   */
/*  that do not exist in the target system.  If anything is  */
/*  created, then the application must log off, then log     */
/*  back on for them to be recognized by Folder Manager      */
/*  for other processing withing the interchange import.     */
/*-----------------------------------------------------------*/

  if (fCreateFlag)
    ulRC = Ip2ImportCIFHeader(hSession,
                     pszCIFFileName,
                     fCreateFlag,
                     prcStruct);

  if (ulRC == SUCCESS)
    ulRC = Ip2ImportCIUs(hSession,
                         pszCIFFileName,
                         prcStruct);

  return(ulRC);
}
/*BEGINPROLOGUE*************************************************/
/*  Function  : Ip2ImportCIFHeader           Date:    May      93*/
/*  Module    : FRNOICSI.C                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                            stdio.h                          */
/*                            stdlib.h                         */
/*                Product Functions:                           */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG                                       */
/*                                                             */
/*  Input Parameters:                                          */
/*      HCIF            hCIF              CIF File handle      */
/*                                                             */
/*  Output Parameters:                                         */
/*      None                              output is file       */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Process Flow:                                              */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

  ULONG  _Optlink Ip2ImportCIFHeader(HSESSION hSession,
                                   PSZ pszCIFFileName,
                                   BOOL fCreateFlag,
                                   PRCSTRUCT prcStruct)

{
  ULONG                  ulRC = 0;
  HCIF                   hCIF = 0L;
  PINTCIFHEADER          pCIFHeader;
  PINTUSERATTRINFOSTRUCT pCIFAttr;
  PINTINDCLASSINFOSTRUCT pCIFICls;
  CHAR                   szLangDefault[] = "ENU";
  RCSTRUCT               RCStruct;
  BOOL                   fAttrCreated = FALSE;
  BOOL                   fCIFOpen;



/*------------------------------------------------------------------------*/
/*  Call the interchange API to open the CIF file for import.             */
/*------------------------------------------------------------------------*/

  fCIFOpen = TRUE;
  ulRC = Ip2OpenImportCIF(pszCIFFileName,
                          prcStruct);
  if ( ulRC != SUCCESS)
  {
      call_FFST(ulRC,
                ulRC,
                NULL,
                prcStruct);
      fCIFOpen = FALSE;
  }

  if (ulRC == SUCCESS)
  {
    hCIF = (HCIF) prcStruct->ulParam1;
    hCIF->pNewIDs = NULL;
    hCIF->ulNumNewItems = 0;
    prcStruct->ulParam2 = hCIF->ulNumNewItems;
    prcStruct->ulParam1 = (ULONG) hCIF->pNewIDs;

/*------------------------------------------------------------------------*/
/*  Get the CIF Header information.                                       */
/*------------------------------------------------------------------------*/

    ulRC = Ip2ReadImportHeader( hCIF,
                                prcStruct);

    if ( ulRC != SUCCESS)
    {
        call_FFST(ulRC,
                  ulRC,
                  hCIF,
                  prcStruct);
    }
  }

  if (ulRC == SUCCESS)
  {
    pCIFHeader = (PINTCIFHEADER) prcStruct->ulParam1;
    pCIFAttr   = (PINTUSERATTRINFOSTRUCT) pCIFHeader->Header.pCIFAttr;
    pCIFICls   = (PINTINDCLASSINFOSTRUCT) pCIFHeader->Header.pCIFICls;
    if (pCIFHeader->Header.pszLang != NULL)
      if (strlen(pCIFHeader->Header.pszLang) == 0)
        pCIFHeader->Header.pszLang = NULL;

    if ((pCIFAttr != NULL) &&
        (pCIFHeader->Header.ulNumAttr > 0))
    {
    /*------------------------------------------------------------------------*/
    /*  Check to see if the user attributes are in the system.  If they are   */
    /*  not, create them based on certain default assumptions.                */
    /*------------------------------------------------------------------------*/

      ulRC = validate_import_attributes(hSession,
                                 hCIF,
                                 fCreateFlag,
                                 pCIFHeader,
                                 pCIFAttr,
                                 prcStruct);

    }
  } /* End if ulRC == SUCCESS */

  if (ulRC == INT_ATTR_OR_CLASS_CREATED)
  {
    fAttrCreated = TRUE;
    ulRC = SUCCESS;
  }
  if (ulRC == SUCCESS)
  {
    if ((pCIFICls != NULL) &&
        (pCIFHeader->Header.ulNumClass > 0))
    {

    /*------------------------------------------------------------------------*/
    /*  Check to see if the user index classes are in the system.  If they    */
    /*  are not, create them based on certain default assumptions.            */
    /*------------------------------------------------------------------------*/

      ulRC = validate_import_classes(hSession,
                              hCIF,
                              fCreateFlag,
                              pCIFHeader,
                              pCIFICls,
                              prcStruct);
      if ((ulRC == SUCCESS) && (fAttrCreated))
        ulRC = INT_ATTR_OR_CLASS_CREATED;
    }
  } /* End if ulRC == SUCCESS */

  if (fCIFOpen)
    if (ulRC == SUCCESS)
      ulRC = Ip2CloseImportCIF( hCIF, prcStruct);
    else
      Ip2CloseImportCIF( hCIF, &RCStruct);

  FreeStuff(hCIF);

  if (pCIFHeader != NULL)
     SimLibFree(hSession, (PVOID) pCIFHeader, &RCStruct);

  if (pCIFAttr != NULL)
     SimLibFree(hSession, (PVOID) pCIFAttr, &RCStruct);

  if ( pCIFICls != NULL)
     SimLibFree(hSession, (PVOID) pCIFICls, &RCStruct);

  return(ulRC);
}

/*BEGINPROLOGUE*************************************************/
/*  Function  : Ip2ImportCIUs              Date:    May      93*/
/*  Module    : FRNOICSI.C                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                            stdio.h                          */
/*                            stdlib.h                         */
/*                Product Functions:                           */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG                                       */
/*                                                             */
/*  Input Parameters:                                          */
/*      HCIF            hCIF              CIF File handle      */
/*                                                             */
/*  Output Parameters:                                         */
/*      None                              output is file       */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Process Flow:                                              */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

  ULONG  _Optlink Ip2ImportCIUs(HSESSION hSession,
                                PSZ pszCIFFileName,
                                PRCSTRUCT prcStruct)

{
  ULONG                  ulRC = 0;
  HCIF                   hCIF = 0L;
  BOOL                   fMoreCIUs;
  PINTCIFHEADER          pCIFHeader;
  PINTUSERATTRINFOSTRUCT pCIFAttr;
  PINTINDCLASSINFOSTRUCT pCIFICls;
  PINTCIUHEADER          pCIUHeader;
  PINTCIUDATALIST        pCIUData;
  CHAR                   szLangDefault[] = "ENU";
  ULONG                  ulTemp;
  RCSTRUCT               RCStruct;
  BOOL                   fCIFOpen;


/*------------------------------------------------------------------------*/
/*  Call the interchange API to open the CIF file for import.             */
/*------------------------------------------------------------------------*/

  fCIFOpen = TRUE;
  ulRC = Ip2OpenImportCIF(pszCIFFileName,
                          prcStruct);
  if ( ulRC != SUCCESS)
  {
      call_FFST(ulRC,
                ulRC,
                hCIF,
                prcStruct);
      fCIFOpen = FALSE;
  }

  if (ulRC == SUCCESS)
  {
    hCIF = (HCIF) prcStruct->ulParam1;
    hCIF->pNewIDs = NULL;
    hCIF->ulNumNewItems = 0;
    prcStruct->ulParam2 = hCIF->ulNumNewItems;
    prcStruct->ulParam1 = (ULONG) hCIF->pNewIDs;

/*------------------------------------------------------------------------*/
/*  Get the CIF Header information.                                       */
/*------------------------------------------------------------------------*/

    ulRC = Ip2ReadImportHeader( hCIF,
                                prcStruct);

    if ( ulRC != SUCCESS)
    {
        call_FFST(ulRC,
                  ulRC,
                  hCIF,
                  prcStruct);
    }
  }

  if (ulRC == SUCCESS)
  {
    pCIFHeader = (PINTCIFHEADER) prcStruct->ulParam1;
    pCIFAttr   = (PINTUSERATTRINFOSTRUCT) pCIFHeader->Header.pCIFAttr;
    pCIFICls   = (PINTINDCLASSINFOSTRUCT) pCIFHeader->Header.pCIFICls;
    if (pCIFHeader->Header.pszLang != NULL)
      if (strlen(pCIFHeader->Header.pszLang) == 0)
        pCIFHeader->Header.pszLang = NULL;
    ulTemp = pCIFHeader->Header.ulCCSID / 4096;
    hCIF->ulCdPge = pCIFHeader->Header.ulCCSID - (ulTemp*4096);

    if ((pCIFAttr != NULL) &&
        (pCIFHeader->Header.ulNumAttr > 0))
    {
    /*------------------------------------------------------------------------*/
    /*  Check to see if the user attributes are in the system.  If they are   */
    /*  not, create them based on certain default assumptions.                */
    /*------------------------------------------------------------------------*/

      ulRC = validate_import_attributes(hSession,
                                 hCIF,
                                 FALSE,
                                 pCIFHeader,
                                 pCIFAttr,
                                 prcStruct);

    }
  } /* End if ulRC == SUCCESS */

  if (ulRC == SUCCESS)
  {
    if ((pCIFICls != NULL) &&
        (pCIFHeader->Header.ulNumClass > 0))
    {

    /*------------------------------------------------------------------------*/
    /*  Check to see if the user index classes are in the system.  If they    */
    /*  are not, create them based on certain default assumptions.            */
    /*------------------------------------------------------------------------*/

      ulRC = validate_import_classes(hSession,
                              hCIF,
                              FALSE,
                              pCIFHeader,
                              pCIFICls,
                              prcStruct);
    }
  } /* End if ulRC == SUCCESS */

  if (ulRC == SUCCESS)
  {
/*------------------------------------------------------------------------*/
/*  Allocate the area that we will use to store the return information    */
/*------------------------------------------------------------------------*/

    hCIF->pNewItems = (PINTIMPORTITEMSTRUCT) malloc(4096 * sizeof(INTIMPORTITEMSTRUCT));
    hCIF->pNewIDs = hCIF->pNewItems;
    if (hCIF->pNewItems == NULL)
    {
     call_FFST(ulRC,
               INT_ALLOCATE_NEWIDS_FAILED,
               hCIF,
               prcStruct);
     ulRC = INT_ALLOCATE_NEWIDS_FAILED;
    }

    fMoreCIUs = TRUE;
  }

  if (ulRC == SUCCESS)
  {
  /*------------------------------------------------------------------------*/
  /* While there are CIUs within the CIF to process,                        */
  /*       1.  Call the interchange API to read the CIU Header              */
  /*       2.  Call the internal routine to process this CIU                */
  /*------------------------------------------------------------------------*/

    while ((fMoreCIUs) && (ulRC == SUCCESS))
    {
      ulRC = Ip2ReadImportCIU( hCIF, prcStruct);
      if (ulRC != SUCCESS)
      {
        call_FFST(ulRC,
                  ulRC,
                  hCIF,
                  prcStruct);
        if ((PVOID) hCIF->pNewIDs != NULL)
          SimLibFree(hSession, (PVOID) hCIF->pNewIDs, &RCStruct);
      }

      if (ulRC == SUCCESS)
      {
        pCIUHeader = (PINTCIUHEADER)prcStruct->ulParam1;
        pCIUData = pCIUHeader->pCIUData;

        ulRC = process_CIF_for_import(hSession,
                           hCIF,
                           pCIFHeader,
                           pCIUData,
                           prcStruct);
        if (ulRC == SUCCESS)
          prcStruct->ulParam1 = (ULONG) hCIF->pNewIDs;
      }

      fMoreCIUs = pCIUHeader->fMoreCIU;
    } /* End While */
  }

  if (fCIFOpen)
  {
    prcStruct->ulParam1 = (ULONG) hCIF->pNewIDs;
    prcStruct->ulParam2 = hCIF->ulNumNewItems;
    if (ulRC == SUCCESS)
    {
      ulRC = Ip2CloseImportCIF( hCIF, prcStruct);
    }
    else
      Ip2CloseImportCIF( hCIF, &RCStruct);
  }
  else
  {
    prcStruct->ulParam1 = 0;
    prcStruct->ulParam2 = 0;
  }

  FreeStuff(hCIF);

  if (pCIFHeader != NULL)
     SimLibFree(hSession, (PVOID) pCIFHeader, &RCStruct);

  if (pCIFAttr != NULL)
     SimLibFree(hSession, (PVOID) pCIFAttr, &RCStruct);

  if ( pCIFICls != NULL)
     SimLibFree(hSession, (PVOID) pCIFICls, &RCStruct);


  return(ulRC);

} /* END */


/*BEGINPROLOGUE*************************************************/
/*  Function  : validate_import_attributes    Date: May      93*/
/*  Module    : FRNOICSI.C                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                            stdio.h                          */
/*                            stdlib.h                         */
/*                Product Functions:                           */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG                                       */
/*                                                             */
/*  Input Parameters:                                          */
/*                                                             */
/*  Output Parameters:                                         */
/*      None                                                   */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*         0 = SUCCESS                                         */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Process Flow:                                              */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

  ULONG  _Optlink validate_import_attributes(HSESSION hSession,
                                      HCIF hCIF,
                                      BOOL fCreateFlag,
                                      PINTCIFHEADER pCIFHeader,
                                      PINTUSERATTRINFOSTRUCT pCIFAttr,
                                      PRCSTRUCT prcStruct)


{
   ULONG                   ulRC = 0;
   ULONG                   ulIndex;                   // loop counter
   ULONG                   ulNameIndex;               // loop counter
  PNAMESTRUCT              pNames;
  PNAMESTRUCT              pSaveNamesPtr;
  ULONG                    ulNumNames;
  BOOL                     fFoundAttr;
  BOOL                     fAttrMap;
  BOOL                     fAttrCreated;
  BOOL                     fBypassAttrTypeCheck;
  PATTRINFOSTRUCT          pAttrInfo;
  ATTRINFOSTRUCT           NewAttrInfo;
  CHAR                     szTempAttrName[SIM_ATTR_NAME_LENGTH+1];
  RCSTRUCT                 RCStruct;

/*------------------------------------------------------------------------*/
/*  Get a list of all the attributes in the current system.               */
/*------------------------------------------------------------------------*/

  fAttrCreated = FALSE;
  ulRC = Ip2ListAttrs(hSession,
                      NULL,
                      &RCStruct);
  if ( ulRC != SUCCESS)
  {
      call_FFST(ulRC,
                INT_GET_ATTR_INFO_FAILED,
                hCIF,
                prcStruct);
      *prcStruct = RCStruct;
      return(INT_GET_ATTR_INFO_FAILED);
  }

  pNames = (PNAMESTRUCT) RCStruct.ulParam1;
  pSaveNamesPtr = pNames;
  ulNumNames = RCStruct.ulParam2;
  hCIF->usNewAttrIndex = 0;
  if (pCIFHeader->Header.ulNumAttr > 4096)
    return(INT_TOO_MANY_ATTRIBUTES);
  hCIF->pNewAttrArray = malloc (
           pCIFHeader->Header.ulNumAttr * sizeof(NEWATTRARRAY));
  if ((pCIFHeader->Header.ulNumAttr > 0) && (hCIF->pNewAttrArray == NULL))
  {
     call_FFST(ulRC,
               INT_ALLOCATE_ATTRIBUTE_MEMORY,
               hCIF,
               prcStruct);
     return(INT_ALLOCATE_ATTRIBUTE_MEMORY);
  }
  hCIF->pSaveNewAttrPtr = hCIF->pNewAttrArray;

//----------------------------------------------------------------------
//  For each attribute in the CIF Header,
//    1.  Verify that its name exists in the system
//    2.  Verify that the type matches the new system
//----------------------------------------------------------------------
  for ( ulIndex = 0; ulIndex < pCIFHeader->Header.ulNumAttr; ulIndex++)
  {
//    1.  Verify that its name exists in the system
    fAttrMap = FALSE;
    fFoundAttr = FALSE;
    pNames = pSaveNamesPtr;
    fBypassAttrTypeCheck = FALSE;

//  Call Exit to map attributes to new system
    Ip2ImportAttrExit(hSession,
                      pCIFAttr->aAttributes[ulIndex].pszAttrName,
                      pCIFHeader,
                      szTempAttrName,
                      &fAttrMap,
                      &fBypassAttrTypeCheck);
    if (!fAttrMap)
     strcpy(szTempAttrName, pCIFAttr->aAttributes[ulIndex].pszAttrName);

    for ( ulNameIndex = 0; ulNameIndex < ulNumNames; ulNameIndex++)
    {
      if (strcmp(szTempAttrName, pNames->szName) == 0)
         {
         fFoundAttr = TRUE;
         break;
         }
      pNames++;
    }

   if ((fAttrMap) && (!fFoundAttr))
   {
     call_FFST(ulRC,
               INT_INVALID_ATTRIBUTE,
               hCIF,
               prcStruct);
     if ((PVOID) pSaveNamesPtr != NULL)
     {
       ulRC = SimLibFree(hSession, (PVOID) pSaveNamesPtr, &RCStruct);
       if ( ulRC != SUCCESS)
         call_FFST(ulRC,
                   INT_MEMORY_FREEUP_FAILED,
                   hCIF,
                   prcStruct);
     }
     ulRC = INT_INVALID_ATTRIBUTE;
     return(ulRC);
   }

/*------------------------------------------------------------------------*/
/*  Save the ID from the CIF in the array.                                */
/*------------------------------------------------------------------------*/


    hCIF->pNewAttrArray->usOldID =
          pCIFAttr->aAttributes[ulIndex].usAttrID;
    hCIF->pNewAttrArray->usAttrType =
          pCIFAttr->aAttributes[ulIndex].usAttrType;

/*------------------------------------------------------------------------*/
/*  If the attribute was not found in the system, then we will create it. */
/*------------------------------------------------------------------------*/

    if (!fFoundAttr)
    {
      if (!fCreateFlag)
      {
        call_FFST(ulRC,
                  INT_INVALID_ATTRIBUTE,
                  hCIF,
                  prcStruct);
        if ((PVOID) pSaveNamesPtr != NULL)
        {
          ulRC = SimLibFree(hSession, (PVOID) pSaveNamesPtr, &RCStruct);
          if ( ulRC != SUCCESS)
            call_FFST(ulRC,
                      INT_MEMORY_FREEUP_FAILED,
                      hCIF,
                      prcStruct);
        }
        *prcStruct = RCStruct;
        ulRC = INT_INVALID_ATTRIBUTE;
        return(ulRC);
      }
/*------------------------------------------------------------------------*/
/*  NewAttrInfo is the structure that contains the info required for      */
/*  Ip2CreateAttr.                                                        */
/*------------------------------------------------------------------------*/
      NewAttrInfo.ulStruct = sizeof(NewAttrInfo);
      strcpy(NewAttrInfo.szAttributeName, szTempAttrName);
      if (pCIFHeader->Header.pszLang == NULL)
        strcpy(NewAttrInfo.achLanguageCode, "ENU");
      else
        strcpy(NewAttrInfo.achLanguageCode,
               pCIFHeader->Header.pszLang);
      NewAttrInfo.lMin = 0;
      NewAttrInfo.lMax = 80;
      NewAttrInfo.fTypeFlags = SIM_ATTR_NONE;
/*------------------------------------------------------------------------*/
/*  Convert the CIF attribute type to VisualInfo type.                      */
/*------------------------------------------------------------------------*/
      switch(pCIFAttr->aAttributes[ulIndex].usAttrType)
      {
         case  USER_ATTR_UNSPEC:
               NewAttrInfo.usAttrType = SIM_ATTR_UNDEFINED;
               NewAttrInfo.lMax = 0;
               break;

         case  USER_ATTR_TIMESTAMP:
               NewAttrInfo.usAttrType = SIM_ATTR_TIMESTAMP;
               NewAttrInfo.lMax = 0;
               break;

         case  USER_ATTR_TIME:
               NewAttrInfo.usAttrType = SIM_ATTR_TIME;
               NewAttrInfo.lMax = 0;
               break;

         case  USER_ATTR_INTEGER:
               NewAttrInfo.usAttrType = SIM_ATTR_LONG;
               NewAttrInfo.lMax = 0x7FFFFFFF;
               break;

         case  USER_ATTR_DECIMAL:
               NewAttrInfo.usAttrType = SIM_ATTR_DECIMAL;
               NewAttrInfo.lMin = 4;
               NewAttrInfo.lMax = 15;
               break;

         case  USER_ATTR_STRING:
               NewAttrInfo.usAttrType = SIM_ATTR_VSTRING;
               break;

         case  USER_ATTR_ALPHA:
               NewAttrInfo.usAttrType = SIM_ATTR_FSTRING;
               NewAttrInfo.fTypeFlags = SIM_ATTR_ALPHA;
               break;

         case  USER_ATTR_DIGITS:
               NewAttrInfo.usAttrType = SIM_ATTR_FSTRING;
               NewAttrInfo.fTypeFlags = SIM_ATTR_NUMERIC;
               break;

         case  USER_ATTR_NUMBER:
               NewAttrInfo.usAttrType = SIM_ATTR_FLOAT;
               NewAttrInfo.lMax = 0;
               break;

         default:
               NewAttrInfo.usAttrType = SIM_ATTR_UNDEFINED;
               NewAttrInfo.lMax = 0;
               break;

      }

      NewAttrInfo.fUseBidirectional = FALSE;
      NewAttrInfo.usHorizontalOrientation = SIM_ATTR_LEFT_TO_RIGHT;
      NewAttrInfo.usVerticalOrientation = SIM_ATTR_TOP_TO_BOTTOM;
      NewAttrInfo.usMode = SIM_ATTR_VISUAL;
      NewAttrInfo.fShaping = FALSE;
      NewAttrInfo.fSymmetricSwapping = FALSE;
      NewAttrInfo.usNumericSelectionDefault = SIM_ATTR_HINDI;

/*------------------------------------------------------------------------*/
/*    Create the attribute.                                               */
/*------------------------------------------------------------------------*/
      ulRC = Ip2CreateAttr(hSession,
                           &NewAttrInfo,
                           NULL,
                           &RCStruct);
      if (ulRC != SUCCESS)
      {
        call_FFST(ulRC,
                  INT_INVALID_ATTRIBUTE,
                  hCIF,
                  prcStruct);
        if ((PVOID) pSaveNamesPtr != NULL)
          SimLibFree(hSession, (PVOID) pSaveNamesPtr, prcStruct);
        *prcStruct = RCStruct;
        return(INT_INVALID_ATTRIBUTE);
      }
      fAttrCreated = TRUE;
/*------------------------------------------------------------------------*/
/* Save the new ID of the attribute we just created.                      */
/*------------------------------------------------------------------------*/

      hCIF->pNewAttrArray->usNewID = RCStruct.ulParam1;
      hCIF->pNewAttrArray++;
      hCIF->usNewAttrIndex++;
    }
    else /* Attribute already exists */
    {


/*------------------------------------------------------------------------*/
/* Save the ID of the attribute already in the system.                    */
/*------------------------------------------------------------------------*/

      hCIF->pNewAttrArray->usNewID = pNames->usID;
      hCIF->pNewAttrArray++;
      hCIF->usNewAttrIndex++;

      if (!fBypassAttrTypeCheck)
      {
/*------------------------------------------------------------------------*/
/*    Verify that the type of the existing attribute matches the type     */
/*    in the CIF.                                                         */
/*------------------------------------------------------------------------*/

        ulRC = SimLibGetAttrInfo(hSession,
                                 pNames->usID,
                                 NULL,
                                 &RCStruct);
        if ( ulRC != SUCCESS)

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

        {
            call_FFST(ulRC,
                      INT_GET_ATTR_INFO_FAILED,
                      hCIF,
                      prcStruct);
            if ((PVOID) pSaveNamesPtr != NULL)
            {
              ulRC = SimLibFree(hSession, (PVOID) pSaveNamesPtr, prcStruct);
              if ( ulRC != SUCCESS)
                call_FFST(ulRC,
                          INT_MEMORY_FREEUP_FAILED,
                          hCIF,
                          prcStruct);
            }
            *prcStruct = RCStruct;
            return(INT_GET_ATTR_INFO_FAILED);
        }

/*------------------------------------------------------------------------*/
/*    Get the attribute type from the system and check it against the     */
/*    match that is indicated in the ausAttrType array.                   */
/*    NOTE:  A special case is made for SHORT and DATE types since        */
/*           these are no supported in the CIF data stream.               */
/*------------------------------------------------------------------------*/


        pAttrInfo = (PATTRINFOSTRUCT) RCStruct.ulParam1;
        fFoundAttr = FALSE;
        if (pCIFAttr->aAttributes[ulIndex].usAttrType <= 11)
          if (ausAttrType[pCIFAttr->aAttributes[ulIndex].usAttrType] ==
              pAttrInfo->usAttrType)
            fFoundAttr = TRUE;
          else
          if ((ausAttrType[pCIFAttr->aAttributes[ulIndex].usAttrType] ==
              SIM_ATTR_TIMESTAMP) && (pAttrInfo->usAttrType == SIM_ATTR_DATE))
            fFoundAttr = TRUE;
          else
            if ((ausAttrType[pCIFAttr->aAttributes[ulIndex].usAttrType] ==
                SIM_ATTR_LONG) && (pAttrInfo->usAttrType == SIM_ATTR_SHORT))
              fFoundAttr = TRUE;
            else
              if ((ausAttrType[pCIFAttr->aAttributes[ulIndex].usAttrType] ==
                  SIM_ATTR_VSTRING) && (pAttrInfo->usAttrType == SIM_ATTR_FSTRING))
                fFoundAttr = TRUE;
              else
                if ((ausAttrType[pCIFAttr->aAttributes[ulIndex].usAttrType] ==
                    SIM_ATTR_FSTRING) && (pAttrInfo->usAttrType == SIM_ATTR_VSTRING))
                  fFoundAttr = TRUE;

        if (!fFoundAttr)
        {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

          call_FFST(ulRC,
                    INT_INVALID_ATTRIBUTE,
                    hCIF,
                    prcStruct);
          if ((PVOID) pSaveNamesPtr != NULL)
          {
            ulRC = SimLibFree(hSession, (PVOID) pSaveNamesPtr, prcStruct);
            if ( ulRC != SUCCESS)
              call_FFST(ulRC,
                        INT_MEMORY_FREEUP_FAILED,
                        hCIF,
                        prcStruct);
          }
          if ((PVOID) pAttrInfo != NULL)
          {
            ulRC = SimLibFree(hSession, (PVOID) pAttrInfo, prcStruct);
            if ( ulRC != SUCCESS)
              call_FFST(ulRC,
                        INT_MEMORY_FREEUP_FAILED,
                        hCIF,
                        prcStruct);
          }
          ulRC = INT_INVALID_ATTRIBUTE;
          return(ulRC);
        }
        if ((PVOID) pAttrInfo != NULL)
        {
          ulRC = SimLibFree(hSession, (PVOID) pAttrInfo, prcStruct);
          if ( ulRC != SUCCESS)
          {
            call_FFST(ulRC,
                      INT_MEMORY_FREEUP_FAILED,
                      hCIF,
                      prcStruct);
            return(INT_MEMORY_FREEUP_FAILED);
          }
        }
      }
    }


  } /* End the for number of attributes loop */

  if ((PVOID) pSaveNamesPtr != NULL)
  {
    ulRC = SimLibFree(hSession, (PVOID) pSaveNamesPtr, prcStruct);
    if ( ulRC != SUCCESS)
    {
      call_FFST(ulRC,
                INT_MEMORY_FREEUP_FAILED,
                hCIF,
                prcStruct);
      return(INT_MEMORY_FREEUP_FAILED);
    }
  }
  if ((fAttrCreated) && (ulRC == SUCCESS))
    ulRC = INT_ATTR_OR_CLASS_CREATED;

  prcStruct->ulRC = ulRC;
  return(ulRC);
}



/*BEGINPROLOGUE*************************************************/
/*  Function  : validate_import_classes    Date:    May      93*/
/*  Module    : FRNOICSI.C                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                            stdio.h                          */
/*                            stdlib.h                         */
/*                Product Functions:                           */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG                                       */
/*                                                             */
/*  Input Parameters:                                          */
/*                                                             */
/*  Output Parameters:                                         */
/*      None                                                   */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Process Flow:                                              */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

  ULONG  _Optlink validate_import_classes(HSESSION hSession,
                                   HCIF  hCIF,
                                   BOOL  fCreateFlag,
                                   PINTCIFHEADER pCIFHeader,
                                   PINTINDCLASSINFOSTRUCT pCIFICls,
                                   PRCSTRUCT prcStruct)


{
  ULONG                  ulRC = 0;
  ULONG                  ulIndex    = 0;            // loop counter
  PNAMESTRUCT            pNames;
  PNAMESTRUCT            pSaveNamesPtr;
  ULONG                  ulNumNames;
  ULONG                  ulNameIndex;
  ULONG                  ulAttrIndex;
  ULONG                  ulClassAttrIndex;
  ULONG                  ulAttrArrayIndex;
  BOOL                   fFoundClass;
  BOOL                   fClassMap;
  BOOL                   fFoundClassAttr;
  BOOL                   fClassCreated;
  BOOL                   fDLL_Created;
  CLASSINFOSTRUCT        NewClassInfo;
  PCLASSATTRSTRUCT       pSaveClassAttrPtr;
  CHAR                   szTempClassName[SIM_CLASS_NAME_LENGTH+1];
  RCSTRUCT               RCStruct;

/*------------------------------------------------------------------------*/
/*  List all the classes that are currently in the system                 */
/*------------------------------------------------------------------------*/

  fClassCreated = FALSE;
  ulRC = SimLibListClasses(hSession,
                           SIM_ENUM_USER_ACCESS|
                           SIM_ENUM_USER_OWNER|
                           SIM_ENUM_APPL,
                           NULL,
                           &RCStruct);
  if ( ulRC != SUCCESS)
  {
      call_FFST(ulRC,
                INT_LIST_CLASSES_FAILED,
                hCIF,
                prcStruct);
      *prcStruct = RCStruct;
      return(INT_LIST_CLASSES_FAILED);
  }

  pNames = (PNAMESTRUCT) RCStruct.ulParam1;
  pSaveNamesPtr = pNames;
  ulNumNames = RCStruct.ulParam2;

  hCIF->pClassMatch = malloc (
           pCIFHeader->Header.ulNumClass * sizeof(CLASSMATCHSTRUCT));
  if ((pCIFHeader->Header.ulNumClass > 0) && (hCIF->pClassMatch == NULL))
  {
     call_FFST(ulRC,
               INT_ALLOCATE_ATTRIBUTE_MEMORY,
               hCIF,
               prcStruct);
     return(INT_ALLOCATE_ATTRIBUTE_MEMORY);
  }
  hCIF->pSaveClassMatch = hCIF->pClassMatch;

/*------------------------------------------------------------------------*/
/*  For each class in the CIF header,                                     */
/*     1.  Check to see if it exists.                                     */
/*     2.  Try to create it of it doesn't exist.                          */
/*------------------------------------------------------------------------*/

  for ( ulIndex = 0; ulIndex < pCIFHeader->Header.ulNumClass; ulIndex++)
  {
    fFoundClass = FALSE;
    fClassMap = FALSE;
    pNames = pSaveNamesPtr;
//  Call exit to map class name from old to new system
    Ip2ImportClassExit(hSession,
                       pCIFICls->aClasses[ulIndex].pszClassName,
                       szTempClassName,
                       &fClassMap);
    if (!fClassMap)
      strcpy(szTempClassName, pCIFICls->aClasses[ulIndex].pszClassName);

    strcpy(hCIF->pClassMatch->szClassName, szTempClassName);
    hCIF->pClassMatch->usOldID = pCIFICls->aClasses[ulIndex].usClassID;

    for ( ulNameIndex = 0; ulNameIndex < ulNumNames; ulNameIndex++)
    {
      if (strcmp(szTempClassName, pNames->szName) == 0)
         {
         fFoundClass = TRUE;
         hCIF->pClassMatch->usNewID = pNames->usID;
         break;
         }
      pNames++;
    }

    if ((fClassMap) && (!fFoundClass))
    {

/*------------------------------------------------------------------------*/
/*    If the class mapping was made but we can't find the new name        */
/*    in the system, then we have an error.                               */
/*------------------------------------------------------------------------*/

      call_FFST(ulRC,
                INT_INVALID_CLASS,
                hCIF,
                prcStruct);
      if ((PVOID) pSaveNamesPtr != NULL)
      {
         ulRC = SimLibFree(hSession, (PVOID) pSaveNamesPtr, prcStruct);
         if ( ulRC != SUCCESS)
         {
           call_FFST(ulRC,
                     INT_MEMORY_FREEUP_FAILED,
                     hCIF,
                     prcStruct);
           return(INT_MEMORY_FREEUP_FAILED);
         }
      }
      ulRC = INT_INVALID_CLASS;
      return(ulRC);
    }

    if (!fFoundClass)
    {
      if (!fCreateFlag)
      {

        call_FFST(ulRC,
                  INT_INVALID_CLASS,
                  hCIF,
                  prcStruct);
        if ((PVOID) pSaveNamesPtr != NULL)
        {
           ulRC = SimLibFree(hSession, (PVOID) pSaveNamesPtr, prcStruct);
           if ( ulRC != SUCCESS)
           {
             call_FFST(ulRC,
                       INT_MEMORY_FREEUP_FAILED,
                       hCIF,
                       prcStruct);
             return(INT_MEMORY_FREEUP_FAILED);
           }
        }
        ulRC = INT_INVALID_CLASS;
        return(ulRC);
      }
      NewClassInfo.usNbrAttrIds =
             pCIFICls->aClasses[ulIndex].ulNumReqAttr +
             pCIFICls->aClasses[ulIndex].ulNumOptAttr;
      NewClassInfo.pClassAttrStruct = malloc(
                       NewClassInfo.usNbrAttrIds * sizeof(CLASSATTRSTRUCT));
      if ((NewClassInfo.usNbrAttrIds > 0) && (NewClassInfo.pClassAttrStruct == NULL))
      {
         call_FFST(ulRC,
                   INT_ALLOCATE_ATTRIBUTE_MEMORY,
                   hCIF,
                   prcStruct);
         return(INT_ALLOCATE_ATTRIBUTE_MEMORY);
      }
      pSaveClassAttrPtr = NewClassInfo.pClassAttrStruct;
      NewClassInfo.ulStruct = sizeof(NewClassInfo);
      strcpy(NewClassInfo.szClassName, szTempClassName);
      if (pCIFHeader->Header.pszLang == NULL)
        strcpy(NewClassInfo.achLanguageCode, "ENU");
      else
        strcpy(NewClassInfo.achLanguageCode,
               pCIFHeader->Header.pszLang);
      NewClassInfo.usMaxVersions = 10;
      memset(NewClassInfo.szACLName, '\0', sizeof(NewClassInfo.szACLName));
      NewClassInfo.usIndexClass = SIM_INDEX_NOT_UNIQUE;
    }

/*------------------------------------------------------------------------*/
/*    For each required attribute in this class,                          */
/*        1. get the ID for the attribute in this system                  */
/*        1. add it to the CLASSINFOSTRUCT for this class                 */
/*------------------------------------------------------------------------*/
    ulClassAttrIndex = 0;
    for ( ulAttrIndex = 0;
          ulAttrIndex < pCIFICls->aClasses[ulIndex].ulNumReqAttr;
          ulAttrIndex ++)
    {
      if (!fFoundClass)
        NewClassInfo.pClassAttrStruct->ulStruct = sizeof(CLASSATTRSTRUCT);

/*------------------------------------------------------------------------*/
/*    Find the attribute in the pNewAttrArray to get the new ID            */
/*------------------------------------------------------------------------*/

      hCIF->pNewAttrArray = hCIF->pSaveNewAttrPtr;
      for (ulAttrArrayIndex = 0;
           ulAttrArrayIndex <= hCIF->usNewAttrIndex;
           ulAttrArrayIndex++)
      {
        fFoundClassAttr = FALSE;
        if (hCIF->pNewAttrArray->usOldID ==
            pCIFICls->aClasses[ulIndex].ausReqAttr[ulAttrIndex])
        {
          fFoundClassAttr = TRUE;
          hCIF->pClassMatch->ausAttrNewIDs[ulClassAttrIndex] =
                       hCIF->pNewAttrArray->usNewID;
          ulClassAttrIndex++;
          break;
        }
        else
          hCIF->pNewAttrArray++;
      }
      if (!fFoundClassAttr)
      {

/*------------------------------------------------------------------------*/
/*    If the attribute ID was not in the pNewAttrArray, then we            */
/*    encountered an error where this attribute was not in the CIF        */
/*    header.                                                             */
/*------------------------------------------------------------------------*/

        call_FFST(ulRC,
                  INT_INVALID_CLASS,
                  hCIF,
                  prcStruct);
        if ((PVOID) pSaveNamesPtr != NULL)
        {
           ulRC = SimLibFree(hSession, (PVOID) pSaveNamesPtr, prcStruct);
           if ( ulRC != SUCCESS)
           {
             call_FFST(ulRC,
                       INT_MEMORY_FREEUP_FAILED,
                       hCIF,
                       prcStruct);
             return(INT_MEMORY_FREEUP_FAILED);
           }
        }
        ulRC = INT_INVALID_CLASS;
        return(ulRC);
      }


/*------------------------------------------------------------------------*/
/*    Set up the CLASSINFOSTRUCT for creating a new class.                */
/*------------------------------------------------------------------------*/

      if (!fFoundClass)
      {
        NewClassInfo.pClassAttrStruct->fAttrRequiredField = TRUE;
        NewClassInfo.pClassAttrStruct->fAttrAccess = SIM_ACCESS_READ_WRITE;
        NewClassInfo.pClassAttrStruct->usAttrId =
             hCIF->pNewAttrArray->usNewID;
        NewClassInfo.pClassAttrStruct++;
      }
    }

/*------------------------------------------------------------------------*/
/*    do same as above for all the Optional attributes                    */
/*------------------------------------------------------------------------*/

    for ( ulAttrIndex = 0;
          ulAttrIndex < pCIFICls->aClasses[ulIndex].ulNumOptAttr;
          ulAttrIndex ++)
    {
      if (!fFoundClass)
        NewClassInfo.pClassAttrStruct->ulStruct = sizeof(CLASSATTRSTRUCT);

      hCIF->pNewAttrArray = hCIF->pSaveNewAttrPtr;
      for (ulAttrArrayIndex = 0;
           ulAttrArrayIndex <= hCIF->usNewAttrIndex;
           ulAttrArrayIndex++)
      {
        if (hCIF->pNewAttrArray->usOldID ==
            pCIFICls->aClasses[ulIndex].ausOptAttr[ulAttrIndex])
        {
          fFoundClassAttr = TRUE;
          hCIF->pClassMatch->ausAttrNewIDs[ulClassAttrIndex] =
                       hCIF->pNewAttrArray->usNewID;
          ulClassAttrIndex++;
          break;
        }
        else
          hCIF->pNewAttrArray++;
      }
      if (!fFoundClassAttr)
      {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

        call_FFST(ulRC,
                  INT_INVALID_CLASS,
                  hCIF,
                  prcStruct);
        if ((PVOID) pSaveNamesPtr != NULL)
        {
           ulRC = SimLibFree(hSession, (PVOID) pSaveNamesPtr, prcStruct);
           if ( ulRC != SUCCESS)
           {
             call_FFST(ulRC,
                       INT_MEMORY_FREEUP_FAILED,
                       hCIF,
                       prcStruct);
             return(INT_MEMORY_FREEUP_FAILED);
           }
        }
        ulRC = INT_INVALID_CLASS;
        return(ulRC);
      }
      if (!fFoundClass)
      {
        NewClassInfo.pClassAttrStruct->fAttrRequiredField = FALSE;
        NewClassInfo.pClassAttrStruct->fAttrAccess = SIM_ACCESS_READ_WRITE;
        NewClassInfo.pClassAttrStruct->usAttrId =
              hCIF->pNewAttrArray->usNewID;
        NewClassInfo.pClassAttrStruct++;
      }
    }


/*------------------------------------------------------------------------*/
/*   All the required and optional attributes have now been added to      */
/*   the CLASSINFOSTRUCT->CLASSATTRSTRUCT so we can now add the new       */
/*   index class.                                                         */
/*------------------------------------------------------------------------*/
    if (!fFoundClass)
    {
      NewClassInfo.pClassAttrStruct = pSaveClassAttrPtr;
      ulRC = Ip2CreateClass(hSession,
                            &NewClassInfo,
                            0,
                            OIM_NONE,
                            NULL,
                            &RCStruct);
      if (ulRC != SUCCESS)
      {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

        call_FFST(ulRC,
                  INT_INVALID_CLASS,
                  hCIF,
                  prcStruct);
        if ((PVOID) pSaveNamesPtr != NULL)
           SimLibFree(hSession, (PVOID) pSaveNamesPtr, prcStruct);
        *prcStruct = RCStruct;
        return(ulRC);
      }
      hCIF->pClassMatch->usNewID = RCStruct.ulParam1;

      fDLL_Created = FALSE;
      while (!fDLL_Created)
      {
        ulRC = Ip2GetIndexClassStatus(hSession,
                                      hCIF->pClassMatch->usNewID,
                                      NULL,
                                      &RCStruct);
        if (ulRC != SUCCESS)
        {
/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

          call_FFST(ulRC,
                    INT_INVALID_CLASS,
                    hCIF,
                    prcStruct);
          if ((PVOID) pSaveNamesPtr != NULL)
             ulRC = SimLibFree(hSession, (PVOID) pSaveNamesPtr, prcStruct);
          *prcStruct = RCStruct;
          return(INT_INVALID_CLASS);
        }
        else
        {
          if ((RCStruct.usParam == 0) ||
              (RCStruct.ulParam1 == 0))
          {
              fDLL_Created = TRUE;
              fClassCreated = TRUE;
          }
          else
          {
            if ((RCStruct.ulParam1 != 1) &&
                (RCStruct.ulParam1 != RC_PREPARING_FOR_CODE_GEN))
            {
/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

              call_FFST(ulRC,
                        INT_INVALID_CLASS,
                        hCIF,
                        prcStruct);
              if ((PVOID) pSaveNamesPtr != NULL)
                 ulRC = SimLibFree(hSession, (PVOID) pSaveNamesPtr, prcStruct);
              *prcStruct = RCStruct;
              return(INT_INVALID_CLASS);
            }
          }
        }
      } /* end  while dll not created */
      ulRC = AddClassToClassTables(hSession, hCIF, hCIF->pClassMatch->usNewID, prcStruct);
      if ( ulRC != SUCCESS)
        return(ulRC);

    }  /* End if !fFoundClass */

    hCIF->pClassMatch++;
  } /* end for ulNumClass loop */

  if ((PVOID) pSaveNamesPtr != NULL)
  {
    ulRC = SimLibFree(hSession, (PVOID) pSaveNamesPtr, prcStruct);
    if ( ulRC != SUCCESS)
    {
      call_FFST(ulRC,
                INT_MEMORY_FREEUP_FAILED,
                hCIF,
                prcStruct);
      return(INT_MEMORY_FREEUP_FAILED);
    }
  }

  if ((fClassCreated) && (ulRC == SUCCESS))
    ulRC = INT_ATTR_OR_CLASS_CREATED;

  prcStruct->ulRC = ulRC;
  return(ulRC);
}


/*BEGINPROLOGUE*************************************************/
/*  Function  : process_CIF_for_import     Date:    May      93*/
/*  Module    : FRNOICSI.C                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                            stdio.h                          */
/*                            stdlib.h                         */
/*                Product Functions:                           */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG                                       */
/*                                                             */
/*  Input Parameters:                                          */
/*                                                             */
/*  Output Parameters:                                         */
/*      None                                                   */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Process Flow:                                              */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

  ULONG  _Optlink process_CIF_for_import(HSESSION hSession,
                              HCIF hCIF,
                              PINTCIFHEADER   pCIFHeader,
                              PINTCIUDATALIST pCIUData,
                              PRCSTRUCT prcStruct)
{
  BOOL                   fParentFound;
  BOOL                   fItemFound;
  BOOL                   fContentClass;
  BOOL                   fIndexClass;
  BOOL                   fFoundClassAttr;
  BOOL                   fFoundClass;
  BOOL                   fMoreToRead;
  BOOL                   fFirstPart;
  BOOL                   fUserAttr;
  INT                    iSaveOffset;
  ULONG                  ulIndex;
  ULONG                  ulObjectIndex;
  ULONG                  ulRC;
  ULONG                  ulSaveContentClass;
  ULONG                  ulTempContentClass;
  ULONG                  ulObjectClass;
  ULONG                  ulClassAttrIndex;
  ULONG                  ulClassIndex;
  ULONG                  ulObjectLength;
  ULONG                  ulNumNames;
  ULONG                  ulNameIndex;
  LONG                   lTemp;
  SHORT                  sTemp;
  USHORT                 usNewID;
  USHORT                 usAttrType;
  USHORT                 usIDIndex;
  USHORT                 usSaveIndexClass;
  ULONG                  ulBufferSize;
  ULONG                  ulNumBytes;
  USHORT                 usNumUserAttr;
  USHORT                 usNumClassAttr;
  USHORT                 usIndex;
  USHORT                 usIntIndex;
  USHORT                 usFreeIndex;
  CHAR                   szAsciiBuffer[34];
  CHAR                   szTempClassName[34];
  CHAR                   *pObjectBuffer;
  SMS                    sSMS;
  HOBJ                   hNewObj;
  OBJ                    Obj;
  HOBJACC                hObjAcc;
  RCSTRUCT               RCStruct;
  PITEMID                pNewItemID;
  PNAMESTRUCT            pNames;
  PNAMESTRUCT            pSaveNamesPtr;
  PCLASSINFOSTRUCT       pClassInfo;
  PCLASSATTRSTRUCT       pClassAttrStruct;
  PINTIMPORTITEMSTRUCT   pFindItem;
  PATTRINFOSTRUCT        pAttrInfo;
  PATTRLISTSTRUCT        pClassAttrList;
  PATTRLISTSTRUCT        pSaveClassAttr;
  PATTRLISTSTRUCT        pAttrList = NULL;
  PATTRLISTSTRUCT        pSaveAttrListPtr = NULL;
  PINTEGERATTRIBUTE      pIntegers = NULL;
  PINTEGERATTRIBUTE      pSaveIntegersPtr = NULL;

   fContentClass = FALSE;
   while(pCIUData != NULL)
   {
     fIndexClass = FALSE;
     usIntIndex = 0;
//-------------------------------------------------------------------------
//   Check for case of duplicate item or empty contents.
//-------------------------------------------------------------------------
     if ((pCIUData->ulNumAttr == 0) &&
         (pCIUData->ulNumNotes == 0) &&
         (pCIUData->ulNumObj == 0))
     {
       fItemFound = FALSE;
       pFindItem = hCIF->pNewIDs;
       for (usIDIndex = 0; usIDIndex < hCIF->ulNumNewItems; usIDIndex++)
       {
         if (pCIUData->ulUID == pFindItem->ulUID)
         {
           fItemFound = TRUE;
           break;
         }
         pFindItem++;
       }
//-------------------------------------------------------------------------
//   If the item UID was already encountered, then this is a duplicate.
//   Otherwise, the CIU contents are empty, which can occur for a empty
//   folder.
//-------------------------------------------------------------------------
       fParentFound = FALSE;
       if (fItemFound)
       {
         hCIF->pNewItems->ulUID = pCIUData->ulUID;
         strcpy((char *)hCIF->pNewItems->szItemID, (char *)pFindItem->szItemID);

         pFindItem = hCIF->pNewIDs;
         if (pCIUData->ulParentID != 0)
         {
           for (usIDIndex = 0; usIDIndex < hCIF->ulNumNewItems; usIDIndex++)
           {
             if (pCIUData->ulParentID == pFindItem->ulUID)
             {
               fParentFound = TRUE;
               break;
             }
             pFindItem++;
           }
         }


         hCIF->pNewItems->ulParentID = pCIUData->ulParentID;
         if (fParentFound)
           strcpy((char *)hCIF->pNewItems->szParentID, pFindItem->szItemID);
         else
           strcpy((char *)hCIF->pNewItems->szParentID, "");

         if ((strcmp((char *)pFindItem->szParentID, "") != 0) &&
             (fParentFound))
         {
           ulRC = SimLibAddFolderItem(hSession,
                                      &(hCIF->pNewItems->szParentID),
                                      &(hCIF->pNewItems->szItemID),
                                      NULL,
                                      &RCStruct);
            if (ulRC != SUCCESS)
            {
                call_FFST(ulRC,
                          INT_ADD_FOLDER_ITEM_FAILED,
                          hCIF,
                          prcStruct);
                *prcStruct = RCStruct;
                return(INT_ADD_FOLDER_ITEM_FAILED);
            }
         }
         pCIUData = pCIUData->pCIUData;
         continue;
       }
     }

//-------------------------------------------------------------------------
//   Allocate memory to hold the attributes associated with the item we
//   are about to create.
//-------------------------------------------------------------------------
     if (pCIUData->ulNumAttr > 0)
     {
       pAttrList = (PATTRLISTSTRUCT)
                    malloc(pCIUData->ulNumAttr*sizeof(ATTRLISTSTRUCT));
      if ((pCIUData->ulNumAttr > 0) && (pAttrList == NULL))
      {
         call_FFST(ulRC,
                   INT_ALLOCATE_ATTRIBUTE_MEMORY,
                   hCIF,
                   prcStruct);
         return(INT_ALLOCATE_ATTRIBUTE_MEMORY);
      }
       pIntegers = (PINTEGERATTRIBUTE)
                    malloc(pCIUData->ulNumAttr*sizeof(INTEGERATTRIBUTE));
       if ((pAttrList == NULL) || (pIntegers == NULL))
       {
          call_FFST(ulRC,
                    INT_ALLOCATE_ATTRIBUTE_MEMORY,
                    hCIF,
                    prcStruct);
          return(INT_ALLOCATE_ATTRIBUTE_MEMORY);
       }
       pSaveAttrListPtr = pAttrList;
       pSaveIntegersPtr = pIntegers;
     }

/*------------------------------------------------------------------------*/
/*  For each attribute in the CIU for this item,                          */
/*     1.  Set up the ATTRLISTSTRUCT for SimLibCreateItem                 */
/*     2.  Call the SImLibCreateItem API                                  */
/*------------------------------------------------------------------------*/

     usNumUserAttr = 0;
     for ( ulIndex = 0; ulIndex < pCIUData->ulNumAttr; ulIndex++)
     {
      fUserAttr = FALSE;
/*------------------------------------------------------------------------*/
/*    if no user attributes existed in the header, then call the exit     */
/*    which allows mapping of system attributes to user attributes. It    */
/*    also allows overriding the index class ID.                          */
/*------------------------------------------------------------------------*/
      Ip2ImportSetupAttrExit(hSession,
                         &fUserAttr,
                         &fIndexClass,
                         ulIndex,
                         &usNewID,
                         &usSaveIndexClass,
                         pCIFHeader,
                         pCIUData);

/*------------------------------------------------------------------------*/
/*    If the exit did not map this attribute, then look for the match     */
/*    in the newattr structure.                                           */
/*------------------------------------------------------------------------*/
      usAttrType = USER_ATTR_UNSPEC;
      if (!fUserAttr)
      {
        if (pCIFHeader->Header.ulNumAttr > 0)
        {
          if (pCIUData->pItemAttrs->aAttributes[ulIndex]->fAttrSys == FALSE)
          {
            fUserAttr = TRUE;
/*------------------------------------------------------------------------*/
/*    Find the attribute in the pNewAttrArray to get the new ID            */
/*------------------------------------------------------------------------*/

            hCIF->pNewAttrArray = hCIF->pSaveNewAttrPtr;
            for (ulClassAttrIndex = 0;
                 ulClassAttrIndex <= hCIF->usNewAttrIndex;
                 ulClassAttrIndex++)
            {
              fFoundClassAttr = FALSE;
              if (hCIF->pNewAttrArray->usOldID ==
                  pCIUData->pItemAttrs->aAttributes[ulIndex]->usAttrID)
              {
                fFoundClassAttr = TRUE;
                usNewID    = hCIF->pNewAttrArray->usNewID;
                usAttrType = hCIF->pNewAttrArray->usAttrType;
                break;
              }
              else
                hCIF->pNewAttrArray++;
            }
            if (!fFoundClassAttr)
            {

/*------------------------------------------------------------------------*/
/*    If the attribute ID was not in the pNewAttrArray, then we            */
/*    encountered an error where this attribute was not in the CIF        */
/*    header.                                                             */
/*------------------------------------------------------------------------*/

              call_FFST(ulRC,
                        INT_INVALID_CLASS,
                        hCIF,
                        prcStruct);
              ulRC = INT_INVALID_CLASS;
              return(ulRC);
            }
          }
        }
      }

/*------------------------------------------------------------------------*/
/*     Get the attribute info from the system (type and value) if the     */
/*     attribute type is user.  The Setup exit will set this flag if a    */
/*     mapping is done from system to user attributes.                    */
/*------------------------------------------------------------------------*/
      if (fUserAttr)
      {

        ulRC = SimLibGetAttrInfo(hSession,
                          usNewID,
                          NULL,
                          &RCStruct);
        if ( ulRC != SUCCESS)
        {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

           call_FFST(ulRC,
                     INT_GET_ATTR_INFO_FAILED,
                     hCIF,
                     prcStruct);
           if ((PVOID) pSaveAttrListPtr != NULL)
              free((PVOID) pSaveAttrListPtr);
           if ((PVOID) pSaveIntegersPtr != NULL)
              free((PVOID) pSaveIntegersPtr);
           *prcStruct = RCStruct;
           return(INT_GET_ATTR_INFO_FAILED);
        }
        pAttrInfo = (PATTRINFOSTRUCT) RCStruct.ulParam1;

        pAttrList->ulStruct = sizeof(ATTRLISTSTRUCT);
        pAttrList->fAttrFlags = SIM_ATTR_READWRITE;
        pAttrList->usAttrId = usNewID;
        pAttrList->usAttrType = pAttrInfo->usAttrType;
        pAttrList->pszAttributeValue =
                      pCIUData->pItemAttrs->aAttributes[ulIndex]->pAttrValue;
        memset(szAsciiBuffer, '\0', sizeof(szAsciiBuffer));
        if ((pAttrInfo->usAttrType == SIM_ATTR_TIME)      ||
            (pAttrInfo->usAttrType == SIM_ATTR_TIMESTAMP) ||
            (pAttrInfo->usAttrType == SIM_ATTR_DATE)      ||
            (pAttrInfo->usAttrType == SIM_ATTR_DECIMAL)   ||
            (pAttrInfo->usAttrType == SIM_ATTR_VSTRING)   ||
            (pAttrInfo->usAttrType == SIM_ATTR_FSTRING)   ||
            (usAttrType != USER_ATTR_INTEGER))
        {
          if (pCIUData->pItemAttrs->aAttributes[ulIndex]->fAttrSys == FALSE)
            ebcdic2ascii((PSZ)pAttrList->pszAttributeValue,
                        pCIUData->pItemAttrs->aAttributes[ulIndex]->ulLen,
                        hCIF);
          else
          {
            if (pAttrInfo->usAttrType == SIM_ATTR_SHORT)
            {
              sTemp = 0;
              copybytes((char *)&sTemp,
                     (char *)pCIUData->pItemAttrs->aAttributes[ulIndex]->pAttrValue,
                     pCIUData->pItemAttrs->aAttributes[ulIndex]->ulLen);
              pAttrList->pszAttributeValue = itoa(sTemp, szAsciiBuffer, 10);
              pIntegers->aInteger[usIntIndex] = malloc(strlen(szAsciiBuffer)+1);
              strcpy(pIntegers->aInteger[usIntIndex], szAsciiBuffer);
              pAttrList->pszAttributeValue = pIntegers->aInteger[usIntIndex];
              usIntIndex++;
            }
            else
            {
              if (pAttrInfo->usAttrType == SIM_ATTR_LONG)
              {
                lTemp = 0;
                copybytes((char *)&lTemp,
                       (char *)pCIUData->pItemAttrs->aAttributes[ulIndex]->pAttrValue,
                       pCIUData->pItemAttrs->aAttributes[ulIndex]->ulLen);
                pAttrList->pszAttributeValue = itoa(lTemp, szAsciiBuffer, 10);
                pIntegers->aInteger[usIntIndex] = malloc(strlen(szAsciiBuffer)+1);
                strcpy(pIntegers->aInteger[usIntIndex], szAsciiBuffer);
                pAttrList->pszAttributeValue = pIntegers->aInteger[usIntIndex];
                usIntIndex++;
              }
            }
          }
        }
        else
        {
          if (pAttrInfo->usAttrType == SIM_ATTR_SHORT)
          {
             if (pCIUData->pItemAttrs->aAttributes[ulIndex]->pAttrValue != NULL)
             {
               if (pCIUData->pItemAttrs->aAttributes[ulIndex]->ulLen <
                   sizeof(sTemp))
                 copybytes((char *)szAsciiBuffer,
                        (char *)pCIUData->pItemAttrs->aAttributes[ulIndex]->pAttrValue,
                        pCIUData->pItemAttrs->aAttributes[ulIndex]->ulLen);
               else
                 copybytes((char *)szAsciiBuffer,
                        (char *)pCIUData->pItemAttrs->aAttributes[ulIndex]->pAttrValue,
                        sizeof(sTemp));
               if (pCIUData->pItemAttrs->aAttributes[ulIndex]->fAttrSys == FALSE)
               {
                 szAsciiBuffer[2] = szAsciiBuffer[0];
                 szAsciiBuffer[0] = szAsciiBuffer[1];
                 szAsciiBuffer[1] = szAsciiBuffer[2];
               }
               copybytes((char *)&sTemp, (char *)szAsciiBuffer,
                      sizeof(sTemp));
               pAttrList->pszAttributeValue = itoa(sTemp, szAsciiBuffer, 10);
               pIntegers->aInteger[usIntIndex] = malloc(strlen(szAsciiBuffer)+1);
               strcpy(pIntegers->aInteger[usIntIndex], szAsciiBuffer);
               pAttrList->pszAttributeValue = pIntegers->aInteger[usIntIndex];
               usIntIndex++;
             }
             else
               pAttrList->pszAttributeValue = NULL;
          }
          else
          {
             if (pCIUData->pItemAttrs->aAttributes[ulIndex]->pAttrValue != NULL)
             {
               if (pCIUData->pItemAttrs->aAttributes[ulIndex]->ulLen <
                   sizeof(lTemp))
                 copybytes((char *)szAsciiBuffer,
                        (char *)pCIUData->pItemAttrs->aAttributes[ulIndex]->pAttrValue,
                        pCIUData->pItemAttrs->aAttributes[ulIndex]->ulLen);
               else
                 copybytes((char *)szAsciiBuffer,
                        (char *)pCIUData->pItemAttrs->aAttributes[ulIndex]->pAttrValue,
                        sizeof(lTemp));
               if (pCIUData->pItemAttrs->aAttributes[ulIndex]->fAttrSys == FALSE)
               {
                 szAsciiBuffer[4] = szAsciiBuffer[0];
                 szAsciiBuffer[5] = szAsciiBuffer[1];
                 szAsciiBuffer[0] = szAsciiBuffer[3];
                 szAsciiBuffer[1] = szAsciiBuffer[2];
                 szAsciiBuffer[2] = szAsciiBuffer[5];
                 szAsciiBuffer[3] = szAsciiBuffer[4];
               }
               copybytes((char *)&lTemp, (char *)szAsciiBuffer,
                      sizeof(lTemp));
               pAttrList->pszAttributeValue = ltoa(lTemp, szAsciiBuffer, 10);
               pIntegers->aInteger[usIntIndex] = malloc(strlen(szAsciiBuffer)+1);
               strcpy(pIntegers->aInteger[usIntIndex], szAsciiBuffer);
               pAttrList->pszAttributeValue = pIntegers->aInteger[usIntIndex];
               usIntIndex++;
             }
             else
               pAttrList->pszAttributeValue = NULL;
          }
        }


        pAttrList++;
        usNumUserAttr++;
        ulRC = SimLibFree(hSession, (PVOID) pAttrInfo, prcStruct);
        if ( ulRC != SUCCESS)
        {

 /*------------------------------------------------------------------------*/
 /*    If the API fails, we have to free up anything left open.            */
 /*------------------------------------------------------------------------*/

          call_FFST(ulRC,
                    INT_MEMORY_FREEUP_FAILED,
                    hCIF,
                    prcStruct);
          if ((PVOID) pSaveAttrListPtr != NULL)
             free((PVOID) pSaveAttrListPtr);
          if ((PVOID) pSaveIntegersPtr != NULL)
             free((PVOID) pSaveIntegersPtr);
          return(INT_MEMORY_FREEUP_FAILED);
        }
      }
      else   /* Else it's a system attribute */
      {
       if (pCIUData->pItemAttrs->aAttributes[ulIndex]->usAttrID == 4)
       {
         fContentClass = TRUE;
         ulSaveContentClass = 1;
       }

       if (pCIUData->pItemAttrs->aAttributes[ulIndex]->usAttrID == 6)
       {
          fContentClass = TRUE;
          memset(&ulSaveContentClass, '\0', sizeof(ulSaveContentClass));
          copybytes((char *)&ulSaveContentClass,
                 (char *)pCIUData->pItemAttrs->aAttributes[ulIndex]->pAttrValue,
                 pCIUData->pItemAttrs->aAttributes[ulIndex]->ulLen);
       }

       if ((pCIUData->pItemAttrs->aAttributes[ulIndex]->usAttrID == 14) &&
           (fIndexClass == FALSE))
       {
          memset(&usSaveIndexClass, '\0', sizeof(usSaveIndexClass));
          copybytes((char *)&usSaveIndexClass,
                 (char *)pCIUData->pItemAttrs->aAttributes[ulIndex]->pAttrValue,
                 pCIUData->pItemAttrs->aAttributes[ulIndex]->ulLen);
          hCIF->pClassMatch = hCIF->pSaveClassMatch;
          for ( ulClassIndex = 0;
                ulClassIndex < pCIFHeader->Header.ulNumClass;
                ulClassIndex++)
          {
            if (hCIF->pClassMatch->usOldID == usSaveIndexClass)
            {
              usSaveIndexClass = hCIF->pClassMatch->usNewID;
              fIndexClass = TRUE;
              break;
            }
            hCIF->pClassMatch++;
          }
       }  /* End if Attr ID is Index Class */
     } /* End if - else for checking fAttrSys */

     } /* End the for loop */

     if (!fIndexClass)
        usSaveIndexClass = SIM_INDEX_NOINDEX;  // NOINDEX index class

     ulRC = SimLibGetClassInfo(hSession,
                              SIM_INDEXCLASSID,
                              usSaveIndexClass,
                              NULL,
                              &RCStruct);
     if ( ulRC != SUCCESS)
     {
         call_FFST(ulRC,
                   INT_LIST_CLASSES_FAILED,
                   hCIF,
                   prcStruct);
         *prcStruct = RCStruct;
         return(INT_LIST_CLASSES_FAILED);
     }

     pClassInfo = (PCLASSINFOSTRUCT) RCStruct.ulParam1;
     pClassAttrList = malloc(usNumUserAttr * sizeof(ATTRLISTSTRUCT));
     if ((usNumUserAttr > 0) && (pClassAttrList == NULL))
     {
        call_FFST(ulRC,
                  INT_ALLOCATE_ATTRIBUTE_MEMORY,
                  hCIF,
                  prcStruct);
        return(INT_ALLOCATE_ATTRIBUTE_MEMORY);
     }
     pSaveClassAttr = pClassAttrList;
     pAttrList = pSaveAttrListPtr;
     usNumClassAttr = 0;

     for (ulIndex = 0; ulIndex < usNumUserAttr; ulIndex++)
     {
        pClassAttrStruct = pClassInfo->pClassAttrStruct;
        for (usIndex = 0; usIndex < pClassInfo->usNbrAttrIds; usIndex++)
        {
          if (pClassAttrStruct->usAttrId ==
              pAttrList->usAttrId)
          {
            *pClassAttrList = *pAttrList;
            pClassAttrList++;
            usNumClassAttr++;
            break;
          }
          pClassAttrStruct++;
        }
        pAttrList++;
     }
     if (pSaveAttrListPtr != NULL)
       free(pSaveAttrListPtr);
     if ((PVOID) pClassInfo != NULL)
        SimLibFree(hSession, (PVOID) pClassInfo, &RCStruct);

     if (pCIUData->ulDataType == INT_EXPORT_DOCUMENT)
       ulRC = SimLibCreateItem(hSession,
                               SIM_DOCUMENT,
                               usSaveIndexClass,
                               usNumClassAttr,
                               pSaveClassAttr,
                               SIM_ACC_DEFAULT,
                               NULL,
                               &RCStruct);
     else
       ulRC = SimLibCreateItem(hSession,
                               SIM_FOLDER,
                               usSaveIndexClass,
                               usNumClassAttr,
                               pSaveClassAttr,
                               SIM_ACC_DEFAULT,
                               NULL,
                               &RCStruct);
       for (usFreeIndex = 0; usFreeIndex < usIntIndex; usFreeIndex++)
       {
         free(pIntegers->aInteger[usFreeIndex]);
       }
       if ( ulRC != SUCCESS)
       {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

           call_FFST(ulRC,
                     INT_CREATE_ITEM_FAILED,
                     hCIF,
                     prcStruct);
           if ((PVOID) pSaveClassAttr != NULL)
              free((PVOID) pSaveClassAttr);
           if ((PVOID) pSaveIntegersPtr != NULL)
              free((PVOID) pSaveIntegersPtr);
           *prcStruct = RCStruct;
           return(INT_CREATE_ITEM_FAILED);
       }

//-----------------------------------------------------------------------------
//   Save the new ID in the structure to match parents of later items to
//   be created.
//-----------------------------------------------------------------------------
     pNewItemID = (PITEMID) RCStruct.ulParam1;
     if ((PVOID) pSaveClassAttr != NULL)
       free((PVOID) pSaveClassAttr);
     if ((PVOID) pSaveIntegersPtr != NULL)
        free((PVOID) pSaveIntegersPtr);

     fParentFound = FALSE;
     pFindItem = hCIF->pNewIDs;
     if (pCIUData->ulParentID != 0)
     {
       for (usIDIndex = 0; usIDIndex < hCIF->ulNumNewItems; usIDIndex++)
       {
         if (pCIUData->ulParentID == pFindItem->ulUID)
         {
           fParentFound = TRUE;
           break;
         }
         pFindItem++;
       }
     }


     hCIF->pNewItems->ulUID = pCIUData->ulUID;
     hCIF->pNewItems->ulParentID = pCIUData->ulParentID;
     strcpy((char *)hCIF->pNewItems->szItemID, (char *)pNewItemID);
     if (fParentFound)
       strcpy((char *)hCIF->pNewItems->szParentID, pFindItem->szItemID);
     else
       strcpy((char *)hCIF->pNewItems->szParentID, "");


     if (strcmp((char *)hCIF->pNewItems->szParentID, "") != 0)
     {
       ulRC = SimLibAddFolderItem(hSession,
                                  &hCIF->pNewItems->szParentID,
                                  pNewItemID,
                                  NULL,
                                  &RCStruct);
        if (ulRC != SUCCESS)
        {
            call_FFST(ulRC,
                      INT_ADD_FOLDER_ITEM_FAILED,
                      hCIF,
                      prcStruct);
            *prcStruct = RCStruct;
            return(INT_ADD_FOLDER_ITEM_FAILED);
        }
      }

     hCIF->pNewItems++;
     hCIF->ulNumNewItems++;
     if (hCIF->ulNumNewItems > 4096)
       return(INT_TOO_MANY_ITEMS);

     sSMS.ulStruct = sizeof(SMS);
     sSMS.lSMSRetention = -1;
     strcpy(sSMS.szCollectionName,"");
     strcpy(sSMS.szObjectName, "");
     strcpy(sSMS.szMgtCls, "");
     strcpy(sSMS.szStgCls, "");
     strcpy(sSMS.szDataCls, "");
     strcpy(sSMS.szStoreSite, "");
     strcpy(sSMS.szStoreHint, "");
     Obj.ulStruct = sizeof(OBJ);
     Obj.ulPart = 0;
     Obj.sVersion = 0;
     strcpy(Obj.chRepType, "");
     strcpy(Obj.szItemID, (char *)pNewItemID);


//-------------------------------------------------------------------------
//   Add all the notes as affiliated objects;
//-------------------------------------------------------------------------
     if (pCIUData->pItemNotes != NULL)
     {
       for ( ulIndex = 0; ulIndex < pCIUData->pItemNotes->ulNumNotes; ulIndex++)
       {

           Obj.ulPart++;
           ulRC = SimLibCreateObject(hSession,
                                     &Obj,
                                     SIM_CC_FRN_NOTE,
                                     &sSMS,
                                     OM_NORMAL_PRIORITY,
                                     SIM_OPEN,
                                     SIM_VER_ADDNEW,
                                     0,
                                     SIM_NOTE,
                                     NULL,
                                     NULL,
                                     &RCStruct);

           if (ulRC != SUCCESS)
           {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

               call_FFST(ulRC,
                         INT_ADD_AFF_OBJECT_FAILED,
                         hCIF,
                         prcStruct);
               if ((PVOID) pNewItemID != NULL)
                 SimLibFree(hSession, (PVOID) pNewItemID, prcStruct);
               *prcStruct = RCStruct;
               return(INT_ADD_AFF_OBJECT_FAILED);
           }
           hObjAcc = (HOBJACC) RCStruct.ulParam2;
           hNewObj = (HOBJ) RCStruct.ulParam1;
           ulRC = SimLibWriteObject(hSession,
                           hObjAcc,
                           (PHBUF) pCIUData->pItemNotes->aNote[ulIndex].pContent,
                           pCIUData->pItemNotes->aNote[ulIndex].ulLength,
                           NULL,
                           &RCStruct);
           if ( ulRC != SUCCESS)
           {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

               call_FFST(ulRC,
                         INT_CREATE_OBJECT_FAILED,
                         hCIF,
                         prcStruct);
               if ((PVOID) hNewObj != NULL)
                 SimLibFree(hSession, (PVOID) hNewObj, prcStruct);

               if ((PVOID) pNewItemID != NULL)
                 SimLibFree(hSession, (PVOID) pNewItemID, prcStruct);

               SimLibCloseObject(hSession,
                                 hObjAcc,
                                 TRUE,
                                 NULL,
                                 prcStruct);
               *prcStruct = RCStruct;
               return(INT_WRITE_OBJECT_FAILED);
           }

           ulRC = SimLibCloseObject(hSession,
                                    hObjAcc,
                                    TRUE,
                                    NULL,
                                    &RCStruct);
           if ( ulRC != SUCCESS)
           {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

               call_FFST(ulRC,
                         INT_CLOSE_OBJECT_FAILED,
                         hCIF,
                         prcStruct);
               if ((PVOID) hNewObj != NULL)
                 SimLibFree(hSession, (PVOID) hNewObj, prcStruct);
               *prcStruct = RCStruct;
               return(INT_CLOSE_OBJECT_FAILED);
           }

           if ((PVOID) hNewObj != NULL)
           {
             ulRC = SimLibFree(hSession, (PVOID) hNewObj, prcStruct);
             if ( ulRC != SUCCESS)
             {
               call_FFST(ulRC,
                         INT_MEMORY_FREEUP_FAILED,
                         hCIF,
                         prcStruct);
               return(INT_MEMORY_FREEUP_FAILED);
             }
           }
       } /* end the for ulNumNotes loop */
     } /* End - if pCIUData->pItemNotes != NULL */

//-------------------------------------------------------------------------
//   Add all the objects for the documents.
//-------------------------------------------------------------------------
     if (pCIUData->ulDataType == INT_EXPORT_DOCUMENT)
     {

       iSaveOffset = ftell((FILE *)hCIF->fpCIF);
       if (!fContentClass)
          ulSaveContentClass = SIM_CC_UNKNOWN;

       fFirstPart = TRUE;
       for ( ulObjectIndex = 0;
             ulObjectIndex < pCIUData->ulNumObj;
             ulObjectIndex++)
       {
         ulObjectClass = ulSaveContentClass;
         for ( ulIndex = 0;
               ulIndex < pCIUData->pObj->pObject[ulObjectIndex]->ulNumAttr;
               ulIndex++)
         {
           if (pCIUData->pObj->pObject[ulObjectIndex]->pItemAttrs != NULL)
           {
             if ((pCIUData->pObj->pObject[ulObjectIndex]->pItemAttrs->
                  aAttributes[ulIndex]->fAttrSys == TRUE) &&
                 (pCIUData->pObj->pObject[ulObjectIndex]->pItemAttrs->
                  aAttributes[ulIndex]->usAttrID == 6))
             {
              memset(&ulObjectClass, '\0', sizeof(ulObjectClass));
              copybytes((char *)&ulObjectClass,
                     (char *)pCIUData->pObj->pObject[ulObjectIndex]->pItemAttrs->
                     aAttributes[ulIndex]->pAttrValue,
                     pCIUData->pObj->pObject[ulObjectIndex]->pItemAttrs->
                     aAttributes[ulIndex]->ulLen);
             }
           }
         }

         if (fFirstPart)
         {
           Obj.ulPart++;
           fFirstPart = FALSE;
           ulRC = SimLibCreateObject(hSession,
                                     &Obj,
                                     ulObjectClass,
                                     &sSMS,
                                     OM_NORMAL_PRIORITY,
                                     SIM_OPEN,
                                     SIM_VER_ADDNEW,
                                     0,
                                     SIM_BASE,
                                     NULL,
                                     NULL,
                                     &RCStruct);
           if ( ulRC != SUCCESS)
           {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

               call_FFST(ulRC,
                         INT_CREATE_OBJECT_FAILED,
                         hCIF,
                         prcStruct);
               if ((PVOID) pNewItemID != NULL)
                 SimLibFree(hSession, (PVOID) pNewItemID, prcStruct);
               *prcStruct = RCStruct;
               return(INT_CREATE_OBJECT_FAILED);
           }

           hObjAcc = (HOBJACC) RCStruct.ulParam2;
           hNewObj = (HOBJ) RCStruct.ulParam1;
         }


         fseek((FILE *)hCIF->fpCIF,
               pCIUData->pObj->pObject[ulObjectIndex]->ulObjectOffset,
               SEEK_SET);
         fMoreToRead = TRUE;
         ulObjectLength = pCIUData->pObj->pObject[ulObjectIndex]->ulObjectLen;
         ulNumBytes = (ulObjectLength < 0x800000) ? ulObjectLength : 0x800000;
         pObjectBuffer = malloc(ulNumBytes);

         if (pObjectBuffer == NULL)
         {
            call_FFST(ulRC,
                      INT_ALLOCATE_OBJECT_BUFFER,
                      hCIF,
                      prcStruct);
            if ((PVOID) hNewObj != NULL)
              SimLibFree(hSession, (PVOID) hNewObj, prcStruct);

            if ((PVOID) pNewItemID != NULL)
              SimLibFree(hSession, (PVOID) pNewItemID, prcStruct);

         }
         ulBufferSize = ulNumBytes;

         while (fMoreToRead)
         {
           if (ulObjectLength > ulBufferSize)
           {
             ulNumBytes = fread(pObjectBuffer, 1, ulBufferSize, (FILE *)hCIF->fpCIF);
             ulObjectLength = ulObjectLength - ulBufferSize;
           }
           else
           {
             fMoreToRead = FALSE;
             ulNumBytes = fread(pObjectBuffer, 1, ulObjectLength, (FILE *)hCIF->fpCIF);
           }

           if (ulNumBytes > 0)
           {

             ulRC = SimLibWriteObject(hSession,
                             hObjAcc,
                             (PHBUF) pObjectBuffer,
                             ulNumBytes,
                             NULL,
                             &RCStruct);
             if ( ulRC != SUCCESS)
             {

    /*------------------------------------------------------------------------*/
    /*    If the API fails, we have to free up anything left open.            */
    /*------------------------------------------------------------------------*/

                 call_FFST(ulRC,
                           INT_CREATE_OBJECT_FAILED,
                           hCIF,
                           prcStruct);
                 if ((PVOID) hNewObj != NULL)
                   SimLibFree(hSession, (PVOID) hNewObj, prcStruct);

                 if ((PVOID) pNewItemID != NULL)
                   SimLibFree(hSession, (PVOID) pNewItemID, prcStruct);

                 SimLibCloseObject(hSession,
                                   hObjAcc,
                                   TRUE,
                                   NULL,
                                   prcStruct);
                 free(pObjectBuffer);
                 *prcStruct = RCStruct;
                 return(INT_WRITE_OBJECT_FAILED);
             }
           } /* End - if num bytes read > 0 */
         } /* End - while object bytes are left */

         free(pObjectBuffer);

/*------------------------------------------------------------------------*/
/*    If the next object is a first part, then this is the end of the     */
/*    current object.                                                     */
/*------------------------------------------------------------------------*/

         if ((ulObjectIndex+1) < pCIUData->ulNumObj)
           if (pCIUData->pObj->pObject[ulObjectIndex+1]->fFirstPart == TRUE)
             fFirstPart = TRUE;
           else
             fFirstPart = FALSE;
         else
           fFirstPart = TRUE;

         if (fFirstPart)
         {
           ulRC = SimLibCloseObject(hSession,
                                    hObjAcc,
                                    TRUE,
                                    NULL,
                                    &RCStruct);
           if ( ulRC != SUCCESS)
           {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

               call_FFST(ulRC,
                         INT_CLOSE_OBJECT_FAILED,
                         hCIF,
                         prcStruct);
               if ((PVOID) hNewObj != NULL)
                 SimLibFree(hSession, (PVOID) hNewObj, prcStruct);
               *prcStruct = RCStruct;
               return(INT_CLOSE_OBJECT_FAILED);
           }

           if ((PVOID) hNewObj != NULL)
           {
             ulRC = SimLibFree(hSession, (PVOID) hNewObj, prcStruct);
             if ( ulRC != SUCCESS)
             {
               call_FFST(ulRC,
                         INT_MEMORY_FREEUP_FAILED,
                         hCIF,
                         prcStruct);
               return(INT_MEMORY_FREEUP_FAILED);
             }
           }
         }
       }   /* End the for ulNumObj loop */

       fseek((FILE *)hCIF->fpCIF, iSaveOffset, SEEK_SET);

       if ((PVOID) pNewItemID != NULL)
       {
         ulRC = SimLibFree(hSession, (PVOID) pNewItemID, prcStruct);
         if ( ulRC != SUCCESS)
         {
           call_FFST(ulRC,
                     INT_MEMORY_FREEUP_FAILED,
                     hCIF,
                     prcStruct);
           return(INT_MEMORY_FREEUP_FAILED);
         }
       }
     }

     pCIUData = pCIUData->pCIUData;
   } /* end while(pCIUData != NULL); */

  prcStruct->ulRC = ulRC;
  return(ulRC);
}


/*BEGINPROLOGUE*************************************************/
/*  Function  : AddClassToClassTables      Date:    May      93*/
/*  Module    : FRNOICSE.C                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                            stdio.h                          */
/*                            stdlib.h                         */
/*                Product Functions:                           */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG                                       */
/*                                                             */
/*  Input Parameters:                                          */
/*                                                             */
/*  Output Parameters:                                         */
/*      None                              output is file       */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Process Flow:                                              */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

  ULONG  _Optlink AddClassToClassTables(HSESSION hSession,
                                        HCIF     hCIF,
                                        USHORT usClassID,
                                        PRCSTRUCT prcStruct)
{
typedef struct _ATTRVALUES          /* ftime */
        {
        CHAR   szValue[4];
        } ATTRVALUES;
CHAR            *pszTemp;
ULONG           ulRC=0;
ULONG           ulIndex;
USHORT          usAttrID;
ATTRLISTSTRUCT  AttrList[28];
CHAR            szBuffer[20];
RCSTRUCT        RCStruct;
ATTRVALUES      szAttrValues[] = {{""},    // Class ID
                             {"0"},
                             {"0"},
                             {"0"},
                             {"0"},
                             {"0"},
                             {"0"},
                             {"100"},
                             {"0"},
                             {""},
                             {"0"},
                             {""},
                             {"0"},
                             {""},
                             {""},
                             {""},
                             {""},
                             {""},
                             {""},
                             {""},
                             {""},   // last for FRN$INDX
                             {""},   // Class ID for FRN$VIEW
                             {"40"},
                             {""},
                             {""},
                             {""},
                             {""},
                             {""},
                                 };


       usAttrID = 12;
       pszTemp = ltoa(usClassID, szBuffer, 10);
       strncpy(szAttrValues[0].szValue,  pszTemp, 3);
       strncpy(szAttrValues[21].szValue, pszTemp, 3);
       for (ulIndex = 0; ulIndex < 29; ulIndex++)
       {
         AttrList[ulIndex].ulStruct = sizeof(ATTRLISTSTRUCT);
         AttrList[ulIndex].fAttrFlags = SIM_ATTR_READWRITE;
         AttrList[ulIndex].usAttrId = usAttrID;
         AttrList[ulIndex].usAttrType = SIM_ATTR_FSTRING;
         AttrList[ulIndex].pszAttributeValue = (CHAR *)&szAttrValues[ulIndex].szValue;
         usAttrID++;
       }

       ulRC = SimLibCreateItem(hSession,
                               SIM_DOCUMENT,
                               4,
                               21,
                               &AttrList[0],
                               NULL,
                               NULL,
                               &RCStruct);
       if ( ulRC != SUCCESS)
       {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

           call_FFST(ulRC,
                     INT_CREATE_ITEM_FAILED,
                     hCIF,
                     prcStruct);
           *prcStruct = RCStruct;
           return(INT_CREATE_ITEM_FAILED);
       }

       ulRC = SimLibCreateItem(hSession,
                               SIM_DOCUMENT,
                               5,
                               7,
                               &AttrList[21],
                               NULL,
                               NULL,
                               &RCStruct);
       if ( ulRC != SUCCESS)
       {

/*------------------------------------------------------------------------*/
/*    If the API fails, we have to free up anything left open.            */
/*------------------------------------------------------------------------*/

           call_FFST(ulRC,
                     INT_CREATE_ITEM_FAILED,
                     hCIF,
                     prcStruct);
           *prcStruct = RCStruct;
           return(INT_CREATE_ITEM_FAILED);
       }

       prcStruct->ulRC = ulRC;
       return(ulRC);
}

/****************************************************************************/
/* This procedure takes an EBCDIC string of a specified length and converts */
/* an ASCii string using the specified table (SV_A, SV_AE, or SV_G).        */
/****************************************************************************/
void ebcdic2ascii (PSZ pszString, const UINT length, HCIF hCIF)
{ /* beginning of ebcdic2ascii() */

   HAB hab=0L;
   USHORT cpSrc=500;
   USHORT cpDst=850; /* universal code page */
   int i = 0;
   PSZ pszTarget;
   ULONG ulList[18];
   ULONG ulSize;
   USHORT usNumCP = 0;
   APIRET rc;
   BOOL   fFound = FALSE;

   if (length > 0)
   {
     /******************************************/
     /* Initialize the list of code pages to 0 */
     /******************************************/
     memset (ulList,0,sizeof(ulList));


     /*********************************/
     /* set the destination code page */
     /*********************************/
     cpSrc = (USHORT)hCIF->ulCdPge;


     /**************************************/
     /* Query the system for the code page */
     /**************************************/
     rc = DosQueryCp( sizeof(ulList),
                 ulList,
                &ulSize);

     if (rc == 0)
     {

       /***********************************************/
       /* Calculate the number of code pages returned */
       /***********************************************/
       usNumCP = (USHORT)(ulSize / 4);


       /*****************************************/
       /* If there are code pages defined then  */
       /* set the Code Page to the primary one. */
       /*****************************************/
       if (usNumCP > 0) cpDst = (USHORT)ulList[0];


       if (cpDst < 900)    // PTR 3867 fix
       {
         /*********************************************/
         /* If any of the code pages specified is the */
         /* universal code page then set the code     */
         /* page to the universal code page.          */
         /*********************************************/
         for (i = 0; i < usNumCP; i++)
           if (ulList[i] == 850) cpDst = (USHORT)ulList[i];
           if (ulList[i] == hCIF->ulCdPge) fFound = TRUE;
       }
     } /* End if rc == 0 */

     if (cpDst < 900)  // PTR 3867 fix
     {
       if ((fFound == FALSE) || (cpSrc == 0))
         cpSrc = 500;

       /*******************************************/
       /* Allocate memory for the translated text */
       /*******************************************/
       pszTarget=calloc(length+1,1);


       /****************************************/
       /* Translate the text from the supplied */
       /* code page to the code page specified */
       /* in the CCSID.                        */
       /****************************************/
       WinCpTranslateString(hab, cpSrc, pszString, cpDst, length+1, pszTarget);


       /**********************************************/
       /* Copy the converted text to the return parm */
       /**********************************************/
       copybytes((char *)pszString,(char *)pszTarget,length+1);


       /*************************************/
       /* Where ever 0xFF is in the string, */
       /* replace it with new line.         */
       /*************************************/
       for(i=0;i<length;i++)
          if(pszString[i]==0xFF) pszString[i]='\n';


       /*****************************************************/
       /* Free the memory allocated for the translated text */
       /*****************************************************/
       free(pszTarget);
     }
   }
   else
     pszString = NULL;


   /**********************************/
   /* Return to the calling function */
   /**********************************/
   return;


} /* end of ebcdic2ascii() */

/*BEGINPROLOGUE*************************************************/
/*  Function  : call_FFST                  Date:    May      93*/
/*  Module    : FRNOICSE.C                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                            stdio.h                          */
/*                            stdlib.h                         */
/*                Product Functions:                           */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG                                       */
/*                                                             */
/*  Input Parameters:                                          */
/*                                                             */
/*  Output Parameters:                                         */
/*      None                              output is file       */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*                                                             */
/*                                                             */
/*  Process Flow:                                              */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

  ULONG  _Optlink call_FFST(ULONG ulAPI_RC,
                            ULONG ulFailRC,
                            HCIF  hCIF,
                            PRCSTRUCT prcStruct)
{
ULONG    ulRC=0;
ULONG    ulLogTypel;
SHORT    sResult=0;

     prcStruct->ulExtRC = (USHORT) ulAPI_RC;
     prcStruct->ulRC    = (USHORT) ulFailRC;
     ulRC = ulFailRC;                   // Return this API's rc.
#ifdef  INTRPROD
     if (hCIF != NULL)
       UtlEpwStrt("FRNIC", &hCIF->ulLogType);
     else
     {
       ulLogType = LOG_ERR;
       UtlEpwStrt("FRNIC", &ulLogType);
     }
     UtlEpwMsg(ulFailRC,
               LOG_ERR,
               "FRNIC",
               __FILE__,
               __LINE__,
               sResult,
               NULL);
      UtlEpwStop();
#endif
      return(ulRC);
}

/*--------------------------------------------------------------------------*/
/* copybytes() routine is used in replaced of memcpy becuase the DBCS       */
/* version of memcpy (mc_memcpy)  replaces the last byte when is some       */
/* cases to maintain DBCS inetgrity.  We do not want that so this routine   */
/* is used instead.                                                         */
/*--------------------------------------------------------------------------*/
void copybytes (char *pTarget, char *pSource, size_t cnt)
{
  size_t  i;

   for (i = 0; i < cnt; i++)
   {
     pTarget[i] = pSource[i];
   }
}

/******************************************************************************/
/* FreeStuff                                                                  */
/* free up stuff allocated in Ip2OpenImportCIF                                */
/******************************************************************************/
void FreeStuff(HCIF hCIF)
{

  if ((PVOID)hCIF != NULL) {

     if ((PVOID)hCIF->pSaveNewAttrPtr != NULL) free(hCIF->pSaveNewAttrPtr);

     if ((PVOID)hCIF->pICBuffer != NULL)       free(hCIF->pICBuffer);

     if ((PVOID)hCIF->pHeader != NULL)         free(hCIF->pHeader);

     if ((PVOID)hCIF->pAttrBuffer != NULL)     free(hCIF->pAttrBuffer);

     if ((PVOID)hCIF->pSaveClassMatch != NULL) free(hCIF->pSaveClassMatch);

     free(hCIF);

  } /* endif */

   return;
}

