/*BEGINPROLOGUE**************************************************************/
/*                                                                          */
/* MODULE: frnouecc.c                    VisualInfo                         */
/*                                                                          */
/* 5697-250, 5621-326                                                       */
/* (C) Copyright IBM Corp. 1993,1994.                                       */
/* All Rights Reserved.                                                     */
/*                                                                          */
/* DERIVATIVE RIGHTS:                                                       */
/* ------------------                                                       */
/* This program is provided for the customer's use and the customer is      */
/* granted permission to copy this program to the extent reasonably         */
/* required for such use.  All title, ownership, and rights to this         */
/* program and any copies remain with IBM, irrespective of the ownership    */
/* of the media on which the program resides.  The customer is permitted    */
/* to create derivative works to this program.  However, all copies of      */
/* the program and its derivative works must contain the IBM copyright      */
/* notice.  The customer understands and agrees that this program in and    */
/* of itself is not to be sold or distributed.  The customer is free to     */
/* sell, distribute, and commercially exploit any derivative works          */
/* created from this program.                                               */
/*                                                                          */
/*                                                                          */
/* DISCLAIMER OF WARRANTIES:                                                */
/* -------------------------                                                */
/* The following [enclosed] code is sample code created by IBM              */
/* Corporation.  This sample code is not part of any standard IBM product   */
/* and is provided to you solely for the purpose of assisting you in the    */
/* development of your applications.  The code is provided "AS IS",         */
/* without warranty of any kind.  IBM shall not be liable for any damages   */
/* arising out of your use of the sample code, even if they have been       */
/* advised of the possibility of such damages.                              */
/*                                                                          */
/* Programmer:                                                              */
/*                                                                          */
/* Date: January 1994                                                       */
/*                                                                          */
/* Status: Version 1 Release 1 Modification 0                               */
/*                                                                          */
/* Description: frnouecc.c - this module contains the Image                 */
/*              Services/2 Content Class User Exit for the                  */
/*              VisualInfo Client Application for OS/2                      */
/*                                                                          */
/* Dependencies:                                                            */
/* Restrictions:                                                            */
/*                                                                          */
/* Entry Points: SimOpsStartClass()                                         */
/*               SimOpsEndClass()                                           */
/*               SimOpsSetClass()                                           */
/*                                                                          */
/* Change History:                                                          */
/*                                                                          */
/* Notes:                                                                   */
/*  - the DCR/PTR number should appear in a comment                         */
/*    near the change                                                       */
/*  - function names should have Capital letters as                         */
/*    demonstrated above                                                    */
/*  - This module is based on isomisc.c of IRM 1.3                          */
/*                                                                          */
/*ENDPROLOGUE****************************************************************/

/*------------------------------------------*/
/* pragma definitions                       */
/*------------------------------------------*/
#pragma strings(readonly)
#pragma alloc_text( SEGONE,   ExternalObjectMonitor )
#pragma alloc_text( SEGONE,   StoreInfo )
#pragma alloc_text( SEGTWO,   SimOpsStartClass )
#pragma alloc_text( SEGTWO,   QueryFileTime )
#pragma alloc_text( SEGTWO,   CreateTempFileName )
#pragma alloc_text( SEGTWO,   CreateTempFile )
#pragma alloc_text( SEGTWO,   GenRandString )
#pragma alloc_text( SEGTRHEE, SimOpsEndClass )
#pragma alloc_text( SEGTHREE, SimOpsSelectClass )
#pragma alloc_text( SEGTHREE, DeleteInfo )

/*--------------------*/
/* OS/2 include files */
/*--------------------*/
#define  INCL_BASE
#define  INCL_DOSERRORS
#define  INCL_DOSSEMAPHORES
#define  INCL_DOSPROCESS
#define  INCL_WIN
#define  INCL_PM
#define  INCL_GPI
#include <os2.h>


/*-----------------*/
/* C include files */
/*-----------------*/

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <direct.h>
#include <sys\stat.h>
#include <io.h>
#include <fcntl.h>
#include <share.h>
#include <time.h>

#define FRN_INCL_FO
#define FRN_INCL_FI
#define FRNPCAPI_NOPPULONG
#define OPS_EXIT_IOSIZE 32000

/*--------------------*/
/* IS/2 include files */
/*--------------------*/
#include "fiwsws.h"
#include "fiwsenv.h"
#include "fiwsxcc.h"


/*---------------------------------------------*/
/* VisualInfo Client Application include files */
/*---------------------------------------------*/
#include "frnpcapi.h"
#include "frnptype.h"
#include "frnpauer.h"
#include "frnp.h"
#include "frnolgar.h"
#include "frnolg.h"
#include "frnpvw.h"


/*--------------------------*/
/* local defines            */
/*--------------------------*/

#define WINGETPARENT(h)    WinQueryWindow(h, QW_PARENT)
#define WINGETFRAME        WINGETPARENT
#define CC_GEN_SEM_WAIT    5000
#define CC_LLST_SEM_WAIT   5000
#define CC_GEN_SEM_NAME    "\\SEM32\\FRNOUECC\\GENERAL"
#define CC_LLST_SEM_NAME   "\\SEM32\\FRNOUECC\\LINKLIST"
#define CC_TERM_QUEUE_NAME "\\QUEUES\\FRNOIMG\\FRNOUECC"


/*--------------------------*/
/* Internal data structures */
/*--------------------------*/

typedef struct _CCLINKLISTSTRUCT
{
   HWND                        hwndView;
   PVWINFO                     pViewInfo;
   ULONG                       ulSessionId;
   HWND                        hwndNotify;
   ULONG                       ulMsgNotify;
   struct _CCLINKLISTSTRUCT  * pNext;
} CCLINKLISTSTRUCT, *PCCLINKLISTSTRUCT;

typedef struct
{
   ULONG    ulSessionId;
   SIMWSOBJ hWsObj;
   ULONG    ulClassId;
   PVWINFO  pViewInfo;
   CHAR     szFileName[ _MAX_PATH + 1 ];
   ULONG    ulFileCreateTime;
} OPSEXITOBJ, *POPSEXITOBJ;


/*--------------------------*/
/* Global variables         */
/*--------------------------*/

static PCCLINKLISTSTRUCT pLinkListHead = NULL;
static PCCLINKLISTSTRUCT pLinkListLast = NULL;
static HMTX              hmtxLinkList = (HMTX) 0;
static HMTX              hmtxFrnouecc = (HMTX) 0;
static HQUEUE            hQueue = (HQUEUE) 0;
static TID               ThreadId = (TID) 0;
static HMODULE           hmodRes = (HMODULE) 0;
static HAB               hab = (HAB) 0;
static CHAR              szTitleString[ 100 + 1 ];


/*--------------------------*/
/* Local function prototypes*/
/*--------------------------*/

#pragma linkage( ExternalObjectMonitor, system )
void ExternalObjectMonitor( void );
ULONG _Optlink QueryFileTime ( PSZ pszFilename );
BOOL  _Optlink StoreInfo ( PVWINFO  pVWInfo, HWND hViewWin );
BOOL  _Optlink DeleteInfo ( PVWINFO  pVWInfo, HWND hViewWin );
PSZ   _Optlink CreateTempFileName( PSZ pszFileName );
ULONG _Optlink CreateTempFile( PSZ pszFileName, SIMBUFFERSTRUCT SimBuffer );
VOID  _Optlink GenRandString( PSZ pszString, USHORT usStringSize );


/*BEGINPROLOGUE*************************************************/
/*  Function  : SimOpsStartClass  Originating Date: January 94 */
/*  Module    : frnouecc.c                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                Product Functions:                           */
/*                                                             */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG SIMENTRY                              */
/*                                                             */
/*  Input Parameters:                                          */
/*                                                             */
/*  Output Parameters:                                         */
/*                                                             */
/*  Synopsis:  ULONG SIMENTRY SimOpsStartClass()               */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*  Process Flow:                                              */
/*                                                             */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

ULONG SIMENTRY SimOpsStartClass(
   HWND     hWinNotify,
   ULONG    ulMsgNotify,
   SIMWSOBJ hWsObj,
   ULONG    ulClassId,
   PSZ      pszPathAndPgm,
   PSZ      pszWorkingDir,
   PSZ      pszParms,
   PVOID    pReserved,
   PPVOID   phObjId )
{
   POPSEXITOBJ       pExitObj;
   PSZ               pszTemp;
   PCCLINKLISTSTRUCT pLinkListCurr;
   ULONG             ulRC;
   ULONG             ulSessionId;
   ULONG             AppType;
   ULONG             ulPid;
   ULONG             ulIndex;
   BOOL              fRestorePrevDrive = FALSE;
   BOOL              fRestorePrevDir = FALSE;
   BOOL              fLinkFound = FALSE;
   BOOL              fhWsObjFound = FALSE;
   int               nPrevDrive;
   int               nTargetDrive;
   HWND              hwndLOW;
   CHAR              szPrevWkDir[ _MAX_PATH + 1 ];
   CHAR              szPgmInputs[ _MAX_PATH + 1 ];
   CHAR              szTargetWkDir[ _MAX_PATH + 1 ];
   CHAR              szPgmExeAndInputs[ _MAX_PATH + 1 ];
   CHAR              szFileName[ _MAX_PATH + 1 ];
   CHAR              szFileExtension[ 3 + 1 ];
   RCSTRUCT          RC;
   SIMBUFFERSTRUCT   SimBuffer;
   STARTDATA         startData;


   APIRET rcq;
   UCHAR  name3  [32];
   CHAR   pidstr [32];
   PTIB   pptib;
   PPIB   pppib;


   /*-------------------------------------------------------------------------*/
   /* Get the general semaphore                                               */
   /*-------------------------------------------------------------------------*/
   ulRC = DosRequestMutexSem( hmtxFrnouecc, CC_GEN_SEM_WAIT );

   printf("Entering SimOpsStartClass\n");

   /*-------------------------------------------------------------------------*/
   /* Initialization                                                          */
   /*-------------------------------------------------------------------------*/
   ulRC = SIM_RC_OK;

   memset( &RC, 0, sizeof( RCSTRUCT ) );
   RC.ulStruct = sizeof( RCSTRUCT );

   memset( &SimBuffer, 0, sizeof( SIMBUFFERSTRUCT ) );
   SimBuffer.ulStruct = sizeof( SIMBUFFERSTRUCT );
   SimBuffer.pucBuffer = NULLHANDLE;

   memset( szFileName, '\0', _MAX_PATH + 1 );
   memset( szPgmInputs, '\0', _MAX_PATH + 1 );
   memset( szPrevWkDir, '\0', _MAX_PATH + 1 );
   memset( szTargetWkDir, '\0', _MAX_PATH + 1 );

   pExitObj = NULL;

   printf("Searching for the link list entry\n");

   /*-------------------------------------------------------------------------*/
   /* Get the linked list semaphore                                           */
   /*-------------------------------------------------------------------------*/
   ulRC = DosRequestMutexSem( hmtxLinkList, CC_LLST_SEM_WAIT );

   /*-------------------------------------------------------------------------*/
   /* Find the element of the linked list that pertains to this hWsObj        */
   /*-------------------------------------------------------------------------*/
   pLinkListCurr = pLinkListHead;
   while ( ( !fLinkFound ) && ( pLinkListCurr != NULL ) )
   {
      ulIndex = 0;
      while ( ( !fhWsObjFound )
           && ( ulIndex < pLinkListCurr->pViewInfo->ulhWsObjTotal ) )
      {
         if ( hWsObj == pLinkListCurr->pViewInfo->PartInfo[ ulIndex ].hWsObj )
         {
            fhWsObjFound = TRUE;
         }
         else
         {
            ulIndex++;
         }
      } /* end while () */

      if ( fhWsObjFound )
      {
         fLinkFound = TRUE;
      }
      else
      {
        pLinkListCurr = pLinkListCurr->pNext;
      }
   } /* end while () */

   /*-------------------------------------------------------------------------*/
   /* Release the linked list semaphore                                       */
   /*-------------------------------------------------------------------------*/
   DosReleaseMutexSem( hmtxLinkList );

   if ( !fLinkFound )
   {
      printf("Searching for the link list entry failed\n");
      ulRC = SIM_RC_OS_ERROR;
   }
   else
   {
      printf("Searching for the link list entry successful\n");
      pLinkListCurr->hwndNotify = hWinNotify;
      pLinkListCurr->ulMsgNotify = ulMsgNotify;

      /*----------------------------------------------------------------------*/
      /* Get the window handle of the library object window                   */
      /*----------------------------------------------------------------------*/
      hwndLOW = WINGETPARENT( WINGETFRAME( pLinkListCurr->pViewInfo->hwndClient ) );

      /*----------------------------------------------------------------------*/
      /* Insure we got a valid object handle and program name                 */
      /*----------------------------------------------------------------------*/
      if ( ( phObjId == NULLHANDLE )
        || ( pszPathAndPgm == NULLHANDLE )
        || ( hWsObj == NULLHANDLE ) )
      {
         /*----------------------------------------------------------------------*/
         /* Log invalid input parameter                                          */
         /*----------------------------------------------------------------------*/
         MsgDisplayErr( hwndLOW,
                        hmodRes,
                        0,
                        szTitleString,
                        INVALID_INPUT_PARM,
                        MB_ICONHAND | MB_OK,
                        INVALID_INPUT_PARM,
                        0,
                        NULL );

         ulRC = SIM_RC_PARM_INVALID;
      }
      else
      {
         /*-------------------------------------------------------------------*/
         /* Allocate a class object structure                                 */
         /*-------------------------------------------------------------------*/
         memset( &RC, 0, sizeof( RCSTRUCT ) );
         RC.ulStruct = sizeof( RCSTRUCT );
         ulRC = SimOpsAllocMem( sizeof( OPSEXITOBJ ),
                                (PVOID) &pExitObj,
                                &RC );
         printf("Return Code from SimOpsAllocMem : %d\n", ulRC );

         if ( ulRC == SIM_RC_OK )
         {
            pExitObj->ulSessionId = 0;
            pExitObj->hWsObj = hWsObj;
            pExitObj->ulClassId = ulClassId;
            pExitObj->pViewInfo = pLinkListCurr->pViewInfo;
            pExitObj->szFileName[ 0 ] = '\0';
            pExitObj->ulFileCreateTime = 0;
            *phObjId= (PVOID) pExitObj;
         }
         else
         {
            MsgDisplayErr( hwndLOW,
                           hmodRes,
                           0,
                           szTitleString,
                           ERR_OUT_OF_MEMORY,
                           MB_ICONHAND | MB_OK,
                           ERR_OUT_OF_MEMORY,
                           0,
                           NULL );

            *phObjId = NULLHANDLE;

            ulRC = SIM_RC_OUT_OF_MEMORY;
         }

         /*-------------------------------------------------------------------*/
         /* If everything is OK so far, proceed                               */
         /*-------------------------------------------------------------------*/
         if ( ulRC == SIM_RC_OK )
         {
            /*----------------------------------------------------------------*/
            /* Let's get the working set object buffer                        */
            /*----------------------------------------------------------------*/
            memset( &RC, 0, sizeof( RCSTRUCT ) );
            RC.ulStruct = sizeof( RCSTRUCT );
            ulRC = SimWsQueryObj( hWsObj,
                                  SIMUSER_DISPLAY,
                                  SIMWS_BUFFER,
                                  (PVOID)&SimBuffer,
                                  &RC );
            printf("Return Code from SimWsQueryObj : %d\n", ulRC );

            if ( ulRC != SIM_RC_OK )
            {
               CHAR szBuffer[ 10 ];

               MsgDisplayErr(hwndLOW,
                             hmodRes,
                             0,
                             szTitleString,
                             ERR_GET_BUFFER,
                             MB_ICONHAND | MB_OK,
                             ERR_GET_BUFFER,
                             0,
                             _itoa( ulRC, szBuffer, 10 ),
                             NULL );

               SimBuffer.pucBuffer = NULLHANDLE;
            } /* endif */
         } /* endif */

         /*-------------------------------------------------------------------*/
         /* If everything is OK so far, proceed                               */
         /*-------------------------------------------------------------------*/
         if ( ulRC == SIM_RC_OK )
         {
            if ( ulRC == SIM_RC_OK )
            {
               /*-------------------------------------------------------------*/
               /* If a working directory was not specified use current        */
               /* directory, otherwise change to that directory               */
               /*-------------------------------------------------------------*/
               if ( pszWorkingDir != NULL)
               {
                  /*----------------------------------------------------------*/
                  /* Get the full target working directory path               */
                  /*----------------------------------------------------------*/
                  if ( _fullpath( szTargetWkDir, pszWorkingDir, _MAX_PATH )
                       != NULL )
                  {
                     /*-------------------------------------------------------*/
                     /* Get the current directory                             */
                     /*-------------------------------------------------------*/
                     if ( _getcwd( szPrevWkDir, _MAX_PATH ) != NULL )
                     {
                        /*----------------------------------------------------*/
                        /* Attempt to change to the target directory          */
                        /*----------------------------------------------------*/
                        if ( _chdir( szTargetWkDir ) == 0 )
                        {
                           /*-------------------------------------------------*/
                           /* We need to restore the directory later          */
                           /*-------------------------------------------------*/
                           fRestorePrevDir = TRUE;

                           /*-------------------------------------------------*/
                           /* Get the current drive                           */
                           /*-------------------------------------------------*/
                           nPrevDrive = _getdrive();

                           /*-------------------------------------------------*/
                           /* Determine the target drive                      */
                           /*-------------------------------------------------*/
                           nTargetDrive = szTargetWkDir[0] - 'A' + 1;

                           /*-------------------------------------------------*/
                           /* Attempt to change to target drive               */
                           /*-------------------------------------------------*/
                           if ( _chdrive(nTargetDrive) == 0 )
                           {
                              /*----------------------------------------------*/
                              /* We need to restore the drive later           */
                              /*----------------------------------------------*/
                              fRestorePrevDrive = TRUE;
                           }
                           else
                           {
                              ulRC = SIM_RC_OS_ERROR;

                              MsgDisplayErr(hwndLOW,
                                            hmodRes,
                                            0,
                                            szTitleString,
                                            ERR_CHANGE_DRV,
                                            MB_ICONHAND | MB_OK,
                                            ERR_CHANGE_DRV,
                                            0,
                                            NULL );
                           }
                        }
                        else
                        {
                           ulRC = SIM_RC_OS_ERROR;

                           MsgDisplayErr(hwndLOW,
                                         hmodRes,
                                         0,
                                         szTitleString,
                                         ERR_CHANGE_DIR,
                                         MB_ICONHAND | MB_OK,
                                         ERR_CHANGE_DIR,
                                         0,
                                         NULL );
                        }
                     }
                     else
                     {
                        ulRC = SIM_RC_OS_ERROR;

                        MsgDisplayErr(hwndLOW,
                                      hmodRes,
                                      0,
                                      szTitleString,
                                      ERR_GET_CURRENT_DIR,
                                      MB_ICONHAND | MB_OK,
                                      ERR_GET_CURRENT_DIR,
                                      0,
                                      NULL );
                     }
                  }
                  else
                  {
                     ulRC = SIM_RC_OS_ERROR;

                     MsgDisplayErr(hwndLOW,
                                   hmodRes,
                                   0,
                                   szTitleString,
                                   ERR_GET_FULL_PATH,
                                   MB_ICONHAND | MB_OK,
                                   ERR_GET_FULL_PATH,
                                   0,
                                   NULL );
                  }
               }

               /*-------------------------------------------------------------*/
               /* If everything is OK so far, proceed                         */
               /*-------------------------------------------------------------*/
               if ( ulRC == SIM_RC_OK )
               {
                  if ( strlen(szFileName) == 0 &&
                       SimBuffer.pucBuffer != NULLHANDLE &&
                       SimBuffer.ulSize > 0 )
                  {
                     /*-------------------------------------------------------*/
                     /* Create a random temporary file name                   */
                     /*-------------------------------------------------------*/
                     CreateTempFileName( szFileName );

                     if ( strlen( szFileName ) != 0 )
                     {
                        PSZ pszStartParms = NULL;

                        // insure we have some parameters and/or a file name
                        // before we try to determine what they are
                        if ( pszParms != NULL )
                        {
                           pszStartParms = pszParms;

                           // If a default extension was specified in SysAdmin,
                           // use it instead of the random one. we will know
                           // from the presence of a '.' as the first character
                           // in the pszParms string. The extension follows,
                           // then a space and the the command line parms.
                           if ( '.' == pszParms[ 0 ] )
                           {
                              // if there is more data after the extension we
                              // only want to put the extension in the file
                              // name so search for the first space
                              pszTemp = NULL;
                              pszTemp = strchr( pszParms, ' ' );

                              if ( pszTemp != NULL )
                              {
                                 // we have cmd line parms, so only extract
                                 // the extension
                                 memset( szFileExtension, 0, 4 );
                                 strncpy( szFileExtension,
                                          pszParms + 1,
                                          pszTemp - ( pszParms + 1 ) );
                              }
                              else
                              {
                                 // we only have an extension, so copy the whole
                                 // thing
                                 memset( szFileExtension, 0, 4 );
                                 strncpy( szFileExtension, pszParms + 1, 3 );
                              }

                              // save the current position of pszTemp as this
                              // is where the parms start if not null and
                              // it is null if there are no additional parms
                              pszStartParms = pszTemp;

                              // search for the "." in the file name and copy
                              // the user specified extension over the randomly
                              // generated one.
                              pszTemp = szFileName;
                              while (strncmp(pszTemp, ".", 1) != 0)
                              {
                                 pszTemp++;
                              }
                              strcpy( pszTemp + 1, szFileExtension );
                           }
                        }

                        printf("CreateTempFileName returned : %s\n", szFileName );

                        // now save the program parms if there are any.
                        // we have two ways to handle cmd line parms.
                        // 1. the sysadmin specifies a parm line with a
                        // substitution field of %s of %S. we will replace
                        // this with the file name of the temp file.
                        // 2. the sysadmin specifies a parm line without
                        // a substitution field. we will pass the data to
                        // the program "'parms' 'filename'"

                        if ( pszStartParms != NULL )
                        {
                           pszTemp = NULL;
                           pszTemp = strstr( pszStartParms, "%s" );
                           if ( pszTemp == NULL )
                           {
                              pszTemp = strstr( pszStartParms, "%S" );
                              if ( pszTemp == NULL )
                              {
                                 strcpy( szPgmInputs, pszStartParms );
                                 strcat( szPgmInputs, " " );
                                 strcat( szPgmInputs, szFileName );
                              }
                              else
                              {
                                 strncpy( szPgmInputs,
                                          pszStartParms,
                                          pszTemp - pszStartParms );
                                 strcat( szPgmInputs, szFileName );
                                 pszTemp += 2;
                                 strcat( szPgmInputs, pszTemp );
                              }
                           }
                           else
                           {
                              strncpy( szPgmInputs,
                                       pszStartParms,
                                       pszTemp - pszStartParms );
                              strcat( szPgmInputs, szFileName );
                              pszTemp += 2;
                              strcat( szPgmInputs, pszTemp );
                           }
                        }
                        else
                        {
                           // no command line parms specified
                           strcpy( szPgmInputs, szFileName );
                        }

                        // Create a file from the object buffer based on the
                        // temporary file name we generated
                        ulRC = CreateTempFile( szFileName, SimBuffer );

                        if ( ulRC == SIM_RC_OK )
                        {
                           /* save the time the document was being writen     */
                           /* to the temp file            - BC                */
                           pExitObj->ulFileCreateTime =
                                                   QueryFileTime( szFileName );

                           /* Remember the file name, so that it can          */
                           /*  be deleted in SimOpsEndClass                   */
                           strcpy( pExitObj->szFileName, szFileName );

                        } /* endif */
                     }
                     else
                     {
                        ulRC = SIM_RC_OS_ERROR;

                        MsgDisplayErr(hwndLOW,
                                      hmodRes,
                                      0,
                                      szTitleString,
                                      ERR_GENERATE_FILENAME,
                                      MB_ICONHAND | MB_OK,
                                      ERR_GENERATE_FILENAME,
                                      0,
                                      NULL );
                     }  /* endif */
                  } /* endif */
               } /* endif */

               rcq = DosGetInfoBlocks(&pptib, &pppib);
               sprintf(pidstr,"%d", pppib->pib_ulpid);
               strcpy(name3,"\\QUEUES\\CCC");
               strncat(name3,pidstr,4);

               // Setup child session start data
               startData.Length =      32;
               startData.FgBg =        SSF_FGBG_FORE;
               startData.TraceOpt =    SSF_TRACEOPT_NONE;
               startData.PgmTitle =    0;
               startData.TermQ =       name3;
               startData.Environment = 0;
               startData.InheritOpt =  SSF_INHERTOPT_PARENT;
               startData.SessionType = SSF_TYPE_DEFAULT;
               startData.Related =     SSF_RELATED_CHILD;

               strcpy( szPgmExeAndInputs, "/C \"" );
               strcat( szPgmExeAndInputs, pszPathAndPgm );
               strcat( szPgmExeAndInputs, " " );
               strcat( szPgmExeAndInputs, szPgmInputs );
               strcat( szPgmExeAndInputs, "\"" );
               startData.PgmName   = "CMD.EXE";
               startData.PgmInputs = szPgmExeAndInputs;

                  // Start child session
                  ulRC = DosStartSession( &startData, &ulSessionId, &ulPid );
                  printf("Return code from DosStartSession : %d\n", ulRC );
                  printf("SessionId from DosStartSession : %d\n", ulSessionId );
                  printf("ulPid from DosStartSession : %d\n", ulPid );
                  if ( ( ulRC == NO_ERROR ) ||
                       ( ulRC == ERROR_SMG_SESSION_NOT_FOREGRND ) ||
                       ( ulRC == ERROR_SMG_START_IN_BACKGROUND ) )
                  {
                     // Set up return values
                     ulRC = SIM_RC_OK;
                     pLinkListCurr->ulSessionId = ulSessionId;
                     pExitObj->ulSessionId = ulSessionId;
                     pExitObj->pViewInfo->fStartExtCCS = TRUE;   // ptr- 3165
                  }
                  else
                  {
                     ulRC = SIM_RC_PROCESS_NOT_STARTED;

                     MsgDisplayErr(hwndLOW,
                                   hmodRes,
                                   0,
                                   szTitleString,
                                   ERR_START_SESSION,
                                   MB_ICONHAND | MB_OK,
                                   ERR_START_SESSION,
                                   0,
                                   NULL );
                  }

               /* Restore previous drive if necessary */
               if ( fRestorePrevDrive )
               {
                  if ( _chdrive(nPrevDrive) != 0 )
                  {
                     ulRC = SIM_RC_OS_ERROR;

                     MsgDisplayErr(hwndLOW,
                                   hmodRes,
                                   0,
                                   szTitleString,
                                   ERR_RESTORE_DRV,
                                   MB_ICONHAND | MB_OK,
                                   ERR_RESTORE_DRV,
                                   0,
                                   NULL );
                  }
               }

               /* Restore previous working directory if necessary */
               if ( fRestorePrevDir )
               {
                  if ( _chdir(szPrevWkDir) != 0 )
                  {
                     ulRC = SIM_RC_OS_ERROR;

                     MsgDisplayErr(hwndLOW,
                                   hmodRes,
                                   0,
                                   szTitleString,
                                   ERR_RESTORE_DIR,
                                   MB_ICONHAND | MB_OK,
                                   ERR_RESTORE_DIR,
                                   0,
                                   NULL );
                  }
               }
            }
            else
            {
               ulRC = SIM_RC_OS_ERROR;

               MsgDisplayErr(hwndLOW,
                             hmodRes,
                             0,
                             szTitleString,
                             ERR_CREATE_QUEUE,
                             MB_ICONHAND | MB_OK,
                             ERR_CREATE_QUEUE,
                             0,
                             NULL );
            }
         }
      }

      if ( ( ulRC != SIM_RC_OK ) && ( pExitObj != NULL ) )
      {
         memset( &RC, 0, sizeof( RCSTRUCT ) );
         RC.ulStruct = sizeof( RCSTRUCT );
         SimOpsFreeMem( (PVOID) pExitObj, &RC );
      }
   }

   printf("Return code from SimOpsStartClass : %d\n", ulRC );

   /*-------------------------------------------------------------------------*/
   /* Release the general semaphore                                           */
   /*-------------------------------------------------------------------------*/
   DosReleaseMutexSem( hmtxFrnouecc );

   return( ulRC );
}   /* End of SimOpsStartClass */


/*BEGINPROLOGUE*************************************************/
/*  Function  : SimOpsEndClass    Originating Date: January 94 */
/*  Module    : frnouecc.c                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                Product Functions:                           */
/*                                                             */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG SIMENTRY                              */
/*                                                             */
/*  Input Parameters:                                          */
/*                                                             */
/*  Output Parameters:                                         */
/*                                                             */
/*  Synopsis:  ULONG SIMENTRY SimOpsEndClass()                 */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*  Process Flow:                                              */
/*                                                             */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

ULONG SIMENTRY SimOpsEndClass( PVOID hObjId )
{
   USHORT      usRC;
   ULONG       ulRC;
   ULONG       ulCurrFileTime;
   ULONG       ulIndex;
   BOOL        fhWsObjFound;
   HWND        hwndLOW;
   PVOID       ppExitObj;
   SIMREF      refType;
   RCSTRUCT    RC;
   POPSEXITOBJ pExitObj;

   /*-------------------------------------------------------------------------*/
   /* Get the general semaphore                                               */
   /*-------------------------------------------------------------------------*/
   ulRC = DosRequestMutexSem( hmtxFrnouecc, CC_GEN_SEM_WAIT );

   printf("Entering SimOpsEndClass\n");

   /*-------------------------------------------------------------------------*/
   /* Initialization                                                          */
   /*-------------------------------------------------------------------------*/
   ulRC = SIM_RC_OK;

   pExitObj = (POPSEXITOBJ) hObjId;

   /*-------------------------------------------------------------------------*/
   /* Get the window handle of the library object window                      */
   /*-------------------------------------------------------------------------*/
   hwndLOW = WINGETPARENT( WINGETFRAME( pExitObj->pViewInfo->hwndClient ) );

   if ( pExitObj != NULL )
   {
       pExitObj->pViewInfo->fStartExtCCS = FALSE;
      /*----------------------------------------------------------------------*/
      /* Stop the specified child session                                     */
      /*----------------------------------------------------------------------*/
      ulRC = DosStopSession( STOP_SESSION_SPECIFIED, pExitObj->ulSessionId );
      printf("Return Code From DosStopSession : %d\n", ulRC );

      if ( ( ulRC == NO_ERROR )
        || ( ulRC == ERROR_SMG_INVALID_SESSION_ID )
        || ( ulRC == ERROR_SMG_SESSION_NOT_FOUND ) )
      {
         ulRC = SIM_RC_OK;
      }
      else
      {
         /*-------------------------------------------------------------------*/
         /* Log error in stop session. Don't stop at this point, the cleanup  */
         /* process should be continued                                       */
         /*-------------------------------------------------------------------*/
         ulRC = SIM_RC_OS_ERROR;
      }

      /*----------------------------------------------------------------------*/
      /* Get the curent file time stamp                                       */
      /*----------------------------------------------------------------------*/
      ulCurrFileTime = QueryFileTime( pExitObj->szFileName );

      /*----------------------------------------------------------------------*/
      /* Check the status of the file, to see whether it's open for           */
      /* read-write, or browse only                                           */
      /*----------------------------------------------------------------------*/
      if ( pExitObj->pViewInfo->acc_mode == SIM_ACCESS_READ_WRITE )
      {
         /*-------------------------------------------------------------------*/
         /* Check to see if the file has been changed. If it did, save it back*/
         /* to the server                                                     */
         /*-------------------------------------------------------------------*/

         if ( ( ulCurrFileTime != 0 ) && ( pExitObj->ulFileCreateTime != 0 ) )
         {
            if ( pExitObj->ulFileCreateTime != ulCurrFileTime )
            {
               /*-------------------------------------------------------------*/
               /* Find the hWsObj that's being loaded                         */
               /*-------------------------------------------------------------*/
               ulIndex = 0;
               fhWsObjFound = FALSE;
               while ( ( !fhWsObjFound )
                    && ( ulIndex < pExitObj->pViewInfo->ulhWsObjTotal ) )
               {
                  if ( pExitObj->pViewInfo->PartInfo[ ulIndex ].hWsObj
                       == pExitObj->hWsObj )
                  {
                     pExitObj->pViewInfo->PartInfo[ ulIndex ].hWsObjOld
                              = pExitObj->pViewInfo->PartInfo[ ulIndex ].hWsObj;
                     fhWsObjFound = TRUE;
                  }
                  else
                  {
                     ulIndex++;
                  }
               }

               /*-------------------------------------------------------------*/
               /* since the file has been changed, ask whether the user       */
               /* wants to save the changes - driver 9                        */
               /*-------------------------------------------------------------*/
               usRC = MsgDisplayMsg( hwndLOW,
                                     hmodRes,
                                     0,
                                     szTitleString,
                                     MSG_SAVE_CHANGES,
                                     MB_INFORMATION | MB_YESNO,
                                     MSG_SAVE_CHANGES,
                                     0,
                                     NULL );

               if ( usRC == MBID_YES )
               {
                  refType = SIMREF_END;
                  ppExitObj = &(pExitObj->szFileName);

                  /* replace with SimWsSetObj */
                  memset( &RC, 0, sizeof( RCSTRUCT ) );
                  RC.ulStruct = sizeof( RCSTRUCT );
                  ulRC = SimWsSetObj(pExitObj->hWsObj,
                                     SIMWS_FILENAME,
                                     &ppExitObj,
                                     &RC);
                  printf("Return Code From SimWsSetObj : %d\n", ulRC );

                  if ( ulRC == SIM_RC_OK )
                  {
                     pExitObj->pViewInfo->fObjModified = TRUE;
                     pExitObj->pViewInfo->PartInfo[ ulIndex ].fChanged = TRUE;
                  }
               }
            }
         }
      }
      else
      {
         /*-------------------------------------------------------------------*/
         /* Check to see if the file has been changed. If it did, tell the    */
         /* user they are not authorized                                      */
         /*-------------------------------------------------------------------*/
         if ( ( ulCurrFileTime != 0 )
           && ( pExitObj->ulFileCreateTime != 0 )
           && ( pExitObj->ulFileCreateTime != ulCurrFileTime ) )
         {
            MsgDisplayMsg( hwndLOW,
                           hmodRes,
                           0,
                           szTitleString,
                           MSG_BROWSE_ONLY,
                           MB_INFORMATION | MB_OK,
                           MSG_BROWSE_ONLY,
                           0,
                           NULL );
         }
      }

      /*----------------------------------------------------------------------*/
      /* Delete the temporary file                                            */
      /*----------------------------------------------------------------------*/
      ulRC == DosDelete( pExitObj->szFileName );
      printf( "Return Code From DosDelete( %s ) : %d\n",
              pExitObj->szFileName, ulRC );

      if ( ulRC == NO_ERROR )
      {
         ulRC = SIM_RC_OK;
      }
      else
      {
         ulRC = SIM_RC_OS_ERROR;
      }

      /*----------------------------------------------------------------------*/
      /* Free exit object memory                                              */
      /*----------------------------------------------------------------------*/
      memset( &RC, 0, sizeof( RCSTRUCT ) );
      RC.ulStruct = sizeof( RCSTRUCT );
      SimOpsFreeMem( (PVOID) pExitObj, &RC );
      pExitObj == NULL;

   } /* endif ( pExitObj != NULL ) */

   printf("Return Code From SimOpsEndClass : %d\n", ulRC );

   /*-------------------------------------------------------------------------*/
   /* Release the general semaphore                                           */
   /*-------------------------------------------------------------------------*/
   DosReleaseMutexSem( hmtxFrnouecc );

   return( ulRC );
}  /* end of SimOpsEndClass */


/*BEGINPROLOGUE*************************************************/
/*  Function  : SimOpsSetClass    Originating Date: January 94 */
/*  Module    : frnouecc.c                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                Product Functions:                           */
/*                                                             */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG SIMENTRY                              */
/*                                                             */
/*  Input Parameters:                                          */
/*                                                             */
/*  Output Parameters:                                         */
/*                                                             */
/*  Synopsis:  ULONG SIMENTRY SimOpsSetClass()                 */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*  Process Flow:                                              */
/*                                                             */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

ULONG SIMENTRY SimOpsSetClass( PVOID hObjId )
{
   ULONG       ulRC;
   HWND        hwndLOW;
   POPSEXITOBJ pExitObj;

   /*-------------------------------------------------------------------------*/
   /* Get the general semaphore                                               */
   /*-------------------------------------------------------------------------*/
   ulRC = DosRequestMutexSem( hmtxFrnouecc, CC_GEN_SEM_WAIT );

   ulRC = SIM_RC_OK;

   pExitObj = (POPSEXITOBJ) hObjId;

   /* get the window handle of the library object window */
   hwndLOW = WINGETPARENT( WINGETFRAME(pExitObj->pViewInfo->hwndClient));

   if ( pExitObj != NULLHANDLE )
   {
      /* Select the specified child session */
      ulRC = DosSelectSession( pExitObj->ulSessionId );
      if ( ( ulRC == NO_ERROR )
        || ( ulRC == ERROR_SMG_INVALID_SESSION_ID )
        || ( ulRC == ERROR_SMG_SESSION_NOT_FOUND )
        || ( ulRC == ERROR_SMG_NO_TARGET_WINDOW))
      {
         ulRC = SIM_RC_OK;
      }
      else
      {
         ulRC = SIM_RC_GENERAL_FAILURE;

         MsgDisplayErr(hwndLOW,
                       hmodRes,
                       0,
                       szTitleString,
                       ERR_SELECT_SESSION,
                       MB_ICONHAND | MB_OK,
                       ERR_SELECT_SESSION,
                       0,
                       NULL );
      }
   }

   /*-------------------------------------------------------------------------*/
   /* Release the general semaphore                                           */
   /*-------------------------------------------------------------------------*/
   DosReleaseMutexSem( hmtxFrnouecc );

   return( ulRC );
}  /* end of SimOpsSetClass */


/*BEGINPROLOGUE*************************************************/
/*  Function  : ExternalObjectMonitor Originating Date: January 94 */
/*  Module    : frnouecc.c                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description:                                               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                Product Functions:                           */
/*                                                             */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: VOID _System                                */
/*                                                             */
/*  Input Parameters:                                          */
/*                                                             */
/*  Output Parameters:                                         */
/*                                                             */
/*  Synopsis:  VOID _System ExternalObjectMonitor()            */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*  Process Flow:                                              */
/*                                                             */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

void ExternalObjectMonitor( void )
{
   BYTE              ElemPriority;
   BOOL              fLinkFound;
   ULONG             ulRC;
   ULONG             ulDataLen;
   ULONG             ulElementCode;
   ULONG             ulSessionId;
   PVOID             DataAddress;
   PCCLINKLISTSTRUCT pLinkListCurr;
   REQUESTDATA       ReqData;

   memset( &ReqData, 0, sizeof( REQUESTDATA ) );
   ulElementCode = 0;

   while ( TRUE )
   {
      /*----------------------------------------------------------------------*/
      /* Sit and wait for any child process to die                            */
      /*----------------------------------------------------------------------*/
      ulRC = DosReadQueue( hQueue,
                           &ReqData,
                           &ulDataLen,
                           &DataAddress,
                           ulElementCode,
                           DCWW_WAIT,
                           &ElemPriority,
                           (HEV) 0 );

      printf("Return code from DosReadQueue was :%d\n", ulRC );

      ulSessionId = (ULONG) *((PUSHORT) DataAddress );

      printf("Session ID from DosReadQueue was :%d\n", ulSessionId );

      /*----------------------------------------------------------------------*/
      /* Free the message data buffer                                         */
      /*----------------------------------------------------------------------*/
      DosFreeMem( &DataAddress );

      /*----------------------------------------------------------------------*/
      /* Find out which child process died and tel IS/2                       */
      /* Get the linked list semaphore                                        */
      /*----------------------------------------------------------------------*/
      ulRC = DosRequestMutexSem( hmtxLinkList, CC_LLST_SEM_WAIT );

      /*----------------------------------------------------------------------*/
      /* Find the correct queue to get this message                           */
      /*----------------------------------------------------------------------*/
      fLinkFound = FALSE;
      pLinkListCurr = pLinkListHead;
      while ( ( !( fLinkFound ) )
           && ( pLinkListCurr != NULL ) )
      {
         if ( ulSessionId == pLinkListCurr->ulSessionId )
         {
            fLinkFound = TRUE;
         }
         else
         {
            pLinkListCurr = pLinkListCurr->pNext;
         }
      }

      /*----------------------------------------------------------------------*/
      /* Release the linked list semaphore                                    */
      /*----------------------------------------------------------------------*/
      DosReleaseMutexSem( hmtxLinkList );

      /*----------------------------------------------------------------------*/
      /* A child process has ended, tell IS/2                                 */
      /*----------------------------------------------------------------------*/
      if ( fLinkFound )
      {
         printf("Posting the message!, session id : %d\n", ulSessionId );
         WinPostMsg( pLinkListCurr->hwndNotify,
                     pLinkListCurr->ulMsgNotify,
                     NULLHANDLE,
                     NULLHANDLE );

         // Clear out the ulSessionId field for this link as the session
         // is going to die and the Id will be invalid
         pLinkListCurr->ulSessionId = 0;
      }
      else
      {
         printf("Can NOT post the message!, session id : %d\n", ulSessionId );
         // Major error problem!
      }
   }

   _endthread;
} /* end of ExternalObjectMonitor */


/*BEGINPROLOGUE*************************************************/
/*  Function  : QueryFileTime     Originating Date: January 94 */
/*  Module    : frnouecc.c                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description: query information about a file.               */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                Product Functions:                           */
/*                                                             */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: USHORT _Optlink                             */
/*                                                             */
/*  Input Parameters:                                          */
/*                                                             */
/*  Output Parameters:                                         */
/*                                                             */
/*  Synopsis:  USHORT _Optlink QueryFileTime()                 */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*  Process Flow:                                              */
/*                                                             */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

ULONG _Optlink QueryFileTime ( PSZ pszFilename )
{
  ULONG       ulRC;
  ULONG       ulAction;
  ULONG       ulTemp;
  HFILE       hFile;
  FILESTATUS3 FileStatus;

  printf("Entering QueryFileTime\n" );

  ulRC = DosOpen( pszFilename,
                  &hFile,
                  &ulAction,
                  0,
                  0,
                  OPEN_ACTION_OPEN_IF_EXISTS,
                  OPEN_ACCESS_READONLY | OPEN_SHARE_DENYNONE,
                  NULL );

  if ( ulRC != NO_ERROR )
  {
     ulRC = 0;
     printf("Return code from QueryFileTime : %d\n", ulRC );
     return( ulRC );
  }

  memset( &FileStatus, 0, sizeof( FILESTATUS3 ) );

  ulRC = DosQueryFileInfo( hFile,
                           FIL_STANDARD,
                           &FileStatus,
                           sizeof( FILESTATUS3 ) );

  if ( NO_ERROR == ulRC )
  {
     ulTemp = 0;
     ulTemp += (ULONG) ( FileStatus.ftimeLastWrite.twosecs * 2 );
     ulTemp += (ULONG) ( FileStatus.ftimeLastWrite.minutes * 60 );
     ulTemp += (ULONG) ( FileStatus.ftimeLastWrite.hours * 60 * 60 );
     if ( ulTemp == 0 )
     {
        ulTemp += (ULONG) ( FileStatus.ftimeCreation.twosecs * 2 );
        ulTemp += (ULONG) ( FileStatus.ftimeCreation.minutes * 60 );
        ulTemp += (ULONG) ( FileStatus.ftimeCreation.hours * 60 * 60 );
     }
     ulRC = ulTemp;
  }
  else
  {
     ulRC = 0;
  }

  DosClose( hFile );

  printf("Return code from QueryFileTime : %d\n", ulRC );
  return( ulRC );
} /* QueryFileTime () */


/*BEGINPROLOGUE*************************************************/
/*  Function  : CreateTempFileName Originating Date: January 94 */
/*  Module    : frnouecc.c                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description: Create a random file name for the object to   */
/*               be input to the content class handler         */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                Product Functions:                           */
/*                                                             */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: PSZ _Optlink                                */
/*                                                             */
/*  Input Parameters:                                          */
/*          PSZ pszFilename - buffer to accept the file name   */
/*                                                             */
/*  Output Parameters:                                         */
/*                                                             */
/*  Synopsis:  PSZ _Optlink CreateTempFileName()               */
/*                PSZ pszFileName;                             */
/*                                                             */
/*  Return values: A pointer to the file name string passed in */
/*                 This sting will be of zero length if the    */
/*                 FRNROOT environment wariable is not set.    */
/*                                                             */
/*  Process Flow:                                              */
/*                                                             */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

PSZ _Optlink CreateTempFileName( PSZ pszFileName )
{
   PSZ   pszBasePath;
   CHAR  szTemp[ 9 ];

   /*-------------------------------------------------------------------------*/
   /* Query the FRNROOT environment variable                                  */
   /*-------------------------------------------------------------------------*/
   pszBasePath = getenv( "FRNROOT" );

   if ( pszBasePath == NULL )
   {
      pszFileName[ 0 ] = '\0';
   }
   else
   {
      /*----------------------------------------------------------------------*/
      /* Build the random file name                                           */
      /*----------------------------------------------------------------------*/
      strcpy( pszFileName, pszBasePath );
      strcat( pszFileName, "\\WORK\\" );
      GenRandString( szTemp, 9 );
      strcat( pszFileName, szTemp );
      strcat( pszFileName, "." );
      GenRandString( szTemp, 4 );
      strcat( pszFileName, szTemp );
   }

   return( pszFileName );
}


/*BEGINPROLOGUE*************************************************/
/*  Function  : CreateTempFile    Originating Date: January 94 */
/*  Module    : frnouecc.c                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description: Create a file from a buffer                   */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                Product Functions:                           */
/*                                                             */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG _Optlink                              */
/*                                                             */
/*  Input Parameters:                                          */
/*          PSZ pszFilename - name of file to write            */
/*                                                             */
/*  Output Parameters:                                         */
/*                                                             */
/*  Synopsis:  ULONG _Optlink CreateTempFile()                 */
/*                PSZ pszFileName;                             */
/*                                                             */
/*  Return values: SIM_RC_OK - success                         */
/*                 SIM_RC_OS_ERROR - error                     */
/*                                                             */
/*  Process Flow:                                              */
/*                                                             */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

ULONG _Optlink CreateTempFile(
   PSZ             pszFileName,
   SIMBUFFERSTRUCT SimBuffer )
{
   USHORT     usWriteLength;
   USHORT     usActWriteLength;
   ULONG      ulRC;
   ULONG      ulDataLength;
   BOOL       bContinue;
   PUCHAR     pcData;
   FILE     * pFile;
   RCSTRUCT   RC;

   ulDataLength = SimBuffer.ulSize;
   pcData = SimBuffer.pucBuffer;

   ulRC = SIM_RC_OK;

   // Open the temporary file for write access
   pFile = fopen( pszFileName, "wb+" );

   if ( pFile == NULL )
   {
      // Error in file open
      ulRC = SIM_RC_OS_ERROR;
   }
   else
   {
      bContinue = TRUE;
      while ( bContinue )
      {
         // Set the write buffer length
         usWriteLength = ( ulDataLength > OPS_EXIT_IOSIZE )
                         ? OPS_EXIT_IOSIZE : ulDataLength;

         // Write the next buffer
         usActWriteLength = fwrite( pcData,
                                    sizeof(BYTE),
                                    usWriteLength,
                                    pFile );

         // See if we are done
         if ( usActWriteLength == usWriteLength )
         {
            ulDataLength -= (ULONG) usWriteLength;
            pcData += (ULONG) usWriteLength;
            bContinue = ( ulDataLength > 0 );
         }
         else
         {
            // Error in buffer write
            bContinue= FALSE;
            ulRC = SIM_RC_OS_ERROR;
         }
      }

      // Free the data buffer
      memset( &RC, 0, sizeof( RCSTRUCT ) );
      RC.ulStruct = sizeof( RCSTRUCT );
      SimOpsFreeMem ( (PVOID) SimBuffer.pucBuffer, &RC );

      // Close the file
      fclose( pFile );
   }

   return( ulRC );
}


/*BEGINPROLOGUE*************************************************/
/*  Function  : StoreInfo         Originating Date: January 94 */
/*  Module    : frnouecc.c                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description: Function to allow view to pass us data        */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                Product Functions:                           */
/*                                                             */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: BOOL _Optlink                               */
/*                                                             */
/*  Input Parameters:                                          */
/*                                                             */
/*  Output Parameters:                                         */
/*                                                             */
/*  Synopsis:  BOOL _Optlink StoreInfo()                       */
/*                                                             */
/*  Return values: TRUE                                        */
/*                                                             */
/*  Process Flow:                                              */
/*                                                             */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

BOOL _Optlink StoreInfo(
   PVWINFO  pViewInfo,
   HWND     hwndViewWin )
{
   APIRET rc;
   UCHAR  name1 [32];
   UCHAR  name2 [32];
   UCHAR  name3  [32];
   CHAR   pidstr [32];
   PTIB   pptib;
   PPIB   pppib;
   ULONG  ulRC;
   PCCLINKLISTSTRUCT pLinkListTemp;

   /*-------------------------------------------------------------------------*/
   /* Get the handle to the resource dll (if need be)                         */
   /*-------------------------------------------------------------------------*/
   if ( hmodRes == (HMODULE) 0 )
   {
      ulRC = (ULONG) DosLoadModule( NULL, 0, "FRNOLGAR", &hmodRes );
   }

   /*-------------------------------------------------------------------------*/
   /* Get the anchor block handle (if need be)                                */
   /*-------------------------------------------------------------------------*/
   if ( hab == (HAB) 0 )
   {
      hab = WinQueryAnchorBlock( hwndViewWin );
      /*----------------------------------------------------------------------*/
      /* Get the title for any error messages we might need to display        */
      /*----------------------------------------------------------------------*/
      memset( szTitleString, 0, 100 + 1 );
      WinLoadString( hab, hmodRes, IDS_USEREXIT, 100, szTitleString );
   }

   /*-------------------------------------------------------------------------*/
   /* Create the general semaphore (if need be)                               */
   /*-------------------------------------------------------------------------*/


   rc = DosGetInfoBlocks(&pptib, &pppib);
   sprintf(pidstr,"%d", pppib->pib_ulpid);
   strcpy(name1,"\\SEM32\\CCA");
   strcpy(name2,"\\SEM32\\CCB");
   strcpy(name3,"\\QUEUES\\CCC");
   strncat(name1,pidstr,4);
   strncat(name2,pidstr,4);
   strncat(name3,pidstr,4);




   if ( hmtxFrnouecc == (HMTX) 0 )
   {
//      printf("Calling DosCreateMutexSem( CC_GEN_SEM_NAME )\n");
      printf("Calling DosCreateMutexSem( %s )\n", name1 );
      ulRC = DosCreateMutexSem( name1, &hmtxFrnouecc, 0L, 0L );
      printf("Return code from DosCreateMutexSem : %d\n", ulRC );
   }

   /*-------------------------------------------------------------------------*/
   /* Create the linked list semaphore (create if need be)                    */
   /*-------------------------------------------------------------------------*/
   if ( hmtxLinkList == (HMTX) 0 )
   {
//      printf("Calling DosCreateMutexSem( CC_LLST_SEM_NAME )\n");
      printf("Calling DosCreateMutexSem( %s )\n", name2 );
      DosCreateMutexSem( name2, &hmtxLinkList, 0L, 0L );
      printf("Return code from DosCreateMutexSem : %d\n", ulRC );
   }

   /*-------------------------------------------------------------------------*/
   /* Create the termination queue (if need be)                               */
   /*-------------------------------------------------------------------------*/
   if ( hQueue == (HQUEUE) 0 )
   {
//      printf("Calling DosCreateQueue( CC_TERM_QUEUE_NAME )\n");
      printf("Calling DosCreateQueue( %s )\n", name3 );
      ulRC = DosCreateQueue( &hQueue,
                             QUE_FIFO | QUE_CONVERT_ADDRESS,
                             name3 );
      printf("Return code from DosCreateQueue : %d\n", ulRC );
   }

   /*-------------------------------------------------------------------------*/
   /* Start the montior thread (if need be)                                   */
   /*-------------------------------------------------------------------------*/
   if ( ThreadId == 0 )
   {
      printf("Calling DosCreateThread\n");
      ulRC = DosCreateThread( &ThreadId,
                             (PFNTHREAD)ExternalObjectMonitor,
                             (ULONG)NULL,
                             (ULONG)0,
                             (ULONG)(1024*64));
      printf("Return Code from DosCreateThread : %d\n", ulRC );
      printf("ThreadId from DosCreateThread : %d\n", ThreadId );
   }

   /*-------------------------------------------------------------------------*/
   /* Get the linked list semaphore                                           */
   /*-------------------------------------------------------------------------*/
   ulRC = DosRequestMutexSem( hmtxLinkList, CC_LLST_SEM_WAIT );

   /*-------------------------------------------------------------------------*/
   /* If the linked list is empty, create a new head structure                */
   /*-------------------------------------------------------------------------*/
   if ( pLinkListHead == NULL )
   {
      pLinkListHead = (PCCLINKLISTSTRUCT) malloc( sizeof( CCLINKLISTSTRUCT ) );
      pLinkListLast = pLinkListHead;
   }
   /*-------------------------------------------------------------------------*/
   /* If the linked list is has elements, add a new one to the end            */
   /*-------------------------------------------------------------------------*/
   else
   {
      pLinkListTemp = (PCCLINKLISTSTRUCT) malloc( sizeof( CCLINKLISTSTRUCT ) );
      pLinkListLast->pNext = pLinkListTemp;
      pLinkListLast = pLinkListTemp;
   }

   /*-------------------------------------------------------------------------*/
   /* Store the data from the view window in to the newly created list element*/
   /*-------------------------------------------------------------------------*/
   memset( pLinkListLast, 0, sizeof( CCLINKLISTSTRUCT ) );
   pLinkListLast->hwndView = hwndViewWin;
   pLinkListLast->pViewInfo = pViewInfo;
   pLinkListLast->pNext = NULL;

   /*-------------------------------------------------------------------------*/
   /* Release the linked list semaphore                                       */
   /*-------------------------------------------------------------------------*/
   DosReleaseMutexSem( hmtxLinkList );

   return ( TRUE );
}

/*BEGINPROLOGUE*************************************************/
/*  Function  : DeleteInfo        Originating Date: January 94 */
/*  Module    : frnouecc.c                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description: Function to allow view to delete data stored  */
/*               via store info                                */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                Product Functions:                           */
/*                                                             */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: BOOL _Optlink                               */
/*                                                             */
/*  Input Parameters:                                          */
/*                                                             */
/*  Output Parameters:                                         */
/*                                                             */
/*  Synopsis:  BOOL _Optlink DeleteInfo()                      */
/*                                                             */
/*  Return values: TRUE                                        */
/*                                                             */
/*  Process Flow:                                              */
/*                                                             */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/

BOOL _Optlink DeleteInfo(
   PVWINFO  pViewInfo,
   HWND     hwndViewWin )
{
   ULONG             ulRC;
   BOOL              fLinkFound = FALSE;
   PCCLINKLISTSTRUCT pLinkListCurr;
   PCCLINKLISTSTRUCT pLinkListTemp;

   /*-------------------------------------------------------------------------*/
   /* Get the linked list semaphore                                           */
   /*-------------------------------------------------------------------------*/
   ulRC = DosRequestMutexSem( hmtxLinkList, CC_LLST_SEM_WAIT );

   /*-------------------------------------------------------------------------*/
   /* Find the element of the linked list that pertains to this pViewInfo     */
   /*-------------------------------------------------------------------------*/
   pLinkListCurr = pLinkListHead;
   pLinkListTemp = NULL;
   while ( ( !fLinkFound ) && ( pLinkListCurr != NULL ) )
   {
      if ( pViewInfo == pLinkListCurr->pViewInfo )
      {
         fLinkFound = TRUE;
      }
      else
      {
         pLinkListTemp = pLinkListCurr;
         pLinkListCurr = pLinkListTemp->pNext;
      }
   }

   /*-------------------------------------------------------------------------*/
   /* Only remove the link if we found it                                     */
   /*-------------------------------------------------------------------------*/
   if ( fLinkFound )
   {
      /*----------------------------------------------------------------------*/
      /* Remove our link from the linked list                                 */
      /*----------------------------------------------------------------------*/
      if ( pLinkListCurr == pLinkListLast )
      {
         // This case is where we found the last link in the list
         pLinkListLast = pLinkListTemp;

         // Check for the case where there are no more links
         if ( pLinkListLast == NULL )
         {
            pLinkListHead = NULL;
         }
         else
         {
            pLinkListLast->pNext = NULL;
         }
      }
      else if ( pLinkListCurr == pLinkListHead )
      {
         // This is the case where we found the first link in the list
         pLinkListHead = pLinkListHead->pNext;
      }
      else
      {
         // This is the case where we found a link in the middle of the list
         pLinkListTemp->pNext = pLinkListCurr->pNext;
      }

      free( pLinkListCurr );
   }

   /*-------------------------------------------------------------------------*/
   /* Release the linked list semaphore                                       */
   /*-------------------------------------------------------------------------*/
   DosReleaseMutexSem( hmtxLinkList );

   return ( TRUE );
}


/*BEGINPROLOGUE*************************************************/
/*  Function  : GenRandString                Date: October 92  */
/*  Module    : frnouecc.c                                     */
/*  Programmer:                                                */
/*                                                             */
/*  Description: return(randomly generated NULL terminated     */
/*               string of strlen(usStringSize - 1))           */
/*                                                             */
/*  Dependencies: Global Variables :                           */
/*                Static External  :                           */
/*                Includes         :                           */
/*                Product Functions:                           */
/*                                                             */
/*  Restrictions: none                                         */
/*                                                             */
/*  Function type:       VOID                                  */
/*                                                             */
/*  Input Parameters:    USHORT  usStringSize                  */
/*                                                             */
/*  Output Parameters:   PSZ     pszString                     */
/*                                                             */
/*  Synopsis:    VOID ( pszString, usStringSize )              */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*  Process Flow:                                              */
/*    1. if string is not null, generate a random character    */
/*       for each position of the string up to the input size  */
/*                                                             */
/*  Notes:                                                     */
/*                                                             */
/*ENDPROLOGUE***************************************************/

VOID _Optlink GenRandString( PSZ     pszString,
                             USHORT  usStringSize )
{
   SHORT    sRandNum = 0;
   USHORT   usCharIndex = 0;
   LONG     lctime = 0;


   if (pszString != NULL)
   {
      /*****************************************/
      /* Create a string random digits.        */
      /*****************************************/
      time(&lctime);
      srand((UINT)lctime);

      for (usCharIndex = 0;
           usCharIndex < usStringSize - 1;
           usCharIndex++)
      {
         sRandNum=(SHORT)((rand () / 2048) + (SHORT) 'A');
         pszString[usCharIndex] = (CHAR) sRandNum;
      }

      pszString[usStringSize - 1] = '\0';
    } /* endif */

    return;
} /* end GenRandString() */

