/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/* MODULE:       FRNOUECW.C                                                  */
/*                                                                           */
/* 5697-250, 5621-326, 5655-036, 5622-213, 5655-071, 5655-072                */
/*                                                                           */
/* (C) Copyright IBM Corporation 1993, 1994.                                 */
/* All Rights Reserved.                                                      */
/*                                                                           */
/* DERIVATIVE RIGHTS:                                                        */
/* ------------------                                                        */
/* This program is provided for the customer's use and the customer is       */
/* granted permission to copy this program to the extent reasonably          */
/* required for such use.  All title, ownership, and rights to this          */
/* program and any copies remain with IBM, irrespective of the ownership     */
/* of the media on which the program resides.  The customer is permitted     */
/* to create derivative works to this program.  However, all copies of       */
/* the program and its derivative works must contain the IBM copyright       */
/* notice.  The customer understands and agrees that this program in and     */
/* of itself is not to be sold or distributed.  The customer is free to      */
/* sell, distribute, and commercially exploit any derivative works           */
/* created from this program.                                                */
/*                                                                           */
/*                                                                           */
/* DISCLAIMER OF WARRANTIES:                                                 */
/* -------------------------                                                 */
/* The following [enclosed] code is sample code created by IBM               */
/* Corporation.  This sample code is not part of any standard IBM product    */
/* and is provided to you solely for the purpose of assisting you in the     */
/* development of your applications.  The code is provided "AS IS",          */
/* without warranty of any kind.  IBM shall not be liable for any damages    */
/* arising out of your use of the sample code, even if they have been        */
/* advised of the possibility of such damages.                               */
/*                                                                           */
/*---------------------------------------------------------------------------*/
/*                                                                           */
/*  Description:  Services Default Close Window User Exit                    */
/*                This user exit is invoked when the end user selects CLOSE  */
/*                from the system menu.  It can be used by the application   */
/*                to perform its own close processing and to modify the      */
/*                display window default closing sequence.  The value pointed*/
/*                to by pulAction indicates to Services the closing          */
/*                action it should take.                                     */
/*                FRNOUECW.C - This module contains the user exit function   */
/*                SimOpsCloseWinu that will be built into the FIWSXCLS.DLL.  */
/*                User application, VisualInfo Client Application View       */
/*                Manager and Scan Manager will access this code to be       */
/*                notified that window is closing down.                      */
/*                                                                           */
/* Dependencies:                                                             */
/* Restrictions:                                                             */
/*                                                                           */
/* Entry Points: SimOpsCloseWin                                              */
/*                                                                           */
/* Change History:                                                           */
/*ENDPROLOGUE*****************************************************************/

/*------------------------------------------*/
/* compiler and OS/2 supplied include files */
/*------------------------------------------*/
#define INCL_WIN
#include <os2.h>
#include <string.h>
#include <stdlib.h>
#include <stdio.h>

/*-----------------------------------*/
/*  DAPS specific defines            */
/*-----------------------------------*/

#include "frnptype.h"         /* VisualInfo Common includes         */
#include "fiwsxcls.h"         /* IS/2 header for function prototype */
#include "fiwsdsp.h"          /* IS/2 display window header         */

#define FRN_INCL_FO           /* VisualInfo Object Mgr  */
#define FRN_INCL_FI           /* VisualInfo Object Index Mgr  */

#include "frnoue.h"           /* Common DAPS header for User Exits  */

/*-----------------------------------*/
/*  local defines                    */
/*-----------------------------------*/

#define WINGETPARENT(h)    WinQueryWindow(h, QW_PARENT)
#define WINGETFRAME        WINGETPARENT

ULONG SIMENTRY SimOpsCloseWin(SIMWIN hWin,
                               PULONG pulAction)

{
   ULONG    ulRC=0;
   HWND     hwndOwner;
   HWND     hFrame;              /* IS/2 frame handle */
   PULONG   pTmpPtr;
   RCSTRUCT rcStruct;

   rcStruct.ulRC = 0;
   rcStruct.ulStruct = sizeof(RCSTRUCT);
   *pulAction = SIMCLOSE_CONTINUE;      /* initialization */

        /* Get IS/2's frame handle */
   ulRC = SimDspQueryWin( hWin,                   /* IS/2 window */
                          SIMDSP_HWND,            /* param to query */
                          &hFrame,                /* Frame handle   */
                          &rcStruct );

                                         /* Query Owner of Display window    */
   hwndOwner = WinQueryWindow( hFrame, QW_OWNER );

                                         /* Window data ptr for OWNER. Could */
                                         /* be pointing to User application, */
                                         /* Scan Mgr or View Mgr, so typecast*/
                                         /* pointer to common data(ULONG)    */
                                         /* and branch off to User           */
                                         /* application, Scan Mgr work area  */
                                         /* or VIew mgr work area.           */
   pTmpPtr = (PULONG)WinQueryWindowPtr(hwndOwner, 0);

   switch (*pTmpPtr) {
   case FRNOWFDP_USER_EXIT:
        /* Tell owner that the display window is closing. */
        WinPostMsg( hwndOwner,
                    (ULONG)WM_QUIT,
                    0,
                    0 );
      break;

   case SCAN_USER_EXIT:
         /* Send message to Scan manager that Display is closing       */

      WinPostMsg(      // Changed from Send to Post - IR31857
           hwndOwner,
           SM_CLOSE,   // Scan Manager Close Message
           MPFROMLONG(TRUE),
           NULL
           );

      break;

   case VIEW_USER_EXIT:
          /* Tell parent that the display window is closing. */
       WinPostMsg( WINGETPARENT(WINGETFRAME( hFrame ) ),
                   WM_DM_CLOSE,
                   MPFROMSHORT( DM_VIEW ),
                   0 );

      break;

   } /* endswitch */

  *pulAction = SIMCLOSE_IGNORE;

  return(ulRC);
}
