/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/* MODULE:       FRNOUEIM.C                                                  */
/*                                                                           */
/* 5697-250, 5621-326, 5655-036, 5622-213, 5655-071, 5655-072                */
/*                                                                           */
/* (C) Copyright IBM Corporation 1993, 1994.                                 */
/* All Rights Reserved.                                                      */
/*                                                                           */
/* DERIVATIVE RIGHTS:                                                        */
/* ------------------                                                        */
/* This program is provided for the customer's use and the customer is       */
/* granted permission to copy this program to the extent reasonably          */
/* required for such use.  All title, ownership, and rights to this          */
/* program and any copies remain with IBM, irrespective of the ownership     */
/* of the media on which the program resides.  The customer is permitted     */
/* to create derivative works to this program.  However, all copies of       */
/* the program and its derivative works must contain the IBM copyright       */
/* notice.  The customer understands and agrees that this program in and     */
/* of itself is not to be sold or distributed.  The customer is free to      */
/* sell, distribute, and commercially exploit any derivative works           */
/* created from this program.                                                */
/*                                                                           */
/*                                                                           */
/* DISCLAIMER OF WARRANTIES:                                                 */
/* -------------------------                                                 */
/* The following [enclosed] code is sample code created by IBM               */
/* Corporation.  This sample code is not part of any standard IBM product    */
/* and is provided to you solely for the purpose of assisting you in the     */
/* development of your applications.  The code is provided "AS IS",          */
/* without warranty of any kind.  IBM shall not be liable for any damages    */
/* arising out of your use of the sample code, even if they have been        */
/* advised of the possibility of such damages.                               */
/*                                                                           */
/*---------------------------------------------------------------------------*/
/*                                                                           */
/*  Description:  Services Default Invoke Menu User Exit                     */
/*                This user exit is invoked when the end user selects a menu */
/*                item on the display window.  It can be used by the         */
/*                application to perform an action based on the menu         */
/*                item selected.  The value pointed                          */
/*                to by pulAction indicates to Services the closing          */
/*                action it should take.                                     */
/*                FRNOUEIM.C - This module contains the user exit function   */
/*                SimOpsInvokeMenu that will be built into the FIWSXMNU.DLL. */
/*                User application, Client Application View Manager and      */
/*                Scan Manager will access this code to be notified that     */
/*                a window menu item has been selected.                      */
/*                                                                           */
/* Dependencies:                                                             */
/* Restrictions:                                                             */
/*                                                                           */
/* Entry Points: SimOpsInvokeMenu                                            */
/*                                                                           */
/* Change History:                                                           */
/*ENDPROLOGUE*****************************************************************/

/*------------------------------------------*/
/* pragma definitions                       */
/*------------------------------------------*/
#pragma strings(readonly)

/*------------------------------------------*/
/* compiler and OS/2 supplied include files */
/*------------------------------------------*/
#define INCL_WIN
#define INCL_DOSMODULEMGR
#include <os2.h>
#include <string.h>
#include <stdlib.h>
#include <stdio.h>

/*-----------------------------------*/
/*  DAPS specific defines            */
/*-----------------------------------*/

#define FRN_INCL_FO     /* SB Object Mgr  */
#define FRN_INCL_FI     /* SB Object Index Mgr  */

#define WINGETPARENT(h)    WinQueryWindow(h, QW_PARENT)
#define WINGETFRAME        WINGETPARENT

#include <frnp.h>               /* SB Common includes                 */
#include "fiwsscn.h"               /* IS/2 Scan services header          */
#include "fiwsxcls.h"         /* IS/2 header for function prototype */
#include "fiwsws.h"

#include "frnpauer.h"
#include "frnoue.h"           /* Common DAPS header for User Exits  */
#include "frnolg.h"
#include "frnpvw.h"


ULONG SIMENTRY SimOpsInvokeMenu(SIMWIN hWin,
                                SIMMENUTYPE menuType,
                                SIMMENU hMenu,
                                PBOOL pfContinue)

{

   ULONG         ulRC=0;
   HWND          hwndOwner;
   HWND          hwndLOW;
   PULONG        pTmpPtr;
   RCSTRUCT      rcStruct;
   HWND          hFrame;
   PVWINFO       pVWInfo;
   ULONG         ulNumPage=0;
   USHORT        usRC=0;
   SIMWSOBJ      hCurrent=0;
   SIMWSOBJ      hParent=0;
   BOOL          Found=FALSE;
   INT           i=0;
   HAB           hab=0;
   HMODULE       hmod=0;
   ULONG         ulBufferMax = 50;
   CHAR          szTitleString[ 100 + 1 ];

   rcStruct.ulRC = 0;
   rcStruct.ulStruct = sizeof(RCSTRUCT);

        /* Get IWPM's frame handle */
   ulRC = SimDspQueryWin( hWin,                   /* IWPM window */
                          SIMDSP_HWND,            /* param to query */
                          &hFrame,                 /* Frame handle */
                          &rcStruct );

   if ( ulRC == SIM_RC_OK )
    {
      /* Query Owner of Display window    */
      hwndOwner = WinQueryWindow(hFrame, QW_OWNER);


                                          /* Window data ptr for OWNER. Could */
                                          /* be pointing to either Scan Mgr   */
                                          /* or View Mgr data, so typecast    */
                                          /* pointer to common data(ULONG)    */
                                          /* and branch off first parameter   */
                                          /* to either Scan Mgr work area or  */
                                          /* or VIew mgr work area.           */
       /* ---------------------------------- */
       /* NOTE: First parameter off of       */
       /*       pTmpPtr MUST BE a ULONG and  */
       /*       called ulComponentId         */
       /* ---------------------------------- */

      pTmpPtr = (PULONG) WinQueryWindowPtr ( hwndOwner, VW_WINPTR_OFFSET );

      if (*pTmpPtr == SCAN_USER_EXIT) {

                                          /* Post message to Scan Manager     */
                                          /* window procedure that one of     */
                                          /* the menus it created has been    */
                                          /* selected                         */

                                          /* Pass menu handle to Scan window  */
                                          /* procedure                        */
      WinSendMsg(hwndOwner,
                    SM_VIEW_MENU_ITEM_SELECTED,
                    MPFROMLONG(hMenu),
                    0);





      *pfContinue = TRUE;

      } else if (*pTmpPtr == VIEW_USER_EXIT) {

        /* Get view window data */
        pVWInfo = (PVWINFO) pTmpPtr;
        hwndLOW = WINGETPARENT( WINGETFRAME(hwndOwner) );

       /* fix ptr 2943 */
       /*-----------------------------------------------------------------*/
       /* Get the handle to the resource dll (if need be)                 */
       /*-----------------------------------------------------------------*/
        ulRC = (ULONG) DosLoadModule( NULL, 0, "FRNOLGAR", &hmod );

       /*-----------------------------------------------------------------*/
       /* Get the anchor block handle (if need be)                        */
       /*-----------------------------------------------------------------*/
       hab = WinQueryAnchorBlock( hwndOwner );
       /*----------------------------------------------------------------------*/
       /* Get the title for any error messages we might need to display        */
       /*----------------------------------------------------------------------*/
       memset( szTitleString, 0, 100 + 1 );
       WinLoadString( hab, hmod, IDS_IMAGE, ulBufferMax, szTitleString );

        /* Get the working set handle for the currently displayed page */
        ulRC = SimDspQueryWin(hWin,
                            SIMDSP_CURRENT_PAGE_OBJ,
                            &hCurrent,
                            &rcStruct);

         /* Find the parent of the currently displayed page */
        ulRC = SimWsQueryObj(hCurrent,
                             SIMUSER_DISPLAY,
                             SIMWS_PARENT,
                             &hParent,
                             &rcStruct);

         /* check menu for fit in window before we do anything */
        if (hMenu == SIMMENU_FIT_IN_WINDOW)
         {
             /* Toggle the window's scaling flag */
             pVWInfo->fScale = !pVWInfo->fScale;

         }

        /* whenever the remove page or remove document is being process */
        /* we want to check whether there's only one page left, or the  */
        /* whole document being delete                                  */

        else if (hMenu == SIMMENU_REMOVE_PAGE)
         {
            /* check to see whether the working set is empty or not */
           ulRC = SimWsQueryObj(pVWInfo->hMWsObj,
                                SIMUSER_DISPLAY,
                                SIMWS_NUM_PAGE,
                                &ulNumPage,
                                &rcStruct);

           if ( ulRC == SIM_RC_OK )
            {
              /* if there's only one page left, we have to notify the user */
              if (ulNumPage == 1)
              {
                /* check for the user's access privilege */
                if (pVWInfo->fDeleteItemPriv == TRUE)
               {
                  usRC = MsgDisplayMsg( hwndLOW,
                                        0,
                                        0,
                                        szTitleString,
                                        VW_LAST_PAGE,
                                        MB_INFORMATION | MB_YESNO | MB_HELP,
                                        VW_LAST_PAGE,
                                        NULL);
                 if (usRC == MBID_YES)
                 {
                     /* send LOW a message to tell it to delete */
                    WinPostMsg( WINGETPARENT( WINGETFRAME( hwndOwner ) ),
                             WM_DM_DELETE,
                             FALSE,
                             0);

                    // set the modify flag only if the user is sure to
                    // delete the document, if he select cancel the delete
                    // we won't set the flag. this is the fix for ptr 3391
                    pVWInfo->fObjModified = TRUE;
                    *pfContinue = FALSE;
                 }
                 else
                 {
                    /* stop deleting the last page */
                   *pfContinue = FALSE;
                 }
               }
              else
               {
                  usRC = MsgDisplayMsg( hwndLOW,
                                        0,
                                        0,
                                        szTitleString,
                                        VW_NO_DELITEM_PRIV,
                                        MB_INFORMATION | MB_OK | MB_HELP,
                                        VW_NO_DELITEM_PRIV,
                                        NULL);
                   *pfContinue = FALSE;
                }
            }
           else
            {
               /* there is more than 1 page in the WS, so let's check */
               /* the individual document                             */

              ulRC = SimWsQueryObj(hParent,
                                   SIMUSER_DISPLAY,
                                   SIMWS_NUM_PAGE,
                                   &ulNumPage,
                                   &rcStruct);

              if ( ulRC == SIM_RC_OK )
              {
                   /* find the hObj info about this object from the pVWInfo */
                  while (!Found && (i < pVWInfo->ulhWsObjTotal))
                  {
                    if (pVWInfo->PartInfo[i].hWsObj == hParent)
                      Found = TRUE;
                    else
                      i++;
                  }

                  /* if only 1 page in the document, we have to delete this */
                  /* doucment (object) from the library later, so set the   */
                  /* flag to keep track of this                             */

                if (ulNumPage == 1)
                {
                  if (Found)
                     pVWInfo->PartInfo[i].fDelObj = TRUE;
                  else
                     pVWInfo->PartInfo[i].fDelObj = FALSE;

                }
                else
                {
                    /* there are more than 1 page left, so just set the */
                    /* fChanged flag to TRUE for this object            */
                   if (Found)
                       pVWInfo->PartInfo[i].fChanged = TRUE;
                   else
                       pVWInfo->PartInfo[i].fChanged = FALSE;
                }
              }
            *pfContinue = TRUE;
            pVWInfo->fObjModified = TRUE;
            }
          }
       }

    // removed processing the SIMMENU_CREATE_NOTE, and SIMMENU_CREATE_HIGHLIGHT
    // from the user exit, since we have register for processing those 2 from
    // event process.  this is to fix ptr 3386.

      else if (hMenu == pVWInfo->hMenu_prod_info)
       {
           DisplayLogo(pVWInfo->hwndClient, TRUE);
           *pfContinue = TRUE;
       }

      } /* endif */


    }
   return(ulRC);

}

