/*BEGINPROLOGUE**************************************************************/
/*                                                                          */
/* MODULE: frnoueuc.c                       VisualInfo                      */
/*                                                                          */
/* 5697-250, 5621-326 (C) Copyright IBM Corp.                               */
/* (C) Copyright IBM Corp. 1993,1994.                                       */
/* All Rights Reserved.                                                     */
/*                                                                          */
/* DERIVATIVE RIGHTS:                                                       */
/* ------------------                                                       */
/* This program is provided for the customer's use and the customer is      */
/* granted permission to copy this program to the extent reasonably         */
/* required for such use.  All title, ownership, and rights to this         */
/* program and any copies remain with IBM, irrespective of the ownership    */
/* of the media on which the program resides.  The customer is permitted    */
/* to create derivative works to this program.  However, all copies of      */
/* the program and its derivative works must contain the IBM copyright      */
/* notice.  The customer understands and agrees that this program in and    */
/* of itself is not to be sold or distributed.  The customer is free to     */
/* sell, distribute, and commercially exploit any derivative works          */
/* created from this program.                                               */
/*                                                                          */
/*                                                                          */
/* DISCLAIMER OF WARRANTIES:                                                */
/* -------------------------                                                */
/* The following [enclosed] code is sample code created by IBM              */
/* Corporation.  This sample code is not part of any standard IBM product   */
/* and is provided to you solely for the purpose of assisting you in the    */
/* development of your applications.  The code is provided "AS IS",         */
/* without warranty of any kind.  IBM shall not be liable for any damages   */
/* arising out of your use of the sample code, even if they have been       */
/* advised of the possibility of such damages.                              */
/*                                                                          */
/*                                                                          */
/* Date: October 1992                                                       */
/*                                                                          */
/* Status: Version 1 Release 1 Modification 0                               */
/*                                                                          */
/* Description: frnoueuc.c - this source comtains the Save                  */
/*                           Records and Alternate Search exits             */
/*                           which support case-insensitve                  */
/*                           save and search.                               */
/* Dependencies:                                                            */
/* Restrictions:                                                            */
/*                                                                          */
/*                                                                          */
/* Notes:                                                                   */
/*  - addtional information may be provided here                            */
/*                                                                          */
/*ENDPROLOGUE****************************************************************/

#define INCL_BASE
#define INCL_PM
#define INCL_WIN
#define INCL_DOSNLS
#define FRN_INCL_FI
#define FRN_INCL_FO

#include <os2.h>

#include <frnp.h>
#include <frnpusrx.h>
#include <frnoueuc.h>

ULONG   SearchReturnCode;
ULONG   SearchResults;
ULONG   SearchItemsFound;
ULONG   semExit = 0;

/*BEGINPROLOGUE*************************************************/
/*  Function  : SearchToUpper    Originating Date: November 93 */
/*  Module    : frnoueuc.c                                     */
/*                                                             */
/*  Description: Alternate Search User exit which will upper   */
/*               case the search string before issuing a       */
/*               SimLibSearch call                             */
/*                                                             */
/*  Dependencies: Global Variables : SearchReturnCode          */
/*                                   SearchResults             */
/*                                   SearchItemsFound          */
/*                                   semExit                   */
/*                Static External  :                           */
/*                Includes         : frnp.h                    */
/*                                 : frnpusrx.h                */
/*                                 : frnoueuc.h                */
/*                Product Functions:                           */
/*                                                             */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: ULONG EXPENTRY                              */
/*                                                             */
/*  Input Parameters:                                          */
/*             HSESSION  hSession  - VisualInfo Session handle */
/*             HWND      hwnd      - handle of a VisualInfo    */
/*                                   window for EUI interface  */
/*             PSZ       pszUserId - Logged on User id         */
/*             USHORT    usTypeFilter - Type of item to search */
/*                                      for                    */
/*             BITS      fWipFilter - WIP status of item to    */
/*                                    search for               */
/*             USHORT    usSuspendFilter - Suspension status   */
/*                                    of the item to search for*/
/*             USHORT    usIndexClass - Index class of the     */
/*                                    folder with search       */
/*                                    results                  */
/*             USHORT    usNumCriteria - Number of elements in */
/*                                    pCriteria array          */
/*             PLIBCRITERIASTRUCT pCriteria - Pointer to an    */
/*                                    array containing search  */
/*                                    criteria for each view   */
/*                                    to be searched.          */
/*                                                             */
/*  Output Parameters:                                         */
/*             PITEMID   pItemIdResultFolder - Pointer to      */
/*                                    where the exit should    */
/*                                    store the itemid of the  */
/*                                    search results folder    */
/*                                                             */
/*                                                             */
/*  Synopsis:                                                  */
/*                                                             */
/*                                                             */
/*  Return values: Return code from SimLibSearch.              */
/*                                                             */
/*  Process Flow:                                              */
/*                                                             */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/
ULONG EXPENTRY SearchToUpper( HSESSION hSession,
                              HWND     hwnd,
                              PSZ      pszUserID,
                              USHORT   usTypeFilter,
                              BITS     fWipFilter,
                              USHORT   usSuspendFilter,
                              USHORT   usIndexClass,
                              USHORT   usNumCriteria,
                              PLIBSEARCHCRITERIASTRUCT  pCriteria,
                              PITEMID  pItemIdResultFolder)
{
   APIRET       rc;
   CHAR         szBuffer[80];
   COUNTRYCODE  Country;
   HMODULE      hmod = NULLHANDLE;
   HWND         hwndSearchDlg;
   PLIBSEARCHCRITERIASTRUCT  pCriteriaLocal;
   PSEARCHEXITSTRUCT         pSearchExitStruct;
   RCSTRUCT     RC;
   SHORT        sRC;
   ULONG        CpList;
   ULONG        CpSize;
   ULONG        ulRC;
   USHORT       usNumCriteriaLocal;

   // Load the resource dll
   DosLoadModule( NULL, 0, "FRNOLGAR", &hmod);

   DosQueryCp( sizeof(CpList),
               &CpList,
               &CpSize);

   pSearchExitStruct = (PSEARCHEXITSTRUCT)malloc( sizeof(SEARCHEXITSTRUCT));

   // Uppercase all search strings
   for ( usNumCriteriaLocal=0, pCriteriaLocal=pCriteria;
         usNumCriteriaLocal<usNumCriteria;
         usNumCriteriaLocal++,pCriteriaLocal++) {

       rc = UpperCase( CpList,
                       pCriteriaLocal->pszSearchString);

   } /* endfor */

   pSearchExitStruct->hSession = hSession;
   pSearchExitStruct->usTypeFilter = usTypeFilter;
   pSearchExitStruct->fWipFilter = fWipFilter;
   pSearchExitStruct->usSuspendFilter = usSuspendFilter;
   pSearchExitStruct->usIndexClass = usIndexClass;
   pSearchExitStruct->usNumCriteria = usNumCriteria;
   pSearchExitStruct->pCriteria = pCriteria;

   sRC = WinDlgBox ( hwnd,               /* hwnd of parent */
                     hwnd,               /* hwnd of owner  */
                     SearchingDlgProc,   /* dialog procedure address */
                     hmod,               /* handle of resource module */
                     IDD_SR_SEARCH,      /* identifies dialog */
                     pSearchExitStruct); /* address of app. specific data */


   if (SearchReturnCode==SIM_RC_OK) {
       if (SearchItemsFound!=0) {
          // If we found something copy over the ResultFolder id into the
          // return area.
          memcpy( (PVOID)pItemIdResultFolder, (PVOID)SearchResults, sizeof(ITEMID));
       } else {
          // If we did not find anything null out the Results area.
          memset( (PVOID)pItemIdResultFolder, '0', sizeof(ITEMID));
       }
   } /* endif */

   if (sRC!=0) {
      pItemIdResultFolder = NULL;
   } /* endif */

   return (SearchReturnCode);

   DosReleaseMutexSem( semExit);

}

/*BEGINPROLOGUE*************************************************/
/*  Function  : SearchingDlgProc Originating Date: November 93 */
/*  Module    : frnoueuc.c                                     */
/*                                                             */
/*  Description: This is the dialog proc for the Search        */
/*               progress indicator dialog box. It issues the  */
/*               SimLibSearch call and processes the results.  */
/*                                                             */
/*  Dependencies: Global Variables : SearchReturnCode          */
/*                                   SearchResults             */
/*                                   SearchItemsFound          */
/*                                   semExit                   */
/*                Static External  :                           */
/*                Includes         : frnp.h                    */
/*                                 : frnpusrx.h                */
/*                                 : frnoueuc.h                */
/*                Product Functions:                           */
/*                                                             */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: MRESULT EXPENTRY                            */
/*                                                             */
/*  Input Parameters:                                          */
/*             HWND      hwnd      - handle of the dialog      */
/*             ULONG     msg       - Msg id                    */
/*             MPARAM    mp1       - Message parameter 1       */
/*             MPARAM    mp2       - Message parameter 2       */
/*                                                             */
/*  Output Parameters:                                         */
/*                                                             */
/*  Synopsis:                                                  */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*  Process Flow:                                              */
/*                                                             */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/
MRESULT EXPENTRY SearchingDlgProc( HWND hwnd,
                                   ULONG msg,
                                   MPARAM mp1,
                                   MPARAM mp2)
{
   ASYNCCTLSTRUCT  AsyncParms;
   MRESULT mResult;
   RCSTRUCT   RC;
   PRCSTRUCT  pRC;
   PSEARCHEXITSTRUCT  pSearchExitStruct;
   PSZ        pszDotText;
   ULONG              ulRC;

   switch (msg) {
   case WM_COMMAND:
      switch (SHORT1FROMMP(mp1)) {
      case IDD_SR_BUTTON_CLOSE:
         // Hide the window
         WinSetWindowPos( hwnd,
                          NULLHANDLE,
                          0, 0, 0, 0,
                          SWP_MOVE | SWP_SIZE );
         mResult = 0L;
         break;
      case IDD_SR_BUTTON_STOP:
         WinDismissDlg( hwnd, 1);
         mResult = 0L;
         break;
      default:
         mResult = 0L;
        break;
      } /* endswitch */
      break;
   case WM_INITDLG:
      pRC = (PRCSTRUCT)malloc(sizeof(RCSTRUCT));
      pSearchExitStruct = (PSEARCHEXITSTRUCT)mp2;

      pszDotText = (PSZ)malloc(MAX_DOT_TEXT+1);
      if (pszDotText!=NULL) {
         strcpy( pszDotText, ".");
         WinSetWindowPtr( hwnd, 0, pszDotText);
      } /* endif */
      WinStartTimer( WinQueryAnchorBlock(hwnd),
                     hwnd,
                     SR_EXIT_TIMER_ID,
                     500);

      AsyncParms.ulStruct   = sizeof(ASYNCCTLSTRUCT);
      AsyncParms.fOptions   = SIM_OPT_ASYNC | SIM_OPT_MSG;
      AsyncParms.hSync      = (PVOID) hwnd;
      AsyncParms.ulMsgId    = SR_EXIT_SEARCH_DONE;


      ulRC = SimLibSearch( pSearchExitStruct->hSession,
                           NULL,
                           NULL,
                           SIM_SEARCH_STATIC,
                           pSearchExitStruct->usTypeFilter,
                           pSearchExitStruct->fWipFilter,
                           pSearchExitStruct->usSuspendFilter,
                           pSearchExitStruct->usIndexClass,
                           pSearchExitStruct->usNumCriteria,
                           pSearchExitStruct->pCriteria,
                           SIM_SEARCH_MEMLIST_ONE,
                           &AsyncParms,
                           pRC);
      mResult = 0L;
      break;
   case SR_EXIT_SEARCH_DONE:
      DosRequestMutexSem( semExit, -1L );
      pRC = (PRCSTRUCT)mp2;
      SearchReturnCode = pRC->ulRC;
      SearchResults = pRC->ulParam1;
      SearchItemsFound = pRC->ulParam2;
      WinDismissDlg( hwnd, 0);
      mResult = 0L;
      break;
   case WM_TIMER:
      pszDotText = WinQueryWindowPtr( hwnd, 0);
      if (pszDotText!=NULL) {
         if (strlen(pszDotText)>MAX_DOT_TEXT) {
            strcpy(pszDotText, ".");
         } else {
            strcat(pszDotText, ".");
         } /* endif */
         WinSetDlgItemText( hwnd, IDD_SR_TEXT_DOTS, pszDotText);
      }
      mResult = 0L;
      break;
   default:
      mResult = WinDefDlgProc( hwnd, msg, mp1, mp2);
     break;
   } /* endswitch */

   return (mResult);
}

/*BEGINPROLOGUE*************************************************/
/*  Function  : SaveToUpper      Originating Date: November 93 */
/*  Module    : frnoueuc.c                                     */
/*                                                             */
/*  Description: Save Record User exit which will uppercase    */
/*               all character values.                         */
/*                                                             */
/*  Dependencies: Global Variables : SearchReturnCode          */
/*                                   SearchResults             */
/*                                   SearchItemsFound          */
/*                                   semExit                   */
/*                Static External  :                           */
/*                Includes         : frnp.h                    */
/*                                 : frnpusrx.h                */
/*                                 : frnoueuc.h                */
/*                Product Functions:                           */
/*                                                             */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: MRESULT EXPENTRY                            */
/*                                                             */
/*  Input Parameters:                                          */
/*             HWND      hwnd      - Anchor window for dialog  */
/*                                   boxes and other EUI       */
/*                                   interactions              */
/*             USEREXITSTRUCT  pReSaveStruct - User defined    */
/*                                   attribites for documents  */
/*                                   and folder                */
/*                                                             */
/*  Output Parameters:                                         */
/*             PSZ       *ppszErrorMsgs - Address of the       */
/*                                   pointer to an array of    */
/*                                   error messages.           */
/*             PUSHORT   *ppusFieldsInError - Address of the   */
/*                                   pointer to an array of    */
/*                                   attribute ids with error  */
/*                                                             */
/*  Synopsis:                                                  */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*  Process Flow:                                              */
/*                                                             */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/
SHORT EXPENTRY SaveToUpper( HWND hwnd,
                            USEREXITSTRUCT preSaveStruct,
                            PSZ *ppszErrorMsgs,
                            PUSHORT  *ppusFieldsInError)
{
   APIRET       rc;
   COUNTRYCODE  Country;
   FIELDVALUE  *pFields;
   HMODULE      hmod;
   SHORT        sFields = 0;
   ULONG        CpList;
   ULONG        CpSize;

   pFields = preSaveStruct.pFields;

   rc = DosQueryCp( sizeof(CpList),      // Query the current code page.
                    &CpList,
                    &CpSize);

   if (rc!=ERROR_CP_NOT_MOVED) {
      rc = NO_ERROR;

      // Loop over all fields and upper case them.  Stop when we have processed
      // all the fields or there is an error.
      // The loop variables sFields and pFields have been initiailized above.
      for ( ;
            (( sFields<preSaveStruct.sFields && (rc==NO_ERROR) ));
            sFields++,pFields++) {
          rc = UpperCase( CpList, pFields->pBuffer);
      } /* endfor */
   }

   // If there were no errors set ErrorMsg to NULL.  If there were errors
   // load the error string from the string table and set the FieldInError
   // to the current attribute id.
   if (rc==NO_ERROR) {
      *ppszErrorMsgs=NULL;
   } else {
      *ppusFieldsInError = (PUSHORT)malloc(sizeof(USHORT));
      if (*ppusFieldsInError!=NULL) {
        *(*ppusFieldsInError) = pFields->usFieldId;
      }

      // Load the resource dll
      DosLoadModule( NULL, 0, "FRNOLGAR", &hmod);
      *ppszErrorMsgs = (PSZ)malloc(MAX_ERROR_STRING);
      if (*ppszErrorMsgs!=NULL) {

         // Load the error string
         WinLoadString( WinQueryAnchorBlock( hwnd),
                        hmod,
                        SAVE_EXIT_ERROR,
                        MAX_ERROR_STRING,
                        *ppszErrorMsgs);
      } /* endif */
   } /* endif */
   return (0);
}

/*BEGINPROLOGUE*************************************************/
/*  Function  : UpperCase        Originating Date: November 93 */
/*  Module    : frnoueuc.c                                     */
/*                                                             */
/*  Description: Capitalize the passed in string according to  */
/*               convention for the current country and passes */
/*               in code page.                                 */
/*                                                             */
/*  Dependencies: Global Variables : SearchReturnCode          */
/*                                   SearchResults             */
/*                                   SearchItemsFound          */
/*                                   semExit                   */
/*                Static External  :                           */
/*                Includes         : frnp.h                    */
/*                                 : frnpusrx.h                */
/*                                 : frnoueuc.h                */
/*                Product Functions:                           */
/*                                                             */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: APIENTRY EXPENTRY                           */
/*                                                             */
/*  Input Parameters:                                          */
/*             ULONG     ulCodePage - Current code page        */
/*             PSZ       pszString  - String to be             */
/*                                    capitalized.             */
/*                                                             */
/*  Output Parameters:                                         */
/*             PSZ       pszString  - String to be             */
/*                                    capitalized.             */
/*                                                             */
/*  Synopsis:                                                  */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*  Process Flow:                                              */
/*                                                             */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/
APIRET EXPENTRY UpperCase( ULONG ulCodePage, PSZ pszString)
{
   COUNTRYCODE Country;
   APIRET      rc;

      Country.country = 0;               // Use the current country code
      Country.codepage = ulCodePage;     // Use the code page that we are
                                         // passed.

      rc = DosMapCase( strlen(pszString),  // Map the passed in string to
                       &Country,           // upper case.
                       pszString);

   return( rc);
}


/*BEGINPROLOGUE*************************************************/
/*  Function  : _DLL_InitTerm    Originating Date: November 93 */
/*  Module    : frnoueuc.c                                     */
/*                                                             */
/*  Description: Initialization/Termination routine for the    */
/*               dll.                                          */
/*                                                             */
/*  Dependencies: Global Variables : SearchReturnCode          */
/*                                   SearchResults             */
/*                                   SearchItemsFound          */
/*                                   semExit                   */
/*                Static External  :                           */
/*                Includes         : frnp.h                    */
/*                                 : frnpusrx.h                */
/*                                 : frnoueuc.h                */
/*                Product Functions:                           */
/*                                                             */
/*  Restrictions:                                              */
/*                                                             */
/*  Function type: APIENTRY EXPENTRY                           */
/*                                                             */
/*  Input Parameters:                                          */
/*             ULONG     hModule  - Module handle              */
/*             LONG      ulFlag   - Status flag                */
/*                                                             */
/*  Output Parameters:                                         */
/*                                                             */
/*  Synopsis:                                                  */
/*                                                             */
/*                                                             */
/*  Return values:                                             */
/*                                                             */
/*  Process Flow:                                              */
/*                                                             */
/*  Notes:                                                     */
/*                                                             */
/*                                                             */
/*ENDPROLOGUE***************************************************/
unsigned long _System _DLL_InitTerm(
   unsigned long hModule,
   unsigned long ulFlag )
{
   /*-------------------------------------------------------------------------*/
   /* If ulFlag is zero then the DLL is being loaded so initialization should */
   /* be performed.  If ulFlag is 1 then the DLL is being freed so            */
   /* termination should be performed.                                        */
   /*-------------------------------------------------------------------------*/
   switch( ulFlag )
   {
      case 0:  /* initialization                                              */
         /*-------------------------------------------------------------------*/
         /* The C run-time environment initialization function must be called */
         /* before any calls to C run-time functions that are not inlined.    */
         /*-------------------------------------------------------------------*/
         if ( _CRT_init( ) == -1 )
            return 0UL;

         /*-------------------------------------------------------------------*/
         /* Create a pair of semaphores for use later                         */
         /*-------------------------------------------------------------------*/
         DosCreateMutexSem ( NULL,
                             &semExit,
                             0,        /* not shared */
                             FALSE );  /* not owned  */

         break;

      case 1:  /* terminate                                                   */

         /*-------------------------------------------------------------------*/
         /* Destroy the semaphores we created on initialization               */
         /*-------------------------------------------------------------------*/
         DosCloseMutexSem( semExit );
         break;

      default:
         /*-------------------------------------------------------------------*/
         /* If we get here, we've got problems! return a zero                 */
         /*-------------------------------------------------------------------*/
         return 0UL;

   }
   /*-------------------------------------------------------------------------*/
   /* a non-zero value must be returned to indicate success.                  */
   /*-------------------------------------------------------------------------*/
   return 1UL;
}
