/*BEGINPROLOGUE***************************************************************/
/*                                                                           */
/* MODULE: FRNPLLUX.C                       VisualInfo                       */
/*                                                                           */
/* 5697-250, 5621-326, 5655-036, 5622-213, 5655-071, 5655-072                */
/* (C) Copyright IBM Corp. 1993,1994. All Rights Reserved.                   */
/*         US Government Users Restricted Rights -                           */
/*         Use, duplication or disclosure restricted by GSA                  */
/*         ADP Schedule Contract with IBM Corp.                              */
/*                                                                           */
/* DERIVATIVE RIGHTS:                                                        */
/* ------------------                                                        */
/* This program is provided for the customer's use and the customer is       */
/* granted permission to copy this program to the extent reasonably          */
/* required for such use.  All title, ownership, and rights to this          */
/* program and any copies remain with IBM, irrespective of the ownership     */
/* of the media on which the program resides.  The customer is permitted     */
/* to create derivative works to this program.  However, all copies of       */
/* the program and its derivative works must contain the IBM copyright       */
/* notice.  The customer understands and agrees that this program in and     */
/* of itself is not to be sold or distributed.  The customer is free to      */
/* sell, distribute, and commercially exploit any derivative works           */
/* created from this program.                                                */
/*                                                                           */
/*                                                                           */
/* DISCLAIMER OF WARRANTIES:                                                 */
/* -------------------------                                                 */
/* The following [enclosed] code is sample code created by IBM               */
/* Corporation.  This sample code is not part of any standard IBM product    */
/* and is provided to you solely for the purpose of assisting you in the     */
/* development of your applications.  The code is provided "AS IS",          */
/* without warranty of any kind.  IBM shall not be liable for any damages    */
/* arising out of your use of the sample code, even if they have been        */
/* advised of the possibility of such damages.                               */
/*                                                                           */
/* Date: June 1993                                                           */
/*                                                                           */
/* Status: Version 1 Release 1 Modification 0                                */
/*                                                                           */
/* Program Name: FRNPLLUX.C     (LibACUserExitOne)                           */
/*                              (LibACUserExitTwo)                           */
/*                                                                           */
/*                                                                           */
/* Input Params  : See individual routines                                   */
/* Output Params : See individual routines                                   */
/*                                                                           */
/* Returns:  See individual routines                                         */
/*                                                                           */
/* Calls: See individual routines                                            */
/*                                                                           */
/* Called By: See indivual routines                                          */
/*                                                                           */
/* Description: Access control user exits.                                   */
/*                                                                           */
/* Dependencies:                                                             */
/*                                                                           */
/* Restrictions:                                                             */
/*                                                                           */
/* Notes:                                                                    */
/*                                                                           */
/*                                                                           */
/*ENDPROLOGUE*****************************************************************/

#include "frnperr.h"
#include "frnpllxx.h"
#include "frnpllue.h"

/*************************************************************/
/*************************************************************/
/* Define prototypes for functions used only in this module. */
/*************************************************************/
/*************************************************************/
static BOOL LibCheckPrivBitPos( UCHAR  uchPrivStr[50],
                                USHORT usPrivBitPos );

/**********************************************************************
#                                                                     *
# Function name:   LibCheckPrivBitPos                                 *
#                                                                     *
# Subsystem:      Library Server                                      *
#                                                                     *
# Version:        V1R1                                                *
#                                                                     *
# Input Params  : - privilege string.                                 *
#                 - privilege bit position.                           *
#                                                                     *
# Output params : - None.                                             *
#                                                                     *
# Returns       : 0 = Privilege Bit IS NOT Set.                       *
#                 1 = Privilege Bit IS Set.                           *
#                                                                     *
# Description   : This routine checks the specified bit position in   *
#                 the privilege string.  If it is a 1 bit, privilege  *
#                 is granted.  Otherwise, it is denied.               *
#                                                                     *
#                 NOTE: In the privilege bit strings passed to the    *
#                       user exits, the bit positions start at 0.     *
#                       Therefore, when checking whether a bit is     *
#                       set, bit 320, for example, would actually     *
#                       be in the 321'st position of the privilege    *
#                       bit vector.                                   *
#**********************************************************************/
static BOOL LibCheckPrivBitPos( UCHAR  uchPrivStr[50],
                                USHORT usPrivBitPos )
  {
  UCHAR    uchByte;
  UCHAR    uchMask;

  /**************************************************************/
  /* get the byte that contains the desired bit.  Remember that */
  /* privileges are 240 bit indicators stored as 30 bytes       */
  /**************************************************************/
  uchByte = uchPrivStr[ usPrivBitPos / 8 ];

  uchMask = (UCHAR) 1 << (7-(usPrivBitPos%8));

  return( uchByte & uchMask );
  }  /* end LibCheckPrivBitPos */


/********************************/
/********************************/
/* Define exported subroutines. */
/********************************/
/********************************/


/***********************************************************************
#                                                                      *
# Function Name : LibACUserExitOne()                                   *
#                                                                      *
# Subsystem     : Library Server                                       *
#                                                                      *
# Version       : V1R1                                                 *
#                                                                      *
# Input Params  : achSessionPatron - The name of the current Library   *
#                                    user                              *
#                 achGeneralPrivs  - The general privileges of this    *
#                                    user.  Each bit within each byte  *
#                                    corresponds to a specific,        *
#                                    SB-defined privilege.             *
#                 sPatronSecurity  - This is the user' security class  *
#                 usAPIClass       - This is the command code for the  *
#                                    API that is being invoked by the  *
#                                    current user                      *
#                 bAPIAction       - This is the identifier for the    *
#                                    specific action being invoked     *
#                                    within the API                    *
#                 bRefMonDecision  - This value indicates whether or   *
#                                    not the Library Server intends    *
#                                    to allow access to the requested  *
#                                    API.  The following two values    *
#                                    indicate that the API access      *
#                                    will be denied or granted,        *
#                                    respectively:                     *
#                                                                      *
#                                    REFMON_DENY_REQUEST               *
#                                    REFMON_GRANT_REQUEST              *
#                                                                      *
#                 bRefMonDecReason - This value indicates the error    *
#                                    code that corresponds to the      *
#                                    reason why the calling routine    *
#                                    intends to disallow the API       *
#                                    request                           *
#                 achWorkstationID - This is the workstation ID        *
#                                    where the API was issued.         *
#                                    It uniquely identifies the        *
#                                    specific machine within the       *
#                                    network that is issuing calls     *
#                                    to the server.                    *
#                                                                      *
# Output params : pbACDirective    - Indicates what action the         *
#                                    Library Server is to take upon    *
#                                    return from this routine:         *
#     DECISION_CONTINUE_PROCESSING - Let the system's access control   *
#                                    stand.                            *
#     DECISION_DENY_API_REQUEST    - Disallow access to the requested  *
#                                    function.                         *
#     DECISION_GRANT_API_REQUEST   - Allow access to the requested     *
#                                    function.                         *
#                                                                      *
# Returns       : usReturnCode - Currently, 0 should be returned       *
#                                since this code is ignored in         *
#                                favor of the pbACDirective output     *
#                                parameter.                            *
#                                                                      *
# Calls         : LibCheckPrivBitPos(),                                *
#                                                                      *
# Called By     : The Library Server Access Control Routines           *
#                                                                      *
# Description   : This routine is the first user-exit routine for      *
#                 access control.  It is called after the user's       *
#                 general privilege string has been evaluated to       *
#                 determine whether or not the user has the general    *
#                 privilege to perform the requested function.         *
#                                                                      *
#                 NOTE: Look at the file FRNPLLUX.H for a list and     *
#                       description of the values that the parameters  *
#                       may take along with predefined macros          *
#                       enumerating those values.                      *
#                                                                      *
# Modifications (change history):                                      *
#                                                                      *
#   Name     Date   PTS Comments                                       *
# -------- -------- --- --------------------------------------------   *
#                                                                      *
#**********************************************************************/

extern USHORT LibACUserExitOne( CHAR         achSessionPatron[26],  /* input  */
                                UCHAR        uchGeneralPrivs[50],   /* input  */
                                SHORT        sPatronSecurity,       /* input  */
                                USHORT       usAPIClass,            /* input  */
                                BYTE         bAPIAction,            /* input  */
                                BYTE         bRefMonDecision,       /* input  */
                                USHORT       bRefMonDecReason,      /* input  */
                                CHAR         achWorkstationID[17],  /* input  */
                                BYTE         *pbACDirective )       /* output */
  {
/* BA DEB */
#ifdef AIX
  char *CopyRight = "5765-258 (C) Copyright IBM Corp. 1994, 1995";
#endif
/* EA DEB */

  USHORT usReturnCode = 0;

//USHORT usPrivBitPos;
//  /**********************************************************/
//  /* The user can make an access control desision based     */
//  /* on any information available, but as an example of     */
//  /* using the patron's general privilege string to         */
//  /* determine whether or not to grant access, this user    */
//  /* exit can do the following.  It is assumed here that    */
//  /* bit 320 in the privilege bit string is the bit which   */
//  /* controls access to the particular function the user is */
//  /* attempting to perform:                                 */
//  /**********************************************************/
//
//  /**********************************************************/
//  /* Call LibCheckPrivBitPos to see if bit 320 is 0 or 1.   */
//  /* This check determines if the session patron passes the */
//  /* general privileges test.                               */
//  /**********************************************************/
//  usPrivBitPos = 320;
//  if ( ! LibCheckPrivBitPos( uchGeneralPrivs,
//                             usPrivBitPos ) )
//    {
//    /****************************************/
//    /* The calling routine indicated that   */
//    /* the specific bit is turned "off".    */
//    /* DENY access to the requested action. */
//    /****************************************/
//    *pbACDirective = DECISION_DENY_API_REQUEST;
//    return( usReturnCode );
//    }  /* end of "off" bit branch handling */
//  else
//    {
//    /*****************************************/
//    /* The calling routine indicated that    */
//    /* the specific bit is turned "on".      */
//    /* GRANT access to the requested action. */
//    /*****************************************/
//    *pbACDirective = DECISION_GRANT_API_REQUEST;
//    return( usReturnCode );
//    }  /* end of "on" bit branch handling */

  /*******************************************************/
  /* Put User-defined code here                          */
  /*******************************************************/

  /*******************************************************/
  /* Set returned directive to the system default which  */
  /* indicates that whatever access control decision was */
  /* made by the system should not be overridden.        */
  /*******************************************************/
  *pbACDirective = DECISION_CONTINUE_PROCESSING;

  return( usReturnCode );
  } /* LibACUserExitOne */


/***********************************************************************
#                                                                      *
# Function Name : LibACUserExitTwo()                                   *
#                                                                      *
# Subsystem     : Library Server                                       *
#                                                                      *
# Version       : V1R1                                                 *
#                                                                      *
# Input Params  : achSessionPatron - The name of the current Library   *
#                                    user                              *
#                 achGeneralPrivs  - The general privileges of this    *
#                                    user.  Each bit within each byte  *
#                                    corresponds to a specific,        *
#                                    SB-defined privilege.             *
#                 sPatronSecurity  - This is the user' security class  *
#                 usAPIClass       - This is the command code for the  *
#                                    API that is being invoked by the  *
#                                    current user                      *
#                 bAPIAction       - This is the identifier for the    *
#                                    specific action being invoked     *
#                                    within the API                    *
#                 bRefMonDecision  - This value indicates whether or   *
#                                    not the Library Server intends    *
#                                    to allow access to the requested  *
#                                    API.  The following two values    *
#                                    indicate that the API access      *
#                                    will be denied or granted,        *
#                                    respectively:                     *
#                                                                      *
#                                    REFMON_DENY_REQUEST               *
#                                    REFMON_GRANT_REQUEST              *
#                                                                      *
#                 bRefMonDecReason - This value indicates the error    *
#                                    code that corresponds to the      *
#                                    reason why the calling routine    *
#                                    intends to disallow the API       *
#                                    request                           *
#                 bInfoType        - This value indicates if the call  *
#                                    is item-related, view-related,    *
#                                    or both. This enables one to      *
#                                    know what input parms are valid   *
#                 achItemID        - The item Identifier               *
#                 sViewID          - The View Identifier               *
#                 achItemOwner     - The patron who owns the item      *
#                 achViewOwner     - The patron who owns the view      *
#                 sItemSecurity    - The security class associated     *
#                                    with the item                     *
#                 sViewSecurity    - The security class associated     *
#                                    with the view                     *
#                 sItemFlags       - The system flags associated with  *
#                                    the item                          *
#                 sItemUserFlags   - The User flags associated with    *
#                                    the item                          *
#                 sViewFlags       - The system flags associated with  *
#                                    the view                          *
#                 uchItemPrivs     - the privileges derived from the   *
#                                    Access Control List for the       *
#                                    given patron and item             *
#                 uchViewPrivs     - the privileges derived from the   *
#                                    Access Control List for the       *
#                                    given patron and view             *
#                 achWorkstationID - This is the workstation ID        *
#                                    where the API was issued.         *
#                                    It uniquely identifies the        *
#                                    specific machine within the       *
#                                    network that is issuing calls     *
#                                    to the server.                    *
#                                                                      *
# Output params : pbACDirective    - Indicates what action the         *
#                                    Library Server is to take upon    *
#                                    return from this routine:         *
#     DECISION_CONTINUE_PROCESSING - Let the system's access control   *
#                                    stand.                            *
#     DECISION_DENY_API_REQUEST    - Disallow access to the requested  *
#                                    function.                         *
#     DECISION_GRANT_API_REQUEST   - Allow access to the requested     *
#                                    function.                         *
#                                                                      *
# Returns       : usReturnCode - Currently, 0 should be returned       *
#                                since this code is ignored in         *
#                                favor of the pbACDirective output     *
#                                parameter.                            *
#                                                                      *
# Calls         : LibCheckPrivBitPos(),                                *
#                                                                      *
# Called By     : The Library Server Access Control Routines           *
#                                                                      *
# Description   : This routine is the second user-exit routine for     *
#                 access control.  It is called after the item's       *
#                 or view's resolved access control list has been      *
#                 evaluated to determine whether or not the session    *
#                 user has the privilege to perform the requested      *
#                 function on the given item or view.                  *
#                                                                      *
#                 NOTE: Look at the file FRNPLLUX.H for a list and     *
#                       description of the values that the parameters  *
#                       may take along with predefined macros          *
#                       enumerating those values.                      *
#                                                                      *
# Modifications (change history):                                      *
#                                                                      *
#   Name     Date   PTS Comments                                       *
# -------- -------- --- --------------------------------------------   *
#                                                                      *
#**********************************************************************/
extern USHORT LibACUserExitTwo( CHAR         achSessionPatron[26],  /* input  */
                                UCHAR        uchGeneralPrivs[50],   /* input  */
                                SHORT        sPatronSecurity,       /* input  */
                                USHORT       usAPIClass,            /* input  */
                                BYTE         bAPIAction,            /* input  */
                                BYTE         bRefMonDecision,       /* input  */
                                USHORT       bRefMonDecReason,      /* input  */
                                BYTE         bInfoType,             /* input  */
                                CHAR         achItemID[16],         /* input  */
                                SHORT        sViewID,               /* input  */
                                CHAR         achItemOwner[26],      /* input  */
                                CHAR         achViewOwner[26],      /* input  */
                                SHORT        sItemSecurity,         /* input  */
                                SHORT        sViewSecurity,         /* input  */
                                SHORT        sItemFlags,            /* input  */
                                SHORT        sItemUserFlags,        /* input  */
                                SHORT        sViewFlags,            /* input  */
                                UCHAR        uchItemPrivs[50],      /* input  */
                                UCHAR        uchViewPrivs[50],      /* input  */
                                CHAR         achWorkstationID[17],  /* input  */
                                BYTE         *pbACDirective )       /* output */
  {
  USHORT usReturnCode = 0;

//USHORT usPrivBitPos;
//  /**********************************************************/
//  /* The user can make an access control desision based     */
//  /* on any information available, but as an example of     */
//  /* using the patron's general privilege string to         */
//  /* determine whether or not to grant access, this user    */
//  /* exit can do the following.  It is assumed here that    */
//  /* bit 320 in the privilege bit string is the bit which   */
//  /* controls access to the particular function the user is */
//  /* attempting to perform:                                 */
//  /**********************************************************/
//
//  /**********************************************************/
//  /* Call LibCheckPrivBitPos to see if bit 320 is 0 or 1.   */
//  /* This check determines if the session patron passes the */
//  /* general privileges test.                               */
//  /**********************************************************/
//  usPrivBitPos = 320;
//  if ( ! LibCheckPrivBitPos( uchGeneralPrivs,
//                             usPrivBitPos ) )
//    {
//    /****************************************/
//    /* The calling routine indicated that   */
//    /* the specific bit is turned "off".    */
//    /* DENY access to the requested action. */
//    /****************************************/
//    *pbACDirective = DECISION_DENY_API_REQUEST;
//    return( usReturnCode );
//    }  /* end of "off" bit branch handling */
//  else
//    {
//    /*****************************************/
//    /* The calling routine indicated that    */
//    /* the specific bit is turned "on".      */
//    /* GRANT access to the requested action. */
//    /*****************************************/
//    *pbACDirective = DECISION_GRANT_API_REQUEST;
//    return( usReturnCode );
//    }  /* end of "on" bit branch handling */

  /*******************************************************/
  /* Put User-defined code here                          */
  /*******************************************************/

  /*******************************************************/
  /* Set returned directive to the system default which  */
  /* indicates that whatever access control decision was */
  /* made by the system should not be overridden.        */
  /*******************************************************/
  *pbACDirective = DECISION_CONTINUE_PROCESSING;

  return( usReturnCode );
  } /* LibACUserExitTwo */
